#!/bin/bash
#--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

#README
#This script is combining bash commands to count barcodes with 0 mismatches in a given fastq files and was written by Tom Beneke.
#If you would like to count your barcodes with mismatches (which we do not recommend!), you can modify the "agrep" command in the script below.
#Please cite Beneke and Gluenz, MBP 2020 when using it.

#Dependencies:
#Please install "Pandas" to run this script.

#Instructions on usage:
#To run this script copy it into a directory containing all fastq files and the python script 'pivot_table.py'
#Your fastq files will need to be de-multiplexed and unzipped. You can unzip your file e.g. by using "gunzip".
#Navigate to your directory and execute the script with "sh agrep_count_14995_barcodes.sh"

#Output:
#Once the script started it will prompt you to type in your Illumina sequencing machine ID, which it will need to determine the total read count. This will be the "total_read_count.txt" file.
#Additionally, you will find two files termed: "all_counts.csv" and "all_counts.txt". Both output files will contain the barcode counts across all fastq files, but the table is not further formatted.
#The final output file with all counts in an appropriate format will be called "0mismatch_all_barcodes_count.csv". This file will contain all raw barcode counts and should be used for further analysis. 
#
#

#--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

pause(){
   read -p "Press [Enter] key to continue..." fackEnterKey
}

read -p 'Please enter your Illumina sequencing machine ID. Usually this is something like: "@M04023". You will find this above each read in any of your fastq files.: ' MACHINE_ID
	echo "You are uploading <"$MACHINE_ID"> as your Illumina sequencing machine ID."
	pause

#create file folder
mkdir count

#total read count
echo "Counting total number of reads in all fastq files!"
grep -c $MACHINE_ID *.fastq > total_read_count.txt
echo "Count of reads done!"

#count all barcodes
echo "Starting to count all barcodes...this will take a while."

agrep -0 -c 'TCACGGCTGTAACGGAC' *.fastq > count/B4_Fm0.txt
agrep -0 -c 'CGAGTTCGCTATACCGG' *.fastq > count/B5_Fm0.txt
agrep -0 -c 'TACACGAGGTCCGAAAT' *.fastq > count/B7_Fm0.txt
agrep -0 -c 'CTATACATACCCCAGAG' *.fastq > count/B10_Fm0.txt
agrep -0 -c 'ACACCAATAGTGTGATC' *.fastq > count/B11_Fm0.txt
agrep -0 -c 'ATGGCTGCTGCACACCT' *.fastq > count/B14_Fm0.txt
agrep -0 -c 'AAGTCCCGAATGATATC' *.fastq > count/B15_Fm0.txt
agrep -0 -c 'CGTGTCTATGAGGCCGT' *.fastq > count/B16_Fm0.txt
agrep -0 -c 'GATTCCACGCGCTCTTC' *.fastq > count/B17_Fm0.txt
agrep -0 -c 'AGGTCCCAGCATTCTAG' *.fastq > count/B18_Fm0.txt
agrep -0 -c 'GTATGATACGTACCCAA' *.fastq > count/B19_Fm0.txt
agrep -0 -c 'TGCGCAAGGTTAAGTTA' *.fastq > count/B21_Fm0.txt
agrep -0 -c 'TATCCACTTTCTCGACG' *.fastq > count/B22_Fm0.txt
agrep -0 -c 'CCGCCCCTTAAATAAAG' *.fastq > count/B23_Fm0.txt
agrep -0 -c 'GCTTAGATCCATGTCGG' *.fastq > count/B24_Fm0.txt
agrep -0 -c 'CAAGTCAGGGTTGTAGT' *.fastq > count/B25_Fm0.txt
agrep -0 -c 'GTCCACTCACAATCTGA' *.fastq > count/B26_Fm0.txt
agrep -0 -c 'CGTTGTCTTAAGTGCGC' *.fastq > count/B27_Fm0.txt
agrep -0 -c 'CAGGATTACTATAGGCT' *.fastq > count/B29_Fm0.txt
agrep -0 -c 'AGTACTTGTGCTGGCAA' *.fastq > count/B30_Fm0.txt
agrep -0 -c 'TGTTTGTAACGGTTTGC' *.fastq > count/B33_Fm0.txt
agrep -0 -c 'ACATATGCATGGCACCC' *.fastq > count/B34_Fm0.txt
agrep -0 -c 'ATCTGCGGCAGTAGGTC' *.fastq > count/B35_Fm0.txt
agrep -0 -c 'GACACGTGGCAGGTATT' *.fastq > count/B36_Fm0.txt
agrep -0 -c 'TCGACCGTACGTTAGGT' *.fastq > count/B37_Fm0.txt
agrep -0 -c 'GTATATGAGATAGACGG' *.fastq > count/B39_Fm0.txt
agrep -0 -c 'TGACTTTTACCGCGTGA' *.fastq > count/B40_Fm0.txt
agrep -0 -c 'CAATACTCCCGCCGAAT' *.fastq > count/B42_Fm0.txt
agrep -0 -c 'GATCTCTATGCTCTAGT' *.fastq > count/B44_Fm0.txt
agrep -0 -c 'CATAGTACCCAGCCTGA' *.fastq > count/B45_Fm0.txt
agrep -0 -c 'TACACCTAGACGGCTAG' *.fastq > count/B46_Fm0.txt
agrep -0 -c 'GTAGTATCGTATCGGAA' *.fastq > count/B48_Fm0.txt
agrep -0 -c 'TTGCGACCGGATAGCCA' *.fastq > count/B49_Fm0.txt
agrep -0 -c 'TAATCGGGCACTGCCAC' *.fastq > count/B50_Fm0.txt
agrep -0 -c 'CACTCACGCTATTCGTA' *.fastq > count/B51_Fm0.txt
agrep -0 -c 'TACCGCCGGGTGTCTAA' *.fastq > count/B52_Fm0.txt
agrep -0 -c 'CTTGGATATTAGCGTCA' *.fastq > count/B53_Fm0.txt
agrep -0 -c 'CAAACGTCGATACATTG' *.fastq > count/B54_Fm0.txt
agrep -0 -c 'TAAGGACAAGCGTACAA' *.fastq > count/B55_Fm0.txt
agrep -0 -c 'AGATCGAATGCTCACGC' *.fastq > count/B56_Fm0.txt
agrep -0 -c 'CAGCGTTCGAACACACA' *.fastq > count/B57_Fm0.txt
agrep -0 -c 'TAGACGGGCAAACCAGA' *.fastq > count/B58_Fm0.txt
agrep -0 -c 'TATAGCGGCACCATCGC' *.fastq > count/B60_Fm0.txt
agrep -0 -c 'TCATAATGACAGGACCT' *.fastq > count/B61_Fm0.txt
agrep -0 -c 'CCGCACAATTCTACAGG' *.fastq > count/B62_Fm0.txt
agrep -0 -c 'CTCTAAGGGCGGTTTGG' *.fastq > count/B63_Fm0.txt
agrep -0 -c 'AAGAGGAGATTAACGAG' *.fastq > count/B64_Fm0.txt
agrep -0 -c 'CGAAATCCTTAGTTCCC' *.fastq > count/B65_Fm0.txt
agrep -0 -c 'GACCATAAACCCACTCG' *.fastq > count/B66_Fm0.txt
agrep -0 -c 'GGTAGTTGTCAAGCATA' *.fastq > count/B67_Fm0.txt
agrep -0 -c 'GGACGTATTCAGTCGAC' *.fastq > count/B68_Fm0.txt
agrep -0 -c 'CTCCTTACTCTCCCGGT' *.fastq > count/B69_Fm0.txt
agrep -0 -c 'TTCAATTCCCTATTCGC' *.fastq > count/B71_Fm0.txt
agrep -0 -c 'CTGACTGTTCCCACAAC' *.fastq > count/B72_Fm0.txt
agrep -0 -c 'GATCACAGCGTAGTACC' *.fastq > count/B73_Fm0.txt
agrep -0 -c 'TGTGTTGTATGAGCGGA' *.fastq > count/B75_Fm0.txt
agrep -0 -c 'CGAGCGGCAAATATTAT' *.fastq > count/B76_Fm0.txt
agrep -0 -c 'ACCGCGAAGAGAGGACT' *.fastq > count/B77_Fm0.txt
agrep -0 -c 'TCACAGGGCGTAAAGTC' *.fastq > count/B78_Fm0.txt
agrep -0 -c 'ACCTTAGTTTCCCAAAC' *.fastq > count/B79_Fm0.txt
agrep -0 -c 'TACGGGGATTTGTTCCC' *.fastq > count/B80_Fm0.txt
agrep -0 -c 'CGGTCTTTCGCGTCAAG' *.fastq > count/B81_Fm0.txt
agrep -0 -c 'GCCATGTAGTTAGCCTT' *.fastq > count/B82_Fm0.txt
agrep -0 -c 'GACAGCCTCGAACCTCA' *.fastq > count/B83_Fm0.txt
agrep -0 -c 'TTGATCTGGCTGCAAAC' *.fastq > count/B84_Fm0.txt
agrep -0 -c 'AGGTCTACCTTTGATGG' *.fastq > count/B85_Fm0.txt
agrep -0 -c 'GGATATCAGTTGACAAC' *.fastq > count/B87_Fm0.txt
agrep -0 -c 'CAACTTCGCAACCAGTT' *.fastq > count/B88_Fm0.txt
agrep -0 -c 'CACCGTAGCGTGCCTTA' *.fastq > count/B89_Fm0.txt
agrep -0 -c 'TTCTTTTCCACCCGGAG' *.fastq > count/B90_Fm0.txt
agrep -0 -c 'GGCTTTCACATTGGTTA' *.fastq > count/B91_Fm0.txt
agrep -0 -c 'GGTAAAAGTGGCAGAGT' *.fastq > count/B92_Fm0.txt
agrep -0 -c 'CACGACACATTACTGGC' *.fastq > count/B93_Fm0.txt
agrep -0 -c 'ACAAGTACACCCTACAT' *.fastq > count/B94_Fm0.txt
agrep -0 -c 'TTGTAGTGTCGTGGGGA' *.fastq > count/B95_Fm0.txt
agrep -0 -c 'AAGTACGCCTATCTACA' *.fastq > count/B96_Fm0.txt
agrep -0 -c 'CTTGGCCGGGACAGATT' *.fastq > count/B97_Fm0.txt
agrep -0 -c 'CCAGCCCTGAGCTTACA' *.fastq > count/B98_Fm0.txt
agrep -0 -c 'AGTCTTCGCAAAGCTCA' *.fastq > count/B99_Fm0.txt
agrep -0 -c 'AGCGGGCCATATTTTAC' *.fastq > count/B100_Fm0.txt
agrep -0 -c 'TAAGGCTGGTTCCGTCA' *.fastq > count/B103_Fm0.txt
agrep -0 -c 'ACTATCTTCCGTCCCCC' *.fastq > count/B104_Fm0.txt
agrep -0 -c 'GAGAATTCGCAGTTGGC' *.fastq > count/B105_Fm0.txt
agrep -0 -c 'ACAGCAAATCGATTACC' *.fastq > count/B106_Fm0.txt
agrep -0 -c 'TACACCAATAGCTGATG' *.fastq > count/B107_Fm0.txt
agrep -0 -c 'ATTCCAAGTCTCACGAG' *.fastq > count/B108_Fm0.txt
agrep -0 -c 'CATCCGCTGTTGTGAGC' *.fastq > count/B109_Fm0.txt
agrep -0 -c 'GAGCGCATGGTCTGATC' *.fastq > count/B110_Fm0.txt
agrep -0 -c 'CGGGACCTCGTTCTTAT' *.fastq > count/B112_Fm0.txt
agrep -0 -c 'GTCGACGGGTTTCTGTA' *.fastq > count/B113_Fm0.txt
agrep -0 -c 'TTGAATGAACCCCGCTC' *.fastq > count/B114_Fm0.txt
agrep -0 -c 'TCATGGGACGTACGCAA' *.fastq > count/B115_Fm0.txt
agrep -0 -c 'ATAAGAATCGGCCTTGA' *.fastq > count/B116_Fm0.txt
agrep -0 -c 'CGAGACGATACAGTGTG' *.fastq > count/B117_Fm0.txt
agrep -0 -c 'GCAAACTAGAGAGTCAA' *.fastq > count/B118_Fm0.txt
agrep -0 -c 'GACTTCGGACGAGTCAA' *.fastq > count/B120_Fm0.txt
agrep -0 -c 'GACACAGCCTCAATATT' *.fastq > count/B121_Fm0.txt
agrep -0 -c 'CGTGGGTTTCGGTTTTG' *.fastq > count/B122_Fm0.txt
agrep -0 -c 'AGACCCGTCGATCAATG' *.fastq > count/B123_Fm0.txt
agrep -0 -c 'GTCAGGAAGTATCCGGA' *.fastq > count/B124_Fm0.txt
agrep -0 -c 'ATGTAGGCTCGCAAAGG' *.fastq > count/B125_Fm0.txt
agrep -0 -c 'GCGGTGGCTAAAAATGC' *.fastq > count/B126_Fm0.txt
agrep -0 -c 'GGTGTACCAAACTTGTA' *.fastq > count/B128_Fm0.txt
agrep -0 -c 'GCCTGGTGGATTTTCAC' *.fastq > count/B129_Fm0.txt
agrep -0 -c 'ATAGGAAGAATCACACG' *.fastq > count/B131_Fm0.txt
agrep -0 -c 'ACATATCTCGGTATTCG' *.fastq > count/B5446_Fm0.txt
agrep -0 -c 'AGTATAACCGAGGGAAC' *.fastq > count/B8570_Fm0.txt
agrep -0 -c 'GCGAACTACTCCAGTGC' *.fastq > count/B269_Fm0.txt
agrep -0 -c 'AAGCTACGACTACTTAG' *.fastq > count/B1313_Fm0.txt
agrep -0 -c 'GTGGATTACGTAGACCG' *.fastq > count/B160_Fm0.txt
agrep -0 -c 'GTCACCACAGTTAATTG' *.fastq > count/B167_Fm0.txt
agrep -0 -c 'TCATCTGGACACTGCAA' *.fastq > count/B259_Fm0.txt
agrep -0 -c 'GCCGGTGCACATATTCG' *.fastq > count/B305_Fm0.txt
agrep -0 -c 'ATCCTATACGACAGGAA' *.fastq > count/B306_Fm0.txt
agrep -0 -c 'GTCATAAATCGCTTGTC' *.fastq > count/B374_Fm0.txt
agrep -0 -c 'CCGACCATCGTTGTCAC' *.fastq > count/B4161_Fm0.txt
agrep -0 -c 'TTACGGGCACTTCCTAT' *.fastq > count/B5277_Fm0.txt
agrep -0 -c 'GTCCATCTGGTCATTGT' *.fastq > count/B5328_Fm0.txt
agrep -0 -c 'CAGTATGAAGGCTCCTG' *.fastq > count/B5744_Fm0.txt
agrep -0 -c 'CTCGTACGTCCCGCATT' *.fastq > count/B7238_Fm0.txt
agrep -0 -c 'CATACTCCCCGTTTTGA' *.fastq > count/B7310_Fm0.txt
agrep -0 -c 'ACCTGCTCGAACGGTAT' *.fastq > count/B8804_Fm0.txt
agrep -0 -c 'TAAGAAGAGACTGATGC' *.fastq > count/B8863_Fm0.txt
agrep -0 -c 'CCATGGACGTATTGTGT' *.fastq > count/B9338_Fm0.txt
agrep -0 -c 'CTATCCCACTCACGTTA' *.fastq > count/B9783_Fm0.txt
agrep -0 -c 'GCAGGTCTTCTCATACG' *.fastq > count/B9788_Fm0.txt
agrep -0 -c 'GCTAACGGAGTGAGCGT' *.fastq > count/B1058_Fm0.txt
agrep -0 -c 'GGCAGAAATCTGCTTGT' *.fastq > count/B1065_Fm0.txt
agrep -0 -c 'GGCCCGCGTATCTAACT' *.fastq > count/B132_Fm0.txt
agrep -0 -c 'TGGCTTAGCGCGAGACA' *.fastq > count/B133_Fm0.txt
agrep -0 -c 'AATACTAGGCAACGAGG' *.fastq > count/B134_Fm0.txt
agrep -0 -c 'GTGTTTCACATCTACGC' *.fastq > count/B137_Fm0.txt
agrep -0 -c 'GCAGTCTCAATGCGGGT' *.fastq > count/B139_Fm0.txt
agrep -0 -c 'TACCAGCGGAAAGGAGA' *.fastq > count/B141_Fm0.txt
agrep -0 -c 'TACAGATGCGTAGTCGG' *.fastq > count/B142_Fm0.txt
agrep -0 -c 'ACCAATATGTCTGCTCG' *.fastq > count/B144_Fm0.txt
agrep -0 -c 'AATCGGTGGTCGATCTT' *.fastq > count/B146_Fm0.txt
agrep -0 -c 'AGAATATCGAGCAGGGC' *.fastq > count/B148_Fm0.txt
agrep -0 -c 'GTAGTTCGCTCCAGACG' *.fastq > count/B149_Fm0.txt
agrep -0 -c 'ATGACCTTCGGGGTCTA' *.fastq > count/B150_Fm0.txt
agrep -0 -c 'GTCGAATATGTCAACGA' *.fastq > count/B151_Fm0.txt
agrep -0 -c 'ACATTATGGAGCTACGA' *.fastq > count/B152_Fm0.txt
agrep -0 -c 'CTCCGACTACGACGCAA' *.fastq > count/B153_Fm0.txt
agrep -0 -c 'GGTTTACACATAGCCTG' *.fastq > count/B155_Fm0.txt
agrep -0 -c 'GCCCTACCCTGTGGATT' *.fastq > count/B156_Fm0.txt
agrep -0 -c 'GGTAGGTACGGCAAATA' *.fastq > count/B159_Fm0.txt
agrep -0 -c 'CAAAGTCCATACCCGAC' *.fastq > count/B161_Fm0.txt
agrep -0 -c 'GTTTGGTCGTCGTTCCT' *.fastq > count/B162_Fm0.txt
agrep -0 -c 'CGAGAAACTTGGACGCC' *.fastq > count/B163_Fm0.txt
agrep -0 -c 'TGTAGGTACTATCTCCT' *.fastq > count/B164_Fm0.txt
agrep -0 -c 'GGTCACACATGACGGTT' *.fastq > count/B165_Fm0.txt
agrep -0 -c 'CGTCGTAAAACTAGACA' *.fastq > count/B166_Fm0.txt
agrep -0 -c 'CATGCAAGAATTCAGAG' *.fastq > count/B168_Fm0.txt
agrep -0 -c 'TAATATCCCCGAGCTTT' *.fastq > count/B169_Fm0.txt
agrep -0 -c 'CGAAGCACTGGACAATC' *.fastq > count/B170_Fm0.txt
agrep -0 -c 'TTAGCATCGAACACGTT' *.fastq > count/B171_Fm0.txt
agrep -0 -c 'TCGAGCGACTTCATGCA' *.fastq > count/B172_Fm0.txt
agrep -0 -c 'TTGGCCTTTGGCCATTC' *.fastq > count/B173_Fm0.txt
agrep -0 -c 'ACGCGAGTGATGTGTTC' *.fastq > count/B174_Fm0.txt
agrep -0 -c 'AGTGAGCTCAGAATTCA' *.fastq > count/B175_Fm0.txt
agrep -0 -c 'GTTCTTAAACCGGTCCC' *.fastq > count/B176_Fm0.txt
agrep -0 -c 'CATCCCGAAGCACTCTT' *.fastq > count/B177_Fm0.txt
agrep -0 -c 'TTGACCCAAACTTCGAA' *.fastq > count/B179_Fm0.txt
agrep -0 -c 'TCTGATGAAACACGACA' *.fastq > count/B180_Fm0.txt
agrep -0 -c 'GCAGTACATGTAGGGAT' *.fastq > count/B183_Fm0.txt
agrep -0 -c 'ACGGATTAGGCCACTTA' *.fastq > count/B184_Fm0.txt
agrep -0 -c 'GTTAAACCTTCACGTTC' *.fastq > count/B185_Fm0.txt
agrep -0 -c 'TACCGTAAAGCTCTTTG' *.fastq > count/B186_Fm0.txt
agrep -0 -c 'TGGCCGGAACACAACCT' *.fastq > count/B187_Fm0.txt
agrep -0 -c 'GCCCCAGCAACCTAGAT' *.fastq > count/B188_Fm0.txt
agrep -0 -c 'GTATGCAGTAGCGGATC' *.fastq > count/B189_Fm0.txt
agrep -0 -c 'GTGTACAACGAAGTCTC' *.fastq > count/B190_Fm0.txt
agrep -0 -c 'GGGACTCTGATTCGAAA' *.fastq > count/B191_Fm0.txt
agrep -0 -c 'AACACTGGGGTCGACTG' *.fastq > count/B192_Fm0.txt
agrep -0 -c 'CCATAACGAAAACACTG' *.fastq > count/B194_Fm0.txt
agrep -0 -c 'TCGTAAGACTGGTCGTT' *.fastq > count/B195_Fm0.txt
agrep -0 -c 'ATGGTGCGGCTTAGAAA' *.fastq > count/B196_Fm0.txt
agrep -0 -c 'TCAAACCCACTAACACC' *.fastq > count/B197_Fm0.txt
agrep -0 -c 'AACACAAATGCCCTCGC' *.fastq > count/B198_Fm0.txt
agrep -0 -c 'ATGTGGCTCAATCACTT' *.fastq > count/B199_Fm0.txt
agrep -0 -c 'TGCAGGACGTGCAACAT' *.fastq > count/B200_Fm0.txt
agrep -0 -c 'TACGCAACAAGCTGATT' *.fastq > count/B201_Fm0.txt
agrep -0 -c 'AGGGCAAACGTGGAAGT' *.fastq > count/B202_Fm0.txt
agrep -0 -c 'AACAACGTCGTACCCGC' *.fastq > count/B205_Fm0.txt
agrep -0 -c 'GTTCACCAGTACCAGTC' *.fastq > count/B206_Fm0.txt
agrep -0 -c 'TCGCGGGCTCACCATTT' *.fastq > count/B207_Fm0.txt
agrep -0 -c 'GTCGTAGTAAAATGACC' *.fastq > count/B208_Fm0.txt
agrep -0 -c 'CACAAGAGTCGTGTACC' *.fastq > count/B209_Fm0.txt
agrep -0 -c 'AGCCTCTACACGTTGCG' *.fastq > count/B210_Fm0.txt
agrep -0 -c 'TCTACACCACGGGTAAA' *.fastq > count/B211_Fm0.txt
agrep -0 -c 'AAGCAAGCATTCGTTGA' *.fastq > count/B213_Fm0.txt
agrep -0 -c 'AACTCCATAGGACACGC' *.fastq > count/B214_Fm0.txt
agrep -0 -c 'ACAAGACACGACACATA' *.fastq > count/B215_Fm0.txt
agrep -0 -c 'GCGTTAGTACCGAACAC' *.fastq > count/B216_Fm0.txt
agrep -0 -c 'AGCTCCTTTGGCACAAA' *.fastq > count/B217_Fm0.txt
agrep -0 -c 'CACTACGAGCGAAAACA' *.fastq > count/B219_Fm0.txt
agrep -0 -c 'TTGCTGAAGATTTGGTC' *.fastq > count/B220_Fm0.txt
agrep -0 -c 'ATAAGAGACCCCCCTTT' *.fastq > count/B221_Fm0.txt
agrep -0 -c 'CTCATAACTTTGCCCGA' *.fastq > count/B222_Fm0.txt
agrep -0 -c 'TAACAGCCGTAGTGTTA' *.fastq > count/B223_Fm0.txt
agrep -0 -c 'AGACGTGCTGGCAGATC' *.fastq > count/B224_Fm0.txt
agrep -0 -c 'GTTGGTGTTAGGACTCT' *.fastq > count/B225_Fm0.txt
agrep -0 -c 'CGCTTATCCCAATGACT' *.fastq > count/B226_Fm0.txt
agrep -0 -c 'TCATCTGGGGGAACACC' *.fastq > count/B227_Fm0.txt
agrep -0 -c 'CGAATCGGATATCTGGA' *.fastq > count/B228_Fm0.txt
agrep -0 -c 'CCTCCTCTAGTACCCGA' *.fastq > count/B229_Fm0.txt
agrep -0 -c 'TACAGTTACCAGGCGAT' *.fastq > count/B230_Fm0.txt
agrep -0 -c 'CTGGCCCATAGAACCAT' *.fastq > count/B231_Fm0.txt
agrep -0 -c 'CGGCTTTACTTTTACCA' *.fastq > count/B233_Fm0.txt
agrep -0 -c 'CAATGTCGCATTCACTT' *.fastq > count/B234_Fm0.txt
agrep -0 -c 'GTCAACGTATATCAGGC' *.fastq > count/B235_Fm0.txt
agrep -0 -c 'GTCGCTAACTCCAAATC' *.fastq > count/B236_Fm0.txt
agrep -0 -c 'GGTGGTTTAACATGCAG' *.fastq > count/B238_Fm0.txt
agrep -0 -c 'TGAAACATAGGCGAACA' *.fastq > count/B239_Fm0.txt
agrep -0 -c 'TTATCCTCTATCGAACG' *.fastq > count/B240_Fm0.txt
agrep -0 -c 'TATCAGTGTCCAGCAAC' *.fastq > count/B241_Fm0.txt
agrep -0 -c 'TTCGTCGACATCTGCCC' *.fastq > count/B242_Fm0.txt
agrep -0 -c 'GGAGCCACTTGACGAAC' *.fastq > count/B243_Fm0.txt
agrep -0 -c 'TAAGCATTGCTGCCATC' *.fastq > count/B244_Fm0.txt
agrep -0 -c 'GCTTAGTTCCCTCTAAT' *.fastq > count/B245_Fm0.txt
agrep -0 -c 'CGTGGTTCTGTGTATCT' *.fastq > count/B247_Fm0.txt
agrep -0 -c 'GTGTTGCGTTGGCGTGA' *.fastq > count/B248_Fm0.txt
agrep -0 -c 'AAGGTTGCGCGTAACCG' *.fastq > count/B249_Fm0.txt
agrep -0 -c 'GCGTTCCACTTTAGTAA' *.fastq > count/B251_Fm0.txt
agrep -0 -c 'CATGAAAGGGTACGAAC' *.fastq > count/B252_Fm0.txt
agrep -0 -c 'TGTGAGGTCGGGGGTAT' *.fastq > count/B253_Fm0.txt
agrep -0 -c 'AAGTTTAAGTCACCGCA' *.fastq > count/B254_Fm0.txt
agrep -0 -c 'CTCCCGACAGATGCTTA' *.fastq > count/B255_Fm0.txt
agrep -0 -c 'TGATCGTAACCACGATT' *.fastq > count/B257_Fm0.txt
agrep -0 -c 'GGGAGTGTCGTGATGAC' *.fastq > count/B258_Fm0.txt
agrep -0 -c 'ATATCTGCGAAGTCCGA' *.fastq > count/B260_Fm0.txt
agrep -0 -c 'CCGGTCACAGATGAAAT' *.fastq > count/B261_Fm0.txt
agrep -0 -c 'CGAATGACCCACGGAAA' *.fastq > count/B262_Fm0.txt
agrep -0 -c 'GTCTTAACCCCGTTTGA' *.fastq > count/B263_Fm0.txt
agrep -0 -c 'ATCAGGTCACCCCATAC' *.fastq > count/B264_Fm0.txt
agrep -0 -c 'GAGAGCTGTCAGGTGTA' *.fastq > count/B267_Fm0.txt
agrep -0 -c 'GTAAGGGTTACTGTCAG' *.fastq > count/B268_Fm0.txt
agrep -0 -c 'TGTCCATCGGATTGGTA' *.fastq > count/B270_Fm0.txt
agrep -0 -c 'CAGAACCGGCAAACCAA' *.fastq > count/B271_Fm0.txt
agrep -0 -c 'GGGAGCACATACATTGG' *.fastq > count/B273_Fm0.txt
agrep -0 -c 'GGAAGTTTGGTCTGTGC' *.fastq > count/B274_Fm0.txt
agrep -0 -c 'AGCTCGAAACGCCCAGT' *.fastq > count/B276_Fm0.txt
agrep -0 -c 'CCAAGTGGTAGCGAGTG' *.fastq > count/B277_Fm0.txt
agrep -0 -c 'GCGTAAGTTTCCACAGA' *.fastq > count/B278_Fm0.txt
agrep -0 -c 'GACTCTTATCCGGATGG' *.fastq > count/B279_Fm0.txt
agrep -0 -c 'ATTACCACGTGGATGTC' *.fastq > count/B281_Fm0.txt
agrep -0 -c 'CGTGGATGGGATAGTGT' *.fastq > count/B282_Fm0.txt
agrep -0 -c 'ATACACAGGTGGCGTGT' *.fastq > count/B283_Fm0.txt
agrep -0 -c 'ATAGGTGAAGACCGGGC' *.fastq > count/B284_Fm0.txt
agrep -0 -c 'AGTAACGGTTTGTGTAC' *.fastq > count/B286_Fm0.txt
agrep -0 -c 'AGACCTCGTCAGTCATC' *.fastq > count/B288_Fm0.txt
agrep -0 -c 'TAGATGCGTACTTGGAG' *.fastq > count/B289_Fm0.txt
agrep -0 -c 'ATCCCAATTCCGCCTAG' *.fastq > count/B290_Fm0.txt
agrep -0 -c 'TGCTCGGGTCAGATGAA' *.fastq > count/B291_Fm0.txt
agrep -0 -c 'AGCTTTCTTCGCTGGAA' *.fastq > count/B293_Fm0.txt
agrep -0 -c 'AGGGTCAACTCGGGGTT' *.fastq > count/B294_Fm0.txt
agrep -0 -c 'GCGGTCTTAGGCTAGCT' *.fastq > count/B295_Fm0.txt
agrep -0 -c 'TGTGAAGAAGAGCTCAA' *.fastq > count/B296_Fm0.txt
agrep -0 -c 'CAAATCAGGCTCGATAA' *.fastq > count/B297_Fm0.txt
agrep -0 -c 'CAGCCATGTCCCTCAAA' *.fastq > count/B299_Fm0.txt
agrep -0 -c 'ACACGGGTAGATGCCCA' *.fastq > count/B300_Fm0.txt
agrep -0 -c 'AAGAATCGACTCGTAGT' *.fastq > count/B301_Fm0.txt
agrep -0 -c 'CTATTCATCGTGGGATT' *.fastq > count/B302_Fm0.txt
agrep -0 -c 'TAGGCAATCAGTCATCT' *.fastq > count/B303_Fm0.txt
agrep -0 -c 'TCGGACGCTATTAAGGG' *.fastq > count/B304_Fm0.txt
agrep -0 -c 'GGCAACCGATAGATTCA' *.fastq > count/B307_Fm0.txt
agrep -0 -c 'TTCAAACGGTTAGGAGG' *.fastq > count/B309_Fm0.txt
agrep -0 -c 'ACCCTCAGTAGGTATAC' *.fastq > count/B311_Fm0.txt
agrep -0 -c 'GTATCGGGTCATCGTTT' *.fastq > count/B312_Fm0.txt
agrep -0 -c 'GCGTCGAGAGTACGTAG' *.fastq > count/B313_Fm0.txt
agrep -0 -c 'CCTCAATCGGGATAAAG' *.fastq > count/B314_Fm0.txt
agrep -0 -c 'TACCTGTAGTGTGCTCG' *.fastq > count/B315_Fm0.txt
agrep -0 -c 'CCGCGACAGAGAATTCT' *.fastq > count/B316_Fm0.txt
agrep -0 -c 'CAGGTGACGGCACTGAT' *.fastq > count/B317_Fm0.txt
agrep -0 -c 'GCATCTGTGGTGACTTA' *.fastq > count/B318_Fm0.txt
agrep -0 -c 'AGTCACTGCGCTCCGAT' *.fastq > count/B322_Fm0.txt
agrep -0 -c 'GTTTTGTGCTGCCCGAC' *.fastq > count/B323_Fm0.txt
agrep -0 -c 'TACATATGCCGTAGGGT' *.fastq > count/B324_Fm0.txt
agrep -0 -c 'TGTTGGTCGTAAGGGAA' *.fastq > count/B325_Fm0.txt
agrep -0 -c 'AACCCATATTTTGGCGC' *.fastq > count/B327_Fm0.txt
agrep -0 -c 'AGTGATCGTAGTTCCAG' *.fastq > count/B329_Fm0.txt
agrep -0 -c 'AGCACAAGACAGATTGT' *.fastq > count/B331_Fm0.txt
agrep -0 -c 'AGGTGGTGAATGCTCTA' *.fastq > count/B332_Fm0.txt
agrep -0 -c 'GCCGCTTACCCTTCGAA' *.fastq > count/B333_Fm0.txt
agrep -0 -c 'AACACGGATAAGCCGGG' *.fastq > count/B335_Fm0.txt
agrep -0 -c 'TCACTAAAGGCGTACCG' *.fastq > count/B336_Fm0.txt
agrep -0 -c 'GGCGGACCTAGGAAGTA' *.fastq > count/B337_Fm0.txt
agrep -0 -c 'TTACAGACACGAGTCCT' *.fastq > count/B338_Fm0.txt
agrep -0 -c 'GCGTATACCAGGACTGC' *.fastq > count/B340_Fm0.txt
agrep -0 -c 'TAAAGTGGCCCCACAAG' *.fastq > count/B341_Fm0.txt
agrep -0 -c 'ACTACCCAAGTTGCCCG' *.fastq > count/B342_Fm0.txt
agrep -0 -c 'TTACGTGCTGATGCACA' *.fastq > count/B344_Fm0.txt
agrep -0 -c 'GCATCGTACTAGGTAGG' *.fastq > count/B346_Fm0.txt
agrep -0 -c 'CTCCAAAGGTAGCGCCA' *.fastq > count/B347_Fm0.txt
agrep -0 -c 'AATTCGTGGGTCCGGCT' *.fastq > count/B349_Fm0.txt
agrep -0 -c 'GCGTCTAAATTAGGGAC' *.fastq > count/B350_Fm0.txt
agrep -0 -c 'AATGTAGACGAGGCATC' *.fastq > count/B351_Fm0.txt
agrep -0 -c 'CAGGTCACCATGTTACC' *.fastq > count/B353_Fm0.txt
agrep -0 -c 'TGTTAGAGAGGAGCCCT' *.fastq > count/B354_Fm0.txt
agrep -0 -c 'GTTAGTCTCTGCTGCAG' *.fastq > count/B355_Fm0.txt
agrep -0 -c 'AAGGAGTGATTACTCAC' *.fastq > count/B357_Fm0.txt
agrep -0 -c 'ATAGAGGACGTGTATCT' *.fastq > count/B358_Fm0.txt
agrep -0 -c 'AATCGGGTCCTCCTTAC' *.fastq > count/B360_Fm0.txt
agrep -0 -c 'AAGCTATTGGAGCGCGT' *.fastq > count/B361_Fm0.txt
agrep -0 -c 'TGACATCCGGCATAAAT' *.fastq > count/B362_Fm0.txt
agrep -0 -c 'GGAGTCTGATAGTCACG' *.fastq > count/B363_Fm0.txt
agrep -0 -c 'TTACACGACGAACGGCC' *.fastq > count/B364_Fm0.txt
agrep -0 -c 'CGCCTCCAATTCTAAAG' *.fastq > count/B365_Fm0.txt
agrep -0 -c 'TGCGTAATCAAATGCTC' *.fastq > count/B366_Fm0.txt
agrep -0 -c 'AGAACGAGATGCACGTA' *.fastq > count/B367_Fm0.txt
agrep -0 -c 'TGTAATGTTTCCGGCCT' *.fastq > count/B369_Fm0.txt
agrep -0 -c 'AACAGCCGAAGCGTCTC' *.fastq > count/B370_Fm0.txt
agrep -0 -c 'ATGTCTTCTCATGTCGG' *.fastq > count/B372_Fm0.txt
agrep -0 -c 'TCTTACGACGGTCTAAT' *.fastq > count/B375_Fm0.txt
agrep -0 -c 'TACAGAAGCCTCATCTA' *.fastq > count/B376_Fm0.txt
agrep -0 -c 'GGGTGGAGTTCCTATGT' *.fastq > count/B377_Fm0.txt
agrep -0 -c 'TGCGTAAGTTCGCTTTG' *.fastq > count/B378_Fm0.txt
agrep -0 -c 'CTGTTGTCGAATCATTG' *.fastq > count/B379_Fm0.txt
agrep -0 -c 'AACACCATAGAACGGAC' *.fastq > count/B381_Fm0.txt
agrep -0 -c 'GGCATACCGCCTTTCGA' *.fastq > count/B382_Fm0.txt
agrep -0 -c 'ATGGAATTACCGCGACT' *.fastq > count/B383_Fm0.txt
agrep -0 -c 'GCGTATAGAACGAGATC' *.fastq > count/B384_Fm0.txt
agrep -0 -c 'ACGCCTACCTCCAAATG' *.fastq > count/B385_Fm0.txt
agrep -0 -c 'CATCTGTCAAGCTGCTC' *.fastq > count/B386_Fm0.txt
agrep -0 -c 'AAGCTGGCTCTAGCTGT' *.fastq > count/B387_Fm0.txt
agrep -0 -c 'GCACCCCAAGGTAACCA' *.fastq > count/B388_Fm0.txt
agrep -0 -c 'GAGGTTGTGATGTCGCT' *.fastq > count/B389_Fm0.txt
agrep -0 -c 'CGATTCATTAACCCACA' *.fastq > count/B390_Fm0.txt
agrep -0 -c 'ATGAAAGACTGGACGAT' *.fastq > count/B392_Fm0.txt
agrep -0 -c 'GGCGCATTCAGGTTTTC' *.fastq > count/B393_Fm0.txt
agrep -0 -c 'ACGCTAAGCCCCGACTA' *.fastq > count/B394_Fm0.txt
agrep -0 -c 'GTGCTATGTACAGTGGC' *.fastq > count/B395_Fm0.txt
agrep -0 -c 'TATGTCCCGCTTCGACT' *.fastq > count/B396_Fm0.txt
agrep -0 -c 'GACAGTTTAATTGGGGC' *.fastq > count/B397_Fm0.txt
agrep -0 -c 'GCTATATAAGTCCAAGG' *.fastq > count/B398_Fm0.txt
agrep -0 -c 'GACGTACACAAAAGACC' *.fastq > count/B399_Fm0.txt
agrep -0 -c 'ACATGGAATAAGTTCGG' *.fastq > count/B400_Fm0.txt
agrep -0 -c 'TCGGTGAACTCATCATC' *.fastq > count/B401_Fm0.txt
agrep -0 -c 'GGAGTGTCGCTCGAGAA' *.fastq > count/B402_Fm0.txt
agrep -0 -c 'ATAGTAGAAGCGCAGTT' *.fastq > count/B403_Fm0.txt
agrep -0 -c 'CATCTCTCACCGATATC' *.fastq > count/B404_Fm0.txt
agrep -0 -c 'TAGGGTACATAGGGGGC' *.fastq > count/B405_Fm0.txt
agrep -0 -c 'CATGTCATGAAGGGCGC' *.fastq > count/B407_Fm0.txt
agrep -0 -c 'CTGACATATCTTCGCCA' *.fastq > count/B408_Fm0.txt
agrep -0 -c 'GGCAATGCTTGCTGAGT' *.fastq > count/B409_Fm0.txt
agrep -0 -c 'ATTTCAGACCTACAGCC' *.fastq > count/B411_Fm0.txt
agrep -0 -c 'GTGCTAGCGCGTATGAA' *.fastq > count/B412_Fm0.txt
agrep -0 -c 'CTGCCGTTGACTACAGA' *.fastq > count/B413_Fm0.txt
agrep -0 -c 'ACGCGCCCTATAATCAA' *.fastq > count/B414_Fm0.txt
agrep -0 -c 'CATAACTACGCCAGCGA' *.fastq > count/B416_Fm0.txt
agrep -0 -c 'GACTCTATTTCGCCCCT' *.fastq > count/B417_Fm0.txt
agrep -0 -c 'TTAGATAGGACCGAGTG' *.fastq > count/B418_Fm0.txt
agrep -0 -c 'AACGCAACGTTAGAGTC' *.fastq > count/B419_Fm0.txt
agrep -0 -c 'CAGTGTGGCGAATATTC' *.fastq > count/B420_Fm0.txt
agrep -0 -c 'GAGAGCCTTGTCATGGT' *.fastq > count/B421_Fm0.txt
agrep -0 -c 'ATGATCCGTTGGACAGG' *.fastq > count/B422_Fm0.txt
agrep -0 -c 'GCCAATTCCCAAAATCG' *.fastq > count/B424_Fm0.txt
agrep -0 -c 'CAAGTGGTCCCTTCATC' *.fastq > count/B429_Fm0.txt
agrep -0 -c 'CAGTATCTCAGAATACG' *.fastq > count/B430_Fm0.txt
agrep -0 -c 'ACCTCGAAAATCCAGGT' *.fastq > count/B431_Fm0.txt
agrep -0 -c 'GTCGGGGGAGATTTTCC' *.fastq > count/B432_Fm0.txt
agrep -0 -c 'GCAAACGATTTTCGCTA' *.fastq > count/B433_Fm0.txt
agrep -0 -c 'ATGATCCTTCGTGTCGT' *.fastq > count/B434_Fm0.txt
agrep -0 -c 'CCGAACTAGTAGCTTCG' *.fastq > count/B435_Fm0.txt
agrep -0 -c 'TGAATGTGCGCCTCTCA' *.fastq > count/B436_Fm0.txt
agrep -0 -c 'TGTGGTCATGCTGTCGC' *.fastq > count/B437_Fm0.txt
agrep -0 -c 'GCCGGTAAGGTACCAAT' *.fastq > count/B438_Fm0.txt
agrep -0 -c 'CCAGCATTGTTCGCGAC' *.fastq > count/B439_Fm0.txt
agrep -0 -c 'AAGAGATATCGCGCTGA' *.fastq > count/B440_Fm0.txt
agrep -0 -c 'GAGGACGGCGAAAGTAT' *.fastq > count/B441_Fm0.txt
agrep -0 -c 'ATGAGAGCCACGTGGAG' *.fastq > count/B442_Fm0.txt
agrep -0 -c 'TACAGGCGGCACTTGCT' *.fastq > count/B443_Fm0.txt
agrep -0 -c 'ATGCACCTTAGCACTGT' *.fastq > count/B444_Fm0.txt
agrep -0 -c 'TAGGTTGTAAGACCATG' *.fastq > count/B445_Fm0.txt
agrep -0 -c 'TCGGCGTGTTTGCTCCT' *.fastq > count/B446_Fm0.txt
agrep -0 -c 'CTAACGGGACAGCGATA' *.fastq > count/B447_Fm0.txt
agrep -0 -c 'ATACGCAACACCACCAG' *.fastq > count/B448_Fm0.txt
agrep -0 -c 'GATATCAAAGGCCGGAG' *.fastq > count/B449_Fm0.txt
agrep -0 -c 'CACTGTACAGGGCGATT' *.fastq > count/B450_Fm0.txt
agrep -0 -c 'TACTACAGTCCGAACTC' *.fastq > count/B451_Fm0.txt
agrep -0 -c 'AGCTGCATTGCCGTGAA' *.fastq > count/B452_Fm0.txt
agrep -0 -c 'TGCGTTGGATCGGCAAG' *.fastq > count/B453_Fm0.txt
agrep -0 -c 'ACCGCAGGATAGAGCAA' *.fastq > count/B454_Fm0.txt
agrep -0 -c 'ACCTCCTAGTCGAGAGG' *.fastq > count/B455_Fm0.txt
agrep -0 -c 'CACAGTACCGAAGCAGT' *.fastq > count/B456_Fm0.txt
agrep -0 -c 'TCGCTTGAGTTGCGACT' *.fastq > count/B457_Fm0.txt
agrep -0 -c 'ATCTCGTCCAAGGTGTG' *.fastq > count/B458_Fm0.txt
agrep -0 -c 'TCACCCCACCCGGTTTA' *.fastq > count/B459_Fm0.txt
agrep -0 -c 'TAAGCCTAAACCACGCA' *.fastq > count/B460_Fm0.txt
agrep -0 -c 'ACCAGTTGGACCCCACA' *.fastq > count/B461_Fm0.txt
agrep -0 -c 'GTATCCACTCTTCCAAT' *.fastq > count/B462_Fm0.txt
agrep -0 -c 'TGCTACTTTTGAGGGCG' *.fastq > count/B463_Fm0.txt
agrep -0 -c 'GTATTGTCTCACCCAAA' *.fastq > count/B464_Fm0.txt
agrep -0 -c 'CCTGCTCGACACCAACT' *.fastq > count/B465_Fm0.txt
agrep -0 -c 'TCGAATTTGTGTCGGAA' *.fastq > count/B467_Fm0.txt
agrep -0 -c 'CGCACTCCCTCATAGAT' *.fastq > count/B468_Fm0.txt
agrep -0 -c 'TACAACCGGTTCGAAGT' *.fastq > count/B469_Fm0.txt
agrep -0 -c 'GGAACAGAGGGTGATGT' *.fastq > count/B471_Fm0.txt
agrep -0 -c 'GTGCTTCGTCGTTCGAA' *.fastq > count/B472_Fm0.txt
agrep -0 -c 'ACGATCATGGCTGGCTA' *.fastq > count/B473_Fm0.txt
agrep -0 -c 'GACTAGGTTCAGTGAGA' *.fastq > count/B474_Fm0.txt
agrep -0 -c 'ATCAACCCGTCGTCAGG' *.fastq > count/B475_Fm0.txt
agrep -0 -c 'CGGGACTGGAAGCTGTT' *.fastq > count/B476_Fm0.txt
agrep -0 -c 'AGATGAATCTCGTGACG' *.fastq > count/B477_Fm0.txt
agrep -0 -c 'GATTCACTGTTGACCAG' *.fastq > count/B478_Fm0.txt
agrep -0 -c 'GCGCGCCTAAGCATGTT' *.fastq > count/B479_Fm0.txt
agrep -0 -c 'TTAGCGAACTGTAAAGC' *.fastq > count/B482_Fm0.txt
agrep -0 -c 'AATTACCGGAGGAAGCT' *.fastq > count/B483_Fm0.txt
agrep -0 -c 'ATGCTATCAGAAGAGAC' *.fastq > count/B484_Fm0.txt
agrep -0 -c 'ATCCCGTATGCACCAAC' *.fastq > count/B485_Fm0.txt
agrep -0 -c 'GTTGTTCAAGATACGGG' *.fastq > count/B486_Fm0.txt
agrep -0 -c 'GGGGTGGTTCTACTAGA' *.fastq > count/B487_Fm0.txt
agrep -0 -c 'GTGAGCCTGTAGCATAC' *.fastq > count/B488_Fm0.txt
agrep -0 -c 'GCTAGGCAACCTCTGCT' *.fastq > count/B489_Fm0.txt
agrep -0 -c 'CTTCTGGCGCTGTTTCG' *.fastq > count/B490_Fm0.txt
agrep -0 -c 'ATCAAACTTAGGTCGGA' *.fastq > count/B491_Fm0.txt
agrep -0 -c 'TTCGGGACAAACGTTAA' *.fastq > count/B492_Fm0.txt
agrep -0 -c 'AGTAGGAACATCCTGGC' *.fastq > count/B493_Fm0.txt
agrep -0 -c 'CTAGAAGTTATGGCCTT' *.fastq > count/B494_Fm0.txt
agrep -0 -c 'CGAGTCTGTAGTTACTT' *.fastq > count/B495_Fm0.txt
agrep -0 -c 'CTTAACGCTAAGGAGTT' *.fastq > count/B496_Fm0.txt
agrep -0 -c 'CCAGTTTCACGGGTCTG' *.fastq > count/B497_Fm0.txt
agrep -0 -c 'GCAACGCCACAGTGTTA' *.fastq > count/B498_Fm0.txt
agrep -0 -c 'TGCCGAGCATTCTTGAC' *.fastq > count/B499_Fm0.txt
agrep -0 -c 'TCTCTAGGGTACTTGAG' *.fastq > count/B500_Fm0.txt
agrep -0 -c 'CACATTCGTCACTCACC' *.fastq > count/B501_Fm0.txt
agrep -0 -c 'GTTAGATGCTCATTGAC' *.fastq > count/B502_Fm0.txt
agrep -0 -c 'GATCGCAATAGGATTCC' *.fastq > count/B504_Fm0.txt
agrep -0 -c 'TATCTTGTGCACAAGGG' *.fastq > count/B505_Fm0.txt
agrep -0 -c 'CCTGAGTCTGTTGGAAA' *.fastq > count/B506_Fm0.txt
agrep -0 -c 'GTTGCTGCGCGTCAAGT' *.fastq > count/B507_Fm0.txt
agrep -0 -c 'CCACACTAAAGTCTTCT' *.fastq > count/B508_Fm0.txt
agrep -0 -c 'CACGGTTATAGGGAAGT' *.fastq > count/B510_Fm0.txt
agrep -0 -c 'TTAAGTGCCGAGGCTAC' *.fastq > count/B511_Fm0.txt
agrep -0 -c 'AGCCGACTGCATTCGCT' *.fastq > count/B512_Fm0.txt
agrep -0 -c 'GTTACCGTGCACTTGCT' *.fastq > count/B513_Fm0.txt
agrep -0 -c 'TACTTGAGCGGCGATGA' *.fastq > count/B514_Fm0.txt
agrep -0 -c 'CCGATTGGTGAGAACCT' *.fastq > count/B515_Fm0.txt
agrep -0 -c 'ACTATATGGTCCGTCGT' *.fastq > count/B517_Fm0.txt
agrep -0 -c 'ATCCTTCGGCGAAATTT' *.fastq > count/B518_Fm0.txt
agrep -0 -c 'GCTCGAAGTTAAACACT' *.fastq > count/B519_Fm0.txt
agrep -0 -c 'GATCCAGATTCCCGCAA' *.fastq > count/B520_Fm0.txt
agrep -0 -c 'GCCCCATCAGAAATTTA' *.fastq > count/B521_Fm0.txt
agrep -0 -c 'CTCCTACGGCTTATAAT' *.fastq > count/B522_Fm0.txt
agrep -0 -c 'GCTCGGTGGACAGAAGA' *.fastq > count/B523_Fm0.txt
agrep -0 -c 'GACTTGGGTATGTGTAC' *.fastq > count/B524_Fm0.txt
agrep -0 -c 'CCATGATACCGCATACG' *.fastq > count/B525_Fm0.txt
agrep -0 -c 'TGCGCGGAGAATCGGAT' *.fastq > count/B526_Fm0.txt
agrep -0 -c 'ACGAGGGTTCCTCTGTA' *.fastq > count/B527_Fm0.txt
agrep -0 -c 'GATCAGATCGAGGACTG' *.fastq > count/B528_Fm0.txt
agrep -0 -c 'AGCCGAAGCGGCATTAA' *.fastq > count/B529_Fm0.txt
agrep -0 -c 'ACGGTCGCTCATTGGAT' *.fastq > count/B530_Fm0.txt
agrep -0 -c 'AAGACGGAAAGTGGCAC' *.fastq > count/B533_Fm0.txt
agrep -0 -c 'TTAGGGCTGGCCACATT' *.fastq > count/B534_Fm0.txt
agrep -0 -c 'GTCACTAGGTTGAGGGG' *.fastq > count/B537_Fm0.txt
agrep -0 -c 'GACTTGCATCCCTGCTA' *.fastq > count/B538_Fm0.txt
agrep -0 -c 'CCGGAGAACTTTATTCG' *.fastq > count/B539_Fm0.txt
agrep -0 -c 'GTTATAGTTGGCAGTCG' *.fastq > count/B540_Fm0.txt
agrep -0 -c 'GCCAAATACGCTGTAAC' *.fastq > count/B541_Fm0.txt
agrep -0 -c 'CCTACAAATCAAAGGTG' *.fastq > count/B543_Fm0.txt
agrep -0 -c 'TTGTAGGACTCGTTTGC' *.fastq > count/B544_Fm0.txt
agrep -0 -c 'GCGTCGTAACACTATTC' *.fastq > count/B545_Fm0.txt
agrep -0 -c 'CAACCGGTTGAGTTCGG' *.fastq > count/B546_Fm0.txt
agrep -0 -c 'CATGGACGAATTCCGTA' *.fastq > count/B547_Fm0.txt
agrep -0 -c 'TGTGTATGCGTCGAAAA' *.fastq > count/B548_Fm0.txt
agrep -0 -c 'CACCTGCGTCAACAAAT' *.fastq > count/B549_Fm0.txt
agrep -0 -c 'ATCCGGTGGAGCTAAGT' *.fastq > count/B550_Fm0.txt
agrep -0 -c 'TACCTTGCGGTTGGAGG' *.fastq > count/B553_Fm0.txt
agrep -0 -c 'AAGCATACTGTCGCTGC' *.fastq > count/B554_Fm0.txt
agrep -0 -c 'CACGACGAATGTACGCG' *.fastq > count/B556_Fm0.txt
agrep -0 -c 'CAGTATCCAGTCCGTAC' *.fastq > count/B557_Fm0.txt
agrep -0 -c 'CGGAGTCACTTGCGCAT' *.fastq > count/B558_Fm0.txt
agrep -0 -c 'GTGTAGCAAGAACTCGA' *.fastq > count/B559_Fm0.txt
agrep -0 -c 'GAGTGCAAAAGCGACCT' *.fastq > count/B560_Fm0.txt
agrep -0 -c 'TTCAACACAGGGAGCGT' *.fastq > count/B561_Fm0.txt
agrep -0 -c 'CTAAGCCCCAAGGCAGA' *.fastq > count/B563_Fm0.txt
agrep -0 -c 'TAGTACTAGGCGGAATC' *.fastq > count/B564_Fm0.txt
agrep -0 -c 'CGGTGTGGTGCTCCTTT' *.fastq > count/B565_Fm0.txt
agrep -0 -c 'ATTAGGGAGGTGTTAGA' *.fastq > count/B567_Fm0.txt
agrep -0 -c 'ATTTACGCCACGCTTGG' *.fastq > count/B568_Fm0.txt
agrep -0 -c 'GGTGGCAGGTCCTATTT' *.fastq > count/B569_Fm0.txt
agrep -0 -c 'GCGTTCAAGCCATAAAG' *.fastq > count/B570_Fm0.txt
agrep -0 -c 'GATTAAGAGGGGCATCG' *.fastq > count/B571_Fm0.txt
agrep -0 -c 'GTGACTGCTAAATCCGG' *.fastq > count/B572_Fm0.txt
agrep -0 -c 'GTCCCGTCAAGATACGA' *.fastq > count/B573_Fm0.txt
agrep -0 -c 'CATGAACTTCCGAAAGC' *.fastq > count/B574_Fm0.txt
agrep -0 -c 'ACGCTAGAAGAGCAGAT' *.fastq > count/B575_Fm0.txt
agrep -0 -c 'GCTTCTACATCACGGAA' *.fastq > count/B576_Fm0.txt
agrep -0 -c 'TGTTAGATGATCACCAG' *.fastq > count/B577_Fm0.txt
agrep -0 -c 'ACTTAATCGCTCCCGCA' *.fastq > count/B579_Fm0.txt
agrep -0 -c 'ATTAACGGGCATCTTTG' *.fastq > count/B580_Fm0.txt
agrep -0 -c 'CCGGATAATCCATCATA' *.fastq > count/B581_Fm0.txt
agrep -0 -c 'TAAGATGCCGTTGTCCT' *.fastq > count/B582_Fm0.txt
agrep -0 -c 'TATCTGTAACCCATGGG' *.fastq > count/B583_Fm0.txt
agrep -0 -c 'CCAAATTCCCACCTACC' *.fastq > count/B584_Fm0.txt
agrep -0 -c 'TAAAGAAGACCCACAGT' *.fastq > count/B586_Fm0.txt
agrep -0 -c 'AGGAGGTTAAACCAAGC' *.fastq > count/B587_Fm0.txt
agrep -0 -c 'CCAGTTTGTGAATAACC' *.fastq > count/B588_Fm0.txt
agrep -0 -c 'TGTCCTACGATGGCGTT' *.fastq > count/B591_Fm0.txt
agrep -0 -c 'TGGCTGGCCTAAGTCTC' *.fastq > count/B592_Fm0.txt
agrep -0 -c 'AACTTCACCTATTGGCG' *.fastq > count/B593_Fm0.txt
agrep -0 -c 'TTCCAGTCTTAGTGGCA' *.fastq > count/B595_Fm0.txt
agrep -0 -c 'GGCGAGTGTGTCATCTG' *.fastq > count/B596_Fm0.txt
agrep -0 -c 'AGCGCTGAAAGCCATCA' *.fastq > count/B597_Fm0.txt
agrep -0 -c 'TAAGGGATTAGCAACGC' *.fastq > count/B598_Fm0.txt
agrep -0 -c 'TGAGTAAGGGTCCATAC' *.fastq > count/B599_Fm0.txt
agrep -0 -c 'ACTACCGAGAACCAGAG' *.fastq > count/B600_Fm0.txt
agrep -0 -c 'GGCATGTGAAAGATCTC' *.fastq > count/B601_Fm0.txt
agrep -0 -c 'ATTTCAGGGAGCACGCG' *.fastq > count/B602_Fm0.txt
agrep -0 -c 'ATTCCAAAGGCACAACT' *.fastq > count/B603_Fm0.txt
agrep -0 -c 'GCTGTACGGGATCATTC' *.fastq > count/B604_Fm0.txt
agrep -0 -c 'ATCTCTCTTTTGAGGGC' *.fastq > count/B605_Fm0.txt
agrep -0 -c 'ATCGAAATTTCCGGAGG' *.fastq > count/B606_Fm0.txt
agrep -0 -c 'GTCTACCTAGCACTCAT' *.fastq > count/B607_Fm0.txt
agrep -0 -c 'CTAAGTCGCAGATGTAT' *.fastq > count/B608_Fm0.txt
agrep -0 -c 'CTGACGATAAATGCTAG' *.fastq > count/B609_Fm0.txt
agrep -0 -c 'TTCACCTACTACCCTAA' *.fastq > count/B610_Fm0.txt
agrep -0 -c 'CCTTCTAAGTGCTACCA' *.fastq > count/B611_Fm0.txt
agrep -0 -c 'GATACATTACCAACCAG' *.fastq > count/B614_Fm0.txt
agrep -0 -c 'CTGCGATCCCTGACGAT' *.fastq > count/B615_Fm0.txt
agrep -0 -c 'ACACTATTACGCATTGC' *.fastq > count/B616_Fm0.txt
agrep -0 -c 'GCGGTAATAGCGTGTTT' *.fastq > count/B617_Fm0.txt
agrep -0 -c 'CACGACCGCATAGGTGT' *.fastq > count/B618_Fm0.txt
agrep -0 -c 'CTCTTGATCGACGGGCT' *.fastq > count/B619_Fm0.txt
agrep -0 -c 'AGTTGGGTAGATCACAG' *.fastq > count/B620_Fm0.txt
agrep -0 -c 'CATGTAGGATTCGTCAA' *.fastq > count/B621_Fm0.txt
agrep -0 -c 'TCGCTGTGTCTCGAATT' *.fastq > count/B622_Fm0.txt
agrep -0 -c 'ATGGGTAACACGAACGC' *.fastq > count/B623_Fm0.txt
agrep -0 -c 'TAGAACCTACGGCCTCT' *.fastq > count/B626_Fm0.txt
agrep -0 -c 'CTCGTGAGGAGACCATG' *.fastq > count/B627_Fm0.txt
agrep -0 -c 'AGGGTCATATGACTTTG' *.fastq > count/B628_Fm0.txt
agrep -0 -c 'CACTAAAGCAAGAACGT' *.fastq > count/B629_Fm0.txt
agrep -0 -c 'CATCGTGGTGCGAGTCA' *.fastq > count/B632_Fm0.txt
agrep -0 -c 'GTTGGACTGTGATTGCA' *.fastq > count/B633_Fm0.txt
agrep -0 -c 'CGGATACTGCGCACACT' *.fastq > count/B634_Fm0.txt
agrep -0 -c 'TGTTCGTTTCCTGGAAT' *.fastq > count/B636_Fm0.txt
agrep -0 -c 'CCACATGTTGACGAGCA' *.fastq > count/B637_Fm0.txt
agrep -0 -c 'GAGGAACGTAGGATTTT' *.fastq > count/B638_Fm0.txt
agrep -0 -c 'GATCCGAATCGCTTTGG' *.fastq > count/B639_Fm0.txt
agrep -0 -c 'TGGCGTGTGGTACGATG' *.fastq > count/B640_Fm0.txt
agrep -0 -c 'CCAACACCTACCGCTTT' *.fastq > count/B642_Fm0.txt
agrep -0 -c 'CGGGGTTGTTTTCGCAG' *.fastq > count/B645_Fm0.txt
agrep -0 -c 'CATTCATTGAAGAGGAG' *.fastq > count/B647_Fm0.txt
agrep -0 -c 'ATTGCTGACGCGCGTAA' *.fastq > count/B648_Fm0.txt
agrep -0 -c 'CTCTAGTCATATCCGCC' *.fastq > count/B649_Fm0.txt
agrep -0 -c 'CTAGTAGTATAACGGAG' *.fastq > count/B650_Fm0.txt
agrep -0 -c 'TGAAATAATTGGGCGTC' *.fastq > count/B651_Fm0.txt
agrep -0 -c 'GGTACTAGGTGCGTTTT' *.fastq > count/B652_Fm0.txt
agrep -0 -c 'AACAAGCTCTCGCCAAT' *.fastq > count/B653_Fm0.txt
agrep -0 -c 'GCGAAAGGGTCGGTTCT' *.fastq > count/B655_Fm0.txt
agrep -0 -c 'GGAATATGCGATACCAC' *.fastq > count/B657_Fm0.txt
agrep -0 -c 'AACGAGACTCGAAGCTT' *.fastq > count/B658_Fm0.txt
agrep -0 -c 'GCTCTACGTCGCCTCTA' *.fastq > count/B659_Fm0.txt
agrep -0 -c 'GGTTATCACTCTCACCG' *.fastq > count/B661_Fm0.txt
agrep -0 -c 'CACTTAAGACCCAAGCG' *.fastq > count/B663_Fm0.txt
agrep -0 -c 'TCGCGGCATGTCCTAAC' *.fastq > count/B664_Fm0.txt
agrep -0 -c 'TAACCAGTTACACGAGG' *.fastq > count/B666_Fm0.txt
agrep -0 -c 'AGAAGCTACATGATAGG' *.fastq > count/B667_Fm0.txt
agrep -0 -c 'TGACTAGCCTCGTCGTC' *.fastq > count/B669_Fm0.txt
agrep -0 -c 'TGAGTCGTGAACACGAG' *.fastq > count/B670_Fm0.txt
agrep -0 -c 'CTGCACTGAATAGTTAC' *.fastq > count/B671_Fm0.txt
agrep -0 -c 'AATTTGCGCCTTGTCGA' *.fastq > count/B672_Fm0.txt
agrep -0 -c 'TATTCGCTGTGCTCCAG' *.fastq > count/B673_Fm0.txt
agrep -0 -c 'GACTAATCTGGGTACGA' *.fastq > count/B674_Fm0.txt
agrep -0 -c 'CAGTACTACCTAGACGC' *.fastq > count/B675_Fm0.txt
agrep -0 -c 'CTGACTCGCAGAATGTT' *.fastq > count/B676_Fm0.txt
agrep -0 -c 'GGTACACACGCAATGTT' *.fastq > count/B677_Fm0.txt
agrep -0 -c 'AGTGTACAACTCTACGG' *.fastq > count/B678_Fm0.txt
agrep -0 -c 'GCCATTCAGACCGAGTC' *.fastq > count/B679_Fm0.txt
agrep -0 -c 'TGAACTCAGTGCTATAG' *.fastq > count/B680_Fm0.txt
agrep -0 -c 'ATCATCCTACTGCAGGG' *.fastq > count/B682_Fm0.txt
agrep -0 -c 'CCGAACTCAACTGGTTG' *.fastq > count/B683_Fm0.txt
agrep -0 -c 'CATGGCGTGAGACGATC' *.fastq > count/B686_Fm0.txt
agrep -0 -c 'GGCGGCGATCGTAATTA' *.fastq > count/B687_Fm0.txt
agrep -0 -c 'AAGTGCTGCACTTGGGG' *.fastq > count/B688_Fm0.txt
agrep -0 -c 'TATTTGACCGACGCCCG' *.fastq > count/B689_Fm0.txt
agrep -0 -c 'TCAATTCCCTGATAAGC' *.fastq > count/B690_Fm0.txt
agrep -0 -c 'TTGCAAACAGGAGGTAC' *.fastq > count/B691_Fm0.txt
agrep -0 -c 'CTTCGTCCAATCCGCGA' *.fastq > count/B692_Fm0.txt
agrep -0 -c 'CCACCGTGAGTAATTAT' *.fastq > count/B693_Fm0.txt
agrep -0 -c 'GGAACGAGTAGCTCAGG' *.fastq > count/B694_Fm0.txt
agrep -0 -c 'ATGCCGATAAGTAGGTT' *.fastq > count/B695_Fm0.txt
agrep -0 -c 'ACACTGACACATCACGA' *.fastq > count/B696_Fm0.txt
agrep -0 -c 'CACGATCGATAGGTTCA' *.fastq > count/B698_Fm0.txt
agrep -0 -c 'GTTCAAGCTTTGGAGTG' *.fastq > count/B699_Fm0.txt
agrep -0 -c 'CACTCGCTGTGTACTAG' *.fastq > count/B701_Fm0.txt
agrep -0 -c 'GCTACGGAATACACTGT' *.fastq > count/B702_Fm0.txt
agrep -0 -c 'CAAACGAACGATAACCT' *.fastq > count/B704_Fm0.txt
agrep -0 -c 'GCTCTAAGGTAGAAGTC' *.fastq > count/B705_Fm0.txt
agrep -0 -c 'TAGGTAGCATGATGTGT' *.fastq > count/B706_Fm0.txt
agrep -0 -c 'GCTTATCGTCGAAACAT' *.fastq > count/B707_Fm0.txt
agrep -0 -c 'ATGCGTACTACCCTGGT' *.fastq > count/B708_Fm0.txt
agrep -0 -c 'AAGTCGATTCACGGGCC' *.fastq > count/B709_Fm0.txt
agrep -0 -c 'GCGCGCTTATATGGATA' *.fastq > count/B710_Fm0.txt
agrep -0 -c 'AAGGTCAAACACCGTGA' *.fastq > count/B711_Fm0.txt
agrep -0 -c 'GTCTATACGTCAGATCA' *.fastq > count/B712_Fm0.txt
agrep -0 -c 'GCCAGACCCAGGTGTAA' *.fastq > count/B715_Fm0.txt
agrep -0 -c 'GATCGCGATGCGAGCAA' *.fastq > count/B717_Fm0.txt
agrep -0 -c 'TGAATGTCTAGATCCCT' *.fastq > count/B718_Fm0.txt
agrep -0 -c 'AGGAGGGTCTATCGTTA' *.fastq > count/B719_Fm0.txt
agrep -0 -c 'CCTACAGGCAACAGGAC' *.fastq > count/B720_Fm0.txt
agrep -0 -c 'TAGTGCTATTTCCATCG' *.fastq > count/B721_Fm0.txt
agrep -0 -c 'TCTTCCGGTTGACTGAT' *.fastq > count/B722_Fm0.txt
agrep -0 -c 'CGCCGAACGGACTCTAT' *.fastq > count/B723_Fm0.txt
agrep -0 -c 'AGAGGAAGTTAGGTCCG' *.fastq > count/B724_Fm0.txt
agrep -0 -c 'ATATCCGCCAGACCAAT' *.fastq > count/B725_Fm0.txt
agrep -0 -c 'AAGTTCTCGACTGTCTT' *.fastq > count/B726_Fm0.txt
agrep -0 -c 'CTGCTTCGACGGATACA' *.fastq > count/B727_Fm0.txt
agrep -0 -c 'GTACGGTACTCATTTGT' *.fastq > count/B728_Fm0.txt
agrep -0 -c 'GTAGCTCTCGTCGGTGA' *.fastq > count/B729_Fm0.txt
agrep -0 -c 'CGCCGGGTTTACTCTCA' *.fastq > count/B730_Fm0.txt
agrep -0 -c 'AAGCTATACAGCTTCCT' *.fastq > count/B731_Fm0.txt
agrep -0 -c 'TAACTGTGAGGCCTTGC' *.fastq > count/B732_Fm0.txt
agrep -0 -c 'TCAAAACTACAGCGTTG' *.fastq > count/B733_Fm0.txt
agrep -0 -c 'GGTGGCTCGATTGATAC' *.fastq > count/B734_Fm0.txt
agrep -0 -c 'AATACCACCGACGCTAG' *.fastq > count/B735_Fm0.txt
agrep -0 -c 'GGTCTCCTGTTCGTAGT' *.fastq > count/B736_Fm0.txt
agrep -0 -c 'ACTTTTGTATCGCGCCC' *.fastq > count/B737_Fm0.txt
agrep -0 -c 'ACCTTTATGCCAAGTGG' *.fastq > count/B738_Fm0.txt
agrep -0 -c 'GGGTTACAGCACACAGT' *.fastq > count/B739_Fm0.txt
agrep -0 -c 'TGGCTAGGATTCGTCTG' *.fastq > count/B740_Fm0.txt
agrep -0 -c 'GTCAGTCAAATGCCAAC' *.fastq > count/B741_Fm0.txt
agrep -0 -c 'GCAGCTGTCTTATCAAT' *.fastq > count/B742_Fm0.txt
agrep -0 -c 'CTCAAAAGCAAGTTCTG' *.fastq > count/B743_Fm0.txt
agrep -0 -c 'CGCTCAAGCGGATGTTC' *.fastq > count/B744_Fm0.txt
agrep -0 -c 'GTGTTAACGAGGATGCT' *.fastq > count/B745_Fm0.txt
agrep -0 -c 'GTACCTGCCCGTAGTGT' *.fastq > count/B746_Fm0.txt
agrep -0 -c 'ACTGATAGGAAACAGCA' *.fastq > count/B747_Fm0.txt
agrep -0 -c 'ATTACCAGTACAGCGCC' *.fastq > count/B748_Fm0.txt
agrep -0 -c 'ACGCTCTACGTCAAGGC' *.fastq > count/B749_Fm0.txt
agrep -0 -c 'TTGGTATGCCCCCGATA' *.fastq > count/B750_Fm0.txt
agrep -0 -c 'TCTACGTGCCTCACGCT' *.fastq > count/B752_Fm0.txt
agrep -0 -c 'TGGAGCTGGGCCAAAGT' *.fastq > count/B753_Fm0.txt
agrep -0 -c 'GTTCTCCGCGTAGACAA' *.fastq > count/B754_Fm0.txt
agrep -0 -c 'ATCGTTGCCGGGGATGT' *.fastq > count/B755_Fm0.txt
agrep -0 -c 'ACGTCAAAGCTGCTCAC' *.fastq > count/B756_Fm0.txt
agrep -0 -c 'ATTCGGTGGTTACCGTA' *.fastq > count/B758_Fm0.txt
agrep -0 -c 'GTAGGCACTGTAAAGTA' *.fastq > count/B759_Fm0.txt
agrep -0 -c 'GGCTAATCGACGACAGG' *.fastq > count/B760_Fm0.txt
agrep -0 -c 'GCACGTAACTCTCCCTC' *.fastq > count/B761_Fm0.txt
agrep -0 -c 'TAAAACTCCTCGCGCTG' *.fastq > count/B762_Fm0.txt
agrep -0 -c 'GCGAAAATCTCGGCAAC' *.fastq > count/B763_Fm0.txt
agrep -0 -c 'GGGACGATTGCCTTTAC' *.fastq > count/B765_Fm0.txt
agrep -0 -c 'GATACTTCCTTCCTACC' *.fastq > count/B767_Fm0.txt
agrep -0 -c 'AGCCGCCGTGCTAGTAA' *.fastq > count/B768_Fm0.txt
agrep -0 -c 'TTCCGATTCTGCGGGCT' *.fastq > count/B769_Fm0.txt
agrep -0 -c 'TGCTCACATTGCAGCCC' *.fastq > count/B770_Fm0.txt
agrep -0 -c 'TGGAAATAAGTCCTACG' *.fastq > count/B771_Fm0.txt
agrep -0 -c 'ATTCGCAAGAATCACGC' *.fastq > count/B772_Fm0.txt
agrep -0 -c 'ACGATAAACACTACCCC' *.fastq > count/B773_Fm0.txt
agrep -0 -c 'ACTCTCGAGTACTTCAT' *.fastq > count/B774_Fm0.txt
agrep -0 -c 'AGGCCCGCATTACCTAT' *.fastq > count/B775_Fm0.txt
agrep -0 -c 'CTTGCGAGGACTGGTCA' *.fastq > count/B776_Fm0.txt
agrep -0 -c 'TTAGAGCCGGGATTACT' *.fastq > count/B777_Fm0.txt
agrep -0 -c 'TTCCGTCGGTCCGTAAG' *.fastq > count/B778_Fm0.txt
agrep -0 -c 'CCAAGTATCCTCGCTAG' *.fastq > count/B779_Fm0.txt
agrep -0 -c 'ATGGCTCGGGACTCCTT' *.fastq > count/B781_Fm0.txt
agrep -0 -c 'CTGGATCTTATAGTGCT' *.fastq > count/B782_Fm0.txt
agrep -0 -c 'CGATCTTGACCTCTCAC' *.fastq > count/B783_Fm0.txt
agrep -0 -c 'TAGCGATGACCCCGAAG' *.fastq > count/B784_Fm0.txt
agrep -0 -c 'CAATTCCAAGCCATGCT' *.fastq > count/B785_Fm0.txt
agrep -0 -c 'GTTATCGGCCTGGCGAT' *.fastq > count/B787_Fm0.txt
agrep -0 -c 'AACATCCGACCCACGGA' *.fastq > count/B788_Fm0.txt
agrep -0 -c 'CATCCGCACCAGCGTAA' *.fastq > count/B789_Fm0.txt
agrep -0 -c 'GTTAGGACGTGTCACAT' *.fastq > count/B790_Fm0.txt
agrep -0 -c 'ACTCACTAAAGGGCATT' *.fastq > count/B791_Fm0.txt
agrep -0 -c 'ATGGACGTAATGCGGAT' *.fastq > count/B792_Fm0.txt
agrep -0 -c 'GTCTGTTAAGCCTAGGC' *.fastq > count/B793_Fm0.txt
agrep -0 -c 'CTGGGTGCTTGCACGTT' *.fastq > count/B795_Fm0.txt
agrep -0 -c 'AGTTCGAACACCCGCTG' *.fastq > count/B800_Fm0.txt
agrep -0 -c 'TAGGGAGGGATTAGGAC' *.fastq > count/B801_Fm0.txt
agrep -0 -c 'TTAGTCAAGGCAAACGG' *.fastq > count/B802_Fm0.txt
agrep -0 -c 'CCTCACTAGTCGAGGTG' *.fastq > count/B804_Fm0.txt
agrep -0 -c 'TATGGCCATATGAGAGT' *.fastq > count/B806_Fm0.txt
agrep -0 -c 'GACTCCTGTTCGTTTCA' *.fastq > count/B807_Fm0.txt
agrep -0 -c 'GTCTTCGTTCTAGGAAC' *.fastq > count/B808_Fm0.txt
agrep -0 -c 'TTGCAACCGATGTATCG' *.fastq > count/B809_Fm0.txt
agrep -0 -c 'GGTGTGTTTCAGACGCT' *.fastq > count/B812_Fm0.txt
agrep -0 -c 'ACTCTTAATCCGTGCAC' *.fastq > count/B813_Fm0.txt
agrep -0 -c 'CACCTGCAGGTAACGAT' *.fastq > count/B814_Fm0.txt
agrep -0 -c 'CCTCTTGGAATCTGCGT' *.fastq > count/B815_Fm0.txt
agrep -0 -c 'TGATCATCGCAAATCGT' *.fastq > count/B816_Fm0.txt
agrep -0 -c 'TTATTGGCCAGCGTATG' *.fastq > count/B817_Fm0.txt
agrep -0 -c 'CAAAGACGCCTCGCAAT' *.fastq > count/B818_Fm0.txt
agrep -0 -c 'GGTTTGCGATAGCTCGA' *.fastq > count/B819_Fm0.txt
agrep -0 -c 'ACACTCGTTTCTACATG' *.fastq > count/B821_Fm0.txt
agrep -0 -c 'ACTAGTTGGCTAGCGAA' *.fastq > count/B822_Fm0.txt
agrep -0 -c 'TGACTCGATGGGGCTCT' *.fastq > count/B823_Fm0.txt
agrep -0 -c 'AAGTTCAATTCGGGTTC' *.fastq > count/B824_Fm0.txt
agrep -0 -c 'GTTTTTGTGGAGTTGCT' *.fastq > count/B825_Fm0.txt
agrep -0 -c 'CCTGATCCTTGGTATTG' *.fastq > count/B826_Fm0.txt
agrep -0 -c 'TGTGAAGCCACCGCTTC' *.fastq > count/B828_Fm0.txt
agrep -0 -c 'ATAGTGTGGTCGGTTCT' *.fastq > count/B829_Fm0.txt
agrep -0 -c 'AAGACAACCGTCGCCGT' *.fastq > count/B830_Fm0.txt
agrep -0 -c 'CCACGGAGTACGTAATG' *.fastq > count/B832_Fm0.txt
agrep -0 -c 'TCAATGCGTAACACTGA' *.fastq > count/B833_Fm0.txt
agrep -0 -c 'AGCTGCGTCATGTGCTA' *.fastq > count/B834_Fm0.txt
agrep -0 -c 'TGACCCAGGTAGCTATG' *.fastq > count/B836_Fm0.txt
agrep -0 -c 'AGCCCTGACTAATACGA' *.fastq > count/B837_Fm0.txt
agrep -0 -c 'TGATCACCAGTACCCAT' *.fastq > count/B838_Fm0.txt
agrep -0 -c 'CATAAGGGCAGAGCATG' *.fastq > count/B839_Fm0.txt
agrep -0 -c 'AGCAAGAGGCCGAAGGA' *.fastq > count/B840_Fm0.txt
agrep -0 -c 'GAGGGGTCGAAGATAAG' *.fastq > count/B841_Fm0.txt
agrep -0 -c 'AGACGAGCAGTGCAGAA' *.fastq > count/B842_Fm0.txt
agrep -0 -c 'GTCCAGTGGTAGAACTT' *.fastq > count/B843_Fm0.txt
agrep -0 -c 'GACATGGTGGCATAGTA' *.fastq > count/B846_Fm0.txt
agrep -0 -c 'GACACGACAGGGATCAA' *.fastq > count/B848_Fm0.txt
agrep -0 -c 'TGTAGGCGCCATCTAGC' *.fastq > count/B850_Fm0.txt
agrep -0 -c 'GCGGTGAGAAGTTAATC' *.fastq > count/B852_Fm0.txt
agrep -0 -c 'CGCAGCGCTGGGTATAA' *.fastq > count/B853_Fm0.txt
agrep -0 -c 'CATCGAACACGATCTAG' *.fastq > count/B854_Fm0.txt
agrep -0 -c 'GTTGTATGTTGCTCAGT' *.fastq > count/B855_Fm0.txt
agrep -0 -c 'ACCATCGACGACAGACG' *.fastq > count/B856_Fm0.txt
agrep -0 -c 'TAAACAGAAACGCCACC' *.fastq > count/B857_Fm0.txt
agrep -0 -c 'GATAGATCAATAGCGCT' *.fastq > count/B858_Fm0.txt
agrep -0 -c 'GTCGTGGTGCTCATGAA' *.fastq > count/B859_Fm0.txt
agrep -0 -c 'TGCTTCCAACTATGGAG' *.fastq > count/B860_Fm0.txt
agrep -0 -c 'TCGTTTCCTTCTTACAG' *.fastq > count/B861_Fm0.txt
agrep -0 -c 'CGTAGTACCTGCGAACT' *.fastq > count/B862_Fm0.txt
agrep -0 -c 'TTGACCCCCCATGGAAA' *.fastq > count/B863_Fm0.txt
agrep -0 -c 'CAGACGCTCCGTTAAGT' *.fastq > count/B864_Fm0.txt
agrep -0 -c 'GGGGTCCGACTATCTTA' *.fastq > count/B865_Fm0.txt
agrep -0 -c 'TCTGGAAGAGACAAGTT' *.fastq > count/B866_Fm0.txt
agrep -0 -c 'AGAATAAGCTTCGTCCA' *.fastq > count/B867_Fm0.txt
agrep -0 -c 'GTCCCTAAGCATAGTGG' *.fastq > count/B868_Fm0.txt
agrep -0 -c 'CAAGCCACAAACTACGT' *.fastq > count/B869_Fm0.txt
agrep -0 -c 'GTTCAAGCGCTAGGGAT' *.fastq > count/B870_Fm0.txt
agrep -0 -c 'AGACTTGCCCACCGGTA' *.fastq > count/B871_Fm0.txt
agrep -0 -c 'TGCGGGCGGTTTATACC' *.fastq > count/B872_Fm0.txt
agrep -0 -c 'CTATTATACTACGCGCT' *.fastq > count/B873_Fm0.txt
agrep -0 -c 'CCAACTCTTTAGCCCGC' *.fastq > count/B875_Fm0.txt
agrep -0 -c 'AGAAAGTCACTCCGGCA' *.fastq > count/B877_Fm0.txt
agrep -0 -c 'AGTAACCAGCATTAGCC' *.fastq > count/B880_Fm0.txt
agrep -0 -c 'TACGTCGAGAGCAGGAA' *.fastq > count/B881_Fm0.txt
agrep -0 -c 'AGTTTCCAAAATCGCCC' *.fastq > count/B882_Fm0.txt
agrep -0 -c 'TCGGACTGTCAGTACAG' *.fastq > count/B883_Fm0.txt
agrep -0 -c 'GTCCACTACCGTCTGTC' *.fastq > count/B884_Fm0.txt
agrep -0 -c 'CGATATACTGCAGGTAG' *.fastq > count/B885_Fm0.txt
agrep -0 -c 'TGCGCTAGCCTAAATAT' *.fastq > count/B886_Fm0.txt
agrep -0 -c 'CGACAACTTCACGCTGG' *.fastq > count/B887_Fm0.txt
agrep -0 -c 'TCGTACTTCGTCAGTTT' *.fastq > count/B888_Fm0.txt
agrep -0 -c 'CATTACGGCCGCGATGA' *.fastq > count/B889_Fm0.txt
agrep -0 -c 'CTGCTTGCCTGGTTGAA' *.fastq > count/B890_Fm0.txt
agrep -0 -c 'AATCTCAGCGGATCGAC' *.fastq > count/B891_Fm0.txt
agrep -0 -c 'CGTTACAGCCACAGCAC' *.fastq > count/B892_Fm0.txt
agrep -0 -c 'TTAATCTAGGGACGGCG' *.fastq > count/B893_Fm0.txt
agrep -0 -c 'CAGTATATCGCCATGTA' *.fastq > count/B894_Fm0.txt
agrep -0 -c 'GCGACCCTTCACGTTTG' *.fastq > count/B895_Fm0.txt
agrep -0 -c 'AACTGTTCAATGCCCAC' *.fastq > count/B896_Fm0.txt
agrep -0 -c 'TAGGGGTCGGCATTCAA' *.fastq > count/B897_Fm0.txt
agrep -0 -c 'GCAAAAGGCTCAGTCCG' *.fastq > count/B898_Fm0.txt
agrep -0 -c 'ATCGTAGTATCGCTGCC' *.fastq > count/B899_Fm0.txt
agrep -0 -c 'TAATACGTGCCGACAGT' *.fastq > count/B900_Fm0.txt
agrep -0 -c 'CGTGATATCGCCGGTAT' *.fastq > count/B901_Fm0.txt
agrep -0 -c 'TGCAAGTTGCAGGGTTA' *.fastq > count/B902_Fm0.txt
agrep -0 -c 'AGCCCAAATAGTTCTTC' *.fastq > count/B903_Fm0.txt
agrep -0 -c 'CCTGGCAGAAATTGGCT' *.fastq > count/B905_Fm0.txt
agrep -0 -c 'GTTACCCGGTTCTAACT' *.fastq > count/B906_Fm0.txt
agrep -0 -c 'GCAACTGAACACCACAG' *.fastq > count/B907_Fm0.txt
agrep -0 -c 'TCAGGAGAGAGCGCTTT' *.fastq > count/B908_Fm0.txt
agrep -0 -c 'TGCGTGTTAAGAGCGTC' *.fastq > count/B909_Fm0.txt
agrep -0 -c 'GATAGCAACGTTGCCGC' *.fastq > count/B910_Fm0.txt
agrep -0 -c 'TCTACCTTTGGGCCGGT' *.fastq > count/B911_Fm0.txt
agrep -0 -c 'ATTCACTTGATGGGCCC' *.fastq > count/B912_Fm0.txt
agrep -0 -c 'TCTGTACGTTTGGCCTG' *.fastq > count/B913_Fm0.txt
agrep -0 -c 'GGAATTCGGAGAAAGAG' *.fastq > count/B915_Fm0.txt
agrep -0 -c 'TGGAAGACACGAAGCTA' *.fastq > count/B916_Fm0.txt
agrep -0 -c 'CGATACGATACAAAGAG' *.fastq > count/B918_Fm0.txt
agrep -0 -c 'CTCCCCGTCAATCTCCT' *.fastq > count/B919_Fm0.txt
agrep -0 -c 'TACCAGGCTTATTACGC' *.fastq > count/B920_Fm0.txt
agrep -0 -c 'GACGCTTAGTCCAGCTA' *.fastq > count/B921_Fm0.txt
agrep -0 -c 'AGTCTCACATAACTTCG' *.fastq > count/B922_Fm0.txt
agrep -0 -c 'TTGGAGGATTTATGCCT' *.fastq > count/B923_Fm0.txt
agrep -0 -c 'GTTATAGAGGGTACTAC' *.fastq > count/B924_Fm0.txt
agrep -0 -c 'ATGGCCGTATATCGCGA' *.fastq > count/B925_Fm0.txt
agrep -0 -c 'ATCTGGACTGGATTGGT' *.fastq > count/B926_Fm0.txt
agrep -0 -c 'GGGCGCACCTTGTTTAA' *.fastq > count/B927_Fm0.txt
agrep -0 -c 'GACGCGTATACTTCAGT' *.fastq > count/B928_Fm0.txt
agrep -0 -c 'GCTGGAGGTAACTTATT' *.fastq > count/B929_Fm0.txt
agrep -0 -c 'TCGCTACGGCGTGTAGT' *.fastq > count/B930_Fm0.txt
agrep -0 -c 'TGTGGGCGTGACTTTGA' *.fastq > count/B932_Fm0.txt
agrep -0 -c 'ACCCAGTTGTTTGTGTT' *.fastq > count/B933_Fm0.txt
agrep -0 -c 'CGCATCCTAGTAGGTAA' *.fastq > count/B934_Fm0.txt
agrep -0 -c 'AACTATCTCAACCGTTC' *.fastq > count/B935_Fm0.txt
agrep -0 -c 'CGCTTGGAGACAAATGC' *.fastq > count/B936_Fm0.txt
agrep -0 -c 'CTTCCAAATGGCGCATA' *.fastq > count/B938_Fm0.txt
agrep -0 -c 'GAGTAACTGACGGAGAC' *.fastq > count/B939_Fm0.txt
agrep -0 -c 'ATTGCGCCAAATTGGAG' *.fastq > count/B941_Fm0.txt
agrep -0 -c 'TGCGCAAACACCTTGAA' *.fastq > count/B942_Fm0.txt
agrep -0 -c 'ATATAGAGAGAACAGCC' *.fastq > count/B943_Fm0.txt
agrep -0 -c 'TATGAAGGATAAGCCCG' *.fastq > count/B945_Fm0.txt
agrep -0 -c 'CCATGCACGGTTCCAGT' *.fastq > count/B947_Fm0.txt
agrep -0 -c 'TACTATGCTCCAACCCC' *.fastq > count/B948_Fm0.txt
agrep -0 -c 'ATCCCATGGGTTTTAAG' *.fastq > count/B949_Fm0.txt
agrep -0 -c 'GATAGCAATAGCGACGA' *.fastq > count/B950_Fm0.txt
agrep -0 -c 'CGCAAACACAAAACGAA' *.fastq > count/B951_Fm0.txt
agrep -0 -c 'CCTGCTCATGTAGTTAG' *.fastq > count/B952_Fm0.txt
agrep -0 -c 'CGTTTAGTGCATGCGTC' *.fastq > count/B953_Fm0.txt
agrep -0 -c 'TGGACGTAGCTGGGTAC' *.fastq > count/B954_Fm0.txt
agrep -0 -c 'AAGGACTATCTTTCACC' *.fastq > count/B955_Fm0.txt
agrep -0 -c 'GATAGCTTGGTACGATC' *.fastq > count/B956_Fm0.txt
agrep -0 -c 'GCGGATATGTTTGCATT' *.fastq > count/B957_Fm0.txt
agrep -0 -c 'AATCCAAAGATCACGCG' *.fastq > count/B958_Fm0.txt
agrep -0 -c 'AGGCACAAGTTAGAGGC' *.fastq > count/B960_Fm0.txt
agrep -0 -c 'GAGGAACCCATATCGCG' *.fastq > count/B961_Fm0.txt
agrep -0 -c 'GGACATCACGCGGAATA' *.fastq > count/B962_Fm0.txt
agrep -0 -c 'GTTAGTCCAATCTGTGA' *.fastq > count/B963_Fm0.txt
agrep -0 -c 'GCTGACGAAAGAACCAG' *.fastq > count/B964_Fm0.txt
agrep -0 -c 'ACCCAGGTAAGTTTGAC' *.fastq > count/B965_Fm0.txt
agrep -0 -c 'GGGTAATTTAAGGGCTG' *.fastq > count/B966_Fm0.txt
agrep -0 -c 'CTACCGGGAGCGTACTA' *.fastq > count/B969_Fm0.txt
agrep -0 -c 'AGACAAGGCCGGGATGA' *.fastq > count/B971_Fm0.txt
agrep -0 -c 'GTGAAGAATCTTCTAGC' *.fastq > count/B972_Fm0.txt
agrep -0 -c 'GCGTCATTGTTGACGAC' *.fastq > count/B973_Fm0.txt
agrep -0 -c 'CTGTAACGTGTCATAAG' *.fastq > count/B974_Fm0.txt
agrep -0 -c 'GATACGCGCTACTCATC' *.fastq > count/B976_Fm0.txt
agrep -0 -c 'ACTACAACTTCGGCTAA' *.fastq > count/B977_Fm0.txt
agrep -0 -c 'CCTAGACCGCAATACTG' *.fastq > count/B979_Fm0.txt
agrep -0 -c 'GCTGTGGTAAGCATCAC' *.fastq > count/B982_Fm0.txt
agrep -0 -c 'TCTGGGTTTTGCTATGA' *.fastq > count/B983_Fm0.txt
agrep -0 -c 'ACTCAGCAATGTCACGC' *.fastq > count/B985_Fm0.txt
agrep -0 -c 'CTAACTGACCCAACTCA' *.fastq > count/B986_Fm0.txt
agrep -0 -c 'TTCCGTTTAAACTGCCC' *.fastq > count/B987_Fm0.txt
agrep -0 -c 'TCGGTAACGGTGCTTTA' *.fastq > count/B988_Fm0.txt
agrep -0 -c 'AGACCATAAAAGATGGG' *.fastq > count/B990_Fm0.txt
agrep -0 -c 'AATGTTCGATGTGAGAG' *.fastq > count/B991_Fm0.txt
agrep -0 -c 'AACGTAAGGAGAACCAA' *.fastq > count/B992_Fm0.txt
agrep -0 -c 'CCAGTGCTCTGTCAAAA' *.fastq > count/B993_Fm0.txt
agrep -0 -c 'GGTTCAGCGCGAATCTT' *.fastq > count/B994_Fm0.txt
agrep -0 -c 'CTCTCCTGAAAGACGTT' *.fastq > count/B995_Fm0.txt
agrep -0 -c 'GTTATGGTCCCTTACCC' *.fastq > count/B996_Fm0.txt
agrep -0 -c 'GTTGGAGTGTGAAGCAC' *.fastq > count/B997_Fm0.txt
agrep -0 -c 'TCTGCTTCGGACCAACA' *.fastq > count/B998_Fm0.txt
agrep -0 -c 'AGTTGGCGGGCTGTTTT' *.fastq > count/B999_Fm0.txt
agrep -0 -c 'CTGCTTTTATGACTGCT' *.fastq > count/B1000_Fm0.txt
agrep -0 -c 'CGGCCTAACGGGTTGAT' *.fastq > count/B1001_Fm0.txt
agrep -0 -c 'AATAGAGAAGGCCGTTG' *.fastq > count/B1002_Fm0.txt
agrep -0 -c 'CAAACAAGGGACACAAC' *.fastq > count/B1003_Fm0.txt
agrep -0 -c 'CTTCTGCACAGAACGTT' *.fastq > count/B1004_Fm0.txt
agrep -0 -c 'CTTAACCGACCGTTTCC' *.fastq > count/B1005_Fm0.txt
agrep -0 -c 'TGCCTAGCTAAGACTGG' *.fastq > count/B1006_Fm0.txt
agrep -0 -c 'CTCGGGCTCTGTTATGG' *.fastq > count/B1007_Fm0.txt
agrep -0 -c 'GCTCCCATATATGTGTT' *.fastq > count/B1010_Fm0.txt
agrep -0 -c 'GCCTAAGATCGTCGACA' *.fastq > count/B1012_Fm0.txt
agrep -0 -c 'CACCTTGAGTAATGAAC' *.fastq > count/B1013_Fm0.txt
agrep -0 -c 'ACTATCCGCCGTAACGC' *.fastq > count/B1014_Fm0.txt
agrep -0 -c 'AGCCCTGGTCCGGAATA' *.fastq > count/B1015_Fm0.txt
agrep -0 -c 'ATGGTTGCTCGCTTTTT' *.fastq > count/B1016_Fm0.txt
agrep -0 -c 'CTCGTATTTGAACTCTG' *.fastq > count/B1017_Fm0.txt
agrep -0 -c 'CAATCCTACGATCATGA' *.fastq > count/B1018_Fm0.txt
agrep -0 -c 'CAACTGTGTCAAACAGA' *.fastq > count/B1019_Fm0.txt
agrep -0 -c 'AAGACCGTGCACTACAG' *.fastq > count/B1020_Fm0.txt
agrep -0 -c 'CGCTTGGGTCCACCATA' *.fastq > count/B1023_Fm0.txt
agrep -0 -c 'ACTGGATCAAGCTCAGG' *.fastq > count/B1024_Fm0.txt
agrep -0 -c 'ATATGTGCACCGACAAG' *.fastq > count/B1025_Fm0.txt
agrep -0 -c 'TAGTCGTCCAGTTCGAT' *.fastq > count/B1026_Fm0.txt
agrep -0 -c 'TTCGGTCTTTTCGCTTG' *.fastq > count/B1027_Fm0.txt
agrep -0 -c 'CTCAAACCAAGTCCCTT' *.fastq > count/B1028_Fm0.txt
agrep -0 -c 'CACTACGTATCGAAGAC' *.fastq > count/B1029_Fm0.txt
agrep -0 -c 'GTGTATAGAGGGATGAC' *.fastq > count/B1032_Fm0.txt
agrep -0 -c 'GTCCTACTCCAGCCGTT' *.fastq > count/B1033_Fm0.txt
agrep -0 -c 'CTTCGTGCGCAAGAGTA' *.fastq > count/B1034_Fm0.txt
agrep -0 -c 'CAAGCATCAGTAGACCA' *.fastq > count/B1035_Fm0.txt
agrep -0 -c 'TGTGAACGAAGCAGATT' *.fastq > count/B1036_Fm0.txt
agrep -0 -c 'ATCGTCCTCGTTTGCAA' *.fastq > count/B1037_Fm0.txt
agrep -0 -c 'CACTGACGACATTGGCG' *.fastq > count/B1038_Fm0.txt
agrep -0 -c 'CACCTAATAACATGGGG' *.fastq > count/B1039_Fm0.txt
agrep -0 -c 'AGTTGTTAACGCCCAAC' *.fastq > count/B1040_Fm0.txt
agrep -0 -c 'TGCTAGCGATCCATGGA' *.fastq > count/B1041_Fm0.txt
agrep -0 -c 'CGTGCCGAGTATATATG' *.fastq > count/B1042_Fm0.txt
agrep -0 -c 'CGTTTCGCTCTAGATGA' *.fastq > count/B1045_Fm0.txt
agrep -0 -c 'AATACTACACAGTCAGG' *.fastq > count/B1046_Fm0.txt
agrep -0 -c 'GGCCTTCCACGCAATTT' *.fastq > count/B1047_Fm0.txt
agrep -0 -c 'GACGTAGTCGTGTTCTT' *.fastq > count/B1048_Fm0.txt
agrep -0 -c 'GTGCACTATCAAACGGG' *.fastq > count/B1049_Fm0.txt
agrep -0 -c 'CCTGAACATGACTGGGG' *.fastq > count/B1050_Fm0.txt
agrep -0 -c 'TCACCAGTAATTGTGCT' *.fastq > count/B1051_Fm0.txt
agrep -0 -c 'CGCCAATATAGATCGAT' *.fastq > count/B1052_Fm0.txt
agrep -0 -c 'GTGAGGCTAATCACGAG' *.fastq > count/B1054_Fm0.txt
agrep -0 -c 'CAGTTGAGGAGGTTCGC' *.fastq > count/B1056_Fm0.txt
agrep -0 -c 'ACCGTCGCTAACTATGT' *.fastq > count/B1057_Fm0.txt
agrep -0 -c 'GACATACACAGGACGGC' *.fastq > count/B1059_Fm0.txt
agrep -0 -c 'TACATATCTAGCCGCAA' *.fastq > count/B1061_Fm0.txt
agrep -0 -c 'TGGAAGCCAGTCCGCAA' *.fastq > count/B1062_Fm0.txt
agrep -0 -c 'CATACTACTCCCGCAAA' *.fastq > count/B1063_Fm0.txt
agrep -0 -c 'ACTACTCTCTTATGCGC' *.fastq > count/B1066_Fm0.txt
agrep -0 -c 'ACAACGAATGTCAAGCT' *.fastq > count/B1067_Fm0.txt
agrep -0 -c 'CCGTACAGGAAGGTTGC' *.fastq > count/B1068_Fm0.txt
agrep -0 -c 'GCCAGGAGTCCTATAAG' *.fastq > count/B1069_Fm0.txt
agrep -0 -c 'ATTGTTCCATGGTGCTT' *.fastq > count/B1070_Fm0.txt
agrep -0 -c 'TGCAACGATGGGTTAGC' *.fastq > count/B1071_Fm0.txt
agrep -0 -c 'GTTCCCGATATGACAGT' *.fastq > count/B1072_Fm0.txt
agrep -0 -c 'ATGGTATCCAGAAGGTA' *.fastq > count/B1074_Fm0.txt
agrep -0 -c 'ACCGCGGAAACAAATTT' *.fastq > count/B1075_Fm0.txt
agrep -0 -c 'GGCATATGTCTACACCT' *.fastq > count/B1076_Fm0.txt
agrep -0 -c 'TCGCCTAAATCATGCTC' *.fastq > count/B1078_Fm0.txt
agrep -0 -c 'GACCAACCGAACCATTT' *.fastq > count/B1080_Fm0.txt
agrep -0 -c 'GGCCATTGGCGTCTCTA' *.fastq > count/B1082_Fm0.txt
agrep -0 -c 'GTAAAGGACCTATGATC' *.fastq > count/B1083_Fm0.txt
agrep -0 -c 'ACCGAGGGCATCTCTAT' *.fastq > count/B1084_Fm0.txt
agrep -0 -c 'TTGACGAGGAGAATTCT' *.fastq > count/B1086_Fm0.txt
agrep -0 -c 'GCTGTGGCGTATTCGAA' *.fastq > count/B1087_Fm0.txt
agrep -0 -c 'TGACGCCAAGACAGGTA' *.fastq > count/B1088_Fm0.txt
agrep -0 -c 'TACTGAGCCGCCAGTTC' *.fastq > count/B1089_Fm0.txt
agrep -0 -c 'TGCGTGTCCGTTTGTAT' *.fastq > count/B1090_Fm0.txt
agrep -0 -c 'AGGGTAATCGCAAAGAC' *.fastq > count/B1092_Fm0.txt
agrep -0 -c 'CACGAATATGCGGCCTT' *.fastq > count/B1093_Fm0.txt
agrep -0 -c 'TTACATGGCATGATCGA' *.fastq > count/B1094_Fm0.txt
agrep -0 -c 'CGTAGTTGAACCTCTCC' *.fastq > count/B1095_Fm0.txt
agrep -0 -c 'TATTAGACCGGCGCTGT' *.fastq > count/B1097_Fm0.txt
agrep -0 -c 'GCGCTCGTTCGATTCTG' *.fastq > count/B1098_Fm0.txt
agrep -0 -c 'ATTATGGCGGAAACCAT' *.fastq > count/B1099_Fm0.txt
agrep -0 -c 'CTGGCTGTATGACGACG' *.fastq > count/B1102_Fm0.txt
agrep -0 -c 'CATCATAGTCAGTACTC' *.fastq > count/B1103_Fm0.txt
agrep -0 -c 'AACAATAGAGCAACGTC' *.fastq > count/B1104_Fm0.txt
agrep -0 -c 'TAATTTTCCCCTCCGCG' *.fastq > count/B1105_Fm0.txt
agrep -0 -c 'TGGAGTATTCAGGGAAG' *.fastq > count/B1106_Fm0.txt
agrep -0 -c 'AACCCCTGCGCTATGCA' *.fastq > count/B1107_Fm0.txt
agrep -0 -c 'GGAGAAGGCTATGGGTG' *.fastq > count/B1109_Fm0.txt
agrep -0 -c 'TATGCAGGGCGCGGAAT' *.fastq > count/B1111_Fm0.txt
agrep -0 -c 'CGGCAATTATGACCCAC' *.fastq > count/B1112_Fm0.txt
agrep -0 -c 'GCCATGTTTCATTACGC' *.fastq > count/B1113_Fm0.txt
agrep -0 -c 'AGTGCCCAAATCATCTG' *.fastq > count/B1114_Fm0.txt
agrep -0 -c 'TGCACTATCAGGGGTGC' *.fastq > count/B1116_Fm0.txt
agrep -0 -c 'AGGACAGCCACTAATTT' *.fastq > count/B1121_Fm0.txt
agrep -0 -c 'TTAGGCCGCCTAGGACT' *.fastq > count/B1122_Fm0.txt
agrep -0 -c 'GGAACAGATATTACGCT' *.fastq > count/B1123_Fm0.txt
agrep -0 -c 'CTGTTTACCCCCGAAAC' *.fastq > count/B1124_Fm0.txt
agrep -0 -c 'TAGCGACTCCGTTCAAA' *.fastq > count/B1125_Fm0.txt
agrep -0 -c 'TTGTGAGAACATCTACG' *.fastq > count/B1126_Fm0.txt
agrep -0 -c 'TCGAGTCGGTAAGACAA' *.fastq > count/B1127_Fm0.txt
agrep -0 -c 'GTGCCATCGCTACTTGA' *.fastq > count/B1129_Fm0.txt
agrep -0 -c 'TGGACGCGAACCGTTGA' *.fastq > count/B1130_Fm0.txt
agrep -0 -c 'GATAACGGCTGTTACAC' *.fastq > count/B1131_Fm0.txt
agrep -0 -c 'CGCTAGGTTCCATAGAA' *.fastq > count/B1132_Fm0.txt
agrep -0 -c 'CAGCCCTCAGGTTCGTT' *.fastq > count/B1135_Fm0.txt
agrep -0 -c 'ATATAGGGTCGACTGGG' *.fastq > count/B1137_Fm0.txt
agrep -0 -c 'TGCGTGAGCGATCTGTG' *.fastq > count/B1138_Fm0.txt
agrep -0 -c 'CCGGTTAATCACAACAT' *.fastq > count/B1139_Fm0.txt
agrep -0 -c 'CCATAAGATCGGCTTCC' *.fastq > count/B1140_Fm0.txt
agrep -0 -c 'TTACCATTGTCGCGATG' *.fastq > count/B1143_Fm0.txt
agrep -0 -c 'TATTTCCCGTCTCACAT' *.fastq > count/B1145_Fm0.txt
agrep -0 -c 'AGTTCACCCCCTTTGCT' *.fastq > count/B1146_Fm0.txt
agrep -0 -c 'ATCGTATGCCCCTGAAG' *.fastq > count/B1148_Fm0.txt
agrep -0 -c 'GGCCATAGAGGGCCTTT' *.fastq > count/B1149_Fm0.txt
agrep -0 -c 'TAGCAGTCCTCGGTTCG' *.fastq > count/B1150_Fm0.txt
agrep -0 -c 'ATCTATTACGGGGCTTA' *.fastq > count/B1151_Fm0.txt
agrep -0 -c 'AGAAGCTTAAGTCAAGC' *.fastq > count/B1152_Fm0.txt
agrep -0 -c 'GCGACTTTATGCTGACT' *.fastq > count/B1153_Fm0.txt
agrep -0 -c 'AGCTAAGGACGAAGGCC' *.fastq > count/B1154_Fm0.txt
agrep -0 -c 'CTAGGTGTTCAGTTCGT' *.fastq > count/B1155_Fm0.txt
agrep -0 -c 'CACGTAGGGCTCGAAAA' *.fastq > count/B1156_Fm0.txt
agrep -0 -c 'ATACAGACTATAGCGAC' *.fastq > count/B1158_Fm0.txt
agrep -0 -c 'CTCCCGGTAGGGTTAGA' *.fastq > count/B1159_Fm0.txt
agrep -0 -c 'TAATACATACGAGGGCC' *.fastq > count/B1160_Fm0.txt
agrep -0 -c 'TCGTAGACGATGGTTAT' *.fastq > count/B1161_Fm0.txt
agrep -0 -c 'CAACTTCCATTATCCTC' *.fastq > count/B1162_Fm0.txt
agrep -0 -c 'CAGATGTTCATAGTGGT' *.fastq > count/B1163_Fm0.txt
agrep -0 -c 'GAGACATGACTGCCCAT' *.fastq > count/B1164_Fm0.txt
agrep -0 -c 'ACGGGGGACATCCAAAC' *.fastq > count/B1165_Fm0.txt
agrep -0 -c 'AGCATGATGGCTGTTGC' *.fastq > count/B1167_Fm0.txt
agrep -0 -c 'ACCATGTAGACGCGCCT' *.fastq > count/B1168_Fm0.txt
agrep -0 -c 'GTTAGCGTGATCTTGTC' *.fastq > count/B1169_Fm0.txt
agrep -0 -c 'CTACGAACTATGGGAAG' *.fastq > count/B1170_Fm0.txt
agrep -0 -c 'TACTAAACTGCCCTTGA' *.fastq > count/B1171_Fm0.txt
agrep -0 -c 'CTCTCTGAACGCCTAAA' *.fastq > count/B1172_Fm0.txt
agrep -0 -c 'GCCACAGCGATTCTTAA' *.fastq > count/B1174_Fm0.txt
agrep -0 -c 'GCGTCTAGTCGTGATCT' *.fastq > count/B1175_Fm0.txt
agrep -0 -c 'GTCAAGAGAACCACAAT' *.fastq > count/B1176_Fm0.txt
agrep -0 -c 'AGACGGCACGCAGTTTG' *.fastq > count/B1177_Fm0.txt
agrep -0 -c 'CGCGGATGTCAAGCATT' *.fastq > count/B1178_Fm0.txt
agrep -0 -c 'GGACCATAAATCTCGCG' *.fastq > count/B1180_Fm0.txt
agrep -0 -c 'AAGTGCTCCTCCCCTAC' *.fastq > count/B1181_Fm0.txt
agrep -0 -c 'CATCTCCTATCCCTTAC' *.fastq > count/B1183_Fm0.txt
agrep -0 -c 'CATGATTCAAGCTTACC' *.fastq > count/B1184_Fm0.txt
agrep -0 -c 'TATCAGCGTACGAGAGG' *.fastq > count/B1185_Fm0.txt
agrep -0 -c 'CATAGAGCCGATACGGC' *.fastq > count/B1187_Fm0.txt
agrep -0 -c 'TCGAGCCTTGGTTAGCG' *.fastq > count/B1188_Fm0.txt
agrep -0 -c 'CAGTCTATCCGGCTGTG' *.fastq > count/B1189_Fm0.txt
agrep -0 -c 'AGTCAGTCGTGTCCGCA' *.fastq > count/B1190_Fm0.txt
agrep -0 -c 'CCATTATTCAGTGCCAG' *.fastq > count/B1192_Fm0.txt
agrep -0 -c 'CGGCTTGTGGGAACAGA' *.fastq > count/B1193_Fm0.txt
agrep -0 -c 'CGGTGCTTTGCTAAGGT' *.fastq > count/B1195_Fm0.txt
agrep -0 -c 'GATAGGGGCGGTTGAAA' *.fastq > count/B1198_Fm0.txt
agrep -0 -c 'CAATCGTTCCTGGGTGA' *.fastq > count/B1199_Fm0.txt
agrep -0 -c 'ACGTTCTGTCGCAACAG' *.fastq > count/B1203_Fm0.txt
agrep -0 -c 'GATTAGAACACGGGAAG' *.fastq > count/B1204_Fm0.txt
agrep -0 -c 'GCTGCGATCCAGAATAC' *.fastq > count/B1206_Fm0.txt
agrep -0 -c 'CACCTAGCGACCTGTGA' *.fastq > count/B1207_Fm0.txt
agrep -0 -c 'TGTTCATACAGTGTGCC' *.fastq > count/B1208_Fm0.txt
agrep -0 -c 'CTTAACCTCCGCCATTA' *.fastq > count/B1211_Fm0.txt
agrep -0 -c 'ATTCCTTTATTACGGCC' *.fastq > count/B1212_Fm0.txt
agrep -0 -c 'TGACACGACCTGAATGA' *.fastq > count/B1213_Fm0.txt
agrep -0 -c 'ACGTTGTAAAATCGGCA' *.fastq > count/B1214_Fm0.txt
agrep -0 -c 'CGCCGAGTATACCTCTT' *.fastq > count/B1216_Fm0.txt
agrep -0 -c 'GATACGAGCTAGAAACC' *.fastq > count/B1217_Fm0.txt
agrep -0 -c 'GTTACAAGACGGTCCTG' *.fastq > count/B1218_Fm0.txt
agrep -0 -c 'AATCGTCTACGCCATAA' *.fastq > count/B1219_Fm0.txt
agrep -0 -c 'ATGACGTGGTGAATGTG' *.fastq > count/B1222_Fm0.txt
agrep -0 -c 'AGGACAAATGCAGACGT' *.fastq > count/B1223_Fm0.txt
agrep -0 -c 'CGTGGAAGACTATCCTC' *.fastq > count/B1224_Fm0.txt
agrep -0 -c 'ACTCTCTCTCGAATCAT' *.fastq > count/B1225_Fm0.txt
agrep -0 -c 'CTAAGCTATACCGAAGC' *.fastq > count/B1226_Fm0.txt
agrep -0 -c 'ATCTGAGGGCACAGACT' *.fastq > count/B1227_Fm0.txt
agrep -0 -c 'AACAAGTGTCAGTACTC' *.fastq > count/B1231_Fm0.txt
agrep -0 -c 'AGCGAAGAGCATATGGG' *.fastq > count/B1232_Fm0.txt
agrep -0 -c 'AGGGCATACGCCGAACA' *.fastq > count/B1233_Fm0.txt
agrep -0 -c 'AGTATTCAGTCGCATAC' *.fastq > count/B1234_Fm0.txt
agrep -0 -c 'CCTATGTGTCAAGTTGT' *.fastq > count/B1235_Fm0.txt
agrep -0 -c 'AATAAGCGACCTCTCTT' *.fastq > count/B1237_Fm0.txt
agrep -0 -c 'CAGCTCGTTGTACGTCT' *.fastq > count/B1238_Fm0.txt
agrep -0 -c 'GCCAACGAATCTCCTTA' *.fastq > count/B1239_Fm0.txt
agrep -0 -c 'TAACGGCACAGGGATGG' *.fastq > count/B1240_Fm0.txt
agrep -0 -c 'ATGCGACCATACTGTGT' *.fastq > count/B1241_Fm0.txt
agrep -0 -c 'ACGGGATTGAGTACCTG' *.fastq > count/B1243_Fm0.txt
agrep -0 -c 'ATCTGGGGGGAGTCCTA' *.fastq > count/B1244_Fm0.txt
agrep -0 -c 'GGGATCTCACGTAGAAG' *.fastq > count/B1245_Fm0.txt
agrep -0 -c 'AATCGGAGCCTGCGCAT' *.fastq > count/B1246_Fm0.txt
agrep -0 -c 'GCACCTTAGCGATCGAC' *.fastq > count/B1247_Fm0.txt
agrep -0 -c 'TCGGTTACGAACTGATA' *.fastq > count/B1248_Fm0.txt
agrep -0 -c 'GCTTCAACTCGTGGAAC' *.fastq > count/B1250_Fm0.txt
agrep -0 -c 'TAAGTGCTAAGTTCCCT' *.fastq > count/B1251_Fm0.txt
agrep -0 -c 'ATGGTCAAAACTGGGAG' *.fastq > count/B1252_Fm0.txt
agrep -0 -c 'TTCCGTCACTGAGTCGC' *.fastq > count/B1253_Fm0.txt
agrep -0 -c 'CCTCATATAGGATCGGA' *.fastq > count/B1254_Fm0.txt
agrep -0 -c 'ATAGTGGTTGACTCACC' *.fastq > count/B1255_Fm0.txt
agrep -0 -c 'CAGGAACTTCTGCGAGT' *.fastq > count/B1256_Fm0.txt
agrep -0 -c 'GACGGTTTCTGGCATAA' *.fastq > count/B1257_Fm0.txt
agrep -0 -c 'CACTTGTGGTACGTAGC' *.fastq > count/B1258_Fm0.txt
agrep -0 -c 'TAAAGTCGCCGATCAAC' *.fastq > count/B1259_Fm0.txt
agrep -0 -c 'CTCCGATTTGAAATGGA' *.fastq > count/B1260_Fm0.txt
agrep -0 -c 'CACTGCATGGGAGTTAG' *.fastq > count/B1261_Fm0.txt
agrep -0 -c 'ACAGATGCAATCGCTTA' *.fastq > count/B1263_Fm0.txt
agrep -0 -c 'GGGGGTAGAAGTTCAGG' *.fastq > count/B1264_Fm0.txt
agrep -0 -c 'GTCAGATATGTGCCATT' *.fastq > count/B1266_Fm0.txt
agrep -0 -c 'GGTGATAGGCCAGCATG' *.fastq > count/B1267_Fm0.txt
agrep -0 -c 'ACTCTGTTCCGGTCCGT' *.fastq > count/B1268_Fm0.txt
agrep -0 -c 'CACTCACCGTTGACCAT' *.fastq > count/B1270_Fm0.txt
agrep -0 -c 'TGATGTTGGGACGTAAG' *.fastq > count/B1272_Fm0.txt
agrep -0 -c 'CGGTAATGCAGTGGTTT' *.fastq > count/B1273_Fm0.txt
agrep -0 -c 'CGAGCAAACCTATATCA' *.fastq > count/B1274_Fm0.txt
agrep -0 -c 'CTAGTACGCTCGTTCAC' *.fastq > count/B1275_Fm0.txt
agrep -0 -c 'CAACTACAGCATTTACG' *.fastq > count/B1277_Fm0.txt
agrep -0 -c 'TATCACCAAGAGTGACC' *.fastq > count/B1278_Fm0.txt
agrep -0 -c 'GTGGGTAAAATTCCGAA' *.fastq > count/B1280_Fm0.txt
agrep -0 -c 'TGCGAGGGGAGATTATG' *.fastq > count/B1281_Fm0.txt
agrep -0 -c 'AGGAACTTGACGATAGA' *.fastq > count/B1283_Fm0.txt
agrep -0 -c 'TGTTGGAATTGGATGCA' *.fastq > count/B1284_Fm0.txt
agrep -0 -c 'TACACGAGATGCATATC' *.fastq > count/B1285_Fm0.txt
agrep -0 -c 'GAGATACTCGAGTTACA' *.fastq > count/B1286_Fm0.txt
agrep -0 -c 'GCGACTAACCAGGTCAA' *.fastq > count/B1287_Fm0.txt
agrep -0 -c 'TATCTACCCCATCCTCC' *.fastq > count/B1288_Fm0.txt
agrep -0 -c 'CTCTTGGCTTGTTCGGT' *.fastq > count/B1289_Fm0.txt
agrep -0 -c 'GCGTTGTCACCCCTTTA' *.fastq > count/B1290_Fm0.txt
agrep -0 -c 'CTGGATAACGCATTAGT' *.fastq > count/B1291_Fm0.txt
agrep -0 -c 'TACCGTGCATTCCACCT' *.fastq > count/B1292_Fm0.txt
agrep -0 -c 'CTCCTCGTCATGACACA' *.fastq > count/B1293_Fm0.txt
agrep -0 -c 'TTGAACAGGCCGAATCT' *.fastq > count/B1294_Fm0.txt
agrep -0 -c 'TTAAAAGCCCGTTACCT' *.fastq > count/B1295_Fm0.txt
agrep -0 -c 'TTGTCTACTTCAGGGCG' *.fastq > count/B1296_Fm0.txt
agrep -0 -c 'CGTTATATCGTAGGGTT' *.fastq > count/B1297_Fm0.txt
agrep -0 -c 'CTGCGTTCACGTGGCTA' *.fastq > count/B1298_Fm0.txt
agrep -0 -c 'GGTTAGGGCATACTTAC' *.fastq > count/B1299_Fm0.txt
agrep -0 -c 'CCTACAATTTGATACGG' *.fastq > count/B1300_Fm0.txt
agrep -0 -c 'AGGATAACCCAAAGCCA' *.fastq > count/B1301_Fm0.txt
agrep -0 -c 'TGCAGATTCCCGCCAGA' *.fastq > count/B1302_Fm0.txt
agrep -0 -c 'GATGAGTCGTCTCAGAA' *.fastq > count/B1303_Fm0.txt
agrep -0 -c 'CTAGCCTGTTTTTGCAG' *.fastq > count/B1305_Fm0.txt
agrep -0 -c 'TCGTGTCATTGTCCACT' *.fastq > count/B1306_Fm0.txt
agrep -0 -c 'GCGACATCTCATTACTC' *.fastq > count/B1307_Fm0.txt
agrep -0 -c 'GTGATAGGGCACACACT' *.fastq > count/B1308_Fm0.txt
agrep -0 -c 'GTAGAGAGATCGAGTCA' *.fastq > count/B1309_Fm0.txt
agrep -0 -c 'ACGATATAAGTCGACCC' *.fastq > count/B1310_Fm0.txt
agrep -0 -c 'CACACATTCGAAAGGCA' *.fastq > count/B1311_Fm0.txt
agrep -0 -c 'TGACCCATTCGAATAGC' *.fastq > count/B1312_Fm0.txt
agrep -0 -c 'ACGGGAAAGTGTAACTA' *.fastq > count/B1314_Fm0.txt
agrep -0 -c 'GCTAGGGAGCAGTTGGT' *.fastq > count/B1315_Fm0.txt
agrep -0 -c 'CAGCGTATGTTGAACTT' *.fastq > count/B1316_Fm0.txt
agrep -0 -c 'TAAGATAATCGCTCGGC' *.fastq > count/B1317_Fm0.txt
agrep -0 -c 'ACTATCGGATTGTACAG' *.fastq > count/B1319_Fm0.txt
agrep -0 -c 'TATTTGCACGGCTCCCA' *.fastq > count/B1321_Fm0.txt
agrep -0 -c 'TTATACGTCTGTTCGAG' *.fastq > count/B1322_Fm0.txt
agrep -0 -c 'CAATCCTCATGTCCCCC' *.fastq > count/B1323_Fm0.txt
agrep -0 -c 'AAGTGGTGCTGAAGGCC' *.fastq > count/B1324_Fm0.txt
agrep -0 -c 'ATGTGTCCTCATGGGGG' *.fastq > count/B1325_Fm0.txt
agrep -0 -c 'TGCATCCCGCATAGAGG' *.fastq > count/B1326_Fm0.txt
agrep -0 -c 'ATACGCTGGACCAGCGT' *.fastq > count/B1327_Fm0.txt
agrep -0 -c 'CGCAAGCATATAGACGT' *.fastq > count/B1328_Fm0.txt
agrep -0 -c 'AATCTAAGCGCCCAGGA' *.fastq > count/B1329_Fm0.txt
agrep -0 -c 'TGCTTTAACTTGGTTCC' *.fastq > count/B1330_Fm0.txt
agrep -0 -c 'CGTCTCTTTAAACGCGG' *.fastq > count/B1332_Fm0.txt
agrep -0 -c 'ACATCGCCAATCCTAAA' *.fastq > count/B1333_Fm0.txt
agrep -0 -c 'CTGTAATACGACAACGA' *.fastq > count/B1336_Fm0.txt
agrep -0 -c 'TGTACCCGAATCACAAC' *.fastq > count/B1338_Fm0.txt
agrep -0 -c 'AAGTAGTCCGGTTGATA' *.fastq > count/B1339_Fm0.txt
agrep -0 -c 'ACCGATCAAGCAGCCTC' *.fastq > count/B1340_Fm0.txt
agrep -0 -c 'CAACGATCGTCTATATC' *.fastq > count/B1342_Fm0.txt
agrep -0 -c 'ACCAGCCACTTAACCCT' *.fastq > count/B1343_Fm0.txt
agrep -0 -c 'CGCACAGAATCAAGAAC' *.fastq > count/B1344_Fm0.txt
agrep -0 -c 'TTAGATTAGCCCCCTTT' *.fastq > count/B1345_Fm0.txt
agrep -0 -c 'TATGTGGGGAAAACTCG' *.fastq > count/B1346_Fm0.txt
agrep -0 -c 'TGACATTCGACTTTGAC' *.fastq > count/B1347_Fm0.txt
agrep -0 -c 'CTCTCAACTCCTACTCG' *.fastq > count/B1348_Fm0.txt
agrep -0 -c 'ACCTATCACAGGTCTAT' *.fastq > count/B1349_Fm0.txt
agrep -0 -c 'ATGCTCGGTGCGTTTAT' *.fastq > count/B1350_Fm0.txt
agrep -0 -c 'GGTCGCGAACTGGACAT' *.fastq > count/B1351_Fm0.txt
agrep -0 -c 'AGGGACGTTAACTTCAG' *.fastq > count/B1352_Fm0.txt
agrep -0 -c 'AAGCGATTAGGCCCAGT' *.fastq > count/B1353_Fm0.txt
agrep -0 -c 'TACAAATCATGGCCTCC' *.fastq > count/B1355_Fm0.txt
agrep -0 -c 'CGCAAACTATATCGTGG' *.fastq > count/B1357_Fm0.txt
agrep -0 -c 'TGGCCGCTGAGTAGAAT' *.fastq > count/B1358_Fm0.txt
agrep -0 -c 'CACACAGGGTTAAGCTG' *.fastq > count/B1359_Fm0.txt
agrep -0 -c 'CCTCCTTATAGCAGGCC' *.fastq > count/B1361_Fm0.txt
agrep -0 -c 'TAGTGGCGGATCAGACA' *.fastq > count/B1362_Fm0.txt
agrep -0 -c 'CGTAATACGGGGATACG' *.fastq > count/B1363_Fm0.txt
agrep -0 -c 'ACGGCATGTTCTTATGG' *.fastq > count/B1365_Fm0.txt
agrep -0 -c 'AGGCACGTCAGAAACTG' *.fastq > count/B1366_Fm0.txt
agrep -0 -c 'CGCTGAGATTGCGACTC' *.fastq > count/B1367_Fm0.txt
agrep -0 -c 'TCGACGAGGACAGAGTG' *.fastq > count/B1368_Fm0.txt
agrep -0 -c 'CGGTTATCACTTTTGAG' *.fastq > count/B1369_Fm0.txt
agrep -0 -c 'AGGACCAAGGAGCTGAT' *.fastq > count/B1370_Fm0.txt
agrep -0 -c 'TAGTGTCTGGGGATATA' *.fastq > count/B1371_Fm0.txt
agrep -0 -c 'CGATACAACCTAACACG' *.fastq > count/B1374_Fm0.txt
agrep -0 -c 'GTGAGTTACGAATCGAA' *.fastq > count/B1375_Fm0.txt
agrep -0 -c 'GTTCTCCGCTGATAAAC' *.fastq > count/B1378_Fm0.txt
agrep -0 -c 'CATCTCGTGGTGTCTAG' *.fastq > count/B1380_Fm0.txt
agrep -0 -c 'GACCCTGAGCTGCTAAA' *.fastq > count/B1381_Fm0.txt
agrep -0 -c 'GCGCAATGAACTGCTCA' *.fastq > count/B1383_Fm0.txt
agrep -0 -c 'TCTGTAGGCGGTAGATT' *.fastq > count/B1384_Fm0.txt
agrep -0 -c 'CAAGAGGGACGAAGCAT' *.fastq > count/B1385_Fm0.txt
agrep -0 -c 'CACGCGATCCGTTACGA' *.fastq > count/B1386_Fm0.txt
agrep -0 -c 'ATAGGAAGTCTTATGGC' *.fastq > count/B1387_Fm0.txt
agrep -0 -c 'GGGCCTATAAAGTTCCA' *.fastq > count/B1388_Fm0.txt
agrep -0 -c 'GTGGAGGGTAACTTAAA' *.fastq > count/B1389_Fm0.txt
agrep -0 -c 'GTCTGAGACACCTCACC' *.fastq > count/B1391_Fm0.txt
agrep -0 -c 'GGCAGTAAGCTCGCAAT' *.fastq > count/B1392_Fm0.txt
agrep -0 -c 'GTACCCGGTGCCTTATG' *.fastq > count/B1393_Fm0.txt
agrep -0 -c 'GCATTCCATCGCTGCTG' *.fastq > count/B1394_Fm0.txt
agrep -0 -c 'AGTTTGGCACGAAGGCT' *.fastq > count/B1395_Fm0.txt
agrep -0 -c 'GTCACGGTCGCATGATC' *.fastq > count/B1397_Fm0.txt
agrep -0 -c 'TCTGAGTGGTCGGACAC' *.fastq > count/B1398_Fm0.txt
agrep -0 -c 'GGACCCATAGTTTTGAA' *.fastq > count/B1399_Fm0.txt
agrep -0 -c 'TAAAAGGGCAACCAACC' *.fastq > count/B1400_Fm0.txt
agrep -0 -c 'CAATCCACCTAGTTTGC' *.fastq > count/B1401_Fm0.txt
agrep -0 -c 'CTGCTACACAGTTGCCA' *.fastq > count/B1402_Fm0.txt
agrep -0 -c 'ATAGAGGTGGAGTCTAC' *.fastq > count/B1403_Fm0.txt
agrep -0 -c 'GCATTACTCTCCGAAAT' *.fastq > count/B1404_Fm0.txt
agrep -0 -c 'CGTTTAGGGACAATTGC' *.fastq > count/B1405_Fm0.txt
agrep -0 -c 'TCGCTGTCCTAAGCGGA' *.fastq > count/B1406_Fm0.txt
agrep -0 -c 'CTAAGAGGGCACAACAG' *.fastq > count/B1407_Fm0.txt
agrep -0 -c 'CCTAAACGCCCTATGCC' *.fastq > count/B1408_Fm0.txt
agrep -0 -c 'AGCTGGTGATCTGTAGG' *.fastq > count/B1409_Fm0.txt
agrep -0 -c 'CGAAGTCAGGATTCCGG' *.fastq > count/B1410_Fm0.txt
agrep -0 -c 'CAAGGTCCCTCATTAAT' *.fastq > count/B1412_Fm0.txt
agrep -0 -c 'TACGCGCAATACCTCAT' *.fastq > count/B1413_Fm0.txt
agrep -0 -c 'AGTAGCCTAAGAGATGC' *.fastq > count/B1414_Fm0.txt
agrep -0 -c 'TGCAGCGCATACCTTTC' *.fastq > count/B1415_Fm0.txt
agrep -0 -c 'AGCTCGACGGGTACTAT' *.fastq > count/B1416_Fm0.txt
agrep -0 -c 'ATTAACGCCGGTAATTG' *.fastq > count/B1417_Fm0.txt
agrep -0 -c 'GTAGGGTCGCTGCTATC' *.fastq > count/B1418_Fm0.txt
agrep -0 -c 'TCATCCAGGGAAGCGTT' *.fastq > count/B1419_Fm0.txt
agrep -0 -c 'GGAGTACCGGATCATGG' *.fastq > count/B1420_Fm0.txt
agrep -0 -c 'ACGGTGGAAATTTATGG' *.fastq > count/B1422_Fm0.txt
agrep -0 -c 'TCGCATTAGTGTCCCTT' *.fastq > count/B1423_Fm0.txt
agrep -0 -c 'CAAGTTCTGCGAATACG' *.fastq > count/B1424_Fm0.txt
agrep -0 -c 'GGTAGCCGCAACTACGA' *.fastq > count/B1425_Fm0.txt
agrep -0 -c 'AGTTCTAATTCCCCCGG' *.fastq > count/B1427_Fm0.txt
agrep -0 -c 'GACGTAGGTAGCCTGTT' *.fastq > count/B1429_Fm0.txt
agrep -0 -c 'AGCAAGGGTATGTAATC' *.fastq > count/B1430_Fm0.txt
agrep -0 -c 'GGCTAAAAGAGCTGGGC' *.fastq > count/B1431_Fm0.txt
agrep -0 -c 'AGTCGAATGTACTGACC' *.fastq > count/B1433_Fm0.txt
agrep -0 -c 'GATTGAGAAAGTAGCCG' *.fastq > count/B1435_Fm0.txt
agrep -0 -c 'TTGCCAACTATCCCATC' *.fastq > count/B1436_Fm0.txt
agrep -0 -c 'TCGCCAGCAATAGACCG' *.fastq > count/B1437_Fm0.txt
agrep -0 -c 'GTCCTGTTTCAGTGTGC' *.fastq > count/B1439_Fm0.txt
agrep -0 -c 'GTGTCGTCAGACGGTTG' *.fastq > count/B1440_Fm0.txt
agrep -0 -c 'TTGTCAACTGGTTCCTG' *.fastq > count/B1441_Fm0.txt
agrep -0 -c 'GTATGTCGTTCCTAAGC' *.fastq > count/B1442_Fm0.txt
agrep -0 -c 'GGGTTGGGATTGCTAGC' *.fastq > count/B1443_Fm0.txt
agrep -0 -c 'GCAATCTTCCGTGCAGC' *.fastq > count/B1444_Fm0.txt
agrep -0 -c 'CGAATAGGGATTTCGCT' *.fastq > count/B1445_Fm0.txt
agrep -0 -c 'CTAAGCATCGGCCCTCA' *.fastq > count/B1446_Fm0.txt
agrep -0 -c 'CATCGATATTGGTGGCG' *.fastq > count/B1447_Fm0.txt
agrep -0 -c 'CGATTCATAGCGCCGTG' *.fastq > count/B1448_Fm0.txt
agrep -0 -c 'AGGAGTATGGTTATGTG' *.fastq > count/B1449_Fm0.txt
agrep -0 -c 'CTTACGGCGTTACATGA' *.fastq > count/B1450_Fm0.txt
agrep -0 -c 'GTCTCTATTCCCGCCCA' *.fastq > count/B1451_Fm0.txt
agrep -0 -c 'ATTACGCTTGGTGGGAC' *.fastq > count/B1452_Fm0.txt
agrep -0 -c 'TTCCGACTTCGGCACAC' *.fastq > count/B1453_Fm0.txt
agrep -0 -c 'ACTAATGGGTAGTTCGT' *.fastq > count/B1454_Fm0.txt
agrep -0 -c 'CTAGAACTTTCGGGGCC' *.fastq > count/B1455_Fm0.txt
agrep -0 -c 'GGACTGCCCTCCAATTG' *.fastq > count/B1457_Fm0.txt
agrep -0 -c 'TCGGATTTGATCTTGTG' *.fastq > count/B1458_Fm0.txt
agrep -0 -c 'TACTGTCCATTAACGCA' *.fastq > count/B1459_Fm0.txt
agrep -0 -c 'ATCCAATGCTGGTGCTA' *.fastq > count/B1461_Fm0.txt
agrep -0 -c 'CTACTCGAGCCCTGTAC' *.fastq > count/B1463_Fm0.txt
agrep -0 -c 'AGTACTGTCTCGCTCTT' *.fastq > count/B1464_Fm0.txt
agrep -0 -c 'GCCGTATATCTTCGGTC' *.fastq > count/B1465_Fm0.txt
agrep -0 -c 'GTGAAATCCCTGTTTGC' *.fastq > count/B1468_Fm0.txt
agrep -0 -c 'GCCTGTATCGGCACATA' *.fastq > count/B1470_Fm0.txt
agrep -0 -c 'GCCGTAACGAGAAGCGA' *.fastq > count/B1471_Fm0.txt
agrep -0 -c 'ACATGGGTAAAGCCAAT' *.fastq > count/B1472_Fm0.txt
agrep -0 -c 'GTACTGCATCATACTCT' *.fastq > count/B1473_Fm0.txt
agrep -0 -c 'GGAACCTAGACTACCCG' *.fastq > count/B1474_Fm0.txt
agrep -0 -c 'TCTCCCTTCGACAGACA' *.fastq > count/B1475_Fm0.txt
agrep -0 -c 'CGAATCTTGGACGTTTG' *.fastq > count/B1476_Fm0.txt
agrep -0 -c 'AGTCGGAGAGATCGACC' *.fastq > count/B1477_Fm0.txt
agrep -0 -c 'ATAGCCTCGTGGAAGCA' *.fastq > count/B1479_Fm0.txt
agrep -0 -c 'CTGTGTGATTAGCCGGG' *.fastq > count/B1480_Fm0.txt
agrep -0 -c 'CAAACTCTTTGAATCGC' *.fastq > count/B1481_Fm0.txt
agrep -0 -c 'AGAAGTTACCTCCGTAA' *.fastq > count/B1483_Fm0.txt
agrep -0 -c 'CAGGCGTTACGATCTAG' *.fastq > count/B1484_Fm0.txt
agrep -0 -c 'GGGATCATACCTTGAAC' *.fastq > count/B1485_Fm0.txt
agrep -0 -c 'CATCTAGCTTGGAAGGG' *.fastq > count/B1486_Fm0.txt
agrep -0 -c 'TGCGAATGAGAGCGCTG' *.fastq > count/B1487_Fm0.txt
agrep -0 -c 'AAGGTGACCAGATCAAG' *.fastq > count/B1488_Fm0.txt
agrep -0 -c 'CTTGGTAATTGTGGAGC' *.fastq > count/B1489_Fm0.txt
agrep -0 -c 'TGTTTGGACGTCGTTAC' *.fastq > count/B1491_Fm0.txt
agrep -0 -c 'CAGAACCGCTATGGCTT' *.fastq > count/B1492_Fm0.txt
agrep -0 -c 'CCTCCGGGTTGTTCAAG' *.fastq > count/B1494_Fm0.txt
agrep -0 -c 'CGCGGTTACTCCAAATC' *.fastq > count/B1495_Fm0.txt
agrep -0 -c 'GGGATGTACGGATTGTA' *.fastq > count/B1496_Fm0.txt
agrep -0 -c 'GCATAGTACTACTACGT' *.fastq > count/B1497_Fm0.txt
agrep -0 -c 'TATTTGTGGCTGGCGTA' *.fastq > count/B1498_Fm0.txt
agrep -0 -c 'CGACGCGGTACATTCTG' *.fastq > count/B1500_Fm0.txt
agrep -0 -c 'TCTGCACGTAGCAAGCC' *.fastq > count/B1501_Fm0.txt
agrep -0 -c 'CGTTCTTCGACGCTCCT' *.fastq > count/B1502_Fm0.txt
agrep -0 -c 'ACTGGCTATGTGGGATG' *.fastq > count/B1503_Fm0.txt
agrep -0 -c 'TCGGTAACTACGCCACT' *.fastq > count/B1504_Fm0.txt
agrep -0 -c 'ATTGCAGTAGAGTCCGA' *.fastq > count/B1505_Fm0.txt
agrep -0 -c 'ACTTCACGTGTTGATGC' *.fastq > count/B1506_Fm0.txt
agrep -0 -c 'TTGATCCGGGTTTGTTT' *.fastq > count/B1507_Fm0.txt
agrep -0 -c 'ACGAGCCTTATGGAAGT' *.fastq > count/B1509_Fm0.txt
agrep -0 -c 'TGTAATGAAGGCACAAC' *.fastq > count/B1511_Fm0.txt
agrep -0 -c 'ATAACCCCGTTTGGCCT' *.fastq > count/B1512_Fm0.txt
agrep -0 -c 'TCATATGCCGATGCCGC' *.fastq > count/B1513_Fm0.txt
agrep -0 -c 'TTGCTTCGAGCAATTCT' *.fastq > count/B1514_Fm0.txt
agrep -0 -c 'CCTGATGGTGGTTAGTC' *.fastq > count/B1515_Fm0.txt
agrep -0 -c 'CGGGGTATTACCTTCTA' *.fastq > count/B1516_Fm0.txt
agrep -0 -c 'CTCGAGCTAAACACATT' *.fastq > count/B1517_Fm0.txt
agrep -0 -c 'TGCTTACACGGTTCGTT' *.fastq > count/B1518_Fm0.txt
agrep -0 -c 'ACGGATCGGAGCGTTTC' *.fastq > count/B1519_Fm0.txt
agrep -0 -c 'TGCGCCGATTACATACT' *.fastq > count/B1521_Fm0.txt
agrep -0 -c 'CCTCAAAACGGTAGCTG' *.fastq > count/B1522_Fm0.txt
agrep -0 -c 'GATTGCGACTACCATGG' *.fastq > count/B1523_Fm0.txt
agrep -0 -c 'CCGAAGGCCACCAATAA' *.fastq > count/B1524_Fm0.txt
agrep -0 -c 'TAAGTCTACGCTCCCCA' *.fastq > count/B1525_Fm0.txt
agrep -0 -c 'GTTCTGAAGCAAGAACC' *.fastq > count/B1526_Fm0.txt
agrep -0 -c 'TTCAAAATCCGGCGATC' *.fastq > count/B1527_Fm0.txt
agrep -0 -c 'ATATAAACCTCGACGGC' *.fastq > count/B1528_Fm0.txt
agrep -0 -c 'TCACTACTAACCCCCAT' *.fastq > count/B1529_Fm0.txt
agrep -0 -c 'ATATCCAACTTTCGCCT' *.fastq > count/B1530_Fm0.txt
agrep -0 -c 'TTCCGTAAGCTTTCAAC' *.fastq > count/B1531_Fm0.txt
agrep -0 -c 'TTGACTCTGTATGCAGT' *.fastq > count/B1532_Fm0.txt
agrep -0 -c 'TGAGAGATGACCGGCGT' *.fastq > count/B1535_Fm0.txt
agrep -0 -c 'AATGAACCGGCCACACT' *.fastq > count/B1536_Fm0.txt
agrep -0 -c 'AGATAACCGACTGTTTC' *.fastq > count/B1538_Fm0.txt
agrep -0 -c 'GTGGAGTTAGCGTCGCA' *.fastq > count/B1540_Fm0.txt
agrep -0 -c 'TAGCAAAAGTGTAGGAG' *.fastq > count/B1541_Fm0.txt
agrep -0 -c 'TGTTTACCTGGACAGGC' *.fastq > count/B1542_Fm0.txt
agrep -0 -c 'TGTCTCCCGGAACCTGT' *.fastq > count/B1544_Fm0.txt
agrep -0 -c 'CGTGCACGGGCTCAAAA' *.fastq > count/B1545_Fm0.txt
agrep -0 -c 'GGCCAATAGCGCGTTCA' *.fastq > count/B1546_Fm0.txt
agrep -0 -c 'GTTTCCTGACAGTACCC' *.fastq > count/B1547_Fm0.txt
agrep -0 -c 'ATTTCTTTCTACGCGCA' *.fastq > count/B1548_Fm0.txt
agrep -0 -c 'GGCCTGAACCCGAATTA' *.fastq > count/B1549_Fm0.txt
agrep -0 -c 'ACACTGAATCAGCTTCT' *.fastq > count/B1550_Fm0.txt
agrep -0 -c 'GGATTCCGGCCAGCAAA' *.fastq > count/B1551_Fm0.txt
agrep -0 -c 'CTAATTGCTCAACCCCT' *.fastq > count/B1552_Fm0.txt
agrep -0 -c 'GCCGATTTAGAGCGCCA' *.fastq > count/B1553_Fm0.txt
agrep -0 -c 'ACACTTGGAGGGTCTTG' *.fastq > count/B1554_Fm0.txt
agrep -0 -c 'GACCACCGAATATCTTT' *.fastq > count/B1555_Fm0.txt
agrep -0 -c 'CAGTAGAGATCGCATGC' *.fastq > count/B1556_Fm0.txt
agrep -0 -c 'AACGGAGAGGTATGTAT' *.fastq > count/B1557_Fm0.txt
agrep -0 -c 'GATATTGGATCGGGATC' *.fastq > count/B1558_Fm0.txt
agrep -0 -c 'CCATTTCACAGCAGGAG' *.fastq > count/B1559_Fm0.txt
agrep -0 -c 'TTCCGACATGGCATCAC' *.fastq > count/B1561_Fm0.txt
agrep -0 -c 'GGACAATTCCCCATATG' *.fastq > count/B1562_Fm0.txt
agrep -0 -c 'TGACGGAATACCCATGC' *.fastq > count/B1563_Fm0.txt
agrep -0 -c 'TCAAACCGTGCACGAAG' *.fastq > count/B1564_Fm0.txt
agrep -0 -c 'CTACTTCGGACACGGTT' *.fastq > count/B1565_Fm0.txt
agrep -0 -c 'TCACTCTCTAGCTCGAT' *.fastq > count/B1566_Fm0.txt
agrep -0 -c 'AAGCATCTGGCCCCCTT' *.fastq > count/B1567_Fm0.txt
agrep -0 -c 'GGTAAATGCGACCGGGT' *.fastq > count/B1568_Fm0.txt
agrep -0 -c 'GCCAGTGCTAGTAGTGC' *.fastq > count/B1569_Fm0.txt
agrep -0 -c 'GTAGTGAAAACGCGCAA' *.fastq > count/B1570_Fm0.txt
agrep -0 -c 'GCTCGGCCAAAATCCCT' *.fastq > count/B1571_Fm0.txt
agrep -0 -c 'GTTTCGCTCTTACCATT' *.fastq > count/B1572_Fm0.txt
agrep -0 -c 'CGCAGTAAAGGGGTGTT' *.fastq > count/B1573_Fm0.txt
agrep -0 -c 'CGTATGAGGTGGGGTAC' *.fastq > count/B1574_Fm0.txt
agrep -0 -c 'TGCATGTCATGCTTGCC' *.fastq > count/B1575_Fm0.txt
agrep -0 -c 'TTCACGATTCGATTCCC' *.fastq > count/B1576_Fm0.txt
agrep -0 -c 'ATCAACCCAAGCTGTTA' *.fastq > count/B1577_Fm0.txt
agrep -0 -c 'ATGCACGTGAACTGTGT' *.fastq > count/B1580_Fm0.txt
agrep -0 -c 'CGGCACTAGATATCACG' *.fastq > count/B1582_Fm0.txt
agrep -0 -c 'CAAAATGCACTGCGAAC' *.fastq > count/B1584_Fm0.txt
agrep -0 -c 'CCACGGGATAAGATTCT' *.fastq > count/B1585_Fm0.txt
agrep -0 -c 'GATGTCAGGATGAATGT' *.fastq > count/B1586_Fm0.txt
agrep -0 -c 'TGCATCTTACCGAACCC' *.fastq > count/B1587_Fm0.txt
agrep -0 -c 'AACTTCTGGCCAGTTCC' *.fastq > count/B1588_Fm0.txt
agrep -0 -c 'GCTACGAACAGGGCAGT' *.fastq > count/B1589_Fm0.txt
agrep -0 -c 'AGTTGGTAGGTGTCCAG' *.fastq > count/B1590_Fm0.txt
agrep -0 -c 'ACAATAAGGGTGGCGTT' *.fastq > count/B1592_Fm0.txt
agrep -0 -c 'GCAATGTCGTGTGGAAA' *.fastq > count/B1593_Fm0.txt
agrep -0 -c 'TTCCGCTGTACTGAATG' *.fastq > count/B1594_Fm0.txt
agrep -0 -c 'ATAAACCGCTACCGCCC' *.fastq > count/B1595_Fm0.txt
agrep -0 -c 'GACTGTCCTCCCGAGTA' *.fastq > count/B1596_Fm0.txt
agrep -0 -c 'CACAACGTAAACACTAG' *.fastq > count/B1597_Fm0.txt
agrep -0 -c 'AGCATCGACGTAGCAGC' *.fastq > count/B1598_Fm0.txt
agrep -0 -c 'GGATCGAGTACGATACC' *.fastq > count/B1599_Fm0.txt
agrep -0 -c 'GCGTTAAGTCCGCGTAA' *.fastq > count/B1600_Fm0.txt
agrep -0 -c 'ACAACAGTATGGGATCA' *.fastq > count/B1602_Fm0.txt
agrep -0 -c 'ACGAATTCGCCGCGAAG' *.fastq > count/B1603_Fm0.txt
agrep -0 -c 'ATGAACTGCATCTTGCA' *.fastq > count/B1605_Fm0.txt
agrep -0 -c 'ATCCAGTGGCCGTGTGA' *.fastq > count/B1606_Fm0.txt
agrep -0 -c 'TAGTACCCTCATAACGC' *.fastq > count/B1607_Fm0.txt
agrep -0 -c 'ACTCAGTGCGCTAAGCG' *.fastq > count/B1608_Fm0.txt
agrep -0 -c 'GGTATTCCCTAACTATC' *.fastq > count/B1609_Fm0.txt
agrep -0 -c 'GGATGTTCACGCCAGCT' *.fastq > count/B1610_Fm0.txt
agrep -0 -c 'AGGTGGTCAAGAAGGGT' *.fastq > count/B1611_Fm0.txt
agrep -0 -c 'CTCAGGCGCAACGATCT' *.fastq > count/B1612_Fm0.txt
agrep -0 -c 'GGCCGTGGTGAACAAGA' *.fastq > count/B1613_Fm0.txt
agrep -0 -c 'TGCCATCATGAATTCTC' *.fastq > count/B1615_Fm0.txt
agrep -0 -c 'TCTATCCTCCTGCTTAC' *.fastq > count/B1616_Fm0.txt
agrep -0 -c 'GGATTGACGTTATGCCG' *.fastq > count/B1617_Fm0.txt
agrep -0 -c 'GTTTATCACGGGATCTC' *.fastq > count/B1618_Fm0.txt
agrep -0 -c 'GCCCGCGTAATTTCATA' *.fastq > count/B1619_Fm0.txt
agrep -0 -c 'AGTCGTCAAGACAGGCA' *.fastq > count/B1620_Fm0.txt
agrep -0 -c 'TTGTTATCGGATGAGGG' *.fastq > count/B1621_Fm0.txt
agrep -0 -c 'TTGCAGAGAGTATCGAA' *.fastq > count/B1622_Fm0.txt
agrep -0 -c 'GCTACTTGAGCTCTGTC' *.fastq > count/B1625_Fm0.txt
agrep -0 -c 'CCTTGTATCGACCATTG' *.fastq > count/B1626_Fm0.txt
agrep -0 -c 'TCTACACATGACCTGGC' *.fastq > count/B1627_Fm0.txt
agrep -0 -c 'AGGGCCACATTTAGGCG' *.fastq > count/B1628_Fm0.txt
agrep -0 -c 'TCACCCCGTATGAAAGG' *.fastq > count/B1629_Fm0.txt
agrep -0 -c 'AAGTGGGTGTTCTCTTC' *.fastq > count/B1630_Fm0.txt
agrep -0 -c 'AGACTGGCCCTTTCGAG' *.fastq > count/B1631_Fm0.txt
agrep -0 -c 'GTCCAACGATGAGGGGA' *.fastq > count/B1632_Fm0.txt
agrep -0 -c 'CGTCATAAGGCGAAAAT' *.fastq > count/B1633_Fm0.txt
agrep -0 -c 'CGTGTCTGAGAGAGACT' *.fastq > count/B1634_Fm0.txt
agrep -0 -c 'ATTGTCTGGGGTCTTGC' *.fastq > count/B1635_Fm0.txt
agrep -0 -c 'CCTTCGCCAGATTCCAC' *.fastq > count/B1636_Fm0.txt
agrep -0 -c 'CCGTATACCACAAAAAC' *.fastq > count/B1637_Fm0.txt
agrep -0 -c 'ACCTGTATCCGTCACGA' *.fastq > count/B1638_Fm0.txt
agrep -0 -c 'ATCTGCGTGGATAAAAG' *.fastq > count/B1639_Fm0.txt
agrep -0 -c 'AAGGCACTTTTGCGAAG' *.fastq > count/B1640_Fm0.txt
agrep -0 -c 'TACTAACGCCCATTCGA' *.fastq > count/B1641_Fm0.txt
agrep -0 -c 'CGAGGATCCGGATTCAA' *.fastq > count/B1642_Fm0.txt
agrep -0 -c 'ATTTTGGCGGCCTTCGG' *.fastq > count/B1643_Fm0.txt
agrep -0 -c 'TGCGCATTTCTGGGCCT' *.fastq > count/B1644_Fm0.txt
agrep -0 -c 'CTCTAAGACCTGGTTAC' *.fastq > count/B1645_Fm0.txt
agrep -0 -c 'CCGCCAAGTTTCACTGG' *.fastq > count/B1646_Fm0.txt
agrep -0 -c 'TTCCGGATAATGTCCCT' *.fastq > count/B1648_Fm0.txt
agrep -0 -c 'CCAATCCCTGATGGCGA' *.fastq > count/B1649_Fm0.txt
agrep -0 -c 'CATGCTAGGGCAACCGA' *.fastq > count/B1650_Fm0.txt
agrep -0 -c 'TATTCCACGTCACAGAA' *.fastq > count/B1651_Fm0.txt
agrep -0 -c 'GCTGGATCTTTCGAGAG' *.fastq > count/B1652_Fm0.txt
agrep -0 -c 'ATCTATGTATGGTCGAC' *.fastq > count/B1653_Fm0.txt
agrep -0 -c 'CGATCAGGTACTTTGCA' *.fastq > count/B1655_Fm0.txt
agrep -0 -c 'CCACTCGTATTGCTAAT' *.fastq > count/B1656_Fm0.txt
agrep -0 -c 'TAATCACCAGTAGCCGC' *.fastq > count/B1657_Fm0.txt
agrep -0 -c 'AGGTCCTCACAGTGAGG' *.fastq > count/B1658_Fm0.txt
agrep -0 -c 'AACACAAACGCGTCCGA' *.fastq > count/B1659_Fm0.txt
agrep -0 -c 'AGGTATGCATCGCGGGA' *.fastq > count/B1660_Fm0.txt
agrep -0 -c 'CACGAGATATGGCGCCA' *.fastq > count/B1662_Fm0.txt
agrep -0 -c 'GTTGCAAGCCAGGAGTT' *.fastq > count/B1663_Fm0.txt
agrep -0 -c 'AATTGAAGCAGTAGTCG' *.fastq > count/B1664_Fm0.txt
agrep -0 -c 'GGATTGCCTAAAATCGA' *.fastq > count/B1665_Fm0.txt
agrep -0 -c 'TTGGGGTCTCAATGCAC' *.fastq > count/B1666_Fm0.txt
agrep -0 -c 'GGCTCCCAACGTTTGTT' *.fastq > count/B1667_Fm0.txt
agrep -0 -c 'GTAACCTGACATGTAGT' *.fastq > count/B1668_Fm0.txt
agrep -0 -c 'TGATCCCGGAAGGTTCT' *.fastq > count/B1669_Fm0.txt
agrep -0 -c 'GCAAAAGCCTAAAACCA' *.fastq > count/B1670_Fm0.txt
agrep -0 -c 'TACCAACCGCCTGTGGA' *.fastq > count/B1671_Fm0.txt
agrep -0 -c 'TGCGGAATCAGTCTCTC' *.fastq > count/B1672_Fm0.txt
agrep -0 -c 'GACCTCCTAGAAGTGCG' *.fastq > count/B1673_Fm0.txt
agrep -0 -c 'GCTACTGTAGTATATCC' *.fastq > count/B1674_Fm0.txt
agrep -0 -c 'AACGCGGTCTCCAGTGT' *.fastq > count/B1675_Fm0.txt
agrep -0 -c 'GTAATTGTTACGCCGTT' *.fastq > count/B1676_Fm0.txt
agrep -0 -c 'TAGGCGTGCTGTTAGGT' *.fastq > count/B1677_Fm0.txt
agrep -0 -c 'GGATTAGATGCCTGTAC' *.fastq > count/B1678_Fm0.txt
agrep -0 -c 'CTTCGGACAGAAGAAGC' *.fastq > count/B1679_Fm0.txt
agrep -0 -c 'ACGTCCTTGCGAGTTCA' *.fastq > count/B1680_Fm0.txt
agrep -0 -c 'TAGTGACTTGTGCGGCG' *.fastq > count/B1681_Fm0.txt
agrep -0 -c 'CTGTTCTATAGATAGCG' *.fastq > count/B1682_Fm0.txt
agrep -0 -c 'AACTAACGACCAGCTAT' *.fastq > count/B1683_Fm0.txt
agrep -0 -c 'AGCGGCAGATATGCGCT' *.fastq > count/B1684_Fm0.txt
agrep -0 -c 'TCACGTGGGTAGTCTAA' *.fastq > count/B1685_Fm0.txt
agrep -0 -c 'ATGACCTGGTATAACCC' *.fastq > count/B1686_Fm0.txt
agrep -0 -c 'ACTAACTATCGGCTAGG' *.fastq > count/B1687_Fm0.txt
agrep -0 -c 'GCGAGAACTTTTGTTGG' *.fastq > count/B1688_Fm0.txt
agrep -0 -c 'TAGACCGCACGGGATAT' *.fastq > count/B1689_Fm0.txt
agrep -0 -c 'GTGGGCTCACTGTCAGT' *.fastq > count/B1690_Fm0.txt
agrep -0 -c 'AATACGATGAGGTCCGG' *.fastq > count/B1691_Fm0.txt
agrep -0 -c 'CCATCTTCTAGCGGGCT' *.fastq > count/B1692_Fm0.txt
agrep -0 -c 'AATTGTCCCTGGCGTGT' *.fastq > count/B1694_Fm0.txt
agrep -0 -c 'ATGGACCTATTTGCGTC' *.fastq > count/B1695_Fm0.txt
agrep -0 -c 'GTGTGGGGTGAAGATCA' *.fastq > count/B1697_Fm0.txt
agrep -0 -c 'CATACTATGCCTCGGCC' *.fastq > count/B1698_Fm0.txt
agrep -0 -c 'CGCTCATATGCCAAAAG' *.fastq > count/B1699_Fm0.txt
agrep -0 -c 'GCATTGTGACCCATTAA' *.fastq > count/B1700_Fm0.txt
agrep -0 -c 'CTTGAACAATCGGGTAC' *.fastq > count/B1701_Fm0.txt
agrep -0 -c 'GCGCATATTCAAAGCGT' *.fastq > count/B1702_Fm0.txt
agrep -0 -c 'TCGACATCTTTCCGAAA' *.fastq > count/B1703_Fm0.txt
agrep -0 -c 'TATCCTATGCTCCGCAA' *.fastq > count/B1704_Fm0.txt
agrep -0 -c 'TGTGCAATGCGCAGTAC' *.fastq > count/B1705_Fm0.txt
agrep -0 -c 'TATCGACACGCTATCAT' *.fastq > count/B1707_Fm0.txt
agrep -0 -c 'CTAAAGTGCAGCGAGAC' *.fastq > count/B1708_Fm0.txt
agrep -0 -c 'GATGCCCTACTCTCAGT' *.fastq > count/B1710_Fm0.txt
agrep -0 -c 'ACATGTTAACAACCCGC' *.fastq > count/B1711_Fm0.txt
agrep -0 -c 'CGCTTAACTCCTTTACA' *.fastq > count/B1712_Fm0.txt
agrep -0 -c 'AGACAACAGAGCACGGT' *.fastq > count/B1714_Fm0.txt
agrep -0 -c 'CAGCAAGTTCTAAGGTC' *.fastq > count/B1715_Fm0.txt
agrep -0 -c 'GGCCTGGGTGATTCTTC' *.fastq > count/B1718_Fm0.txt
agrep -0 -c 'CAGGGAAATCCAATCAC' *.fastq > count/B1719_Fm0.txt
agrep -0 -c 'AGAATCGGTAGGGTGGC' *.fastq > count/B1720_Fm0.txt
agrep -0 -c 'CTGGATGTAAATTGCAC' *.fastq > count/B1721_Fm0.txt
agrep -0 -c 'TATCGCGAGCGGTCCTT' *.fastq > count/B1722_Fm0.txt
agrep -0 -c 'ACCCAAGGGCCATTACG' *.fastq > count/B1723_Fm0.txt
agrep -0 -c 'GTTAAACATCGGCGGTG' *.fastq > count/B1724_Fm0.txt
agrep -0 -c 'AGAGAACGCCGGTATAC' *.fastq > count/B1725_Fm0.txt
agrep -0 -c 'CCGCACGTACAAATGTC' *.fastq > count/B1726_Fm0.txt
agrep -0 -c 'TAAACTGAGTCCGTCAC' *.fastq > count/B1728_Fm0.txt
agrep -0 -c 'TAACGACTCTGGTCTTA' *.fastq > count/B1729_Fm0.txt
agrep -0 -c 'GTAATTCGATGGGTCTT' *.fastq > count/B1730_Fm0.txt
agrep -0 -c 'TCGCTACTCCCGTTTTA' *.fastq > count/B1731_Fm0.txt
agrep -0 -c 'ATAAACCTCGGCTTCGG' *.fastq > count/B1732_Fm0.txt
agrep -0 -c 'GACTGCATCGCGCATGA' *.fastq > count/B1733_Fm0.txt
agrep -0 -c 'GTAGTGCGATCTCTAAA' *.fastq > count/B1734_Fm0.txt
agrep -0 -c 'TACGATCTCATCGGGTC' *.fastq > count/B1735_Fm0.txt
agrep -0 -c 'CAGCCGAGGTCGAAACA' *.fastq > count/B1736_Fm0.txt
agrep -0 -c 'GCCATGTCTCTATCGCG' *.fastq > count/B1737_Fm0.txt
agrep -0 -c 'ACCCGAACCTGGTACTC' *.fastq > count/B1738_Fm0.txt
agrep -0 -c 'GCACTCCAATCTCACCC' *.fastq > count/B1739_Fm0.txt
agrep -0 -c 'CTCAGGGAAATCTTCTG' *.fastq > count/B1740_Fm0.txt
agrep -0 -c 'GGAATAGTGAACCGAAA' *.fastq > count/B1741_Fm0.txt
agrep -0 -c 'ACCCGGCAAGTTTAGAG' *.fastq > count/B1743_Fm0.txt
agrep -0 -c 'AGAGCGGTCAACTGTTT' *.fastq > count/B1744_Fm0.txt
agrep -0 -c 'CCGAATTTATATTCGCG' *.fastq > count/B1747_Fm0.txt
agrep -0 -c 'AGTCCAGAACTATACGC' *.fastq > count/B1748_Fm0.txt
agrep -0 -c 'CATATGGGGAGGAGTAC' *.fastq > count/B1749_Fm0.txt
agrep -0 -c 'GTTACGAGGCCTTAGCT' *.fastq > count/B1750_Fm0.txt
agrep -0 -c 'TTCCTACGTTACATTCC' *.fastq > count/B1751_Fm0.txt
agrep -0 -c 'GACCGAATAACTAGGGC' *.fastq > count/B1752_Fm0.txt
agrep -0 -c 'GCTGTACAATGAGCTAT' *.fastq > count/B1754_Fm0.txt
agrep -0 -c 'TAAGGTCAGAGTACGAG' *.fastq > count/B1756_Fm0.txt
agrep -0 -c 'CTACAGACCAGCGAGCT' *.fastq > count/B1757_Fm0.txt
agrep -0 -c 'CTTGATCACGCATTCTG' *.fastq > count/B1758_Fm0.txt
agrep -0 -c 'GCTCCGTTCGTTTTCCT' *.fastq > count/B1759_Fm0.txt
agrep -0 -c 'CGCACCCGACGCAATTA' *.fastq > count/B1760_Fm0.txt
agrep -0 -c 'CTATCCACTTTGTGAAG' *.fastq > count/B1762_Fm0.txt
agrep -0 -c 'TGCAGATAGCAATAGCG' *.fastq > count/B1763_Fm0.txt
agrep -0 -c 'CCTAGGCTGTATCTGCC' *.fastq > count/B1766_Fm0.txt
agrep -0 -c 'TCAGGCTCAACTCTTAG' *.fastq > count/B1767_Fm0.txt
agrep -0 -c 'CGATGCCCCGAAAGTTC' *.fastq > count/B1768_Fm0.txt
agrep -0 -c 'ACGGTGCTGTAAACGTG' *.fastq > count/B1769_Fm0.txt
agrep -0 -c 'TATCCATACGTGAAGGC' *.fastq > count/B1770_Fm0.txt
agrep -0 -c 'AGAAACGGTCGTCTCTT' *.fastq > count/B1771_Fm0.txt
agrep -0 -c 'GGTGGCAACGTGTTTAG' *.fastq > count/B1772_Fm0.txt
agrep -0 -c 'TCTTGTGTCCTTTGGGA' *.fastq > count/B1773_Fm0.txt
agrep -0 -c 'ACTTACTCAGGGGTTGT' *.fastq > count/B1774_Fm0.txt
agrep -0 -c 'TACTGCGTCGTCTGTCG' *.fastq > count/B1775_Fm0.txt
agrep -0 -c 'CAGACAAGTGAGCGAGG' *.fastq > count/B1777_Fm0.txt
agrep -0 -c 'TACACCGGCTCAACGGT' *.fastq > count/B1778_Fm0.txt
agrep -0 -c 'AATGCCTGTTCCGTATT' *.fastq > count/B1779_Fm0.txt
agrep -0 -c 'TTAGCAGCGGATCTGGT' *.fastq > count/B1780_Fm0.txt
agrep -0 -c 'CTGTATAGGTTAATCGC' *.fastq > count/B1781_Fm0.txt
agrep -0 -c 'GGGGTAGTGAGTAATGG' *.fastq > count/B1782_Fm0.txt
agrep -0 -c 'CCTATAAGTCTGGCTTA' *.fastq > count/B1783_Fm0.txt
agrep -0 -c 'TGCACTAGGAGTTTCCG' *.fastq > count/B1784_Fm0.txt
agrep -0 -c 'GTTGGGAAACAGAGTAA' *.fastq > count/B1785_Fm0.txt
agrep -0 -c 'CACGTTCGCCTACGTGA' *.fastq > count/B1786_Fm0.txt
agrep -0 -c 'ACAGAGGCGATGGTATT' *.fastq > count/B1787_Fm0.txt
agrep -0 -c 'ATCCGCCATTCGAAGGC' *.fastq > count/B1789_Fm0.txt
agrep -0 -c 'TCAACACCGGCGACTAT' *.fastq > count/B1790_Fm0.txt
agrep -0 -c 'CCTGCTCTATTGTGATG' *.fastq > count/B1791_Fm0.txt
agrep -0 -c 'ATCGCCGTTAAGATGTT' *.fastq > count/B1792_Fm0.txt
agrep -0 -c 'GACCCATCGTTGACGTT' *.fastq > count/B1794_Fm0.txt
agrep -0 -c 'CGGTGTTACATTCGAAC' *.fastq > count/B1795_Fm0.txt
agrep -0 -c 'CCAAAAGTTACCCGCCC' *.fastq > count/B1798_Fm0.txt
agrep -0 -c 'TGCGAGGAGCACGAATA' *.fastq > count/B1799_Fm0.txt
agrep -0 -c 'TAACACTGAGCTCGCTA' *.fastq > count/B1801_Fm0.txt
agrep -0 -c 'GTCTACGTAAGTATGTC' *.fastq > count/B1802_Fm0.txt
agrep -0 -c 'CCTGTTTGGATAAGCGG' *.fastq > count/B1803_Fm0.txt
agrep -0 -c 'TTCGTTACCCGGCGTTA' *.fastq > count/B1804_Fm0.txt
agrep -0 -c 'TGGCCTAAGTGGCTTTC' *.fastq > count/B1806_Fm0.txt
agrep -0 -c 'ATGGAACGTCCTCCGCT' *.fastq > count/B1807_Fm0.txt
agrep -0 -c 'CTCAGCGAATCTGTGAA' *.fastq > count/B1808_Fm0.txt
agrep -0 -c 'ATGCCCGTAACGTATGT' *.fastq > count/B1809_Fm0.txt
agrep -0 -c 'ACAGTAGACGGAATACG' *.fastq > count/B1810_Fm0.txt
agrep -0 -c 'CTGTAGTCAGGGTCTTC' *.fastq > count/B1811_Fm0.txt
agrep -0 -c 'GCCCAGTCCCCTAATAA' *.fastq > count/B1812_Fm0.txt
agrep -0 -c 'AGGGCTGATTTGTTCCC' *.fastq > count/B1813_Fm0.txt
agrep -0 -c 'TTATTAGGCGAGTAACC' *.fastq > count/B1814_Fm0.txt
agrep -0 -c 'GGACCGAGAGTACGAAC' *.fastq > count/B1815_Fm0.txt
agrep -0 -c 'ACAGTAGGTGACGAGTG' *.fastq > count/B1816_Fm0.txt
agrep -0 -c 'GTAGAGTCGCTTCTAAT' *.fastq > count/B1817_Fm0.txt
agrep -0 -c 'TGCCGAGATTACGAGTT' *.fastq > count/B1818_Fm0.txt
agrep -0 -c 'CTAACGTGTCTCGGTAT' *.fastq > count/B1819_Fm0.txt
agrep -0 -c 'GCTACCAGCACTCGATA' *.fastq > count/B1820_Fm0.txt
agrep -0 -c 'ATCGTCGTGGCTAAGCC' *.fastq > count/B1821_Fm0.txt
agrep -0 -c 'CGTGAGCAGCGTCCTAT' *.fastq > count/B1822_Fm0.txt
agrep -0 -c 'AACTCCCGCTACAAAAC' *.fastq > count/B1823_Fm0.txt
agrep -0 -c 'CTGATCTTATACGCCGT' *.fastq > count/B1824_Fm0.txt
agrep -0 -c 'AGGTGTTCGTAAGAACA' *.fastq > count/B1825_Fm0.txt
agrep -0 -c 'GGCAACGAAGATTACTT' *.fastq > count/B1826_Fm0.txt
agrep -0 -c 'CCATGTCAACCACTTAG' *.fastq > count/B1827_Fm0.txt
agrep -0 -c 'TGAATGCCATCATTGCG' *.fastq > count/B1828_Fm0.txt
agrep -0 -c 'TCATTACCGGTAGACGT' *.fastq > count/B1830_Fm0.txt
agrep -0 -c 'TTCTACGTACTCTCAGT' *.fastq > count/B1831_Fm0.txt
agrep -0 -c 'ACCTGTTATTACCCCTG' *.fastq > count/B1832_Fm0.txt
agrep -0 -c 'GTCTGGGACTATTTCCC' *.fastq > count/B1833_Fm0.txt
agrep -0 -c 'AGCTCGTTTGGAGGGGA' *.fastq > count/B1834_Fm0.txt
agrep -0 -c 'TAAACCGTCTTTGGCCG' *.fastq > count/B1835_Fm0.txt
agrep -0 -c 'CCGAGCGGTTAGGAAAG' *.fastq > count/B1837_Fm0.txt
agrep -0 -c 'ATTCCTACTGTCGCAAA' *.fastq > count/B1838_Fm0.txt
agrep -0 -c 'GCCGACTCAAATTTTGT' *.fastq > count/B1839_Fm0.txt
agrep -0 -c 'AGCTCAAGACCAGAGAA' *.fastq > count/B1840_Fm0.txt
agrep -0 -c 'AATTCTGGGGGAGGCAC' *.fastq > count/B1841_Fm0.txt
agrep -0 -c 'TATGACGTCTCCACAGA' *.fastq > count/B1842_Fm0.txt
agrep -0 -c 'ACTTCCGTCCATATCTT' *.fastq > count/B1843_Fm0.txt
agrep -0 -c 'TAAATCCCTCTCACGGA' *.fastq > count/B1844_Fm0.txt
agrep -0 -c 'TATCTGATGACACCCGG' *.fastq > count/B1845_Fm0.txt
agrep -0 -c 'TTCTACTTACGAACTGC' *.fastq > count/B1846_Fm0.txt
agrep -0 -c 'GTTGCCGACCAAACACG' *.fastq > count/B1847_Fm0.txt
agrep -0 -c 'AGGCAACACGTTTACGC' *.fastq > count/B1848_Fm0.txt
agrep -0 -c 'AGGGCCCGATTGCCTAT' *.fastq > count/B1850_Fm0.txt
agrep -0 -c 'CTTGGCCTATTCATGAC' *.fastq > count/B1851_Fm0.txt
agrep -0 -c 'TCTAACCTCGGTAAGGG' *.fastq > count/B1853_Fm0.txt
agrep -0 -c 'TTAGGGTTTCCGAAAAG' *.fastq > count/B1854_Fm0.txt
agrep -0 -c 'CTTGATATTCCGTGACG' *.fastq > count/B1855_Fm0.txt
agrep -0 -c 'ACAGCATGCTATCGACG' *.fastq > count/B1856_Fm0.txt
agrep -0 -c 'TACTATCCTCTGCCTAT' *.fastq > count/B1857_Fm0.txt
agrep -0 -c 'GTGTATATCCGTAATCG' *.fastq > count/B1858_Fm0.txt
agrep -0 -c 'CATTGAGTTAAGTCCAC' *.fastq > count/B1859_Fm0.txt
agrep -0 -c 'TCTGGAGTGCGCCCAAT' *.fastq > count/B1860_Fm0.txt
agrep -0 -c 'TCGGGATTGGATCTGCA' *.fastq > count/B1862_Fm0.txt
agrep -0 -c 'TAGGGGTAATTGAGGCC' *.fastq > count/B1863_Fm0.txt
agrep -0 -c 'TACGAGAAGGGTCGTAT' *.fastq > count/B1864_Fm0.txt
agrep -0 -c 'CTCACATTTGGGCCCTT' *.fastq > count/B1865_Fm0.txt
agrep -0 -c 'GGTGGGTAAAGAAGGCG' *.fastq > count/B1867_Fm0.txt
agrep -0 -c 'TCGACGCTCGTAAGCGT' *.fastq > count/B1868_Fm0.txt
agrep -0 -c 'GGCGCGTCGTAATACAC' *.fastq > count/B1869_Fm0.txt
agrep -0 -c 'CTTGACTTGTGGTGGCG' *.fastq > count/B1871_Fm0.txt
agrep -0 -c 'TACATTACGGGATGACT' *.fastq > count/B1873_Fm0.txt
agrep -0 -c 'GATTCGACCGATTTGCA' *.fastq > count/B1874_Fm0.txt
agrep -0 -c 'TAAACGAACAGGTCTAC' *.fastq > count/B1875_Fm0.txt
agrep -0 -c 'AGCTGGGAGTTAAGCCC' *.fastq > count/B1876_Fm0.txt
agrep -0 -c 'GCAACCGCCGGTTATTC' *.fastq > count/B1878_Fm0.txt
agrep -0 -c 'TGACGTTTGGGACATAG' *.fastq > count/B1879_Fm0.txt
agrep -0 -c 'GGCTGCGGAAGAAAAAT' *.fastq > count/B1881_Fm0.txt
agrep -0 -c 'CTACCACATCCAACACG' *.fastq > count/B1882_Fm0.txt
agrep -0 -c 'CGCTAAAAGGGTAGCTA' *.fastq > count/B1883_Fm0.txt
agrep -0 -c 'GGATCGTACTACACAAA' *.fastq > count/B1884_Fm0.txt
agrep -0 -c 'AGACGATCGTTTGTGTA' *.fastq > count/B1885_Fm0.txt
agrep -0 -c 'TTGAAGTAGTAGCGATC' *.fastq > count/B1886_Fm0.txt
agrep -0 -c 'TGAGTACACCCATGCGC' *.fastq > count/B1887_Fm0.txt
agrep -0 -c 'CCTGGGCCCCTTATGAT' *.fastq > count/B1888_Fm0.txt
agrep -0 -c 'GGCGCTTTTTGACCGTC' *.fastq > count/B1889_Fm0.txt
agrep -0 -c 'CAGAGAATTGTAATCGG' *.fastq > count/B1890_Fm0.txt
agrep -0 -c 'AGACCGCCTGGGTAGAT' *.fastq > count/B1891_Fm0.txt
agrep -0 -c 'TCTCCCATCTGACTGTA' *.fastq > count/B1892_Fm0.txt
agrep -0 -c 'TATCGAATAAGCCTGCA' *.fastq > count/B1893_Fm0.txt
agrep -0 -c 'AGGAAGCTCAGTTCTCG' *.fastq > count/B1894_Fm0.txt
agrep -0 -c 'CCGGAATCTGGTTTAAT' *.fastq > count/B1895_Fm0.txt
agrep -0 -c 'CACGTGAGTCTTACGGC' *.fastq > count/B1896_Fm0.txt
agrep -0 -c 'TAAGCTTGGCGAAATCT' *.fastq > count/B1897_Fm0.txt
agrep -0 -c 'GCAACGGCTATACTAAG' *.fastq > count/B1898_Fm0.txt
agrep -0 -c 'GCACACTATGCTATTCA' *.fastq > count/B1900_Fm0.txt
agrep -0 -c 'CGCCATCATTTAGGCTG' *.fastq > count/B1901_Fm0.txt
agrep -0 -c 'GTTATAAGCGTGACGCT' *.fastq > count/B1903_Fm0.txt
agrep -0 -c 'TGGAGACACGCTGACTC' *.fastq > count/B1904_Fm0.txt
agrep -0 -c 'GACACTACCACTTCCGT' *.fastq > count/B1905_Fm0.txt
agrep -0 -c 'CGCCACGGTAGTAAACT' *.fastq > count/B1906_Fm0.txt
agrep -0 -c 'CGACCTATCATAAAGTC' *.fastq > count/B1907_Fm0.txt
agrep -0 -c 'CCGGAGTCAAAAGGGTG' *.fastq > count/B1908_Fm0.txt
agrep -0 -c 'AAGAGGAGCGGACTTGA' *.fastq > count/B1910_Fm0.txt
agrep -0 -c 'ACTTCGGTCTGTCATTG' *.fastq > count/B1911_Fm0.txt
agrep -0 -c 'CGGTAAGACAGTCTTGT' *.fastq > count/B1912_Fm0.txt
agrep -0 -c 'CTCCCGCAGATTGGATA' *.fastq > count/B1913_Fm0.txt
agrep -0 -c 'GTCGCGGATAGTAATTT' *.fastq > count/B1914_Fm0.txt
agrep -0 -c 'GATATGACGGCTTACGT' *.fastq > count/B1915_Fm0.txt
agrep -0 -c 'CAATGCGGCACGAGCTA' *.fastq > count/B1916_Fm0.txt
agrep -0 -c 'TTACCATCTCTCCATAG' *.fastq > count/B1917_Fm0.txt
agrep -0 -c 'CACAACGGTAGAGACTC' *.fastq > count/B1918_Fm0.txt
agrep -0 -c 'CATCGTAGTCGACGGGA' *.fastq > count/B1919_Fm0.txt
agrep -0 -c 'TCTATGCCTAGGTCTGA' *.fastq > count/B1920_Fm0.txt
agrep -0 -c 'ACTGGCGGAGCATAGAT' *.fastq > count/B1921_Fm0.txt
agrep -0 -c 'ATGTCCACGGAATTTGT' *.fastq > count/B1923_Fm0.txt
agrep -0 -c 'AAGATGGCCGAACTAGA' *.fastq > count/B1924_Fm0.txt
agrep -0 -c 'GACACCCAAGCACGTGA' *.fastq > count/B1926_Fm0.txt
agrep -0 -c 'AAGGATCGGGACAAGGA' *.fastq > count/B1927_Fm0.txt
agrep -0 -c 'TCTCAATCAAACACGCC' *.fastq > count/B1928_Fm0.txt
agrep -0 -c 'ACGCGTTTAGAGGAGCC' *.fastq > count/B1929_Fm0.txt
agrep -0 -c 'ACAGTCCTCGCGAGTAC' *.fastq > count/B1930_Fm0.txt
agrep -0 -c 'CGTGCAAATAACGCATT' *.fastq > count/B1933_Fm0.txt
agrep -0 -c 'CAATGTTGTCTTACGCA' *.fastq > count/B1935_Fm0.txt
agrep -0 -c 'CACCAATTGGTTTAGGA' *.fastq > count/B1936_Fm0.txt
agrep -0 -c 'GTATGGCGTACATCGTT' *.fastq > count/B1938_Fm0.txt
agrep -0 -c 'GCGCTAAGCAGCAGGTA' *.fastq > count/B1939_Fm0.txt
agrep -0 -c 'GACCTAAGAAAAAGGCG' *.fastq > count/B1941_Fm0.txt
agrep -0 -c 'ATTTGTCGACGGTTTCT' *.fastq > count/B1942_Fm0.txt
agrep -0 -c 'GCCTCAACGCGTCAATT' *.fastq > count/B1943_Fm0.txt
agrep -0 -c 'CGTCTGGCCGTAGATTA' *.fastq > count/B1944_Fm0.txt
agrep -0 -c 'CCGTCGGCATGAGTCTA' *.fastq > count/B1945_Fm0.txt
agrep -0 -c 'CACTTTGGCCACGAACT' *.fastq > count/B1947_Fm0.txt
agrep -0 -c 'CCGTTCATAGCATGTCC' *.fastq > count/B1948_Fm0.txt
agrep -0 -c 'ACGTAAATTGACGGCGC' *.fastq > count/B1949_Fm0.txt
agrep -0 -c 'GTTCACAATTCTGGTCG' *.fastq > count/B1950_Fm0.txt
agrep -0 -c 'CGTAAGTCTATGGTGGC' *.fastq > count/B1952_Fm0.txt
agrep -0 -c 'TAATATACGCGAACGGC' *.fastq > count/B1953_Fm0.txt
agrep -0 -c 'ACCCGGTATGTCTTTTC' *.fastq > count/B1956_Fm0.txt
agrep -0 -c 'CTTAGCTATCACCCATT' *.fastq > count/B1957_Fm0.txt
agrep -0 -c 'ACGCAAACTAAGAGGTA' *.fastq > count/B1958_Fm0.txt
agrep -0 -c 'ATGCATCAGGTCCTGTT' *.fastq > count/B1960_Fm0.txt
agrep -0 -c 'ACAACAATGAGCATGCA' *.fastq > count/B1961_Fm0.txt
agrep -0 -c 'CACGCGTGCTGTCATAA' *.fastq > count/B1962_Fm0.txt
agrep -0 -c 'GAGCTCCTACGCAACAC' *.fastq > count/B1963_Fm0.txt
agrep -0 -c 'CGTAATATGCCACGTCT' *.fastq > count/B1964_Fm0.txt
agrep -0 -c 'GAGATATCTATTCCTCG' *.fastq > count/B1965_Fm0.txt
agrep -0 -c 'TGTATGGCCTCGAAGAA' *.fastq > count/B1967_Fm0.txt
agrep -0 -c 'GCTCTTTATAACGTCGC' *.fastq > count/B1968_Fm0.txt
agrep -0 -c 'CTATCGTATGCAGAGGC' *.fastq > count/B1971_Fm0.txt
agrep -0 -c 'CTGAATATCTTGTACCG' *.fastq > count/B1972_Fm0.txt
agrep -0 -c 'GGCATAAAGAGCTGCTA' *.fastq > count/B1973_Fm0.txt
agrep -0 -c 'TGGATAACCTGCCGGAA' *.fastq > count/B1974_Fm0.txt
agrep -0 -c 'ATTCCATCGTGAAGTGG' *.fastq > count/B1975_Fm0.txt
agrep -0 -c 'ATTCCTTTCGGCTGTAG' *.fastq > count/B1977_Fm0.txt
agrep -0 -c 'GACGGGTGATTATACCC' *.fastq > count/B1978_Fm0.txt
agrep -0 -c 'AAGTTCCTAGCGCTAAG' *.fastq > count/B1979_Fm0.txt
agrep -0 -c 'TGCCATCCGGATAGTTT' *.fastq > count/B1980_Fm0.txt
agrep -0 -c 'CAGCCGCAATGAATCGC' *.fastq > count/B1982_Fm0.txt
agrep -0 -c 'GTGAAATAGCGATCACG' *.fastq > count/B1983_Fm0.txt
agrep -0 -c 'AGCGGTAATGCCTGATG' *.fastq > count/B1984_Fm0.txt
agrep -0 -c 'GTCGTTGCAGAATCGCC' *.fastq > count/B1985_Fm0.txt
agrep -0 -c 'CGAGGAAAGCATCCTTG' *.fastq > count/B1986_Fm0.txt
agrep -0 -c 'TGCAGGCAAATTAGTAC' *.fastq > count/B1987_Fm0.txt
agrep -0 -c 'GTGCACTAGACCAATTC' *.fastq > count/B1988_Fm0.txt
agrep -0 -c 'AATATCTCTCGCCCGTT' *.fastq > count/B1989_Fm0.txt
agrep -0 -c 'CGGACTAGTTATACCGA' *.fastq > count/B1990_Fm0.txt
agrep -0 -c 'CAATAGCATTGCAGACA' *.fastq > count/B1992_Fm0.txt
agrep -0 -c 'AAGATCCCCTTTCGTGA' *.fastq > count/B1993_Fm0.txt
agrep -0 -c 'TGAGGAGTTATGCGGTG' *.fastq > count/B1994_Fm0.txt
agrep -0 -c 'CACCGATCCCCTACTAA' *.fastq > count/B1995_Fm0.txt
agrep -0 -c 'CGTTCGTTTCGATCAGG' *.fastq > count/B1996_Fm0.txt
agrep -0 -c 'TAACTGCCCGGCATTTG' *.fastq > count/B1997_Fm0.txt
agrep -0 -c 'TACACATGCGTCGGTGG' *.fastq > count/B1998_Fm0.txt
agrep -0 -c 'CGTCAAAGTAGAAGCGG' *.fastq > count/B2000_Fm0.txt
agrep -0 -c 'AGATCGGCCATAGGTAG' *.fastq > count/B2001_Fm0.txt
agrep -0 -c 'TCTTGGAGTGAGTATAC' *.fastq > count/B2002_Fm0.txt
agrep -0 -c 'GCTTCTACAGGCTCTTT' *.fastq > count/B2004_Fm0.txt
agrep -0 -c 'GTCAAGCACGCTACGAG' *.fastq > count/B2005_Fm0.txt
agrep -0 -c 'CGTGTATGTGATGGTGA' *.fastq > count/B2006_Fm0.txt
agrep -0 -c 'TGGATACCGCTTGAAGC' *.fastq > count/B2008_Fm0.txt
agrep -0 -c 'AGCTCGGCTCGATATGC' *.fastq > count/B2009_Fm0.txt
agrep -0 -c 'AATGGAGCCCAACCCTC' *.fastq > count/B2011_Fm0.txt
agrep -0 -c 'GTCTTACCATCGCGTCC' *.fastq > count/B2012_Fm0.txt
agrep -0 -c 'AGCGGCTCATGGTCAGA' *.fastq > count/B2014_Fm0.txt
agrep -0 -c 'GACTACTCTACTCTGGG' *.fastq > count/B2016_Fm0.txt
agrep -0 -c 'AAGCGCAGAAACTGGTT' *.fastq > count/B2017_Fm0.txt
agrep -0 -c 'GACATAGTGCGAAGCGT' *.fastq > count/B2019_Fm0.txt
agrep -0 -c 'CCAGTTGCCGCCAAGTT' *.fastq > count/B2020_Fm0.txt
agrep -0 -c 'GTATTAGGCTTAGCACT' *.fastq > count/B2022_Fm0.txt
agrep -0 -c 'GCCGTTGAACCTCCCAA' *.fastq > count/B2023_Fm0.txt
agrep -0 -c 'GTGAGATAACACGGGAC' *.fastq > count/B2024_Fm0.txt
agrep -0 -c 'AACCAACCGGGAATATA' *.fastq > count/B2026_Fm0.txt
agrep -0 -c 'CAGCCCTGGTTGAACTC' *.fastq > count/B2027_Fm0.txt
agrep -0 -c 'CGTGCTATGGCTTCGAC' *.fastq > count/B2028_Fm0.txt
agrep -0 -c 'AGTCTACACTCGGGAGA' *.fastq > count/B2029_Fm0.txt
agrep -0 -c 'ATTGTGACTGGGGTTTA' *.fastq > count/B2030_Fm0.txt
agrep -0 -c 'ACCTCTGACCGTCGAAC' *.fastq > count/B2031_Fm0.txt
agrep -0 -c 'TGACGACGTTTTACCAG' *.fastq > count/B2032_Fm0.txt
agrep -0 -c 'TAATGTACGGCGCGAGA' *.fastq > count/B2033_Fm0.txt
agrep -0 -c 'TGCGCCCAACCACGATA' *.fastq > count/B2034_Fm0.txt
agrep -0 -c 'TTATCACTAGAGGGCTA' *.fastq > count/B2036_Fm0.txt
agrep -0 -c 'CACGGATGACTTCGATT' *.fastq > count/B2037_Fm0.txt
agrep -0 -c 'CGAGATCCTTGCCTTCA' *.fastq > count/B2038_Fm0.txt
agrep -0 -c 'CCTTGTGTTTGTCCGCA' *.fastq > count/B2039_Fm0.txt
agrep -0 -c 'CGTTGTTATTCGTGTAG' *.fastq > count/B2040_Fm0.txt
agrep -0 -c 'TGCTGCGGTCTAAGCTC' *.fastq > count/B2041_Fm0.txt
agrep -0 -c 'TAGGGTGAGCCTTAGCA' *.fastq > count/B2042_Fm0.txt
agrep -0 -c 'CGTACCGAATCTCTCTA' *.fastq > count/B2043_Fm0.txt
agrep -0 -c 'CTTGTGCGGTAACTGCA' *.fastq > count/B2044_Fm0.txt
agrep -0 -c 'TCTTCAAACCGTCTGGG' *.fastq > count/B2045_Fm0.txt
agrep -0 -c 'CAGGTGATAGCCGTAGC' *.fastq > count/B2046_Fm0.txt
agrep -0 -c 'TAGCGCACATGCTCGAT' *.fastq > count/B2049_Fm0.txt
agrep -0 -c 'ATGATAGGCGTCCTGTC' *.fastq > count/B2050_Fm0.txt
agrep -0 -c 'AGTTACGATATTCTCCC' *.fastq > count/B2051_Fm0.txt
agrep -0 -c 'CCTCTTTTGAATTGGGT' *.fastq > count/B2052_Fm0.txt
agrep -0 -c 'CGCTTAGTTGCCTAGAG' *.fastq > count/B2053_Fm0.txt
agrep -0 -c 'GACCGCTTAGAGATCCA' *.fastq > count/B2054_Fm0.txt
agrep -0 -c 'ATTACACAGCAGCTGTG' *.fastq > count/B2055_Fm0.txt
agrep -0 -c 'GGTACATTCCGGAAGAA' *.fastq > count/B2056_Fm0.txt
agrep -0 -c 'GTACCGAGGATGCAAGA' *.fastq > count/B2057_Fm0.txt
agrep -0 -c 'TTCATCCGCCAAGGATC' *.fastq > count/B2058_Fm0.txt
agrep -0 -c 'CCATTACACTTCCGTCG' *.fastq > count/B2059_Fm0.txt
agrep -0 -c 'AATGTTACGCGTACAGT' *.fastq > count/B2060_Fm0.txt
agrep -0 -c 'AGAGATTAGGCGAAGAT' *.fastq > count/B2061_Fm0.txt
agrep -0 -c 'TTAGCTTACCTGCGGCG' *.fastq > count/B2064_Fm0.txt
agrep -0 -c 'GCGGTACTATCTGATTT' *.fastq > count/B2067_Fm0.txt
agrep -0 -c 'CGCGTAGAGCCATACTT' *.fastq > count/B2068_Fm0.txt
agrep -0 -c 'TTCTTCAAGCTAATGCG' *.fastq > count/B2069_Fm0.txt
agrep -0 -c 'CAATGGAGTTCAACTTC' *.fastq > count/B2070_Fm0.txt
agrep -0 -c 'CGTAGTATTGCGTTGAA' *.fastq > count/B2071_Fm0.txt
agrep -0 -c 'TGTCACTGACGTCACGA' *.fastq > count/B2074_Fm0.txt
agrep -0 -c 'CCTATCGACACTCCGCA' *.fastq > count/B2076_Fm0.txt
agrep -0 -c 'TCTTGAGGGTAAGAGGT' *.fastq > count/B2077_Fm0.txt
agrep -0 -c 'TCTGCCTGCCCCGATTA' *.fastq > count/B2078_Fm0.txt
agrep -0 -c 'TGCTCAGTGAGCGTAGG' *.fastq > count/B2079_Fm0.txt
agrep -0 -c 'ATAGCTGCCAGCCGCAT' *.fastq > count/B2080_Fm0.txt
agrep -0 -c 'GACCCAAACGAGACGAA' *.fastq > count/B2081_Fm0.txt
agrep -0 -c 'AAGGAGTAGATGCAGTT' *.fastq > count/B2084_Fm0.txt
agrep -0 -c 'TAACCCGCGCTGGAATC' *.fastq > count/B2085_Fm0.txt
agrep -0 -c 'TTCCTATTCGACGCGTT' *.fastq > count/B2087_Fm0.txt
agrep -0 -c 'TGAGGGCCATACCCTGT' *.fastq > count/B2088_Fm0.txt
agrep -0 -c 'ACTCCGGTTATTACCGG' *.fastq > count/B2089_Fm0.txt
agrep -0 -c 'TGATAGTGCCCCAGCGT' *.fastq > count/B2090_Fm0.txt
agrep -0 -c 'GTCCGCATTAAAGCGTA' *.fastq > count/B2091_Fm0.txt
agrep -0 -c 'ACGTTGTCCCTTGAGTA' *.fastq > count/B2092_Fm0.txt
agrep -0 -c 'CGGGTGTTAGCACTTCT' *.fastq > count/B2093_Fm0.txt
agrep -0 -c 'TCGACTATGCACGTCGA' *.fastq > count/B2094_Fm0.txt
agrep -0 -c 'GTCTCAAACGGCTTCGC' *.fastq > count/B2095_Fm0.txt
agrep -0 -c 'ATTCACAAAGCGTCGCG' *.fastq > count/B2096_Fm0.txt
agrep -0 -c 'TTGATCCCGACCGCTTT' *.fastq > count/B2097_Fm0.txt
agrep -0 -c 'CAAATCAAGCCCCCTCG' *.fastq > count/B2098_Fm0.txt
agrep -0 -c 'TCATAGGGTAGAGCACG' *.fastq > count/B2099_Fm0.txt
agrep -0 -c 'GACCGGTTTTTCAGATT' *.fastq > count/B2100_Fm0.txt
agrep -0 -c 'CACCTTCAAAGTTGTAG' *.fastq > count/B2101_Fm0.txt
agrep -0 -c 'CACAGAGGGATAGGGCA' *.fastq > count/B2103_Fm0.txt
agrep -0 -c 'CTACGCAACGGACCTAC' *.fastq > count/B2104_Fm0.txt
agrep -0 -c 'TAACTGAAAGGGCCTTC' *.fastq > count/B2105_Fm0.txt
agrep -0 -c 'TCTGCTATACGAGAATC' *.fastq > count/B2106_Fm0.txt
agrep -0 -c 'AGCGTCTCAGTCGTTCG' *.fastq > count/B2107_Fm0.txt
agrep -0 -c 'GCGCTATATTGGGAAGC' *.fastq > count/B2108_Fm0.txt
agrep -0 -c 'GAGAAGCTAGAACCGCC' *.fastq > count/B2109_Fm0.txt
agrep -0 -c 'GTTAGAGCGCTTTGTTG' *.fastq > count/B2110_Fm0.txt
agrep -0 -c 'GCAATGGCGACTGATTC' *.fastq > count/B2111_Fm0.txt
agrep -0 -c 'TGAAGTATGTGGTCTTG' *.fastq > count/B2112_Fm0.txt
agrep -0 -c 'TATAGGCGTCAAGAGAC' *.fastq > count/B2114_Fm0.txt
agrep -0 -c 'GAGTAGGTTATGGGGTC' *.fastq > count/B2116_Fm0.txt
agrep -0 -c 'CCTCCCATAGTTTTGCG' *.fastq > count/B2118_Fm0.txt
agrep -0 -c 'GAGTCTATGCTCGTCAG' *.fastq > count/B2119_Fm0.txt
agrep -0 -c 'AAGCGTTTTGCTCATCG' *.fastq > count/B2120_Fm0.txt
agrep -0 -c 'CGTGCCGGATCATGATA' *.fastq > count/B2121_Fm0.txt
agrep -0 -c 'TAGACTGGCGCGATTCA' *.fastq > count/B2122_Fm0.txt
agrep -0 -c 'CGTATCCCTCACAGCCT' *.fastq > count/B2124_Fm0.txt
agrep -0 -c 'GACCAGGTCACTGCTAA' *.fastq > count/B2125_Fm0.txt
agrep -0 -c 'ACCGGGGGACCCTATTT' *.fastq > count/B2126_Fm0.txt
agrep -0 -c 'GATGTGCCTAATGGACG' *.fastq > count/B2127_Fm0.txt
agrep -0 -c 'ACGAGCCTTAGGGTAGC' *.fastq > count/B2128_Fm0.txt
agrep -0 -c 'AGTCTGTAGCGTGCAAC' *.fastq > count/B2129_Fm0.txt
agrep -0 -c 'TACAAAAACGCACTCAG' *.fastq > count/B2130_Fm0.txt
agrep -0 -c 'CGTACTAGCGTCTTTCT' *.fastq > count/B2131_Fm0.txt
agrep -0 -c 'TTGGTGCGTACCATCTC' *.fastq > count/B2132_Fm0.txt
agrep -0 -c 'TCTCGAACGAGGACTTC' *.fastq > count/B2135_Fm0.txt
agrep -0 -c 'ACGCACACGAAATCAAT' *.fastq > count/B2137_Fm0.txt
agrep -0 -c 'ATAAACGCGGTTATGCT' *.fastq > count/B2138_Fm0.txt
agrep -0 -c 'TAGGGACCGTGTGACTA' *.fastq > count/B2139_Fm0.txt
agrep -0 -c 'TCGGTGTTTACTACGTG' *.fastq > count/B2140_Fm0.txt
agrep -0 -c 'TAAACCATGTGCGCTAT' *.fastq > count/B2141_Fm0.txt
agrep -0 -c 'ATACGTATGCCCGTACT' *.fastq > count/B2142_Fm0.txt
agrep -0 -c 'ATGCCTCGCCCCTAACA' *.fastq > count/B2144_Fm0.txt
agrep -0 -c 'TACCAAGTGTAAGTTGG' *.fastq > count/B2145_Fm0.txt
agrep -0 -c 'TTGTAAGCGGTCAACTG' *.fastq > count/B2146_Fm0.txt
agrep -0 -c 'CAGCGCTGCAGATACCA' *.fastq > count/B2148_Fm0.txt
agrep -0 -c 'TTAGGATTCTGCCGCTA' *.fastq > count/B2149_Fm0.txt
agrep -0 -c 'ATGAGGTTCTTAAGTCG' *.fastq > count/B2150_Fm0.txt
agrep -0 -c 'ACATCCTCCTAGGCTAG' *.fastq > count/B2151_Fm0.txt
agrep -0 -c 'GCATACTATGCCTATGG' *.fastq > count/B2152_Fm0.txt
agrep -0 -c 'TTCACTCAATTCACCCG' *.fastq > count/B2153_Fm0.txt
agrep -0 -c 'CACATCTCCGTTGAACG' *.fastq > count/B2154_Fm0.txt
agrep -0 -c 'GTACCTAATTCTCGTAG' *.fastq > count/B2155_Fm0.txt
agrep -0 -c 'CGCTGTATCAAATTGCG' *.fastq > count/B2157_Fm0.txt
agrep -0 -c 'ACGACAGCGACTGTACC' *.fastq > count/B2158_Fm0.txt
agrep -0 -c 'CATTGGCCGTCAACTTT' *.fastq > count/B2159_Fm0.txt
agrep -0 -c 'GTCACCATTTCATCGCC' *.fastq > count/B2160_Fm0.txt
agrep -0 -c 'AGAGGTCGGTAGCTATA' *.fastq > count/B2161_Fm0.txt
agrep -0 -c 'TTAGTAAATCCCGCGGG' *.fastq > count/B2162_Fm0.txt
agrep -0 -c 'ATTACGCGTCCGAAGTC' *.fastq > count/B2163_Fm0.txt
agrep -0 -c 'CCGGCATTATTGCTTAA' *.fastq > count/B2164_Fm0.txt
agrep -0 -c 'TTGGAGCTGACCCCTTA' *.fastq > count/B2165_Fm0.txt
agrep -0 -c 'TTACATAAGGTCCCCAA' *.fastq > count/B2166_Fm0.txt
agrep -0 -c 'CGATGTCGTTAACGGAT' *.fastq > count/B2167_Fm0.txt
agrep -0 -c 'TAATGGCCGAGCCCATT' *.fastq > count/B2170_Fm0.txt
agrep -0 -c 'GCGCACTGTAATCGAAA' *.fastq > count/B2171_Fm0.txt
agrep -0 -c 'CAGACTTCCACCCCGTT' *.fastq > count/B2172_Fm0.txt
agrep -0 -c 'TTAATAGTCCGGGCTAG' *.fastq > count/B2173_Fm0.txt
agrep -0 -c 'CATGACGCGTTAGAGCG' *.fastq > count/B2174_Fm0.txt
agrep -0 -c 'CCTAAGCTGGCTGGGTA' *.fastq > count/B2175_Fm0.txt
agrep -0 -c 'TCGTTCATGAGTTGGAT' *.fastq > count/B2176_Fm0.txt
agrep -0 -c 'GAGGTTTCACCAGGTCA' *.fastq > count/B2177_Fm0.txt
agrep -0 -c 'CAGCAAAATGACCTACG' *.fastq > count/B2179_Fm0.txt
agrep -0 -c 'AACACTCTATGCGGAGT' *.fastq > count/B2180_Fm0.txt
agrep -0 -c 'AGGACTCTCGAGTGTCA' *.fastq > count/B2181_Fm0.txt
agrep -0 -c 'CCTGTGAATGAAACGCT' *.fastq > count/B2182_Fm0.txt
agrep -0 -c 'ATGCGTTATTCTCCACC' *.fastq > count/B2183_Fm0.txt
agrep -0 -c 'ACAATAAGGCGCTCATG' *.fastq > count/B2184_Fm0.txt
agrep -0 -c 'TTGGTATTGACTACCCT' *.fastq > count/B2185_Fm0.txt
agrep -0 -c 'GTAACCTCGGCACAATA' *.fastq > count/B2186_Fm0.txt
agrep -0 -c 'ATGGCCACTACCTTCCC' *.fastq > count/B2187_Fm0.txt
agrep -0 -c 'ATAGGACGATGGGATTC' *.fastq > count/B2188_Fm0.txt
agrep -0 -c 'AGCGCACAATCGTATCA' *.fastq > count/B2189_Fm0.txt
agrep -0 -c 'TCGGCAGCAGTTATTTT' *.fastq > count/B2190_Fm0.txt
agrep -0 -c 'GCAGCCATCCTAGAACC' *.fastq > count/B2192_Fm0.txt
agrep -0 -c 'TAAAGTAGGACGTAGAC' *.fastq > count/B2194_Fm0.txt
agrep -0 -c 'CCGATATAGTAGACGGA' *.fastq > count/B2195_Fm0.txt
agrep -0 -c 'ACTGATACCCAAGTCTG' *.fastq > count/B2196_Fm0.txt
agrep -0 -c 'TTAGCACGATTACCGAG' *.fastq > count/B2197_Fm0.txt
agrep -0 -c 'AGCTTGGCGCATTGTGA' *.fastq > count/B2198_Fm0.txt
agrep -0 -c 'AGAAGGGACGATGGATT' *.fastq > count/B2200_Fm0.txt
agrep -0 -c 'ACGGCAAAGTAAGTCCA' *.fastq > count/B2201_Fm0.txt
agrep -0 -c 'ATCACGATAATTCGTGC' *.fastq > count/B2202_Fm0.txt
agrep -0 -c 'ATAACTGTAAACGGTCC' *.fastq > count/B2203_Fm0.txt
agrep -0 -c 'TCGTGACCTATAACGCT' *.fastq > count/B2204_Fm0.txt
agrep -0 -c 'AATGCTTTACTGCGCCC' *.fastq > count/B2205_Fm0.txt
agrep -0 -c 'ACGCTCTGCAGTGAGCT' *.fastq > count/B2206_Fm0.txt
agrep -0 -c 'CCAAGAAACTGGACCGC' *.fastq > count/B2207_Fm0.txt
agrep -0 -c 'GATTCCGGTTGAACCAA' *.fastq > count/B2208_Fm0.txt
agrep -0 -c 'TCGATGCCCGTATCACC' *.fastq > count/B2209_Fm0.txt
agrep -0 -c 'CAATACATGCTCCTCAA' *.fastq > count/B2210_Fm0.txt
agrep -0 -c 'ATCATGCGGGGATTCTT' *.fastq > count/B2211_Fm0.txt
agrep -0 -c 'ACCATCGATATACTCTC' *.fastq > count/B2212_Fm0.txt
agrep -0 -c 'TTGGAAGGACTAGCGCA' *.fastq > count/B2213_Fm0.txt
agrep -0 -c 'GTGGCGACATTCCTGTT' *.fastq > count/B2214_Fm0.txt
agrep -0 -c 'CGGGACTTACTGTGTGG' *.fastq > count/B2215_Fm0.txt
agrep -0 -c 'CGTACCCGCGTGTAGAT' *.fastq > count/B2217_Fm0.txt
agrep -0 -c 'TAGAAGCTAAAGCGCAA' *.fastq > count/B2218_Fm0.txt
agrep -0 -c 'TCGGGGAACTTTATTCC' *.fastq > count/B2219_Fm0.txt
agrep -0 -c 'CTCCGGTTCTTTAAGAT' *.fastq > count/B2220_Fm0.txt
agrep -0 -c 'GTCACGCTCACAGATCA' *.fastq > count/B2221_Fm0.txt
agrep -0 -c 'ACGGACCATGTTGTCGA' *.fastq > count/B2222_Fm0.txt
agrep -0 -c 'CCACTCTTCAGACGCAC' *.fastq > count/B2223_Fm0.txt
agrep -0 -c 'CACAGTGACCCACGATT' *.fastq > count/B2225_Fm0.txt
agrep -0 -c 'CGACAGCTTATGGTTGC' *.fastq > count/B2227_Fm0.txt
agrep -0 -c 'TACTCGCATTATCCTAG' *.fastq > count/B2228_Fm0.txt
agrep -0 -c 'GCCAAATAACTTGGTCT' *.fastq > count/B2229_Fm0.txt
agrep -0 -c 'GCAACACTATTGGTCAA' *.fastq > count/B2230_Fm0.txt
agrep -0 -c 'TGTGCTCCTTAGCCACC' *.fastq > count/B2231_Fm0.txt
agrep -0 -c 'ACAAAGACCTGGACCTA' *.fastq > count/B2233_Fm0.txt
agrep -0 -c 'GGTTTGCTACGCCAGAT' *.fastq > count/B2234_Fm0.txt
agrep -0 -c 'AGTGAATCCATCTGTGT' *.fastq > count/B2235_Fm0.txt
agrep -0 -c 'AACCGCGATGGTACATT' *.fastq > count/B2236_Fm0.txt
agrep -0 -c 'TACTGGCTGCATCAAAA' *.fastq > count/B2237_Fm0.txt
agrep -0 -c 'CGATTTGGCGACCAATG' *.fastq > count/B2238_Fm0.txt
agrep -0 -c 'GAGATTGACACAAAGTG' *.fastq > count/B2239_Fm0.txt
agrep -0 -c 'CGGGGTACCGAGAACAA' *.fastq > count/B2240_Fm0.txt
agrep -0 -c 'GTGTGAATCAAGCAATC' *.fastq > count/B2241_Fm0.txt
agrep -0 -c 'GTAGTTTTAAGGGGCTA' *.fastq > count/B2242_Fm0.txt
agrep -0 -c 'CCAACTTTGGCACCTCG' *.fastq > count/B2243_Fm0.txt
agrep -0 -c 'TACCCTACCGATCGTTC' *.fastq > count/B2244_Fm0.txt
agrep -0 -c 'CTCGAACCGGGAATATT' *.fastq > count/B2245_Fm0.txt
agrep -0 -c 'TTCGTGTCGACAGCAAC' *.fastq > count/B2246_Fm0.txt
agrep -0 -c 'GCGATCACTTAGCCACA' *.fastq > count/B2247_Fm0.txt
agrep -0 -c 'AGTTAGGACGGGTCGGT' *.fastq > count/B2248_Fm0.txt
agrep -0 -c 'CTACGGAGGTGCTGCAA' *.fastq > count/B2249_Fm0.txt
agrep -0 -c 'CGATAGTCAGGATTAGA' *.fastq > count/B2250_Fm0.txt
agrep -0 -c 'CAAATTCACACGCCCTA' *.fastq > count/B2251_Fm0.txt
agrep -0 -c 'GTACGGCTCTGCTAGTG' *.fastq > count/B2252_Fm0.txt
agrep -0 -c 'GTCTGATAGCTTCGATA' *.fastq > count/B2254_Fm0.txt
agrep -0 -c 'TGCCAAAGTTGCACAAT' *.fastq > count/B2256_Fm0.txt
agrep -0 -c 'CATGACTATCATCACTC' *.fastq > count/B2258_Fm0.txt
agrep -0 -c 'TACGGTTTGTGGCATAG' *.fastq > count/B2260_Fm0.txt
agrep -0 -c 'ATTGTTAGGCCTTCGTG' *.fastq > count/B2261_Fm0.txt
agrep -0 -c 'CAGGTTTAACGGTTTAG' *.fastq > count/B2262_Fm0.txt
agrep -0 -c 'CGCGTGAAAAACTGTTA' *.fastq > count/B2263_Fm0.txt
agrep -0 -c 'AAGGAGGACTGGTGGTA' *.fastq > count/B2264_Fm0.txt
agrep -0 -c 'GTCTTCCTATGCTAGTT' *.fastq > count/B2265_Fm0.txt
agrep -0 -c 'TCGGGTATTCGTGTCGT' *.fastq > count/B2266_Fm0.txt
agrep -0 -c 'TGAATCGATCTACGGTC' *.fastq > count/B2267_Fm0.txt
agrep -0 -c 'CGCCTTATGACTGTGTG' *.fastq > count/B2268_Fm0.txt
agrep -0 -c 'TTCTGATGGGGGGCAAG' *.fastq > count/B2269_Fm0.txt
agrep -0 -c 'CTATGAGCTGGCGCTTA' *.fastq > count/B2270_Fm0.txt
agrep -0 -c 'ATGTCTGCGGGAAAGGC' *.fastq > count/B2272_Fm0.txt
agrep -0 -c 'TAGCCACCGGATCAGAT' *.fastq > count/B2273_Fm0.txt
agrep -0 -c 'TAAATTGTGGGACTCTC' *.fastq > count/B2274_Fm0.txt
agrep -0 -c 'AACGTATCGCATCCTGA' *.fastq > count/B2275_Fm0.txt
agrep -0 -c 'GATGTTGGGGACCTGTT' *.fastq > count/B2277_Fm0.txt
agrep -0 -c 'ATGTACGCGGATGCATG' *.fastq > count/B2278_Fm0.txt
agrep -0 -c 'GGAGTCCTGGTGCCTAA' *.fastq > count/B2279_Fm0.txt
agrep -0 -c 'CGTTAAATAGACGCCTG' *.fastq > count/B2280_Fm0.txt
agrep -0 -c 'TGATTGGCTACCGTAGA' *.fastq > count/B2281_Fm0.txt
agrep -0 -c 'TCGCGTGACCATTACAT' *.fastq > count/B2282_Fm0.txt
agrep -0 -c 'AGGAGATAGGCAAACCC' *.fastq > count/B2283_Fm0.txt
agrep -0 -c 'CTAGGACTTATCTCGCT' *.fastq > count/B2284_Fm0.txt
agrep -0 -c 'AGAGATGGTCATCGAAA' *.fastq > count/B2286_Fm0.txt
agrep -0 -c 'CCTGAGATCGTTCAATT' *.fastq > count/B2287_Fm0.txt
agrep -0 -c 'TTCACCCATGAGACCCA' *.fastq > count/B2288_Fm0.txt
agrep -0 -c 'CGCAAAGCTTTTACACT' *.fastq > count/B2289_Fm0.txt
agrep -0 -c 'AGGAGCTTATCCGTTCA' *.fastq > count/B2290_Fm0.txt
agrep -0 -c 'GATCGTGAGTCCGCTTA' *.fastq > count/B2291_Fm0.txt
agrep -0 -c 'TTAAGAAGAGCGGATGA' *.fastq > count/B2293_Fm0.txt
agrep -0 -c 'TAGTGAAAAGCCGGGTA' *.fastq > count/B2294_Fm0.txt
agrep -0 -c 'GCCTATATGTAACCTAG' *.fastq > count/B2295_Fm0.txt
agrep -0 -c 'GAGTTCCGTCCGTAACA' *.fastq > count/B2296_Fm0.txt
agrep -0 -c 'TCAGTTGATACACAGAG' *.fastq > count/B2297_Fm0.txt
agrep -0 -c 'TGACCGTTTCCTATCTC' *.fastq > count/B2298_Fm0.txt
agrep -0 -c 'CGAAGTTCTGCTATTGG' *.fastq > count/B2299_Fm0.txt
agrep -0 -c 'AGACGAACATGAGGACA' *.fastq > count/B2300_Fm0.txt
agrep -0 -c 'GTCACAACTAACAGGTC' *.fastq > count/B2303_Fm0.txt
agrep -0 -c 'TGAATGCTTGTTACCGG' *.fastq > count/B2304_Fm0.txt
agrep -0 -c 'TTGAGTCATACGACCCG' *.fastq > count/B2305_Fm0.txt
agrep -0 -c 'GCCTGTTTGATCTATGC' *.fastq > count/B2306_Fm0.txt
agrep -0 -c 'CCGGAGCGGATTAATAA' *.fastq > count/B2307_Fm0.txt
agrep -0 -c 'CTATTCCGCGTATGGTC' *.fastq > count/B2308_Fm0.txt
agrep -0 -c 'ATATACCCTCCGGGGTG' *.fastq > count/B2309_Fm0.txt
agrep -0 -c 'CGCACTTAGCCCAAACA' *.fastq > count/B2310_Fm0.txt
agrep -0 -c 'TGGACCAAGTTTTGCAT' *.fastq > count/B2311_Fm0.txt
agrep -0 -c 'CTGTGATACAGCGGGTT' *.fastq > count/B2312_Fm0.txt
agrep -0 -c 'ACGTGGAACGGCTTTAG' *.fastq > count/B2313_Fm0.txt
agrep -0 -c 'TAGTTGACGCGATTGAT' *.fastq > count/B2314_Fm0.txt
agrep -0 -c 'GACCGCAAGAAATCACG' *.fastq > count/B2315_Fm0.txt
agrep -0 -c 'ACAGGGATTGGGCGGAT' *.fastq > count/B2316_Fm0.txt
agrep -0 -c 'ATAAGAATACGGGCCTA' *.fastq > count/B2317_Fm0.txt
agrep -0 -c 'CGCAAACAGAGGGCAGT' *.fastq > count/B2318_Fm0.txt
agrep -0 -c 'CTTGGTTAGATAACCTG' *.fastq > count/B2319_Fm0.txt
agrep -0 -c 'CTTCAGTCGGGAAGTGG' *.fastq > count/B2320_Fm0.txt
agrep -0 -c 'GTACTTGGGTATTGCCC' *.fastq > count/B2321_Fm0.txt
agrep -0 -c 'ATAGATTCTGGCACTGG' *.fastq > count/B2322_Fm0.txt
agrep -0 -c 'AATGACGTAACCTCATC' *.fastq > count/B2323_Fm0.txt
agrep -0 -c 'ATGAATTGGGGGAGTAC' *.fastq > count/B2324_Fm0.txt
agrep -0 -c 'AGGTTTGGCTGGTGGTG' *.fastq > count/B2325_Fm0.txt
agrep -0 -c 'GTGCAGCCCTAGTACCT' *.fastq > count/B2326_Fm0.txt
agrep -0 -c 'GTATTGCCGACCAACCG' *.fastq > count/B2327_Fm0.txt
agrep -0 -c 'CGGGATCATAACTGCTC' *.fastq > count/B2328_Fm0.txt
agrep -0 -c 'AGCGCATATGAGCTAGG' *.fastq > count/B2329_Fm0.txt
agrep -0 -c 'TGATTTGGCGATAGTCA' *.fastq > count/B2330_Fm0.txt
agrep -0 -c 'AGTAGCCCACAAGCGTG' *.fastq > count/B2331_Fm0.txt
agrep -0 -c 'GTTTGAGGTCCGAGCTT' *.fastq > count/B2332_Fm0.txt
agrep -0 -c 'GCGCAATTTCCCAACCC' *.fastq > count/B2333_Fm0.txt
agrep -0 -c 'GTATCCAACTTGTAGTG' *.fastq > count/B2335_Fm0.txt
agrep -0 -c 'AGTCGTCGTTTGGGATA' *.fastq > count/B2336_Fm0.txt
agrep -0 -c 'AACTCAACCACAGTTCT' *.fastq > count/B2337_Fm0.txt
agrep -0 -c 'AGTGACCGCGTTACGGT' *.fastq > count/B2340_Fm0.txt
agrep -0 -c 'AACGCGGGCATGAAGCT' *.fastq > count/B2341_Fm0.txt
agrep -0 -c 'AATGACTGCCCCTTCGA' *.fastq > count/B2342_Fm0.txt
agrep -0 -c 'TTCCAATAGCCGTTACC' *.fastq > count/B2343_Fm0.txt
agrep -0 -c 'CAGAACTGACGGCCTTT' *.fastq > count/B2345_Fm0.txt
agrep -0 -c 'CTTCCTGTAGACGAATA' *.fastq > count/B2346_Fm0.txt
agrep -0 -c 'CTCAAGCCGCAGTTATC' *.fastq > count/B2347_Fm0.txt
agrep -0 -c 'GATATAGAGACTAGCGA' *.fastq > count/B2348_Fm0.txt
agrep -0 -c 'AACTGTTTCGCACCCAC' *.fastq > count/B2349_Fm0.txt
agrep -0 -c 'CTTGGTCACGAAGCCAG' *.fastq > count/B2350_Fm0.txt
agrep -0 -c 'AGCCTTTGTTTCGCGAT' *.fastq > count/B2351_Fm0.txt
agrep -0 -c 'GTGACAGTGAGTATATC' *.fastq > count/B2352_Fm0.txt
agrep -0 -c 'TACAGATTAGAGCGTGC' *.fastq > count/B2353_Fm0.txt
agrep -0 -c 'AGCAGTTATGGATCCCC' *.fastq > count/B2354_Fm0.txt
agrep -0 -c 'CGCCGTATGCAGATCGT' *.fastq > count/B2355_Fm0.txt
agrep -0 -c 'CGGGTGTTGGGACCTTT' *.fastq > count/B2356_Fm0.txt
agrep -0 -c 'ACCCTATCGCATGCATC' *.fastq > count/B2357_Fm0.txt
agrep -0 -c 'TGACTAACGCGGACATT' *.fastq > count/B2359_Fm0.txt
agrep -0 -c 'CCGCAAACAGTCCCAAA' *.fastq > count/B2360_Fm0.txt
agrep -0 -c 'TCGATGAGATAACGGTT' *.fastq > count/B2361_Fm0.txt
agrep -0 -c 'AGTAGCACGATCCATAC' *.fastq > count/B2362_Fm0.txt
agrep -0 -c 'GTTACCTAGGCGCCAGT' *.fastq > count/B2363_Fm0.txt
agrep -0 -c 'ACAATCCCTAACCGAAA' *.fastq > count/B2364_Fm0.txt
agrep -0 -c 'GATTGTGCGATGGACTC' *.fastq > count/B2366_Fm0.txt
agrep -0 -c 'TTATAGGAGTCGACATC' *.fastq > count/B2368_Fm0.txt
agrep -0 -c 'GGTCCCGTAAGCATTGC' *.fastq > count/B2369_Fm0.txt
agrep -0 -c 'AGTTTCGCGGAAGGCCA' *.fastq > count/B2370_Fm0.txt
agrep -0 -c 'TCAAGATCTGGGGGCCT' *.fastq > count/B2371_Fm0.txt
agrep -0 -c 'TGAAAAGCGTCACTGGG' *.fastq > count/B2372_Fm0.txt
agrep -0 -c 'CCTCGGAAGGAACAGAC' *.fastq > count/B2374_Fm0.txt
agrep -0 -c 'ACCGAAATCTTCTTGCC' *.fastq > count/B2375_Fm0.txt
agrep -0 -c 'AGTACACTTTATAGCGC' *.fastq > count/B2377_Fm0.txt
agrep -0 -c 'GAGAAGCATAGTGCGCT' *.fastq > count/B2378_Fm0.txt
agrep -0 -c 'CAGTTCACCGAGCGAAT' *.fastq > count/B2379_Fm0.txt
agrep -0 -c 'TCGGTCTCTGCAAAACC' *.fastq > count/B2380_Fm0.txt
agrep -0 -c 'CAGGGATCTAGTTCAGA' *.fastq > count/B2382_Fm0.txt
agrep -0 -c 'ACTTGAAAGGTTGGTAG' *.fastq > count/B2383_Fm0.txt
agrep -0 -c 'CCACCTTGTACAGCCGA' *.fastq > count/B2384_Fm0.txt
agrep -0 -c 'TGAGGGCACCAGTCTTA' *.fastq > count/B2385_Fm0.txt
agrep -0 -c 'TGAAATGCGGGGTAGAG' *.fastq > count/B2386_Fm0.txt
agrep -0 -c 'TGTTCTCAGGTGGAAGC' *.fastq > count/B2388_Fm0.txt
agrep -0 -c 'AGCGACCCTATACTCCA' *.fastq > count/B2389_Fm0.txt
agrep -0 -c 'AGGGCCCATTCTAGTCT' *.fastq > count/B2390_Fm0.txt
agrep -0 -c 'TGCCCTCCTACATATTT' *.fastq > count/B2392_Fm0.txt
agrep -0 -c 'CACTTTTCAACCATACC' *.fastq > count/B2393_Fm0.txt
agrep -0 -c 'GTGGAACGCATACATCG' *.fastq > count/B2395_Fm0.txt
agrep -0 -c 'ATGTAAGTCGCATCCCT' *.fastq > count/B2397_Fm0.txt
agrep -0 -c 'ACGCACCTTACGATCTC' *.fastq > count/B2398_Fm0.txt
agrep -0 -c 'TCTGGGTATATCGCCCT' *.fastq > count/B2399_Fm0.txt
agrep -0 -c 'GTATGGTAGACTGTGCT' *.fastq > count/B2400_Fm0.txt
agrep -0 -c 'GCACCTCGCGATATTAT' *.fastq > count/B2402_Fm0.txt
agrep -0 -c 'GGGGGTTTTTATGGCAA' *.fastq > count/B2403_Fm0.txt
agrep -0 -c 'CGCGAGCCTGACTAAAG' *.fastq > count/B2404_Fm0.txt
agrep -0 -c 'TCGATTTAGACAGCAAC' *.fastq > count/B2405_Fm0.txt
agrep -0 -c 'ATGGTAATGTAGGTAGG' *.fastq > count/B2406_Fm0.txt
agrep -0 -c 'CACCAGTGAATACCATT' *.fastq > count/B2407_Fm0.txt
agrep -0 -c 'GCGATTGATGCCCGCTA' *.fastq > count/B2408_Fm0.txt
agrep -0 -c 'TAGTTGGGAGTCTAAGT' *.fastq > count/B2410_Fm0.txt
agrep -0 -c 'GCCGTACGTAAAAGTAC' *.fastq > count/B2411_Fm0.txt
agrep -0 -c 'CAAGGGGACACAATTCC' *.fastq > count/B2412_Fm0.txt
agrep -0 -c 'ACGATCAAATATGCCCG' *.fastq > count/B2413_Fm0.txt
agrep -0 -c 'CTGGTGTCAATCGACAT' *.fastq > count/B2414_Fm0.txt
agrep -0 -c 'CTCGAACTTGCGTATAC' *.fastq > count/B2415_Fm0.txt
agrep -0 -c 'CCTAATTTTGTCAAGGG' *.fastq > count/B2416_Fm0.txt
agrep -0 -c 'GTAGCGACTTTATCCGT' *.fastq > count/B2417_Fm0.txt
agrep -0 -c 'AACTACGAGTCTTGCCC' *.fastq > count/B2418_Fm0.txt
agrep -0 -c 'TGCTTATGGCCTACGTA' *.fastq > count/B2420_Fm0.txt
agrep -0 -c 'TGTAAGAGTAATGCTCG' *.fastq > count/B2421_Fm0.txt
agrep -0 -c 'CAGTCCTATCTTCCAGC' *.fastq > count/B2422_Fm0.txt
agrep -0 -c 'GGCGCAGTATGACCATC' *.fastq > count/B2423_Fm0.txt
agrep -0 -c 'CGGGTCTTGGAGAACAG' *.fastq > count/B2424_Fm0.txt
agrep -0 -c 'TGATAAACGATCCCCGG' *.fastq > count/B2425_Fm0.txt
agrep -0 -c 'ATACCCAACTGATTACG' *.fastq > count/B2426_Fm0.txt
agrep -0 -c 'CGCACATAATAGCTACA' *.fastq > count/B2427_Fm0.txt
agrep -0 -c 'AAGCCCCGAGGTAAACG' *.fastq > count/B2428_Fm0.txt
agrep -0 -c 'GTTGACCCATCGTACTA' *.fastq > count/B2429_Fm0.txt
agrep -0 -c 'GTGACATAACGGATCCA' *.fastq > count/B2430_Fm0.txt
agrep -0 -c 'GTGTTTTCGAACTTGCG' *.fastq > count/B2431_Fm0.txt
agrep -0 -c 'CCAAATAGTGGGTGACG' *.fastq > count/B2432_Fm0.txt
agrep -0 -c 'CTCTTTCCCTGTCTATA' *.fastq > count/B2433_Fm0.txt
agrep -0 -c 'ACCCCGTTTCAGCAAAG' *.fastq > count/B2434_Fm0.txt
agrep -0 -c 'GTCATGAGGATGAGAGC' *.fastq > count/B2436_Fm0.txt
agrep -0 -c 'ATCATTAGTTCCGCCCT' *.fastq > count/B2437_Fm0.txt
agrep -0 -c 'AGTTTCGAAGCGTGCTG' *.fastq > count/B2438_Fm0.txt
agrep -0 -c 'GTCAGTCATCCCCTTTT' *.fastq > count/B2439_Fm0.txt
agrep -0 -c 'GGCGAACGTAGAATCCG' *.fastq > count/B2440_Fm0.txt
agrep -0 -c 'GACAGGCTAGGTCTATA' *.fastq > count/B2441_Fm0.txt
agrep -0 -c 'GACTCCGTTGCAATCCC' *.fastq > count/B2442_Fm0.txt
agrep -0 -c 'TAAGCCGCCTAGTTATA' *.fastq > count/B2443_Fm0.txt
agrep -0 -c 'TTCCACGCCTCTACAGA' *.fastq > count/B2445_Fm0.txt
agrep -0 -c 'CGTGGCTAGGAATATGT' *.fastq > count/B2446_Fm0.txt
agrep -0 -c 'CATAGGGTCGTGTCACA' *.fastq > count/B2447_Fm0.txt
agrep -0 -c 'TGTATAATCAGCGTGCA' *.fastq > count/B2448_Fm0.txt
agrep -0 -c 'CTAACTACTTCTGGAGG' *.fastq > count/B2449_Fm0.txt
agrep -0 -c 'GTACGTCTCGCTTGTCA' *.fastq > count/B2450_Fm0.txt
agrep -0 -c 'ATAATCATACTGGCTGG' *.fastq > count/B2452_Fm0.txt
agrep -0 -c 'TGCAGGGTGAAACTCCG' *.fastq > count/B2454_Fm0.txt
agrep -0 -c 'CAGGTTGAATATGGCTC' *.fastq > count/B2455_Fm0.txt
agrep -0 -c 'CCGTAGGGCATTTTGCA' *.fastq > count/B2456_Fm0.txt
agrep -0 -c 'CTTACCCCTGCTAGTTA' *.fastq > count/B2458_Fm0.txt
agrep -0 -c 'CAAACAACCGTATTGCC' *.fastq > count/B2460_Fm0.txt
agrep -0 -c 'TTAACCACACACATAGC' *.fastq > count/B2461_Fm0.txt
agrep -0 -c 'GGGTGACGGGTGTTTTT' *.fastq > count/B2462_Fm0.txt
agrep -0 -c 'TTACCCCGACTTCACAT' *.fastq > count/B2463_Fm0.txt
agrep -0 -c 'GCGGAACAGGAAAACTG' *.fastq > count/B2466_Fm0.txt
agrep -0 -c 'CTAAGAGAGCGCGTGGA' *.fastq > count/B2467_Fm0.txt
agrep -0 -c 'ATGGTGTTATGCTGAGA' *.fastq > count/B2469_Fm0.txt
agrep -0 -c 'ACTAGCCTCAGAGAGTG' *.fastq > count/B2470_Fm0.txt
agrep -0 -c 'GGCTTCTTGGTAAGCGA' *.fastq > count/B2471_Fm0.txt
agrep -0 -c 'TAAGCCTAGTCAGACTT' *.fastq > count/B2472_Fm0.txt
agrep -0 -c 'AGAACACGTGTCGCCCA' *.fastq > count/B2473_Fm0.txt
agrep -0 -c 'CTTGCCGCATAGCAGAA' *.fastq > count/B2474_Fm0.txt
agrep -0 -c 'TTCTACTGGGACTACCA' *.fastq > count/B2476_Fm0.txt
agrep -0 -c 'CGAGTTGGTGACAAGGT' *.fastq > count/B2477_Fm0.txt
agrep -0 -c 'TCTCCGAATTCTCCTAC' *.fastq > count/B2478_Fm0.txt
agrep -0 -c 'CGCCGCCTCAGTACTTT' *.fastq > count/B2479_Fm0.txt
agrep -0 -c 'GAGCACTCGGTGACGTT' *.fastq > count/B2480_Fm0.txt
agrep -0 -c 'GGTAGATTGACGGACGT' *.fastq > count/B2481_Fm0.txt
agrep -0 -c 'ATCGCGACTAGTTACTC' *.fastq > count/B2482_Fm0.txt
agrep -0 -c 'AACTACCTCCTCTGATG' *.fastq > count/B2483_Fm0.txt
agrep -0 -c 'ATCCGAGAGTTTAGGCT' *.fastq > count/B2484_Fm0.txt
agrep -0 -c 'CATCCGTAGTAGTCCAT' *.fastq > count/B2485_Fm0.txt
agrep -0 -c 'CACCCTTACATAGAGTT' *.fastq > count/B2486_Fm0.txt
agrep -0 -c 'CGCTACTTCTCGAGAAG' *.fastq > count/B2487_Fm0.txt
agrep -0 -c 'ACGTGCATAGGATTGCA' *.fastq > count/B2488_Fm0.txt
agrep -0 -c 'ATGGCCGAACTTTCTAG' *.fastq > count/B2489_Fm0.txt
agrep -0 -c 'AAGCTTTTGCGCTTGAC' *.fastq > count/B2490_Fm0.txt
agrep -0 -c 'ATCAGTAGCTTCAGCCC' *.fastq > count/B2491_Fm0.txt
agrep -0 -c 'ATATCTACATACGCGAG' *.fastq > count/B2492_Fm0.txt
agrep -0 -c 'TGCCACCCAGTATATTG' *.fastq > count/B2493_Fm0.txt
agrep -0 -c 'GGCTCGGGGGTTGATTT' *.fastq > count/B2494_Fm0.txt
agrep -0 -c 'CATCCTCAGCATAAGAC' *.fastq > count/B2495_Fm0.txt
agrep -0 -c 'GCGGAAGTTATGAGACT' *.fastq > count/B2496_Fm0.txt
agrep -0 -c 'TCTTTCGCATCTTCCTA' *.fastq > count/B2497_Fm0.txt
agrep -0 -c 'ATAAGAATCCGCCCACT' *.fastq > count/B2498_Fm0.txt
agrep -0 -c 'GTACCAGCAGCAGCTAG' *.fastq > count/B2500_Fm0.txt
agrep -0 -c 'GGAACCTCTGCGTCTTC' *.fastq > count/B2501_Fm0.txt
agrep -0 -c 'AGTACGGCCCTGGTCTT' *.fastq > count/B2502_Fm0.txt
agrep -0 -c 'GATGAGTATGGAAGTCT' *.fastq > count/B2503_Fm0.txt
agrep -0 -c 'ATGGATCAGTTGACTGC' *.fastq > count/B2504_Fm0.txt
agrep -0 -c 'TTATTGTGGGATGACGG' *.fastq > count/B2505_Fm0.txt
agrep -0 -c 'AGGATGGTGGCACGAAG' *.fastq > count/B2506_Fm0.txt
agrep -0 -c 'TTCGTACGGAGAGTTCC' *.fastq > count/B2507_Fm0.txt
agrep -0 -c 'ATGACTTAGTCATTGGC' *.fastq > count/B2508_Fm0.txt
agrep -0 -c 'AGAGAGCTTCGATAGTA' *.fastq > count/B2509_Fm0.txt
agrep -0 -c 'ATGGCCGTGACGACCTA' *.fastq > count/B2513_Fm0.txt
agrep -0 -c 'TAATCAGCGGTTGCAAA' *.fastq > count/B2514_Fm0.txt
agrep -0 -c 'GTAAGAGCTTGAGGATT' *.fastq > count/B2515_Fm0.txt
agrep -0 -c 'ACCATTGAAATGCTGGA' *.fastq > count/B2516_Fm0.txt
agrep -0 -c 'TTCTTAATCACACCGGT' *.fastq > count/B2517_Fm0.txt
agrep -0 -c 'AAGACTTAAAGGCACCC' *.fastq > count/B2518_Fm0.txt
agrep -0 -c 'ATTCCAGCCGGGAAAGA' *.fastq > count/B2519_Fm0.txt
agrep -0 -c 'TTCTTCACCCACAGTTG' *.fastq > count/B2520_Fm0.txt
agrep -0 -c 'AACTCGACCTGCCGACT' *.fastq > count/B2521_Fm0.txt
agrep -0 -c 'TCGGCTTCTCCGATCCA' *.fastq > count/B2522_Fm0.txt
agrep -0 -c 'TTAATCCAGCAGCGCCC' *.fastq > count/B2523_Fm0.txt
agrep -0 -c 'CCGGAAGACACGAATAC' *.fastq > count/B2524_Fm0.txt
agrep -0 -c 'AACGGTATACTGCGGTT' *.fastq > count/B2525_Fm0.txt
agrep -0 -c 'ACCGATGGACCAACACG' *.fastq > count/B2526_Fm0.txt
agrep -0 -c 'CGAATGCCCAAGAAGGC' *.fastq > count/B2528_Fm0.txt
agrep -0 -c 'TGGAATAACTCAAGCCT' *.fastq > count/B2529_Fm0.txt
agrep -0 -c 'TAACAACTGCAATCGGA' *.fastq > count/B2530_Fm0.txt
agrep -0 -c 'ATCGGGCAGCAGATGCA' *.fastq > count/B2531_Fm0.txt
agrep -0 -c 'CCGATATTTGACAGCGA' *.fastq > count/B2532_Fm0.txt
agrep -0 -c 'AGTCTGAATACGCTACA' *.fastq > count/B2533_Fm0.txt
agrep -0 -c 'GCACCTTTTAACGCCAA' *.fastq > count/B2534_Fm0.txt
agrep -0 -c 'GGTGCTTGTCTGGAGTA' *.fastq > count/B2535_Fm0.txt
agrep -0 -c 'TTGGCTTTGGGACGTAG' *.fastq > count/B2537_Fm0.txt
agrep -0 -c 'ACAACGGGTCGTAATCT' *.fastq > count/B2538_Fm0.txt
agrep -0 -c 'GTACGTTTTGGCGACGG' *.fastq > count/B2539_Fm0.txt
agrep -0 -c 'TATACAACGGGACTTCC' *.fastq > count/B2540_Fm0.txt
agrep -0 -c 'CGGCCCAATTCCCATTG' *.fastq > count/B2541_Fm0.txt
agrep -0 -c 'TAAACGAACTCGTTACC' *.fastq > count/B2543_Fm0.txt
agrep -0 -c 'GTTCCTTGAGAACGACG' *.fastq > count/B2544_Fm0.txt
agrep -0 -c 'ACATCCCTAAGTCGTCG' *.fastq > count/B2545_Fm0.txt
agrep -0 -c 'ATGACTCCCCGCAATCC' *.fastq > count/B2546_Fm0.txt
agrep -0 -c 'TGCTCCGATGGTGTTCG' *.fastq > count/B2547_Fm0.txt
agrep -0 -c 'TTAAGGTCGAGTTTACC' *.fastq > count/B2551_Fm0.txt
agrep -0 -c 'TAAGATATCACCGGCTG' *.fastq > count/B2552_Fm0.txt
agrep -0 -c 'CACTGCCGCGTCTAACT' *.fastq > count/B2553_Fm0.txt
agrep -0 -c 'GACCGACTAATATTGAC' *.fastq > count/B2554_Fm0.txt
agrep -0 -c 'CCTGAAACTTACCTGGT' *.fastq > count/B2555_Fm0.txt
agrep -0 -c 'GCTGGAGCCCTATTTGT' *.fastq > count/B2556_Fm0.txt
agrep -0 -c 'TGAGGCTCGAGCCACAA' *.fastq > count/B2557_Fm0.txt
agrep -0 -c 'GTGGGAGGTGTCCAATC' *.fastq > count/B2559_Fm0.txt
agrep -0 -c 'TGAGAAATACGTCTGCT' *.fastq > count/B2560_Fm0.txt
agrep -0 -c 'CGTAAACGAAAACGAGA' *.fastq > count/B2561_Fm0.txt
agrep -0 -c 'TCTTTCCCGTAATCTGT' *.fastq > count/B2562_Fm0.txt
agrep -0 -c 'AGAGCCGAATCATGGTC' *.fastq > count/B2563_Fm0.txt
agrep -0 -c 'GCCAGCTTCGGAGTAAT' *.fastq > count/B2564_Fm0.txt
agrep -0 -c 'TTAGCCTAGGTCGGTGC' *.fastq > count/B2565_Fm0.txt
agrep -0 -c 'GTGGTTCTGCGGTGGTA' *.fastq > count/B2566_Fm0.txt
agrep -0 -c 'ATATGCGCACCGTGATT' *.fastq > count/B2567_Fm0.txt
agrep -0 -c 'GGCTCGGCATGTCATAC' *.fastq > count/B2568_Fm0.txt
agrep -0 -c 'TAACCGACTAGGATGTC' *.fastq > count/B2569_Fm0.txt
agrep -0 -c 'CACGTACAGTGGTAACT' *.fastq > count/B2571_Fm0.txt
agrep -0 -c 'TGCGTTTCTGCTATTTG' *.fastq > count/B2572_Fm0.txt
agrep -0 -c 'CACATAATCCCGTTACG' *.fastq > count/B2573_Fm0.txt
agrep -0 -c 'CCATATCACCGGAACCC' *.fastq > count/B2574_Fm0.txt
agrep -0 -c 'TGCCTAGTGCAGACAAA' *.fastq > count/B2575_Fm0.txt
agrep -0 -c 'GTTCTAAACGAGGCGTT' *.fastq > count/B2576_Fm0.txt
agrep -0 -c 'AATCTCGCCTTGGCACG' *.fastq > count/B2577_Fm0.txt
agrep -0 -c 'TGATCGTAACTCCTGCT' *.fastq > count/B2580_Fm0.txt
agrep -0 -c 'CTTCGTTGCAATCGGAC' *.fastq > count/B2581_Fm0.txt
agrep -0 -c 'TACCTAGTCCACTCCTT' *.fastq > count/B2582_Fm0.txt
agrep -0 -c 'CCGAACTCGCGAATAAG' *.fastq > count/B2583_Fm0.txt
agrep -0 -c 'CAACCATCGACAGCGGT' *.fastq > count/B2584_Fm0.txt
agrep -0 -c 'CGAGACGTCGAGTCATA' *.fastq > count/B2585_Fm0.txt
agrep -0 -c 'AGTTCGCCAGCACTCGA' *.fastq > count/B2586_Fm0.txt
agrep -0 -c 'CGCGTGCAGAATCAAAA' *.fastq > count/B2587_Fm0.txt
agrep -0 -c 'ATACACGTTTAGAGACC' *.fastq > count/B2588_Fm0.txt
agrep -0 -c 'TTGATTCGTTGCATCAC' *.fastq > count/B2589_Fm0.txt
agrep -0 -c 'AATTCCGCCGATTTGCG' *.fastq > count/B2590_Fm0.txt
agrep -0 -c 'GCGCACCAGTTTTAAAG' *.fastq > count/B2593_Fm0.txt
agrep -0 -c 'CTACTAACTAAGGACTG' *.fastq > count/B2594_Fm0.txt
agrep -0 -c 'TGACACTGACATCCCAC' *.fastq > count/B2595_Fm0.txt
agrep -0 -c 'CAGACTCGAGAGTTGGT' *.fastq > count/B2596_Fm0.txt
agrep -0 -c 'CGATACAACAACGTGTG' *.fastq > count/B2597_Fm0.txt
agrep -0 -c 'GCATTGTGCTAGAGAAC' *.fastq > count/B2598_Fm0.txt
agrep -0 -c 'CCACCGGAGTTGCAAAG' *.fastq > count/B2599_Fm0.txt
agrep -0 -c 'TGTAGCAACTACATCGG' *.fastq > count/B2600_Fm0.txt
agrep -0 -c 'AAGTGAAGGCGTACCGA' *.fastq > count/B2601_Fm0.txt
agrep -0 -c 'CGATATTTATAGGGGGG' *.fastq > count/B2602_Fm0.txt
agrep -0 -c 'TGCACGAGCCTTCGTTG' *.fastq > count/B2603_Fm0.txt
agrep -0 -c 'GATTGATTACTCGCTGC' *.fastq > count/B2604_Fm0.txt
agrep -0 -c 'GTCAGGATCAAGCCTGG' *.fastq > count/B2605_Fm0.txt
agrep -0 -c 'GAGCGATTACGGACAGT' *.fastq > count/B2606_Fm0.txt
agrep -0 -c 'CAGATGTTTGAGGCATC' *.fastq > count/B2607_Fm0.txt
agrep -0 -c 'GCCTTAACGATCCACCA' *.fastq > count/B2609_Fm0.txt
agrep -0 -c 'CACGTTCGGAATGATCG' *.fastq > count/B2610_Fm0.txt
agrep -0 -c 'GCGTTACTAGTTAGACG' *.fastq > count/B2614_Fm0.txt
agrep -0 -c 'ACAGACTTGTAACCGGA' *.fastq > count/B2615_Fm0.txt
agrep -0 -c 'GGCTTTGCGGCCTAATG' *.fastq > count/B2616_Fm0.txt
agrep -0 -c 'TGATCGTCTGCTGTGCT' *.fastq > count/B2617_Fm0.txt
agrep -0 -c 'CTTCAATTAATTCCCGG' *.fastq > count/B2618_Fm0.txt
agrep -0 -c 'GTGAAGCCGTAGTTATG' *.fastq > count/B2619_Fm0.txt
agrep -0 -c 'GACTCTGCATAATGACC' *.fastq > count/B2620_Fm0.txt
agrep -0 -c 'CGTCTAGGATAAATCGG' *.fastq > count/B2621_Fm0.txt
agrep -0 -c 'ATAGATGCTGTCGTCGG' *.fastq > count/B2622_Fm0.txt
agrep -0 -c 'CTGACCGTTTCGCTAAA' *.fastq > count/B2623_Fm0.txt
agrep -0 -c 'GTACGGAGCGTATAGCG' *.fastq > count/B2624_Fm0.txt
agrep -0 -c 'TGTGAAGTTCGCGATAG' *.fastq > count/B2625_Fm0.txt
agrep -0 -c 'AAGGCGTCGACTTCTGC' *.fastq > count/B2626_Fm0.txt
agrep -0 -c 'CCGCCATAGAGTACGAG' *.fastq > count/B2627_Fm0.txt
agrep -0 -c 'CGTGCTCTTGATGCGAC' *.fastq > count/B2628_Fm0.txt
agrep -0 -c 'GCTATCTATTATCGCCC' *.fastq > count/B2629_Fm0.txt
agrep -0 -c 'GGCCGTTTCTGCTGGAT' *.fastq > count/B2630_Fm0.txt
agrep -0 -c 'TTGACTAACTGAGGACG' *.fastq > count/B2631_Fm0.txt
agrep -0 -c 'GGCCGGGTACTTCAAGT' *.fastq > count/B2633_Fm0.txt
agrep -0 -c 'AGCCGAGAAAGTTCACC' *.fastq > count/B2634_Fm0.txt
agrep -0 -c 'TCGCTGAATGGGGTTGG' *.fastq > count/B2635_Fm0.txt
agrep -0 -c 'CTCTTTTCTCCTACCGA' *.fastq > count/B2636_Fm0.txt
agrep -0 -c 'ATCTGATAAAGCCTCCC' *.fastq > count/B2637_Fm0.txt
agrep -0 -c 'CTGGGTTTTGCGCAATG' *.fastq > count/B2638_Fm0.txt
agrep -0 -c 'ACGAAAGACAGCGGATC' *.fastq > count/B2641_Fm0.txt
agrep -0 -c 'AGGCCAGTCAAACCCGA' *.fastq > count/B2642_Fm0.txt
agrep -0 -c 'GAGTACGATTCTTACCG' *.fastq > count/B2643_Fm0.txt
agrep -0 -c 'TTCAAATCGTGACACCC' *.fastq > count/B2644_Fm0.txt
agrep -0 -c 'TGCTGGTTGTCTTACCC' *.fastq > count/B2645_Fm0.txt
agrep -0 -c 'ACCTGCGCAAAAGATGA' *.fastq > count/B2646_Fm0.txt
agrep -0 -c 'CCGAGTGGTTAGATTAT' *.fastq > count/B2647_Fm0.txt
agrep -0 -c 'GATCGGATACTAACACT' *.fastq > count/B2648_Fm0.txt
agrep -0 -c 'GGACAGTATACTCAAGA' *.fastq > count/B2649_Fm0.txt
agrep -0 -c 'TAAGCGAAGTTCTTTCC' *.fastq > count/B2650_Fm0.txt
agrep -0 -c 'GCGCCTAAGAAATCTTG' *.fastq > count/B2651_Fm0.txt
agrep -0 -c 'TTGAGACTTTACCAAGG' *.fastq > count/B2652_Fm0.txt
agrep -0 -c 'GGTGACTATAGCCTCGG' *.fastq > count/B2653_Fm0.txt
agrep -0 -c 'AGCGAGACGTGCATATG' *.fastq > count/B2654_Fm0.txt
agrep -0 -c 'ATTAACGCGGCATTTCG' *.fastq > count/B2655_Fm0.txt
agrep -0 -c 'GGTCATAGCGGAAGAAA' *.fastq > count/B2656_Fm0.txt
agrep -0 -c 'AACTTAATCCACTGCGC' *.fastq > count/B2657_Fm0.txt
agrep -0 -c 'ACAACTGCCACTCAACG' *.fastq > count/B2658_Fm0.txt
agrep -0 -c 'GCACTCGTAATGGTAAG' *.fastq > count/B2659_Fm0.txt
agrep -0 -c 'CGTCTCTCGTCTTAAAC' *.fastq > count/B2660_Fm0.txt
agrep -0 -c 'AGAATCGTTGTCGCATC' *.fastq > count/B2661_Fm0.txt
agrep -0 -c 'GGACAGAGAGACTACCG' *.fastq > count/B2663_Fm0.txt
agrep -0 -c 'CGTTCCTAAGGACTTTC' *.fastq > count/B2664_Fm0.txt
agrep -0 -c 'AATGAGCGTCAGGTCCC' *.fastq > count/B2665_Fm0.txt
agrep -0 -c 'ACTTGGTCGTGTTTCGG' *.fastq > count/B2666_Fm0.txt
agrep -0 -c 'GGGAGTGTAAGGGTTGC' *.fastq > count/B2668_Fm0.txt
agrep -0 -c 'AGGTATTCCAAGGAGTA' *.fastq > count/B2670_Fm0.txt
agrep -0 -c 'TCGGATCGCTCACTTCA' *.fastq > count/B2671_Fm0.txt
agrep -0 -c 'ACGCACAGTCCCCTAGA' *.fastq > count/B2672_Fm0.txt
agrep -0 -c 'GGCACAAATGTGCGGGT' *.fastq > count/B2673_Fm0.txt
agrep -0 -c 'CGTGCCACTTCTAGCAT' *.fastq > count/B2674_Fm0.txt
agrep -0 -c 'CAAGTGCACGTGAGAGA' *.fastq > count/B2675_Fm0.txt
agrep -0 -c 'TGTAAAGGGTTGCCCCT' *.fastq > count/B2676_Fm0.txt
agrep -0 -c 'CGACACTTCTGGTAATA' *.fastq > count/B2677_Fm0.txt
agrep -0 -c 'TATTGCACGCCGGGCTA' *.fastq > count/B2679_Fm0.txt
agrep -0 -c 'GAGGCAAGGTAGTTTAC' *.fastq > count/B2680_Fm0.txt
agrep -0 -c 'CGACATGGAGCCGAAAC' *.fastq > count/B2681_Fm0.txt
agrep -0 -c 'TCAGAGAAATATCCGCG' *.fastq > count/B2682_Fm0.txt
agrep -0 -c 'AACCGTTCACTTGCAGG' *.fastq > count/B2683_Fm0.txt
agrep -0 -c 'TGTTGTTCTATCCGTCA' *.fastq > count/B2684_Fm0.txt
agrep -0 -c 'ACCGGTACTACTACCAG' *.fastq > count/B2685_Fm0.txt
agrep -0 -c 'AACTGTGTGATACGCCG' *.fastq > count/B2686_Fm0.txt
agrep -0 -c 'CGCTAGCACCGGTCTTA' *.fastq > count/B2688_Fm0.txt
agrep -0 -c 'CAACAGGTGTTAGCGGG' *.fastq > count/B2689_Fm0.txt
agrep -0 -c 'ACGCGTACTAGCGTCTG' *.fastq > count/B2691_Fm0.txt
agrep -0 -c 'ACAGCCCGGATACAGTC' *.fastq > count/B2692_Fm0.txt
agrep -0 -c 'GGATCCAGAATTAAGAC' *.fastq > count/B2693_Fm0.txt
agrep -0 -c 'CAGCAGTAAGTAGCAGG' *.fastq > count/B2694_Fm0.txt
agrep -0 -c 'ATTGAGCCGATTACTTC' *.fastq > count/B2696_Fm0.txt
agrep -0 -c 'TACATTGTAACCGTAGC' *.fastq > count/B2697_Fm0.txt
agrep -0 -c 'GGGGTTGCCATCCTATC' *.fastq > count/B2698_Fm0.txt
agrep -0 -c 'CAGCTTAACAGCACCTG' *.fastq > count/B2699_Fm0.txt
agrep -0 -c 'AAGAGTACATTCCGGGA' *.fastq > count/B2700_Fm0.txt
agrep -0 -c 'AATGAAGCGTACCTGAG' *.fastq > count/B2702_Fm0.txt
agrep -0 -c 'TAATTCGCAGCTTGTGT' *.fastq > count/B2703_Fm0.txt
agrep -0 -c 'TCACCTCTGATACAATG' *.fastq > count/B2704_Fm0.txt
agrep -0 -c 'AGCCAAGCGCCAGTTAT' *.fastq > count/B2705_Fm0.txt
agrep -0 -c 'TGAGACAGCAATATCAC' *.fastq > count/B2706_Fm0.txt
agrep -0 -c 'AAGCGCATTGTTGGCTG' *.fastq > count/B2707_Fm0.txt
agrep -0 -c 'AGTCGGTTCATAAAGTC' *.fastq > count/B2708_Fm0.txt
agrep -0 -c 'CGGTAGCGATGTATCTT' *.fastq > count/B2709_Fm0.txt
agrep -0 -c 'CCGAGACAGCGTAGGAT' *.fastq > count/B2710_Fm0.txt
agrep -0 -c 'CCGGGGAAATCGCCATA' *.fastq > count/B2712_Fm0.txt
agrep -0 -c 'GCGTGCATGCAACGTTA' *.fastq > count/B2713_Fm0.txt
agrep -0 -c 'TAGCATAGACGTGGCTC' *.fastq > count/B2714_Fm0.txt
agrep -0 -c 'TACTTCGGTAATACCGG' *.fastq > count/B2716_Fm0.txt
agrep -0 -c 'TATAGGGCGATAGTCCA' *.fastq > count/B2717_Fm0.txt
agrep -0 -c 'TGCGTGATGTGACGGAA' *.fastq > count/B2718_Fm0.txt
agrep -0 -c 'GCTCCGCCAATTTGAAA' *.fastq > count/B2719_Fm0.txt
agrep -0 -c 'AGGCGCGTTGATGGTTG' *.fastq > count/B2720_Fm0.txt
agrep -0 -c 'CACTAGGTTATAGTCCC' *.fastq > count/B2721_Fm0.txt
agrep -0 -c 'ACCTTACTTGCAATCCC' *.fastq > count/B2722_Fm0.txt
agrep -0 -c 'CGAACCCGTCTATGAAA' *.fastq > count/B2723_Fm0.txt
agrep -0 -c 'TATGATCGTCAAAGCCG' *.fastq > count/B2724_Fm0.txt
agrep -0 -c 'CGGGCTGAAATTGACCG' *.fastq > count/B2725_Fm0.txt
agrep -0 -c 'TATTAGCAGGGGACGTA' *.fastq > count/B2726_Fm0.txt
agrep -0 -c 'TTGACAGCAACTTAGCT' *.fastq > count/B2727_Fm0.txt
agrep -0 -c 'TAGGGTCCTGATAGTTT' *.fastq > count/B2728_Fm0.txt
agrep -0 -c 'ATGATCTGTCCTCCTAC' *.fastq > count/B2729_Fm0.txt
agrep -0 -c 'TCAGACACCTTCAAAGG' *.fastq > count/B2730_Fm0.txt
agrep -0 -c 'CTGTAATAAGCTGGTCC' *.fastq > count/B2731_Fm0.txt
agrep -0 -c 'GTTGACTTACGGCCAAC' *.fastq > count/B2732_Fm0.txt
agrep -0 -c 'GAGCGTATTCATCTTGT' *.fastq > count/B2734_Fm0.txt
agrep -0 -c 'GGGAGTTGCTACTGGTT' *.fastq > count/B2735_Fm0.txt
agrep -0 -c 'CAAGTCCCGGAGGCTAA' *.fastq > count/B2736_Fm0.txt
agrep -0 -c 'ATTATTGCAAGCAGGCC' *.fastq > count/B2737_Fm0.txt
agrep -0 -c 'AGGTTCCTGTTCGTGCT' *.fastq > count/B2740_Fm0.txt
agrep -0 -c 'CTCAACGTGAGTATCGA' *.fastq > count/B2741_Fm0.txt
agrep -0 -c 'CGTTCCAACTTAGATGA' *.fastq > count/B2743_Fm0.txt
agrep -0 -c 'AGCACATACCTGCGGAA' *.fastq > count/B2744_Fm0.txt
agrep -0 -c 'ACCAGAACATTAGTCAG' *.fastq > count/B2745_Fm0.txt
agrep -0 -c 'TGTCCCTGTCCAACCGT' *.fastq > count/B2746_Fm0.txt
agrep -0 -c 'TCTAGGTGCGGAATCCT' *.fastq > count/B2749_Fm0.txt
agrep -0 -c 'GTGCGATCTAACACCTC' *.fastq > count/B2750_Fm0.txt
agrep -0 -c 'CCGCATAACTTGGAGTC' *.fastq > count/B2751_Fm0.txt
agrep -0 -c 'GTTTGGCGCGCATAACT' *.fastq > count/B2752_Fm0.txt
agrep -0 -c 'GTCAAGCATGAATGCCG' *.fastq > count/B2753_Fm0.txt
agrep -0 -c 'TCGGCACCACTAGTCCT' *.fastq > count/B2754_Fm0.txt
agrep -0 -c 'TCACGGTTCTTAGTTAG' *.fastq > count/B2755_Fm0.txt
agrep -0 -c 'ATAGTCACCGGTCATGC' *.fastq > count/B2756_Fm0.txt
agrep -0 -c 'CCATTCGTCCCATGGAA' *.fastq > count/B2759_Fm0.txt
agrep -0 -c 'CGCAAATGTCGCATTGC' *.fastq > count/B2760_Fm0.txt
agrep -0 -c 'GAGTTCTCGACCTGGGT' *.fastq > count/B2761_Fm0.txt
agrep -0 -c 'TACTAATTCATGCCGAC' *.fastq > count/B2762_Fm0.txt
agrep -0 -c 'GTAGTTAGGCTCCACCA' *.fastq > count/B2763_Fm0.txt
agrep -0 -c 'TAGCCCGCAATAGCACT' *.fastq > count/B2764_Fm0.txt
agrep -0 -c 'TTCTAGAATGGATGACC' *.fastq > count/B2765_Fm0.txt
agrep -0 -c 'CTAAGCAAGTAGCATTG' *.fastq > count/B2766_Fm0.txt
agrep -0 -c 'AACGACGCCTGTTCCAC' *.fastq > count/B2767_Fm0.txt
agrep -0 -c 'TGCAGCATATTGCAGCG' *.fastq > count/B2768_Fm0.txt
agrep -0 -c 'TGATAGCCTACGATCCG' *.fastq > count/B2770_Fm0.txt
agrep -0 -c 'TCGTATAATCTTTGCGG' *.fastq > count/B2771_Fm0.txt
agrep -0 -c 'GTCATTGTTCGCGACCC' *.fastq > count/B2772_Fm0.txt
agrep -0 -c 'GCGTGTGGTAACTTGAC' *.fastq > count/B2774_Fm0.txt
agrep -0 -c 'AGTTCCGATGGTTCCGA' *.fastq > count/B2775_Fm0.txt
agrep -0 -c 'CTGACCGAACCGTAGAC' *.fastq > count/B2776_Fm0.txt
agrep -0 -c 'ATGCGTTCCCTCCTTCT' *.fastq > count/B2777_Fm0.txt
agrep -0 -c 'AGGTAAACCCCTCGTAG' *.fastq > count/B2778_Fm0.txt
agrep -0 -c 'CGCTCCTACAATTTTGC' *.fastq > count/B2781_Fm0.txt
agrep -0 -c 'ATTTGCGTTGAGTAGAC' *.fastq > count/B2782_Fm0.txt
agrep -0 -c 'ACCAGGTCTTAGTTGAA' *.fastq > count/B2783_Fm0.txt
agrep -0 -c 'CGAGCATCCCGGATGTT' *.fastq > count/B2784_Fm0.txt
agrep -0 -c 'GCAGTTGAAGGATGTTT' *.fastq > count/B2785_Fm0.txt
agrep -0 -c 'GGTCCATCCGAATGGTA' *.fastq > count/B2786_Fm0.txt
agrep -0 -c 'ACCGATCCCGTAGGTTT' *.fastq > count/B2788_Fm0.txt
agrep -0 -c 'CTGCTTAGCCGGCTCTA' *.fastq > count/B2789_Fm0.txt
agrep -0 -c 'CAACGCCGACTACTGCT' *.fastq > count/B2790_Fm0.txt
agrep -0 -c 'GTCCCATTCTAGAGATC' *.fastq > count/B2791_Fm0.txt
agrep -0 -c 'TTAGGAAGTCGGATACT' *.fastq > count/B2792_Fm0.txt
agrep -0 -c 'ATGGGGGTTCGATATCC' *.fastq > count/B2793_Fm0.txt
agrep -0 -c 'GCCCTGCTAATAACTTA' *.fastq > count/B2795_Fm0.txt
agrep -0 -c 'CACTGACTTGTCCGTGC' *.fastq > count/B2796_Fm0.txt
agrep -0 -c 'GATTTGATCCCAAGTTG' *.fastq > count/B2797_Fm0.txt
agrep -0 -c 'GTGGGTAGCGTGTCTGT' *.fastq > count/B2798_Fm0.txt
agrep -0 -c 'AGGCTCAATCGGAAGCT' *.fastq > count/B2799_Fm0.txt
agrep -0 -c 'CTGTTCGAGGTTTGACT' *.fastq > count/B2801_Fm0.txt
agrep -0 -c 'AGATGACTCGCAGGGTC' *.fastq > count/B2802_Fm0.txt
agrep -0 -c 'ACTTATCTTACCACCAG' *.fastq > count/B2803_Fm0.txt
agrep -0 -c 'CTCGGTTATACTCCAAG' *.fastq > count/B2804_Fm0.txt
agrep -0 -c 'CCGTGAACTGGCAGGAT' *.fastq > count/B2805_Fm0.txt
agrep -0 -c 'CGACCGTAACAGGTTGC' *.fastq > count/B2806_Fm0.txt
agrep -0 -c 'CGATTCACGAACACGTA' *.fastq > count/B2807_Fm0.txt
agrep -0 -c 'CGCGAAACCTTAGTATG' *.fastq > count/B2808_Fm0.txt
agrep -0 -c 'ATGCCCACGGATAAAAG' *.fastq > count/B2809_Fm0.txt
agrep -0 -c 'ACCTCAACAATTGTCCG' *.fastq > count/B2810_Fm0.txt
agrep -0 -c 'CCTCATCTTGATAGCAC' *.fastq > count/B2813_Fm0.txt
agrep -0 -c 'GCTATCGCTCATAGCTG' *.fastq > count/B2814_Fm0.txt
agrep -0 -c 'AGAGGCGCCATCTGAAC' *.fastq > count/B2815_Fm0.txt
agrep -0 -c 'CCGGTGCAAAACCGCAT' *.fastq > count/B2816_Fm0.txt
agrep -0 -c 'TAACTTGACCAACCGTA' *.fastq > count/B2818_Fm0.txt
agrep -0 -c 'GGGCCATCGAATCGTCT' *.fastq > count/B2819_Fm0.txt
agrep -0 -c 'TGCTGGACGTTATGGTG' *.fastq > count/B2820_Fm0.txt
agrep -0 -c 'ATACTACAAATGCAGCC' *.fastq > count/B2821_Fm0.txt
agrep -0 -c 'CTTGCAAGGACTCGTCG' *.fastq > count/B2822_Fm0.txt
agrep -0 -c 'GCGACAGAGTAAGGACA' *.fastq > count/B2823_Fm0.txt
agrep -0 -c 'AACGAGCATTACGTTGT' *.fastq > count/B2824_Fm0.txt
agrep -0 -c 'CACGTCAAGCTGCTGCT' *.fastq > count/B2825_Fm0.txt
agrep -0 -c 'GTAGCTTCTATCTCCTT' *.fastq > count/B2826_Fm0.txt
agrep -0 -c 'ATCGATTATGCTCTCGT' *.fastq > count/B2827_Fm0.txt
agrep -0 -c 'AGATCTAAGTGACTCGT' *.fastq > count/B2828_Fm0.txt
agrep -0 -c 'GATCAACGAGTAGCTAT' *.fastq > count/B2829_Fm0.txt
agrep -0 -c 'CAACTTGACAGAAGACA' *.fastq > count/B2831_Fm0.txt
agrep -0 -c 'TTCGATTCAGGCCTTTC' *.fastq > count/B2834_Fm0.txt
agrep -0 -c 'GCGAGACCTTGTAACTG' *.fastq > count/B2835_Fm0.txt
agrep -0 -c 'ATACATAACCATTGCGG' *.fastq > count/B2836_Fm0.txt
agrep -0 -c 'TGACTTATTCGTGGCAA' *.fastq > count/B2837_Fm0.txt
agrep -0 -c 'CTAGCCGCACAGAATAG' *.fastq > count/B2838_Fm0.txt
agrep -0 -c 'CCTGGATACACACGATT' *.fastq > count/B2839_Fm0.txt
agrep -0 -c 'AAGGTAGGTCCATCTGC' *.fastq > count/B2842_Fm0.txt
agrep -0 -c 'GTGGACATTCGATAACT' *.fastq > count/B2844_Fm0.txt
agrep -0 -c 'TCGCAGGTTTACGGGAA' *.fastq > count/B2845_Fm0.txt
agrep -0 -c 'ACGATTAGCCAGAGAGA' *.fastq > count/B2847_Fm0.txt
agrep -0 -c 'GAGTTTGATGGGCTAGG' *.fastq > count/B2848_Fm0.txt
agrep -0 -c 'TAGACTAGACTACACGG' *.fastq > count/B2850_Fm0.txt
agrep -0 -c 'ATCGGTCCACGAATACG' *.fastq > count/B2851_Fm0.txt
agrep -0 -c 'CCGCTGAAACACTAGAT' *.fastq > count/B2852_Fm0.txt
agrep -0 -c 'GGGTATTAGGTTGGGTT' *.fastq > count/B2853_Fm0.txt
agrep -0 -c 'ACGTTTGTCCCATTAAG' *.fastq > count/B2854_Fm0.txt
agrep -0 -c 'TGCCATTATGATCAGCC' *.fastq > count/B2855_Fm0.txt
agrep -0 -c 'CCGGTTGATCTTCCACA' *.fastq > count/B2857_Fm0.txt
agrep -0 -c 'AAGGTTGACCTTTTGCA' *.fastq > count/B2858_Fm0.txt
agrep -0 -c 'ACTGGTCGAGTCATCGG' *.fastq > count/B2859_Fm0.txt
agrep -0 -c 'TAACAGCGAGAGGAGTA' *.fastq > count/B2860_Fm0.txt
agrep -0 -c 'ACTCGTTGAATCCTGTC' *.fastq > count/B2861_Fm0.txt
agrep -0 -c 'ATCGCCCGAAATTAATC' *.fastq > count/B2862_Fm0.txt
agrep -0 -c 'CAGTTTACAACGTGCTG' *.fastq > count/B2863_Fm0.txt
agrep -0 -c 'ATCCACAAATATGCGCA' *.fastq > count/B2864_Fm0.txt
agrep -0 -c 'CTGCAAAACCCAGTTTT' *.fastq > count/B2865_Fm0.txt
agrep -0 -c 'CGAGTGTAACGCCAATA' *.fastq > count/B2866_Fm0.txt
agrep -0 -c 'ACATAAGGCAGGCGGTT' *.fastq > count/B2867_Fm0.txt
agrep -0 -c 'GAGGCATCCTTCTCGTA' *.fastq > count/B2869_Fm0.txt
agrep -0 -c 'CATCGGATATGGCTGGT' *.fastq > count/B2870_Fm0.txt
agrep -0 -c 'CACGTATGCCCTGGAAG' *.fastq > count/B2871_Fm0.txt
agrep -0 -c 'GTACACCACTAGTACGT' *.fastq > count/B2872_Fm0.txt
agrep -0 -c 'CGATGACGTCAGTGTGG' *.fastq > count/B2873_Fm0.txt
agrep -0 -c 'ACACTGGGGTTTGCGAC' *.fastq > count/B2874_Fm0.txt
agrep -0 -c 'AGGTGAACCTCACGTTC' *.fastq > count/B2875_Fm0.txt
agrep -0 -c 'TCACGAACTCTTGCGTA' *.fastq > count/B2876_Fm0.txt
agrep -0 -c 'CGTCTGAACGGCAGAAG' *.fastq > count/B2877_Fm0.txt
agrep -0 -c 'CGCGAATAACTTATGGG' *.fastq > count/B2878_Fm0.txt
agrep -0 -c 'CGGCAGAAGTCTACCTG' *.fastq > count/B2880_Fm0.txt
agrep -0 -c 'TACGTTACGCTCACCTT' *.fastq > count/B2881_Fm0.txt
agrep -0 -c 'TTCCATGGACTATCTTG' *.fastq > count/B2883_Fm0.txt
agrep -0 -c 'GGGAGGCTTGGTCGAAT' *.fastq > count/B2884_Fm0.txt
agrep -0 -c 'CCTACGACTGTCGGATC' *.fastq > count/B2885_Fm0.txt
agrep -0 -c 'CACGCAGTTTCAATAAC' *.fastq > count/B2886_Fm0.txt
agrep -0 -c 'ATAATCAACCGCACGGG' *.fastq > count/B2887_Fm0.txt
agrep -0 -c 'CAACCACCATAAATGAG' *.fastq > count/B2888_Fm0.txt
agrep -0 -c 'GTTCATGTCGATTCCGC' *.fastq > count/B2889_Fm0.txt
agrep -0 -c 'TCGTGGAACCAGACTGA' *.fastq > count/B2890_Fm0.txt
agrep -0 -c 'GTGCGTCCGATCATGCT' *.fastq > count/B2892_Fm0.txt
agrep -0 -c 'CATTATCTGAGACATGG' *.fastq > count/B2893_Fm0.txt
agrep -0 -c 'ATCCGTTATCGTAGGAT' *.fastq > count/B2894_Fm0.txt
agrep -0 -c 'AATTCGCAGGCGATACG' *.fastq > count/B2896_Fm0.txt
agrep -0 -c 'GTCTGTGCAGCATTGAC' *.fastq > count/B2897_Fm0.txt
agrep -0 -c 'TTGCGGCTACACTAGTC' *.fastq > count/B2898_Fm0.txt
agrep -0 -c 'ACCCCGTAGAATCGCAT' *.fastq > count/B2899_Fm0.txt
agrep -0 -c 'TCATTCCATCGCTTTCT' *.fastq > count/B2900_Fm0.txt
agrep -0 -c 'CCATTCAACAAGCTGCC' *.fastq > count/B2901_Fm0.txt
agrep -0 -c 'CCTCAGAACAACCCAGG' *.fastq > count/B2902_Fm0.txt
agrep -0 -c 'CCAGGCGCGTGTTATAC' *.fastq > count/B2903_Fm0.txt
agrep -0 -c 'TACAACTCGGCATCGGT' *.fastq > count/B2904_Fm0.txt
agrep -0 -c 'CACGCTGGATGGCTATT' *.fastq > count/B2905_Fm0.txt
agrep -0 -c 'TACGTGATTTTCATGCC' *.fastq > count/B2906_Fm0.txt
agrep -0 -c 'TATTTATGGTGGGCTTG' *.fastq > count/B2907_Fm0.txt
agrep -0 -c 'CGGAACTCCACGCAGAA' *.fastq > count/B2910_Fm0.txt
agrep -0 -c 'GCCGACTTACATTATGC' *.fastq > count/B2911_Fm0.txt
agrep -0 -c 'ACTACGGGTGGGTATCA' *.fastq > count/B2912_Fm0.txt
agrep -0 -c 'CTACCAGGTCGGTATCC' *.fastq > count/B2914_Fm0.txt
agrep -0 -c 'AGCTTTCGCTACTCAAA' *.fastq > count/B2915_Fm0.txt
agrep -0 -c 'CAACTTGCGCGTGACAA' *.fastq > count/B2917_Fm0.txt
agrep -0 -c 'CATATAGAGACGGGAGG' *.fastq > count/B2919_Fm0.txt
agrep -0 -c 'CAGCTTGCTGTCATAGA' *.fastq > count/B2920_Fm0.txt
agrep -0 -c 'ACGTACTGACTGCATAT' *.fastq > count/B2921_Fm0.txt
agrep -0 -c 'AATGGCAAAGGTGAGAC' *.fastq > count/B2922_Fm0.txt
agrep -0 -c 'ACCTCAATGTCAGGCCA' *.fastq > count/B2923_Fm0.txt
agrep -0 -c 'CAGCGCACAGCATGGTT' *.fastq > count/B2924_Fm0.txt
agrep -0 -c 'AACCAGGGCAGACTTAC' *.fastq > count/B2925_Fm0.txt
agrep -0 -c 'CATAGAGGCCCGGTGAA' *.fastq > count/B2926_Fm0.txt
agrep -0 -c 'CTTCAATATCACCGGGT' *.fastq > count/B2927_Fm0.txt
agrep -0 -c 'TAACAGCCACGGGCAAG' *.fastq > count/B2928_Fm0.txt
agrep -0 -c 'AGGTTAGCTACGGGTCA' *.fastq > count/B2930_Fm0.txt
agrep -0 -c 'CCGTCCAGATTTCGGTT' *.fastq > count/B2931_Fm0.txt
agrep -0 -c 'TCAGCTTCTAGGCGTTT' *.fastq > count/B2934_Fm0.txt
agrep -0 -c 'CCGGAGCCACTGTATGT' *.fastq > count/B2935_Fm0.txt
agrep -0 -c 'AGTTCTGTCCCTCCATA' *.fastq > count/B2936_Fm0.txt
agrep -0 -c 'CTCCAGCAGTGACATCG' *.fastq > count/B2937_Fm0.txt
agrep -0 -c 'AAGTTTCACTCGGTAAC' *.fastq > count/B2943_Fm0.txt
agrep -0 -c 'GTTAAGTCGGCTACATA' *.fastq > count/B2944_Fm0.txt
agrep -0 -c 'ACGGTTTCCAAGCTGCC' *.fastq > count/B2947_Fm0.txt
agrep -0 -c 'AACACCCCCATCCAAAG' *.fastq > count/B2948_Fm0.txt
agrep -0 -c 'CCACTAAGAGAATCCGC' *.fastq > count/B2949_Fm0.txt
agrep -0 -c 'TCAGCGTGCACCGATAC' *.fastq > count/B2950_Fm0.txt
agrep -0 -c 'GTACATTTATTCCCTGC' *.fastq > count/B2951_Fm0.txt
agrep -0 -c 'ACGCTTCACCCTACACG' *.fastq > count/B2952_Fm0.txt
agrep -0 -c 'GATGTCGCTCCTCCATA' *.fastq > count/B2954_Fm0.txt
agrep -0 -c 'GGTGTTCAGGTAATGGG' *.fastq > count/B2956_Fm0.txt
agrep -0 -c 'GTATGACTCTGGAGGTA' *.fastq > count/B2957_Fm0.txt
agrep -0 -c 'CGAGAGTACCCAAGACT' *.fastq > count/B2958_Fm0.txt
agrep -0 -c 'CACGAGACGATGTTTAC' *.fastq > count/B2959_Fm0.txt
agrep -0 -c 'TAATTGGAGAACCCAGA' *.fastq > count/B2960_Fm0.txt
agrep -0 -c 'CAAACCCAAGGATATAG' *.fastq > count/B2961_Fm0.txt
agrep -0 -c 'ACTCACGCACTCCATAA' *.fastq > count/B2963_Fm0.txt
agrep -0 -c 'ACCCCAAGTTTTCTACT' *.fastq > count/B2964_Fm0.txt
agrep -0 -c 'TCGGCCATGCGATACGA' *.fastq > count/B2965_Fm0.txt
agrep -0 -c 'CCATACGCGTCGGGATA' *.fastq > count/B2966_Fm0.txt
agrep -0 -c 'GAGTGGGCCAACTGATA' *.fastq > count/B2967_Fm0.txt
agrep -0 -c 'TATGGTATGCATGACAG' *.fastq > count/B2968_Fm0.txt
agrep -0 -c 'AGTAGCAGCTGGCACGA' *.fastq > count/B2969_Fm0.txt
agrep -0 -c 'GATGCACCAAATGTCAT' *.fastq > count/B2970_Fm0.txt
agrep -0 -c 'ATCGAACCTGAACAATC' *.fastq > count/B2971_Fm0.txt
agrep -0 -c 'AATCCTCACACTATACG' *.fastq > count/B2973_Fm0.txt
agrep -0 -c 'ACTGGTCCGGTATCTAG' *.fastq > count/B2974_Fm0.txt
agrep -0 -c 'GCAAGCTCCTGCCACAT' *.fastq > count/B2975_Fm0.txt
agrep -0 -c 'GAGCGAGTCGACGATGA' *.fastq > count/B2976_Fm0.txt
agrep -0 -c 'TTGTATAGTGGTAGACG' *.fastq > count/B2978_Fm0.txt
agrep -0 -c 'GCGTGCTATTCACGTTG' *.fastq > count/B2979_Fm0.txt
agrep -0 -c 'AACCCGTTGTGAAAAGA' *.fastq > count/B2980_Fm0.txt
agrep -0 -c 'TTAGCATCTAAGCGGAG' *.fastq > count/B2981_Fm0.txt
agrep -0 -c 'TAACCGCTGAGAAGAGT' *.fastq > count/B2982_Fm0.txt
agrep -0 -c 'CCGTAGGAACTAACGTT' *.fastq > count/B2983_Fm0.txt
agrep -0 -c 'AATACCTATGCGTTCGC' *.fastq > count/B2985_Fm0.txt
agrep -0 -c 'TAGGTCTGGCCCTAGTT' *.fastq > count/B2986_Fm0.txt
agrep -0 -c 'GCGGATTTCGGATATTT' *.fastq > count/B2987_Fm0.txt
agrep -0 -c 'ATATCGAACACGTCGAA' *.fastq > count/B2989_Fm0.txt
agrep -0 -c 'CTTGGTATTGACGACCG' *.fastq > count/B2990_Fm0.txt
agrep -0 -c 'TTCCCGAGAAGGTGATT' *.fastq > count/B2991_Fm0.txt
agrep -0 -c 'TATGCTGAATGGCACGA' *.fastq > count/B2992_Fm0.txt
agrep -0 -c 'CTAAAATTGACTCACGG' *.fastq > count/B2993_Fm0.txt
agrep -0 -c 'TGCGCCTACTGGATACG' *.fastq > count/B2994_Fm0.txt
agrep -0 -c 'TTCACGTTGTGCGGAAG' *.fastq > count/B2995_Fm0.txt
agrep -0 -c 'ATATCGTCAGAAGGGAA' *.fastq > count/B2996_Fm0.txt
agrep -0 -c 'GAGGAATCCCTGCAGTC' *.fastq > count/B2998_Fm0.txt
agrep -0 -c 'GGTTTTCTTGCGCACTA' *.fastq > count/B2999_Fm0.txt
agrep -0 -c 'ATAGGATAGATGACGAC' *.fastq > count/B3001_Fm0.txt
agrep -0 -c 'GCTATTGAAGAAACGCA' *.fastq > count/B3002_Fm0.txt
agrep -0 -c 'GCAGCTTCACTAGGTTT' *.fastq > count/B3003_Fm0.txt
agrep -0 -c 'GTACGACAGTTGCGACG' *.fastq > count/B3006_Fm0.txt
agrep -0 -c 'CTAAATGTGCCTTCTTC' *.fastq > count/B3007_Fm0.txt
agrep -0 -c 'GACGCTGTCTTGAGAGA' *.fastq > count/B3008_Fm0.txt
agrep -0 -c 'CAGTGTAACTCTCACGG' *.fastq > count/B3009_Fm0.txt
agrep -0 -c 'CGGCATGGGTTCTATCT' *.fastq > count/B3010_Fm0.txt
agrep -0 -c 'CTGATACCAGTCTGGTT' *.fastq > count/B3011_Fm0.txt
agrep -0 -c 'TACGCGGGATCGCTCAT' *.fastq > count/B3012_Fm0.txt
agrep -0 -c 'GTATCGCAGCAAACTTG' *.fastq > count/B3013_Fm0.txt
agrep -0 -c 'CCTTAAACAACGTCGGA' *.fastq > count/B3014_Fm0.txt
agrep -0 -c 'ATAGGAACCTCGTCTTT' *.fastq > count/B3015_Fm0.txt
agrep -0 -c 'CGTGATCAGCCCCTTAC' *.fastq > count/B3016_Fm0.txt
agrep -0 -c 'AGCGGGTAGCCACATCA' *.fastq > count/B3018_Fm0.txt
agrep -0 -c 'TGTAGGGGATCTAAGTG' *.fastq > count/B3019_Fm0.txt
agrep -0 -c 'TGATTCCGCTTCAAAAG' *.fastq > count/B3021_Fm0.txt
agrep -0 -c 'AATCTTAGAGCGTGGTC' *.fastq > count/B3022_Fm0.txt
agrep -0 -c 'TCACTCGTATACACCGG' *.fastq > count/B3023_Fm0.txt
agrep -0 -c 'ACGTAAACGCTCATGAC' *.fastq > count/B3024_Fm0.txt
agrep -0 -c 'TATTTCGACCGTTCACA' *.fastq > count/B3025_Fm0.txt
agrep -0 -c 'ACACACCCGTTGATACC' *.fastq > count/B3026_Fm0.txt
agrep -0 -c 'GCCGCCAGATCGATGTA' *.fastq > count/B3027_Fm0.txt
agrep -0 -c 'TCTTGCGTCTCCACAAG' *.fastq > count/B3028_Fm0.txt
agrep -0 -c 'CAGATACTAAAACCGTC' *.fastq > count/B3029_Fm0.txt
agrep -0 -c 'CGCAAGACCGAAAGCAA' *.fastq > count/B3030_Fm0.txt
agrep -0 -c 'GCGTAAACGGTTAACGG' *.fastq > count/B3031_Fm0.txt
agrep -0 -c 'CATCGCGTACACCGTGT' *.fastq > count/B3032_Fm0.txt
agrep -0 -c 'GTCTCTAGGTTACACGG' *.fastq > count/B3033_Fm0.txt
agrep -0 -c 'AGATGATGACCGAGTCT' *.fastq > count/B3034_Fm0.txt
agrep -0 -c 'TAAGGATTAGTGGGGGA' *.fastq > count/B3035_Fm0.txt
agrep -0 -c 'GCCGTTAGGGTCATAGT' *.fastq > count/B3037_Fm0.txt
agrep -0 -c 'ACTTCCGCATCACTATC' *.fastq > count/B3038_Fm0.txt
agrep -0 -c 'TATGACCCGTGAGGTTC' *.fastq > count/B3039_Fm0.txt
agrep -0 -c 'CGAACCTCAAGGCTCTC' *.fastq > count/B3041_Fm0.txt
agrep -0 -c 'CTAGCGCTCAAGGCCAA' *.fastq > count/B3042_Fm0.txt
agrep -0 -c 'CGCAATCACCCTCTCAC' *.fastq > count/B3043_Fm0.txt
agrep -0 -c 'AACATTTCAGCGACACC' *.fastq > count/B3044_Fm0.txt
agrep -0 -c 'ACCTCACGTCGAACTTC' *.fastq > count/B3046_Fm0.txt
agrep -0 -c 'GATTTCCCTCCACTTGT' *.fastq > count/B3047_Fm0.txt
agrep -0 -c 'TACATCATCCGACCTTC' *.fastq > count/B3048_Fm0.txt
agrep -0 -c 'CTGTGGGCGAGACTAAT' *.fastq > count/B3049_Fm0.txt
agrep -0 -c 'TTCGGTTGGGGTGCATG' *.fastq > count/B3051_Fm0.txt
agrep -0 -c 'GTCGGCATTTGCGTTTT' *.fastq > count/B3052_Fm0.txt
agrep -0 -c 'ATTTCCGTGCAACAAGC' *.fastq > count/B3053_Fm0.txt
agrep -0 -c 'CTGGCTCATCTAAGCCG' *.fastq > count/B3054_Fm0.txt
agrep -0 -c 'TAGAACTGCCCGATCCT' *.fastq > count/B3055_Fm0.txt
agrep -0 -c 'GGTGGCGAAATCTCTGA' *.fastq > count/B3056_Fm0.txt
agrep -0 -c 'GTCTCTATGTGTTCGCC' *.fastq > count/B3057_Fm0.txt
agrep -0 -c 'ACGATAGATCCCCGTGT' *.fastq > count/B3059_Fm0.txt
agrep -0 -c 'ACACCTTTACCGGAATA' *.fastq > count/B3060_Fm0.txt
agrep -0 -c 'AGCAGATTCTTGTCGAG' *.fastq > count/B3061_Fm0.txt
agrep -0 -c 'CTGTACTTAGTACAGGG' *.fastq > count/B3062_Fm0.txt
agrep -0 -c 'TTCTAAAGGGGGGCGAT' *.fastq > count/B3063_Fm0.txt
agrep -0 -c 'ACTAACACGGAGAGCCA' *.fastq > count/B3064_Fm0.txt
agrep -0 -c 'GGCCTATCCACGCAATC' *.fastq > count/B3067_Fm0.txt
agrep -0 -c 'CGCAAGTAACCAGGTCC' *.fastq > count/B3068_Fm0.txt
agrep -0 -c 'AATACTCTGAATGCGAG' *.fastq > count/B3069_Fm0.txt
agrep -0 -c 'TTCGCGCGATACATAAT' *.fastq > count/B3070_Fm0.txt
agrep -0 -c 'CAGAGGCTCACGAGCAA' *.fastq > count/B3071_Fm0.txt
agrep -0 -c 'ATAAGGCATAGAGAGTG' *.fastq > count/B3072_Fm0.txt
agrep -0 -c 'AATACAGGTTGACTGGT' *.fastq > count/B3073_Fm0.txt
agrep -0 -c 'TCTAACCATCGTTCCCG' *.fastq > count/B3074_Fm0.txt
agrep -0 -c 'TACGCCGGGAACATTCT' *.fastq > count/B3076_Fm0.txt
agrep -0 -c 'GCGTGCTATGCGATCTT' *.fastq > count/B3077_Fm0.txt
agrep -0 -c 'AGGAGGATTCCTACAGG' *.fastq > count/B3078_Fm0.txt
agrep -0 -c 'CCGGGGTGGAAACTTTT' *.fastq > count/B3079_Fm0.txt
agrep -0 -c 'GTAGTCGGAGTGCATTT' *.fastq > count/B3080_Fm0.txt
agrep -0 -c 'ACCTGCCCAGTTACTTT' *.fastq > count/B3083_Fm0.txt
agrep -0 -c 'GCCAACCATTTAACAGC' *.fastq > count/B3084_Fm0.txt
agrep -0 -c 'CCGATCCTGGATTCTTG' *.fastq > count/B3085_Fm0.txt
agrep -0 -c 'TCTCTGTTCGCACGTAG' *.fastq > count/B3086_Fm0.txt
agrep -0 -c 'GGTTGAAGCGAAGTTAT' *.fastq > count/B3087_Fm0.txt
agrep -0 -c 'ACTGGGGAAACCGTAGG' *.fastq > count/B3088_Fm0.txt
agrep -0 -c 'AGTCCCGTGGAGATTTG' *.fastq > count/B3089_Fm0.txt
agrep -0 -c 'GGTCCCCAACAAGAATA' *.fastq > count/B3090_Fm0.txt
agrep -0 -c 'GTCCTCTTTGTCGAACA' *.fastq > count/B3091_Fm0.txt
agrep -0 -c 'ACTTGCCAGCGCTTGAG' *.fastq > count/B3092_Fm0.txt
agrep -0 -c 'GTGCTACCTAACTACCC' *.fastq > count/B3094_Fm0.txt
agrep -0 -c 'CAGGTTGGTCATCTCCG' *.fastq > count/B3095_Fm0.txt
agrep -0 -c 'TTCGAGGGTATCAAAAG' *.fastq > count/B3096_Fm0.txt
agrep -0 -c 'TGCATCAGCCGTGACTG' *.fastq > count/B3097_Fm0.txt
agrep -0 -c 'CTATTACCCGTGTCCTT' *.fastq > count/B3098_Fm0.txt
agrep -0 -c 'AATGGGTTACCGTGGTT' *.fastq > count/B3099_Fm0.txt
agrep -0 -c 'CGTTACCTAATGTACTC' *.fastq > count/B3100_Fm0.txt
agrep -0 -c 'AGAGTTACGTGACACCA' *.fastq > count/B3101_Fm0.txt
agrep -0 -c 'TTACATCGCTGCAGGAG' *.fastq > count/B3102_Fm0.txt
agrep -0 -c 'GGTCGATGCGCGAATGA' *.fastq > count/B3103_Fm0.txt
agrep -0 -c 'GTGCTGTGAATCGAGAA' *.fastq > count/B3104_Fm0.txt
agrep -0 -c 'GCAACCAGAATTCGCGG' *.fastq > count/B3105_Fm0.txt
agrep -0 -c 'TAGAAAGCTCTGCGCTA' *.fastq > count/B3106_Fm0.txt
agrep -0 -c 'CAATACCGTCAAAATGG' *.fastq > count/B3107_Fm0.txt
agrep -0 -c 'TCTTATGCCCGTCCCAG' *.fastq > count/B3108_Fm0.txt
agrep -0 -c 'GTCTCGCGTGGGATAAT' *.fastq > count/B3109_Fm0.txt
agrep -0 -c 'TCATGCGGTGTCGGTAG' *.fastq > count/B3110_Fm0.txt
agrep -0 -c 'GGCACAGCTTTGTGCCA' *.fastq > count/B3112_Fm0.txt
agrep -0 -c 'CGTTCACTTAGGCACAG' *.fastq > count/B3113_Fm0.txt
agrep -0 -c 'ACCGGACTTGCAGTTGC' *.fastq > count/B3114_Fm0.txt
agrep -0 -c 'TAGTCCTTAAGCGTGTT' *.fastq > count/B3115_Fm0.txt
agrep -0 -c 'AGGGCGAAATGCCAGAT' *.fastq > count/B3116_Fm0.txt
agrep -0 -c 'GTCATCCTTCTATTGGC' *.fastq > count/B3117_Fm0.txt
agrep -0 -c 'TCAGGACTTGTAATCCG' *.fastq > count/B3118_Fm0.txt
agrep -0 -c 'TGATAGCGGCGTTAAGT' *.fastq > count/B3119_Fm0.txt
agrep -0 -c 'GGATTCCGGTACACGTG' *.fastq > count/B3120_Fm0.txt
agrep -0 -c 'ACCGCAGCCTCGGAAAA' *.fastq > count/B3121_Fm0.txt
agrep -0 -c 'ACTCGAACACGCACCGA' *.fastq > count/B3122_Fm0.txt
agrep -0 -c 'CTACCTATAGAAGGAAC' *.fastq > count/B3123_Fm0.txt
agrep -0 -c 'GCACATAGTTCAAGTGC' *.fastq > count/B3124_Fm0.txt
agrep -0 -c 'AGTCCGGTCTTTCTAAC' *.fastq > count/B3125_Fm0.txt
agrep -0 -c 'ACCTACTTCTGCGGAGA' *.fastq > count/B3126_Fm0.txt
agrep -0 -c 'AACCGCAGGATGTAAAG' *.fastq > count/B3127_Fm0.txt
agrep -0 -c 'ATGGTCGTAGGAGTGGA' *.fastq > count/B3128_Fm0.txt
agrep -0 -c 'AGGTCTGTACCCGTGGT' *.fastq > count/B3129_Fm0.txt
agrep -0 -c 'GCACTTCAGCTCTATCG' *.fastq > count/B3130_Fm0.txt
agrep -0 -c 'CACCCCACTGAGTATTG' *.fastq > count/B3131_Fm0.txt
agrep -0 -c 'CGGAACGTACTACTCGT' *.fastq > count/B3132_Fm0.txt
agrep -0 -c 'GTTCGGGTCATTAGGAA' *.fastq > count/B3133_Fm0.txt
agrep -0 -c 'ACCCCTCAAGACAGCGT' *.fastq > count/B3134_Fm0.txt
agrep -0 -c 'GTCCGTGCGGATTTAGT' *.fastq > count/B3135_Fm0.txt
agrep -0 -c 'AGCAGTACAATAGGATC' *.fastq > count/B3137_Fm0.txt
agrep -0 -c 'CGAAGGGCCAATCAATC' *.fastq > count/B3138_Fm0.txt
agrep -0 -c 'TTGCCCTAGCGAATACG' *.fastq > count/B3139_Fm0.txt
agrep -0 -c 'GCCACCCTATAATATGA' *.fastq > count/B3140_Fm0.txt
agrep -0 -c 'CCATACCATCTGTACTA' *.fastq > count/B3141_Fm0.txt
agrep -0 -c 'CCAGACCAGCATCGAAG' *.fastq > count/B3142_Fm0.txt
agrep -0 -c 'CACGATGTCCGTACTGT' *.fastq > count/B3145_Fm0.txt
agrep -0 -c 'TGTGGTATGTCCCCGAT' *.fastq > count/B3146_Fm0.txt
agrep -0 -c 'AGAGCCAAATGAGATTC' *.fastq > count/B3147_Fm0.txt
agrep -0 -c 'AGAATGTCGCTGTAGAG' *.fastq > count/B3148_Fm0.txt
agrep -0 -c 'GACTTCGATACACGGCC' *.fastq > count/B3149_Fm0.txt
agrep -0 -c 'CAATGGTCGTAGCAGTT' *.fastq > count/B3152_Fm0.txt
agrep -0 -c 'ATCCACGGTGCTTTAGA' *.fastq > count/B3153_Fm0.txt
agrep -0 -c 'CGAGTCATGTAGTGTTG' *.fastq > count/B3155_Fm0.txt
agrep -0 -c 'CTCTTGTAATCCCACGA' *.fastq > count/B3156_Fm0.txt
agrep -0 -c 'GCTAGCTACAACGTAAG' *.fastq > count/B3157_Fm0.txt
agrep -0 -c 'GGTAACAACGGCACTAC' *.fastq > count/B3158_Fm0.txt
agrep -0 -c 'ATAGCACCTCGTTAGCG' *.fastq > count/B3159_Fm0.txt
agrep -0 -c 'CGATTAAGGGAGGGCTA' *.fastq > count/B3161_Fm0.txt
agrep -0 -c 'AGGCGTCTACCTTACTA' *.fastq > count/B3163_Fm0.txt
agrep -0 -c 'CTAGTACCTCGACCCTA' *.fastq > count/B3164_Fm0.txt
agrep -0 -c 'TGCCCTAAAAGTCCCCG' *.fastq > count/B3165_Fm0.txt
agrep -0 -c 'ACGAAGCGAGTTGTCAG' *.fastq > count/B3166_Fm0.txt
agrep -0 -c 'GTACCCTTGTTTCGTTT' *.fastq > count/B3167_Fm0.txt
agrep -0 -c 'GACTGGATGAGTATGGT' *.fastq > count/B3168_Fm0.txt
agrep -0 -c 'CCGGATGTCTGCGAATT' *.fastq > count/B3169_Fm0.txt
agrep -0 -c 'TGGATACTTCGGAAGAC' *.fastq > count/B3170_Fm0.txt
agrep -0 -c 'CGTTCGTTATGGCAACC' *.fastq > count/B3171_Fm0.txt
agrep -0 -c 'CTGATACGGGATAGTTA' *.fastq > count/B3174_Fm0.txt
agrep -0 -c 'TCTCCGATAATTCGGAT' *.fastq > count/B3175_Fm0.txt
agrep -0 -c 'TCTTCCGATCCCAAATG' *.fastq > count/B3176_Fm0.txt
agrep -0 -c 'CGATTGGAATGCGTGAC' *.fastq > count/B3178_Fm0.txt
agrep -0 -c 'ACGGGGAGGGTTTAACC' *.fastq > count/B3181_Fm0.txt
agrep -0 -c 'ACTTAATGTTACCGAGC' *.fastq > count/B3182_Fm0.txt
agrep -0 -c 'TTCCCGCTTGTTCGTGG' *.fastq > count/B3183_Fm0.txt
agrep -0 -c 'CCTATAAAGCCTGTTCC' *.fastq > count/B3184_Fm0.txt
agrep -0 -c 'CTATTTGTCCTGTACGG' *.fastq > count/B3185_Fm0.txt
agrep -0 -c 'CAGGTATCCGCCAGTGA' *.fastq > count/B3186_Fm0.txt
agrep -0 -c 'GAGCGGAAGCAATTACC' *.fastq > count/B3187_Fm0.txt
agrep -0 -c 'GCGATAATGGCACCGTG' *.fastq > count/B3188_Fm0.txt
agrep -0 -c 'GCGTTATCCCTGCGCTA' *.fastq > count/B3189_Fm0.txt
agrep -0 -c 'ACGCGTAAGAACCAGGG' *.fastq > count/B3190_Fm0.txt
agrep -0 -c 'TTACGTGTACCAATGAC' *.fastq > count/B3191_Fm0.txt
agrep -0 -c 'AGACCTCCTATACTCGT' *.fastq > count/B3192_Fm0.txt
agrep -0 -c 'GACTGCGTCTAAATTGC' *.fastq > count/B3193_Fm0.txt
agrep -0 -c 'AAGGACGTATACACCCA' *.fastq > count/B3195_Fm0.txt
agrep -0 -c 'GGAATCCAGGGTTAAAA' *.fastq > count/B3197_Fm0.txt
agrep -0 -c 'AACCAGGGTATACTTCC' *.fastq > count/B3198_Fm0.txt
agrep -0 -c 'TGTGAACGCCAAGACAT' *.fastq > count/B3199_Fm0.txt
agrep -0 -c 'CCTAAGGCGAACGCTTA' *.fastq > count/B3202_Fm0.txt
agrep -0 -c 'GGACCGGTCGCAAATCT' *.fastq > count/B3203_Fm0.txt
agrep -0 -c 'CCTGCGAAGTGCATAAT' *.fastq > count/B3204_Fm0.txt
agrep -0 -c 'TGCCCCCGTACGATCTA' *.fastq > count/B3205_Fm0.txt
agrep -0 -c 'CTAGCTCGTAACAGGCA' *.fastq > count/B3206_Fm0.txt
agrep -0 -c 'CCGTTTGGATTTTCGTA' *.fastq > count/B3208_Fm0.txt
agrep -0 -c 'TGACGTTGTTCCTCCAT' *.fastq > count/B3210_Fm0.txt
agrep -0 -c 'TCTGTGACCGAAACGGC' *.fastq > count/B3211_Fm0.txt
agrep -0 -c 'GGGCACTCGGGATGTTA' *.fastq > count/B3212_Fm0.txt
agrep -0 -c 'CGATCAGCCATAATCCT' *.fastq > count/B3213_Fm0.txt
agrep -0 -c 'GTAGCTTCCCGTATAGA' *.fastq > count/B3215_Fm0.txt
agrep -0 -c 'ACGGTGTCTGGCATTTA' *.fastq > count/B3216_Fm0.txt
agrep -0 -c 'CGACGAGCCAGTGAATT' *.fastq > count/B3217_Fm0.txt
agrep -0 -c 'GTGATGGCTAAGCAATG' *.fastq > count/B3218_Fm0.txt
agrep -0 -c 'GCAGTGCTATCTCTTGA' *.fastq > count/B3220_Fm0.txt
agrep -0 -c 'CAAATCTCATCCGATGC' *.fastq > count/B3221_Fm0.txt
agrep -0 -c 'AATTGGCTCGCATGCTC' *.fastq > count/B3222_Fm0.txt
agrep -0 -c 'CGCTATCGACGCATAAC' *.fastq > count/B3223_Fm0.txt
agrep -0 -c 'AATGATTTTCGCCCCAC' *.fastq > count/B3224_Fm0.txt
agrep -0 -c 'TAACAGGTAGTAACGTC' *.fastq > count/B3226_Fm0.txt
agrep -0 -c 'CGGCCCGAGCTATACTT' *.fastq > count/B3227_Fm0.txt
agrep -0 -c 'AATGCGCAAGTGGGTTC' *.fastq > count/B3228_Fm0.txt
agrep -0 -c 'TGCTCTCGGGGTAGTCA' *.fastq > count/B3229_Fm0.txt
agrep -0 -c 'TGCTGCACACCATTAGA' *.fastq > count/B3230_Fm0.txt
agrep -0 -c 'CATAGGGAATGCTCCGC' *.fastq > count/B3231_Fm0.txt
agrep -0 -c 'ATATCGCTTGCATGGGT' *.fastq > count/B3233_Fm0.txt
agrep -0 -c 'TGCGCATGAACCAGTGC' *.fastq > count/B3234_Fm0.txt
agrep -0 -c 'CATTCGCGCGGAAAATC' *.fastq > count/B3235_Fm0.txt
agrep -0 -c 'GCGCGAATGATGTAGAA' *.fastq > count/B3236_Fm0.txt
agrep -0 -c 'TCAGTTCTGCGAACAAT' *.fastq > count/B3238_Fm0.txt
agrep -0 -c 'ATAAAGGCTGTTCCCCT' *.fastq > count/B3239_Fm0.txt
agrep -0 -c 'TGTGAATCAGCAGGGGA' *.fastq > count/B3240_Fm0.txt
agrep -0 -c 'ATCTGGCTTACTCCCTC' *.fastq > count/B3241_Fm0.txt
agrep -0 -c 'ACCGATAGTTCACCGTA' *.fastq > count/B3242_Fm0.txt
agrep -0 -c 'AGGTCCTAGTGCTTAAG' *.fastq > count/B3244_Fm0.txt
agrep -0 -c 'GTTAACCCAAGGGCATT' *.fastq > count/B3245_Fm0.txt
agrep -0 -c 'GCAGTCGAGATTACATT' *.fastq > count/B3246_Fm0.txt
agrep -0 -c 'CTACGGTGTGCCATGGA' *.fastq > count/B3247_Fm0.txt
agrep -0 -c 'TACAATCCGCCTTGATC' *.fastq > count/B3248_Fm0.txt
agrep -0 -c 'TTGCTTTCTCGGTGTAA' *.fastq > count/B3249_Fm0.txt
agrep -0 -c 'CGTCAACACACCTTCCC' *.fastq > count/B3250_Fm0.txt
agrep -0 -c 'CTATCGTGCAACCTCTT' *.fastq > count/B3252_Fm0.txt
agrep -0 -c 'GTATCAGGAGTCTACAG' *.fastq > count/B3253_Fm0.txt
agrep -0 -c 'ATCCAGCTCACATCGAT' *.fastq > count/B3254_Fm0.txt
agrep -0 -c 'TACGGTGGTGCCTATCG' *.fastq > count/B3255_Fm0.txt
agrep -0 -c 'CTCTGAGTATGATAAGC' *.fastq > count/B3256_Fm0.txt
agrep -0 -c 'ATAAGAGAGCGACACGA' *.fastq > count/B3257_Fm0.txt
agrep -0 -c 'GGATTTGGAGGGCAGCT' *.fastq > count/B3258_Fm0.txt
agrep -0 -c 'TTATACGGACTGCTGGC' *.fastq > count/B3259_Fm0.txt
agrep -0 -c 'AGCAAGTCGCGGTGTTC' *.fastq > count/B3260_Fm0.txt
agrep -0 -c 'GTTTACGTTGTGCAACA' *.fastq > count/B3261_Fm0.txt
agrep -0 -c 'TACGGACACAAGCTCGG' *.fastq > count/B3262_Fm0.txt
agrep -0 -c 'GTCCGAACATTAATGGT' *.fastq > count/B3263_Fm0.txt
agrep -0 -c 'CAGGTGAAGTTACTAAC' *.fastq > count/B3264_Fm0.txt
agrep -0 -c 'ATACCGTCCAACGGTTA' *.fastq > count/B3265_Fm0.txt
agrep -0 -c 'AGCTACAAAGCCATCCG' *.fastq > count/B3266_Fm0.txt
agrep -0 -c 'GGAGTATTGTCAGCGAC' *.fastq > count/B3267_Fm0.txt
agrep -0 -c 'GAGGGAGTACGTAGAGC' *.fastq > count/B3268_Fm0.txt
agrep -0 -c 'GCAGAAATGTCCCGTAG' *.fastq > count/B3269_Fm0.txt
agrep -0 -c 'ACTATCGGTGCTCGAGT' *.fastq > count/B3270_Fm0.txt
agrep -0 -c 'ACAGGACTTAGTGCCAG' *.fastq > count/B3271_Fm0.txt
agrep -0 -c 'CGGAATCCTTGTAAGTG' *.fastq > count/B3272_Fm0.txt
agrep -0 -c 'CGAATGGTCGCAAGCGT' *.fastq > count/B3273_Fm0.txt
agrep -0 -c 'TGTAGACCAGTGCGTAC' *.fastq > count/B3274_Fm0.txt
agrep -0 -c 'TAGCTCATTGATGCATG' *.fastq > count/B3275_Fm0.txt
agrep -0 -c 'TACAGGCAACTTGGAGA' *.fastq > count/B3276_Fm0.txt
agrep -0 -c 'TTGGTTTCCGGGAGCCT' *.fastq > count/B3277_Fm0.txt
agrep -0 -c 'CATAGATTGGGACTCTG' *.fastq > count/B3278_Fm0.txt
agrep -0 -c 'GCGATCTTGGGATCACG' *.fastq > count/B3280_Fm0.txt
agrep -0 -c 'TTAAGCATTCCGTGGGC' *.fastq > count/B3282_Fm0.txt
agrep -0 -c 'GGATCTTTGAGGCCAGT' *.fastq > count/B3283_Fm0.txt
agrep -0 -c 'AATAGATTGGGGGACGA' *.fastq > count/B3284_Fm0.txt
agrep -0 -c 'AGAGGTCTTCCTAGCCG' *.fastq > count/B3285_Fm0.txt
agrep -0 -c 'TTGTAACCTCTGCCAGT' *.fastq > count/B3287_Fm0.txt
agrep -0 -c 'ATATATTTGCTCCGAGC' *.fastq > count/B3289_Fm0.txt
agrep -0 -c 'CGTGACTACCCTGAGAA' *.fastq > count/B3290_Fm0.txt
agrep -0 -c 'ATCCGAATAGCCATTTG' *.fastq > count/B3292_Fm0.txt
agrep -0 -c 'CATTTATGCGCACTAGC' *.fastq > count/B3293_Fm0.txt
agrep -0 -c 'TGTCTTGTCTCGACCGG' *.fastq > count/B3294_Fm0.txt
agrep -0 -c 'CGGATGCTCTCACCTAA' *.fastq > count/B3295_Fm0.txt
agrep -0 -c 'ACCCAGTGCTGAACATG' *.fastq > count/B3296_Fm0.txt
agrep -0 -c 'GGCAAGTGCAACATGTG' *.fastq > count/B3297_Fm0.txt
agrep -0 -c 'TTCGACCAAGAGGCGGT' *.fastq > count/B3298_Fm0.txt
agrep -0 -c 'GCTTGCTATGTTCGATA' *.fastq > count/B3299_Fm0.txt
agrep -0 -c 'TTCCTCCAACTGCAGTC' *.fastq > count/B3300_Fm0.txt
agrep -0 -c 'TGTGCTTCGGGTTAGCA' *.fastq > count/B3301_Fm0.txt
agrep -0 -c 'GTGTTACAGAGCTTGCC' *.fastq > count/B3302_Fm0.txt
agrep -0 -c 'TGTTGCCCCAGAAAGGG' *.fastq > count/B3303_Fm0.txt
agrep -0 -c 'CTTAGTCGGAACCTACC' *.fastq > count/B3304_Fm0.txt
agrep -0 -c 'TACCTGCAGATAGAAGG' *.fastq > count/B3305_Fm0.txt
agrep -0 -c 'ACCAGGCGGCTAACAAA' *.fastq > count/B3306_Fm0.txt
agrep -0 -c 'TTGCACCTATTCGACGT' *.fastq > count/B3307_Fm0.txt
agrep -0 -c 'AGGGACCAGTTGAGCAA' *.fastq > count/B3309_Fm0.txt
agrep -0 -c 'GGATATCCGGTACTACC' *.fastq > count/B3310_Fm0.txt
agrep -0 -c 'GCCGCGCCTTCATTGTT' *.fastq > count/B3311_Fm0.txt
agrep -0 -c 'GGGCGTTATGTAGAGCT' *.fastq > count/B3312_Fm0.txt
agrep -0 -c 'GTATTATCCCTCGCCGC' *.fastq > count/B3313_Fm0.txt
agrep -0 -c 'CTACATGCCACCCCTTG' *.fastq > count/B3314_Fm0.txt
agrep -0 -c 'AATAGGCATACCCTAGA' *.fastq > count/B3315_Fm0.txt
agrep -0 -c 'GGTGGGGTAAAAACGTC' *.fastq > count/B3318_Fm0.txt
agrep -0 -c 'CGAGCGTTCGTAACGTG' *.fastq > count/B3319_Fm0.txt
agrep -0 -c 'CTCGGCACTGCTTATGT' *.fastq > count/B3320_Fm0.txt
agrep -0 -c 'ATTCGAATGGGACGGGA' *.fastq > count/B3321_Fm0.txt
agrep -0 -c 'TGAGATGGCAATAACCG' *.fastq > count/B3322_Fm0.txt
agrep -0 -c 'TTCTAGTAGCGCCTGCG' *.fastq > count/B3323_Fm0.txt
agrep -0 -c 'ACAGTACCCTCAGTACT' *.fastq > count/B3324_Fm0.txt
agrep -0 -c 'TAGGGTTACGCAGATCC' *.fastq > count/B3325_Fm0.txt
agrep -0 -c 'CAACAGGGACTTGTACG' *.fastq > count/B3326_Fm0.txt
agrep -0 -c 'CTAGTCGTGTGGATCAC' *.fastq > count/B3327_Fm0.txt
agrep -0 -c 'TGAGTAACAGAGTGCGT' *.fastq > count/B3328_Fm0.txt
agrep -0 -c 'GTAGAAAGGAAGTCGTA' *.fastq > count/B3329_Fm0.txt
agrep -0 -c 'TGTGCCGTCCGTTATTT' *.fastq > count/B3330_Fm0.txt
agrep -0 -c 'TAGATCACTGGGTCATC' *.fastq > count/B3331_Fm0.txt
agrep -0 -c 'GTGATATGGTGCGAGTG' *.fastq > count/B3332_Fm0.txt
agrep -0 -c 'GGAAGTAGTTCGGATAG' *.fastq > count/B3333_Fm0.txt
agrep -0 -c 'GCTTCGCATGATAGCTT' *.fastq > count/B3336_Fm0.txt
agrep -0 -c 'GCGCTCTAAGCCCATAC' *.fastq > count/B3337_Fm0.txt
agrep -0 -c 'CTCGTGTTTGTCTGCTC' *.fastq > count/B3338_Fm0.txt
agrep -0 -c 'CACTTACGCCGTGTGTC' *.fastq > count/B3339_Fm0.txt
agrep -0 -c 'AATTAACACCGTCCTTC' *.fastq > count/B3340_Fm0.txt
agrep -0 -c 'AAGTCACAACGCGATTA' *.fastq > count/B3341_Fm0.txt
agrep -0 -c 'TGCCGTATGCATGAAGA' *.fastq > count/B3342_Fm0.txt
agrep -0 -c 'TAGCCCTAGTCGCATGG' *.fastq > count/B3343_Fm0.txt
agrep -0 -c 'ACTTGACGCCCTTGCGA' *.fastq > count/B3344_Fm0.txt
agrep -0 -c 'TACGGTAACGCGACGAA' *.fastq > count/B3348_Fm0.txt
agrep -0 -c 'GGCTCGTATACTCCATC' *.fastq > count/B3349_Fm0.txt
agrep -0 -c 'ATAGAGAGGATTAGCGA' *.fastq > count/B3353_Fm0.txt
agrep -0 -c 'AGTCGATTGGTAGTCAT' *.fastq > count/B3355_Fm0.txt
agrep -0 -c 'CGTGGGGTGACGAACTT' *.fastq > count/B3357_Fm0.txt
agrep -0 -c 'GGAATCGAGTGTTTGGC' *.fastq > count/B3358_Fm0.txt
agrep -0 -c 'CAAGATAGCTGGGCGAC' *.fastq > count/B3359_Fm0.txt
agrep -0 -c 'CTGGCGACAGAGGTCTT' *.fastq > count/B3360_Fm0.txt
agrep -0 -c 'TGTACGCGGGTTCGATT' *.fastq > count/B3362_Fm0.txt
agrep -0 -c 'TAGACGAAAGCACTCGG' *.fastq > count/B3363_Fm0.txt
agrep -0 -c 'GCCCGATTGAAACTTCT' *.fastq > count/B3364_Fm0.txt
agrep -0 -c 'CTCCTTGGGAAGGTTCT' *.fastq > count/B3365_Fm0.txt
agrep -0 -c 'AAGTTATAGGTTAGCCG' *.fastq > count/B3366_Fm0.txt
agrep -0 -c 'AAGGGGTGAACCTCTTG' *.fastq > count/B3367_Fm0.txt
agrep -0 -c 'GGAGAGATAACCTAAGG' *.fastq > count/B3370_Fm0.txt
agrep -0 -c 'TGCACTTGTACGTATTG' *.fastq > count/B3371_Fm0.txt
agrep -0 -c 'CAATAGTCTAATGCACC' *.fastq > count/B3374_Fm0.txt
agrep -0 -c 'GCTAAATAGGTTACTCG' *.fastq > count/B3375_Fm0.txt
agrep -0 -c 'GATCACCTTCCTACGGT' *.fastq > count/B3376_Fm0.txt
agrep -0 -c 'TTATGGGTAGGACATAC' *.fastq > count/B3377_Fm0.txt
agrep -0 -c 'AACCAGTGACGCAGCTG' *.fastq > count/B3380_Fm0.txt
agrep -0 -c 'CTCCACGTGCTCTTATA' *.fastq > count/B3381_Fm0.txt
agrep -0 -c 'CGAACCACGGGCAGATT' *.fastq > count/B3382_Fm0.txt
agrep -0 -c 'TGTGTGGTCGTTTTAAC' *.fastq > count/B3383_Fm0.txt
agrep -0 -c 'GGGGTCTATGAGCGTTC' *.fastq > count/B3384_Fm0.txt
agrep -0 -c 'ATAATTGTCACCGTGGA' *.fastq > count/B3386_Fm0.txt
agrep -0 -c 'CGCGAGTAAGGGAGTCA' *.fastq > count/B3387_Fm0.txt
agrep -0 -c 'ATCTGCCTTCGGGAGCA' *.fastq > count/B3389_Fm0.txt
agrep -0 -c 'GACGTTACCAAGCAATC' *.fastq > count/B3390_Fm0.txt
agrep -0 -c 'CGAGCTTATGAAAGGAC' *.fastq > count/B3391_Fm0.txt
agrep -0 -c 'TGGCATTTAGGTTGTAG' *.fastq > count/B3392_Fm0.txt
agrep -0 -c 'TTCACAAAATCCCACCA' *.fastq > count/B3393_Fm0.txt
agrep -0 -c 'GTCGTCACAGTTATAGC' *.fastq > count/B3394_Fm0.txt
agrep -0 -c 'GAGCCGAGTCTAGATAT' *.fastq > count/B3395_Fm0.txt
agrep -0 -c 'GTGTGACTCGCAGTCGT' *.fastq > count/B3396_Fm0.txt
agrep -0 -c 'CGGGTATATGTTAACGT' *.fastq > count/B3397_Fm0.txt
agrep -0 -c 'GTAGTTTTCACGACGAG' *.fastq > count/B3398_Fm0.txt
agrep -0 -c 'ACTCAACACCTTTTCGG' *.fastq > count/B3399_Fm0.txt
agrep -0 -c 'ATTTGGAACCGTGGAAG' *.fastq > count/B3400_Fm0.txt
agrep -0 -c 'TTCAAGTTAAACGGCCC' *.fastq > count/B3401_Fm0.txt
agrep -0 -c 'CAGGGTGATCTAGAAGG' *.fastq > count/B3402_Fm0.txt
agrep -0 -c 'AGCTATAACCAGTGACT' *.fastq > count/B3403_Fm0.txt
agrep -0 -c 'AATGGCCACTTTGAAAC' *.fastq > count/B3404_Fm0.txt
agrep -0 -c 'ATACCTCAGTCGAGTCC' *.fastq > count/B3406_Fm0.txt
agrep -0 -c 'GTTTATGTGCAGTTCTC' *.fastq > count/B3407_Fm0.txt
agrep -0 -c 'GACCGGTTTCGATTAAA' *.fastq > count/B3408_Fm0.txt
agrep -0 -c 'CCTCTTTGAAGCCGAGA' *.fastq > count/B3410_Fm0.txt
agrep -0 -c 'CAGCAGATACGTGTCAC' *.fastq > count/B3412_Fm0.txt
agrep -0 -c 'CGGGGACATAATCTGAT' *.fastq > count/B3413_Fm0.txt
agrep -0 -c 'ACGTTTGGAACCCTCTT' *.fastq > count/B3414_Fm0.txt
agrep -0 -c 'CACTACAAACAGCAATC' *.fastq > count/B3415_Fm0.txt
agrep -0 -c 'TAGCACCTAGGTAGTTA' *.fastq > count/B3417_Fm0.txt
agrep -0 -c 'TCACAGACGCACTGTAG' *.fastq > count/B3418_Fm0.txt
agrep -0 -c 'TAAGTCTCGCGATAGTT' *.fastq > count/B3419_Fm0.txt
agrep -0 -c 'CGAGGAACTAGAGCAAT' *.fastq > count/B3420_Fm0.txt
agrep -0 -c 'GTTCGGCATGAATATTC' *.fastq > count/B3421_Fm0.txt
agrep -0 -c 'TATGCGTGTAGTACCCA' *.fastq > count/B3422_Fm0.txt
agrep -0 -c 'GGGGAGAATAGGTCATT' *.fastq > count/B3423_Fm0.txt
agrep -0 -c 'GATTAGGGAGCTATGGT' *.fastq > count/B3424_Fm0.txt
agrep -0 -c 'TTAAGATCACGGGCATC' *.fastq > count/B3426_Fm0.txt
agrep -0 -c 'GGCTTACAGCTCAATGC' *.fastq > count/B3427_Fm0.txt
agrep -0 -c 'CCTATACGAAGCCGAGC' *.fastq > count/B3428_Fm0.txt
agrep -0 -c 'ATAAGCAGTACTAGGGC' *.fastq > count/B3429_Fm0.txt
agrep -0 -c 'TTGTCGACTCTCGAGGC' *.fastq > count/B3430_Fm0.txt
agrep -0 -c 'CACACCTTGATCGATAG' *.fastq > count/B3431_Fm0.txt
agrep -0 -c 'CTAGCGGGGCTGATTTA' *.fastq > count/B3432_Fm0.txt
agrep -0 -c 'TAAGCTACTAGAGTGGG' *.fastq > count/B3433_Fm0.txt
agrep -0 -c 'GCAGATCCTCTACAAGG' *.fastq > count/B3434_Fm0.txt
agrep -0 -c 'ATGTTGAAAGTCGGTTC' *.fastq > count/B3435_Fm0.txt
agrep -0 -c 'TGCCGACAACGTTAGCT' *.fastq > count/B3436_Fm0.txt
agrep -0 -c 'CACCATTTACTCCCCGT' *.fastq > count/B3437_Fm0.txt
agrep -0 -c 'ACAGCCGTCGGTTTTAG' *.fastq > count/B3438_Fm0.txt
agrep -0 -c 'CTATGCGCGTGATCAAA' *.fastq > count/B3439_Fm0.txt
agrep -0 -c 'CAAGCGAACCGCCCTTA' *.fastq > count/B3440_Fm0.txt
agrep -0 -c 'AAGCCGCAAAACAACAT' *.fastq > count/B3441_Fm0.txt
agrep -0 -c 'TTGCATTGGGGATTCCG' *.fastq > count/B3442_Fm0.txt
agrep -0 -c 'CTAACCTGTATATGGGC' *.fastq > count/B3443_Fm0.txt
agrep -0 -c 'GATACCTTAATCGTACG' *.fastq > count/B3444_Fm0.txt
agrep -0 -c 'GCACTCGCACAACGATC' *.fastq > count/B3446_Fm0.txt
agrep -0 -c 'GCCCCTTAGCTGAACCT' *.fastq > count/B3447_Fm0.txt
agrep -0 -c 'CCGTTAAGGCGAAGGTA' *.fastq > count/B3448_Fm0.txt
agrep -0 -c 'TAAGGTAACCGTCCGTT' *.fastq > count/B3449_Fm0.txt
agrep -0 -c 'AGTCAGGGTGTCGCATG' *.fastq > count/B3451_Fm0.txt
agrep -0 -c 'GCGAAGCACTCTGTTCT' *.fastq > count/B3452_Fm0.txt
agrep -0 -c 'ATCGGGCTTGGTGAAGG' *.fastq > count/B3453_Fm0.txt
agrep -0 -c 'TCGGATCTACATCAGCG' *.fastq > count/B3454_Fm0.txt
agrep -0 -c 'GGTTTTGATCAGAGATG' *.fastq > count/B3456_Fm0.txt
agrep -0 -c 'CAAAGCGGACGTCTAGA' *.fastq > count/B3457_Fm0.txt
agrep -0 -c 'CTCCAGCTCAGACGTAC' *.fastq > count/B3458_Fm0.txt
agrep -0 -c 'AGGCATTCCACAATGGG' *.fastq > count/B3459_Fm0.txt
agrep -0 -c 'TATGCCTCACTGGTGTA' *.fastq > count/B3460_Fm0.txt
agrep -0 -c 'AGTGGCCTTTCTTCTCG' *.fastq > count/B3461_Fm0.txt
agrep -0 -c 'AGAACGCTGAACCCTAG' *.fastq > count/B3462_Fm0.txt
agrep -0 -c 'CTTCTACACCGGCTAAA' *.fastq > count/B3463_Fm0.txt
agrep -0 -c 'GCCCACTGTCACAAAAA' *.fastq > count/B3464_Fm0.txt
agrep -0 -c 'ACGGAGCTTAAGACCGA' *.fastq > count/B3465_Fm0.txt
agrep -0 -c 'GTACGACTTACATGTCA' *.fastq > count/B3467_Fm0.txt
agrep -0 -c 'AGGTATAGCTTGGCAGC' *.fastq > count/B3468_Fm0.txt
agrep -0 -c 'CAATAGTAAATGGCGGC' *.fastq > count/B3469_Fm0.txt
agrep -0 -c 'TATGGTCGTACAGTAAC' *.fastq > count/B3471_Fm0.txt
agrep -0 -c 'AGACCCCGCTTGCACTT' *.fastq > count/B3472_Fm0.txt
agrep -0 -c 'TTAAAGGTAGTGAAGGC' *.fastq > count/B3473_Fm0.txt
agrep -0 -c 'TGCACAACCTTCCGTAT' *.fastq > count/B3474_Fm0.txt
agrep -0 -c 'AGGCCGTCAGATCCTTC' *.fastq > count/B3475_Fm0.txt
agrep -0 -c 'CAGATCGTCCCGGAGTA' *.fastq > count/B3476_Fm0.txt
agrep -0 -c 'TTAGTCGGTCAGTCCGC' *.fastq > count/B3477_Fm0.txt
agrep -0 -c 'ATAAGTCAAATCCTGCC' *.fastq > count/B3479_Fm0.txt
agrep -0 -c 'GCGTAGCATAGTCACGT' *.fastq > count/B3480_Fm0.txt
agrep -0 -c 'GTCACTAAACTCCGGGA' *.fastq > count/B3481_Fm0.txt
agrep -0 -c 'TGTAGCTGCTGTGCAAT' *.fastq > count/B3482_Fm0.txt
agrep -0 -c 'TCGTACCGTCCAACACA' *.fastq > count/B3483_Fm0.txt
agrep -0 -c 'ACGGTCCGCGTAATTAC' *.fastq > count/B3484_Fm0.txt
agrep -0 -c 'TGTCCAAAGACATACGT' *.fastq > count/B3485_Fm0.txt
agrep -0 -c 'TTAGAACGGCTAGGCCT' *.fastq > count/B3486_Fm0.txt
agrep -0 -c 'TGCACTCCATTCCGACT' *.fastq > count/B3487_Fm0.txt
agrep -0 -c 'TTGGGTCAAGTCACCCG' *.fastq > count/B3488_Fm0.txt
agrep -0 -c 'AAGGTTTGTCAGCCACG' *.fastq > count/B3490_Fm0.txt
agrep -0 -c 'GATTCCAGATCCAGCAT' *.fastq > count/B3491_Fm0.txt
agrep -0 -c 'CCTCTCTCGTGAAAGGG' *.fastq > count/B3492_Fm0.txt
agrep -0 -c 'ATCCTAAAAACGGGCAG' *.fastq > count/B3493_Fm0.txt
agrep -0 -c 'CGTTGATGCTTAGGGTC' *.fastq > count/B3494_Fm0.txt
agrep -0 -c 'ACATCGATAGCACGTGT' *.fastq > count/B3495_Fm0.txt
agrep -0 -c 'TCAGATGTATGCACCAC' *.fastq > count/B3496_Fm0.txt
agrep -0 -c 'AGAGCGAACGCTCATCC' *.fastq > count/B3497_Fm0.txt
agrep -0 -c 'GTACTCTCTACGGTTTC' *.fastq > count/B3498_Fm0.txt
agrep -0 -c 'AGGCCTTGAGACATGTA' *.fastq > count/B3499_Fm0.txt
agrep -0 -c 'CGGCTTTCTCAACATCT' *.fastq > count/B3500_Fm0.txt
agrep -0 -c 'TGCCGGTGTATCTAATT' *.fastq > count/B3501_Fm0.txt
agrep -0 -c 'GGTGGGCGAAAATAAGA' *.fastq > count/B3502_Fm0.txt
agrep -0 -c 'ATTGTTGGGTCGAGTAC' *.fastq > count/B3503_Fm0.txt
agrep -0 -c 'TACGTGTACGGGTTCCT' *.fastq > count/B3504_Fm0.txt
agrep -0 -c 'GTAGGAGGTGATGTAGC' *.fastq > count/B3506_Fm0.txt
agrep -0 -c 'TAACGGTCAGCGAATAG' *.fastq > count/B3507_Fm0.txt
agrep -0 -c 'TGCACGTGCTCGTACTT' *.fastq > count/B3508_Fm0.txt
agrep -0 -c 'CAGGACCTTTCCAGTAC' *.fastq > count/B3509_Fm0.txt
agrep -0 -c 'TACCTGGGTGGTGATGC' *.fastq > count/B3510_Fm0.txt
agrep -0 -c 'TGCTGGTGGTCAAATAT' *.fastq > count/B3512_Fm0.txt
agrep -0 -c 'GGTGGCAACGGCTTTCA' *.fastq > count/B3513_Fm0.txt
agrep -0 -c 'CGTTCGCAAATGAGACA' *.fastq > count/B3515_Fm0.txt
agrep -0 -c 'ACGGCCTTATGTAGTCG' *.fastq > count/B3517_Fm0.txt
agrep -0 -c 'TGAGGCCAAAGTCCGTC' *.fastq > count/B3518_Fm0.txt
agrep -0 -c 'ACAATAGGAATCCGCCG' *.fastq > count/B3519_Fm0.txt
agrep -0 -c 'CTTGATATTGGGGATCG' *.fastq > count/B3520_Fm0.txt
agrep -0 -c 'TACCGAAGTCCGCAGAA' *.fastq > count/B3523_Fm0.txt
agrep -0 -c 'TAGGCCGCGAAGTGTGA' *.fastq > count/B3524_Fm0.txt
agrep -0 -c 'AGATAGAGATCATGCGC' *.fastq > count/B3525_Fm0.txt
agrep -0 -c 'GCGAGAACAGACGATGT' *.fastq > count/B3526_Fm0.txt
agrep -0 -c 'TCTATAGTGTTGGGTTG' *.fastq > count/B3527_Fm0.txt
agrep -0 -c 'TGATCGAGGGTCTATTC' *.fastq > count/B3528_Fm0.txt
agrep -0 -c 'CAAACTCGCCTTAGCTC' *.fastq > count/B3529_Fm0.txt
agrep -0 -c 'AGTGTTCTCAGGTCCCC' *.fastq > count/B3530_Fm0.txt
agrep -0 -c 'AGCGTTGAATCGGTTAA' *.fastq > count/B3531_Fm0.txt
agrep -0 -c 'GTGGGCGTTGGCAAACA' *.fastq > count/B3532_Fm0.txt
agrep -0 -c 'TGTCGAACCTAGAACTC' *.fastq > count/B3533_Fm0.txt
agrep -0 -c 'ATCCGCTTAGATCAAGT' *.fastq > count/B3534_Fm0.txt
agrep -0 -c 'CCATTGGGTCTGATTCC' *.fastq > count/B3535_Fm0.txt
agrep -0 -c 'TAGTCCCTCCGATATGT' *.fastq > count/B3536_Fm0.txt
agrep -0 -c 'TATAGTAAGGCGAGCAA' *.fastq > count/B3537_Fm0.txt
agrep -0 -c 'GCCAATAGCCGTAATTA' *.fastq > count/B3540_Fm0.txt
agrep -0 -c 'AGACACTCCGTCCCAAG' *.fastq > count/B3541_Fm0.txt
agrep -0 -c 'GTGAGTAGACATGGACT' *.fastq > count/B3542_Fm0.txt
agrep -0 -c 'CCTGACGTCATGCACGA' *.fastq > count/B3543_Fm0.txt
agrep -0 -c 'CCGTTTTCGGTGCCAGT' *.fastq > count/B3544_Fm0.txt
agrep -0 -c 'GTGCTTAACAGTGCGTT' *.fastq > count/B3545_Fm0.txt
agrep -0 -c 'GACGGTAGAACGATCCC' *.fastq > count/B3546_Fm0.txt
agrep -0 -c 'TGAAACCGCTATCTCCG' *.fastq > count/B3547_Fm0.txt
agrep -0 -c 'TCATTGGCAGTACCCAC' *.fastq > count/B3548_Fm0.txt
agrep -0 -c 'AGGCGGCATTACTGAAA' *.fastq > count/B3550_Fm0.txt
agrep -0 -c 'CTGGAGCTGGTACGAAG' *.fastq > count/B3551_Fm0.txt
agrep -0 -c 'ACGAGCTCTACAGGGAT' *.fastq > count/B3552_Fm0.txt
agrep -0 -c 'CCTTAAAGGGGTTGAAC' *.fastq > count/B3553_Fm0.txt
agrep -0 -c 'GCATGACAGTGGCATGA' *.fastq > count/B3554_Fm0.txt
agrep -0 -c 'AGTTAGTAAAGTACCGG' *.fastq > count/B3555_Fm0.txt
agrep -0 -c 'GCCAGTCAGAGAGACTC' *.fastq > count/B3557_Fm0.txt
agrep -0 -c 'CCTCCCACACGCGATAA' *.fastq > count/B3558_Fm0.txt
agrep -0 -c 'GTGGTGCATAGAGACTA' *.fastq > count/B3559_Fm0.txt
agrep -0 -c 'AGCCACAACTCCCAATG' *.fastq > count/B3560_Fm0.txt
agrep -0 -c 'TGCCAGATTATGCCGCC' *.fastq > count/B3561_Fm0.txt
agrep -0 -c 'GGTTAATGAATGCGGCC' *.fastq > count/B3562_Fm0.txt
agrep -0 -c 'AGTGAACGATCTCGATA' *.fastq > count/B3563_Fm0.txt
agrep -0 -c 'AGTCAGGCTGGAAGTAA' *.fastq > count/B3564_Fm0.txt
agrep -0 -c 'AGTCGGAAGTTATACCT' *.fastq > count/B3565_Fm0.txt
agrep -0 -c 'TATTTAGGACCAGAGCC' *.fastq > count/B3566_Fm0.txt
agrep -0 -c 'TACCCAATCACCTGAAG' *.fastq > count/B3567_Fm0.txt
agrep -0 -c 'AGTCGAGATGTTGTTGG' *.fastq > count/B3568_Fm0.txt
agrep -0 -c 'TTGTCGGACTTGCCTCC' *.fastq > count/B3569_Fm0.txt
agrep -0 -c 'CTACTTAGAAAGGGACT' *.fastq > count/B3570_Fm0.txt
agrep -0 -c 'CTGGTGAGTAGTCGGCA' *.fastq > count/B3571_Fm0.txt
agrep -0 -c 'GCCGTGGCGTCTATTCT' *.fastq > count/B3572_Fm0.txt
agrep -0 -c 'AGTGTGGTCGCCCACAA' *.fastq > count/B3573_Fm0.txt
agrep -0 -c 'TATCGTCTTCTGTGAGG' *.fastq > count/B3574_Fm0.txt
agrep -0 -c 'CACATTTCCGGAGGGAC' *.fastq > count/B3575_Fm0.txt
agrep -0 -c 'TTCTACTGGCCCGCATG' *.fastq > count/B3577_Fm0.txt
agrep -0 -c 'GTATCATCTAGGGACAT' *.fastq > count/B3578_Fm0.txt
agrep -0 -c 'GTCGGAAAGCGGTAGAA' *.fastq > count/B3579_Fm0.txt
agrep -0 -c 'ATCCCAACCTACCAAGG' *.fastq > count/B3580_Fm0.txt
agrep -0 -c 'AGTCTTGTTGGACAACG' *.fastq > count/B3582_Fm0.txt
agrep -0 -c 'ACTTACTCTCTCAATCG' *.fastq > count/B3583_Fm0.txt
agrep -0 -c 'GACTTGTACTAGCCCGT' *.fastq > count/B3584_Fm0.txt
agrep -0 -c 'CTCTTTTTCCTCAGAGT' *.fastq > count/B3585_Fm0.txt
agrep -0 -c 'TGCTCTTTGCGTCTCGT' *.fastq > count/B3586_Fm0.txt
agrep -0 -c 'GGAGGCGTATTCGCGAT' *.fastq > count/B3587_Fm0.txt
agrep -0 -c 'CTGTTACAAAAGAGGCT' *.fastq > count/B3589_Fm0.txt
agrep -0 -c 'GGGCATAGGTCATATAC' *.fastq > count/B3590_Fm0.txt
agrep -0 -c 'CGGGACCAATTGTCACG' *.fastq > count/B3591_Fm0.txt
agrep -0 -c 'GTTATCAGCGAGTTGCG' *.fastq > count/B3592_Fm0.txt
agrep -0 -c 'ACGGGAATCATCGTATA' *.fastq > count/B3594_Fm0.txt
agrep -0 -c 'CCACGCGCACATGTAAG' *.fastq > count/B3595_Fm0.txt
agrep -0 -c 'CCATGTGGTTGTAGTGA' *.fastq > count/B3596_Fm0.txt
agrep -0 -c 'GCAAGACATGCGTGCTG' *.fastq > count/B3597_Fm0.txt
agrep -0 -c 'ACGATGCTTCGAGATAG' *.fastq > count/B3598_Fm0.txt
agrep -0 -c 'CTCCCCCGAGTATTATC' *.fastq > count/B3599_Fm0.txt
agrep -0 -c 'ATGTTTTCCGGTAACCT' *.fastq > count/B3600_Fm0.txt
agrep -0 -c 'CTATGGCACGACCCGAT' *.fastq > count/B3601_Fm0.txt
agrep -0 -c 'TATGGTTAACAGACCCG' *.fastq > count/B3603_Fm0.txt
agrep -0 -c 'AACTCACTCCGGCATGA' *.fastq > count/B3605_Fm0.txt
agrep -0 -c 'TTGTATAACAGGGAGGA' *.fastq > count/B3606_Fm0.txt
agrep -0 -c 'AGATCATGAACGCGCCT' *.fastq > count/B3607_Fm0.txt
agrep -0 -c 'TGACCATGTCCGAGAAT' *.fastq > count/B3608_Fm0.txt
agrep -0 -c 'CGTTTACGCGACCTCTA' *.fastq > count/B3609_Fm0.txt
agrep -0 -c 'CCTCCTATCTGGGCATT' *.fastq > count/B3610_Fm0.txt
agrep -0 -c 'TTGCTTTATTTGCCGCT' *.fastq > count/B3611_Fm0.txt
agrep -0 -c 'GCGAAACCTCGAAAAAC' *.fastq > count/B3612_Fm0.txt
agrep -0 -c 'GGCTGGAATGTCGGTTC' *.fastq > count/B3614_Fm0.txt
agrep -0 -c 'ATTTGAAACCCGCACTC' *.fastq > count/B3616_Fm0.txt
agrep -0 -c 'CAACGAGACTAGGGTTG' *.fastq > count/B3617_Fm0.txt
agrep -0 -c 'TGACCAGAGTCAGTCTT' *.fastq > count/B3618_Fm0.txt
agrep -0 -c 'TGCTATTAACAGCACGT' *.fastq > count/B3619_Fm0.txt
agrep -0 -c 'TACCGCTTACCGTTCCA' *.fastq > count/B3620_Fm0.txt
agrep -0 -c 'GCTTCGACACCATTTCG' *.fastq > count/B3621_Fm0.txt
agrep -0 -c 'ATTGGGGCGATTGGATT' *.fastq > count/B3622_Fm0.txt
agrep -0 -c 'TGACGAGAAACGTGGGT' *.fastq > count/B3623_Fm0.txt
agrep -0 -c 'CAAGGGTGATGCGATGC' *.fastq > count/B3624_Fm0.txt
agrep -0 -c 'TCGCTCACAGCTTCTAG' *.fastq > count/B3626_Fm0.txt
agrep -0 -c 'CTCGACAGACTCTTTAA' *.fastq > count/B3627_Fm0.txt
agrep -0 -c 'CGGTTTAGGGATCTTTT' *.fastq > count/B3628_Fm0.txt
agrep -0 -c 'AAGCGGACCTTGAAGGC' *.fastq > count/B3629_Fm0.txt
agrep -0 -c 'GACCTGGGAATGCACGA' *.fastq > count/B3630_Fm0.txt
agrep -0 -c 'TACGACGCAGACTGTGG' *.fastq > count/B3631_Fm0.txt
agrep -0 -c 'GTCCATCGGAACGTAAA' *.fastq > count/B3632_Fm0.txt
agrep -0 -c 'CCATAAACCGCGTCAGC' *.fastq > count/B3633_Fm0.txt
agrep -0 -c 'AGAGCCCGCCAATCGTA' *.fastq > count/B3634_Fm0.txt
agrep -0 -c 'ATGACCAAGCTCGTGGC' *.fastq > count/B3635_Fm0.txt
agrep -0 -c 'GTCCAACTACAGCCGTA' *.fastq > count/B3636_Fm0.txt
agrep -0 -c 'CCGCTCATACCAGTTGG' *.fastq > count/B3637_Fm0.txt
agrep -0 -c 'ACTATTCCCGCTAATAC' *.fastq > count/B3638_Fm0.txt
agrep -0 -c 'ATATGGTGCGGGGATCT' *.fastq > count/B3639_Fm0.txt
agrep -0 -c 'TCAACGCAAGGTGTCAA' *.fastq > count/B3641_Fm0.txt
agrep -0 -c 'GTGGTCAGTAGGATCCG' *.fastq > count/B3642_Fm0.txt
agrep -0 -c 'CCACTAGCGCATTCAAT' *.fastq > count/B3643_Fm0.txt
agrep -0 -c 'ACGTAGATTAACTCCAC' *.fastq > count/B3644_Fm0.txt
agrep -0 -c 'TTAGTCCCTTGGAGGTG' *.fastq > count/B3645_Fm0.txt
agrep -0 -c 'TCTATGCGGAGGCTTTG' *.fastq > count/B3646_Fm0.txt
agrep -0 -c 'CAGGTATCTGTAGCCCC' *.fastq > count/B3647_Fm0.txt
agrep -0 -c 'GTGCTTAATTGAGCGTC' *.fastq > count/B3648_Fm0.txt
agrep -0 -c 'ATGCTTCACTTATAGGG' *.fastq > count/B3652_Fm0.txt
agrep -0 -c 'CTGATTTCGCAGCAAAT' *.fastq > count/B3653_Fm0.txt
agrep -0 -c 'TGCCGTGACGTGGATTA' *.fastq > count/B3654_Fm0.txt
agrep -0 -c 'TGTATCAGCGCAAACTC' *.fastq > count/B3655_Fm0.txt
agrep -0 -c 'GCCCCTCATCTTCAGAT' *.fastq > count/B3656_Fm0.txt
agrep -0 -c 'GATTTTTGCCTACGCAT' *.fastq > count/B3658_Fm0.txt
agrep -0 -c 'TTACCTCGTCAATCGGG' *.fastq > count/B3659_Fm0.txt
agrep -0 -c 'TACTGTCCCGTCAAATG' *.fastq > count/B3660_Fm0.txt
agrep -0 -c 'TGCCTTTTATAGTCCAG' *.fastq > count/B3661_Fm0.txt
agrep -0 -c 'ACCGTAGTCAGTCAATA' *.fastq > count/B3664_Fm0.txt
agrep -0 -c 'GATATTGCTGCTGATCG' *.fastq > count/B3666_Fm0.txt
agrep -0 -c 'TCTGCCGGATAACCCCT' *.fastq > count/B3668_Fm0.txt
agrep -0 -c 'CGGCGAACTTTAGCTCT' *.fastq > count/B3669_Fm0.txt
agrep -0 -c 'TGCTCAAACAATAGGCT' *.fastq > count/B3670_Fm0.txt
agrep -0 -c 'CCAAGTCGGCAGCAGTA' *.fastq > count/B3671_Fm0.txt
agrep -0 -c 'GCTCTTCCGCGTCGTTT' *.fastq > count/B3673_Fm0.txt
agrep -0 -c 'GTTAGAACCGTACAGGG' *.fastq > count/B3674_Fm0.txt
agrep -0 -c 'TTGTCCCTGCTAGACGA' *.fastq > count/B3675_Fm0.txt
agrep -0 -c 'CATCTGCCTTGATCGAT' *.fastq > count/B3676_Fm0.txt
agrep -0 -c 'GTCACAAGGAACGGCTC' *.fastq > count/B3677_Fm0.txt
agrep -0 -c 'ACGGCTTAGCCCTGGTT' *.fastq > count/B3678_Fm0.txt
agrep -0 -c 'GCGTCCGGTCAAATCCT' *.fastq > count/B3679_Fm0.txt
agrep -0 -c 'CAGAGTTGTGTTTCGGA' *.fastq > count/B3680_Fm0.txt
agrep -0 -c 'GTTCGTGCCACATGTCC' *.fastq > count/B3682_Fm0.txt
agrep -0 -c 'GTGCAAATATTCCCCTG' *.fastq > count/B3683_Fm0.txt
agrep -0 -c 'AGCTCAAAGCGGGCTAT' *.fastq > count/B3685_Fm0.txt
agrep -0 -c 'AACTAAACTCTCGTAGG' *.fastq > count/B3686_Fm0.txt
agrep -0 -c 'CGTCATGTTCGGATGCC' *.fastq > count/B3687_Fm0.txt
agrep -0 -c 'GCGAGGCAATGTTCCCA' *.fastq > count/B3688_Fm0.txt
agrep -0 -c 'GCTGGTGCCAGGATATG' *.fastq > count/B3689_Fm0.txt
agrep -0 -c 'CGACGTCTCGGTTGATG' *.fastq > count/B3691_Fm0.txt
agrep -0 -c 'ATCATCCCTGTTTCGCA' *.fastq > count/B3692_Fm0.txt
agrep -0 -c 'GATCCGGGTGTAATACC' *.fastq > count/B3693_Fm0.txt
agrep -0 -c 'TCGGGGTTAATTCCCCT' *.fastq > count/B3694_Fm0.txt
agrep -0 -c 'GTCCTAGGTCGATGCGA' *.fastq > count/B3695_Fm0.txt
agrep -0 -c 'GTTTCTCCTAATGGCCA' *.fastq > count/B3696_Fm0.txt
agrep -0 -c 'CTGTCGCCCAAATTATA' *.fastq > count/B3697_Fm0.txt
agrep -0 -c 'TAAGTTGGATCCCCCTT' *.fastq > count/B3698_Fm0.txt
agrep -0 -c 'CGATATGCAGGCGGAGT' *.fastq > count/B3699_Fm0.txt
agrep -0 -c 'CAGCGGGGGGACTTATT' *.fastq > count/B3700_Fm0.txt
agrep -0 -c 'AGTGAAAGGTAGTACAC' *.fastq > count/B3701_Fm0.txt
agrep -0 -c 'GAGTAGCTGTGACATCA' *.fastq > count/B3703_Fm0.txt
agrep -0 -c 'CGTCTACTCTTAGCACC' *.fastq > count/B3704_Fm0.txt
agrep -0 -c 'TCGCTACTTGATCCGAC' *.fastq > count/B3705_Fm0.txt
agrep -0 -c 'GGCAAGACACTCGACTC' *.fastq > count/B3706_Fm0.txt
agrep -0 -c 'GGCATAACAGTACGTGC' *.fastq > count/B3707_Fm0.txt
agrep -0 -c 'CAAGAACTGTAGTCGGA' *.fastq > count/B3708_Fm0.txt
agrep -0 -c 'CTGAGGCGAATTCTTCT' *.fastq > count/B3709_Fm0.txt
agrep -0 -c 'GCATTTTGATTCCGCTC' *.fastq > count/B3710_Fm0.txt
agrep -0 -c 'GGTTATCATCTGCATCC' *.fastq > count/B3711_Fm0.txt
agrep -0 -c 'ATATAAGCCCTTGCGCC' *.fastq > count/B3712_Fm0.txt
agrep -0 -c 'AGTCGACACTGCTCTTC' *.fastq > count/B3713_Fm0.txt
agrep -0 -c 'AATTAGCGTCCAGACCA' *.fastq > count/B3714_Fm0.txt
agrep -0 -c 'GGAACCGGCCATAGACT' *.fastq > count/B3715_Fm0.txt
agrep -0 -c 'AGCGGGTGAGTTCGTTC' *.fastq > count/B3716_Fm0.txt
agrep -0 -c 'ATCGCAGATGGGTGACT' *.fastq > count/B3717_Fm0.txt
agrep -0 -c 'GGTACGCTTACTGATGG' *.fastq > count/B3718_Fm0.txt
agrep -0 -c 'TAGGCGAGGTCCGCTTT' *.fastq > count/B3719_Fm0.txt
agrep -0 -c 'GGTGAGATAATCATGGG' *.fastq > count/B3720_Fm0.txt
agrep -0 -c 'CAGGTGGTCCTTCGGAT' *.fastq > count/B3721_Fm0.txt
agrep -0 -c 'AGGCGGGGATTAATGTC' *.fastq > count/B3722_Fm0.txt
agrep -0 -c 'GTACGTCATCCGATCCC' *.fastq > count/B3723_Fm0.txt
agrep -0 -c 'CAGACATTGCTAAAGCG' *.fastq > count/B3724_Fm0.txt
agrep -0 -c 'GACTAAAGAGCCTAAGT' *.fastq > count/B3725_Fm0.txt
agrep -0 -c 'GTGTCATATGCTCGGTA' *.fastq > count/B3726_Fm0.txt
agrep -0 -c 'TCGCACGATCAAAGGAC' *.fastq > count/B3727_Fm0.txt
agrep -0 -c 'CACGGCTACATCCGGAA' *.fastq > count/B3728_Fm0.txt
agrep -0 -c 'GGTTCTTGATAGTACAC' *.fastq > count/B3729_Fm0.txt
agrep -0 -c 'AAGGTCAGTGCAAACGG' *.fastq > count/B3730_Fm0.txt
agrep -0 -c 'CCTCTTTAGACGCTTCA' *.fastq > count/B3732_Fm0.txt
agrep -0 -c 'AGAAAATCTGGTCTTCC' *.fastq > count/B3733_Fm0.txt
agrep -0 -c 'CGAAACGCATTGTTAGA' *.fastq > count/B3734_Fm0.txt
agrep -0 -c 'TGGCTGGGCCAAGTTTC' *.fastq > count/B3735_Fm0.txt
agrep -0 -c 'TGCGGCAACGAATACGA' *.fastq > count/B3736_Fm0.txt
agrep -0 -c 'GTCTGACTGGCGGAATC' *.fastq > count/B3737_Fm0.txt
agrep -0 -c 'ACCGAGCCACGTTAACA' *.fastq > count/B3738_Fm0.txt
agrep -0 -c 'CTGCCACAAAGGATTCT' *.fastq > count/B3739_Fm0.txt
agrep -0 -c 'TTAGCCAGCACAAGTCC' *.fastq > count/B3740_Fm0.txt
agrep -0 -c 'CGATAGCATACTCTAAC' *.fastq > count/B3741_Fm0.txt
agrep -0 -c 'TTGCACGAGCTTGTCCA' *.fastq > count/B3742_Fm0.txt
agrep -0 -c 'GGCGGGAACTTGAAAGG' *.fastq > count/B3744_Fm0.txt
agrep -0 -c 'GGTATATCCATATTGCG' *.fastq > count/B3745_Fm0.txt
agrep -0 -c 'CATAGCGGTAGTCCGAA' *.fastq > count/B3746_Fm0.txt
agrep -0 -c 'GTTTGTCTATACATGCG' *.fastq > count/B3749_Fm0.txt
agrep -0 -c 'TATGGGTTAGTCCAAGT' *.fastq > count/B3750_Fm0.txt
agrep -0 -c 'TTCGTACACGTAATGGC' *.fastq > count/B3751_Fm0.txt
agrep -0 -c 'GCGTCTCGCTCTACTGA' *.fastq > count/B3752_Fm0.txt
agrep -0 -c 'ACCGATTTCGGATGGTT' *.fastq > count/B3753_Fm0.txt
agrep -0 -c 'AGCAGATCACGAACTCA' *.fastq > count/B3754_Fm0.txt
agrep -0 -c 'GGGTGGATACTTCTTAG' *.fastq > count/B3755_Fm0.txt
agrep -0 -c 'AGAGTATCGGCTACCTG' *.fastq > count/B3756_Fm0.txt
agrep -0 -c 'TAACCTATAGCCGGCCT' *.fastq > count/B3757_Fm0.txt
agrep -0 -c 'GCCGGGCAAGGTTTAGT' *.fastq > count/B3758_Fm0.txt
agrep -0 -c 'GCCGAAAATCGATTTCG' *.fastq > count/B3759_Fm0.txt
agrep -0 -c 'GACCCCGTTCTAGCTAC' *.fastq > count/B3760_Fm0.txt
agrep -0 -c 'TTGTCTTCGTTATCCAG' *.fastq > count/B3761_Fm0.txt
agrep -0 -c 'TAGAGGTCAGTAAAAGG' *.fastq > count/B3762_Fm0.txt
agrep -0 -c 'TTACTCCCAGAACGGGC' *.fastq > count/B3763_Fm0.txt
agrep -0 -c 'TAACTACCATAGAGGCC' *.fastq > count/B3764_Fm0.txt
agrep -0 -c 'CATTCTACTTCATCGCT' *.fastq > count/B3765_Fm0.txt
agrep -0 -c 'CGGATTCGGTGGAATCG' *.fastq > count/B3766_Fm0.txt
agrep -0 -c 'GTCTAACTACTGGTGTC' *.fastq > count/B3767_Fm0.txt
agrep -0 -c 'ACAGGTCGGGTATTCTT' *.fastq > count/B3768_Fm0.txt
agrep -0 -c 'TGTCCGTATCTACGCTG' *.fastq > count/B3769_Fm0.txt
agrep -0 -c 'ATTCGCCTCCCAAACAG' *.fastq > count/B3770_Fm0.txt
agrep -0 -c 'CACCCTGCTGGACAATG' *.fastq > count/B3771_Fm0.txt
agrep -0 -c 'CGGAGTATTGGGAGTCT' *.fastq > count/B3772_Fm0.txt
agrep -0 -c 'CAAACGTACGGGTTCCC' *.fastq > count/B3773_Fm0.txt
agrep -0 -c 'ATTCTGTTGTCATCGAC' *.fastq > count/B3774_Fm0.txt
agrep -0 -c 'CCTTGGCTTATGCGTTT' *.fastq > count/B3775_Fm0.txt
agrep -0 -c 'CGAATGCTCGACGGTCT' *.fastq > count/B3776_Fm0.txt
agrep -0 -c 'ATATCCGTACAGCTGCG' *.fastq > count/B3777_Fm0.txt
agrep -0 -c 'TATAGGGCCAGAGACGA' *.fastq > count/B3778_Fm0.txt
agrep -0 -c 'CAGTATTGCTCCTCGCC' *.fastq > count/B3779_Fm0.txt
agrep -0 -c 'CGCTAGTGACTTCTTCT' *.fastq > count/B3780_Fm0.txt
agrep -0 -c 'TTCTCTGAGGGATAGAA' *.fastq > count/B3781_Fm0.txt
agrep -0 -c 'ATATGGCATGTCCGATG' *.fastq > count/B3782_Fm0.txt
agrep -0 -c 'TCGATACCATGATGTGC' *.fastq > count/B3784_Fm0.txt
agrep -0 -c 'GTACATACCTACGGCCA' *.fastq > count/B3785_Fm0.txt
agrep -0 -c 'GGGGACTAATACTCAGT' *.fastq > count/B3786_Fm0.txt
agrep -0 -c 'CTGGTTTTGGGTCACGG' *.fastq > count/B3788_Fm0.txt
agrep -0 -c 'GGGACTGACGTACCTCA' *.fastq > count/B3789_Fm0.txt
agrep -0 -c 'CCTAACACCCGGGGAAT' *.fastq > count/B3790_Fm0.txt
agrep -0 -c 'GTTTCGCGCACGACTAC' *.fastq > count/B3791_Fm0.txt
agrep -0 -c 'TAGTCAACCTATCTTGC' *.fastq > count/B3792_Fm0.txt
agrep -0 -c 'TAGCATCATGCCTGCCG' *.fastq > count/B3794_Fm0.txt
agrep -0 -c 'CGGTTTCAGTATCACTT' *.fastq > count/B3795_Fm0.txt
agrep -0 -c 'AGCGCGATCGACATAGC' *.fastq > count/B3797_Fm0.txt
agrep -0 -c 'GTAAATTGCTTACAGGC' *.fastq > count/B3798_Fm0.txt
agrep -0 -c 'CATATTCCCACAAGAGT' *.fastq > count/B3799_Fm0.txt
agrep -0 -c 'GGTAAGCCGCATGCACT' *.fastq > count/B3800_Fm0.txt
agrep -0 -c 'CCGGTGCACTAGTAGAA' *.fastq > count/B3801_Fm0.txt
agrep -0 -c 'TATGAGGGCCAGTACGT' *.fastq > count/B3802_Fm0.txt
agrep -0 -c 'AGACCGAACTTACAGCG' *.fastq > count/B3803_Fm0.txt
agrep -0 -c 'CCGGACTTCTACTCCCA' *.fastq > count/B3804_Fm0.txt
agrep -0 -c 'TAACAACGAGTGGACAA' *.fastq > count/B3805_Fm0.txt
agrep -0 -c 'GTAAGCTTCCACCTACT' *.fastq > count/B3806_Fm0.txt
agrep -0 -c 'GTGCCCTCGCATTAATG' *.fastq > count/B3808_Fm0.txt
agrep -0 -c 'GGGACCGCGTCTATATT' *.fastq > count/B3810_Fm0.txt
agrep -0 -c 'AATTCATCAGCCCATTG' *.fastq > count/B3811_Fm0.txt
agrep -0 -c 'TCGGCATTGAAGACATC' *.fastq > count/B3813_Fm0.txt
agrep -0 -c 'TAATCCAAGGACCCCAT' *.fastq > count/B3814_Fm0.txt
agrep -0 -c 'CGTTTGAAATTCTTGGG' *.fastq > count/B3815_Fm0.txt
agrep -0 -c 'TGCGAGTTACCTGAACT' *.fastq > count/B3816_Fm0.txt
agrep -0 -c 'AGCCTCCATATTGTATG' *.fastq > count/B3817_Fm0.txt
agrep -0 -c 'TTCTAATGAGCGGCGAC' *.fastq > count/B3818_Fm0.txt
agrep -0 -c 'GACAAACGACGCTATGT' *.fastq > count/B3819_Fm0.txt
agrep -0 -c 'AAGGGGTTCCCTGAATA' *.fastq > count/B3820_Fm0.txt
agrep -0 -c 'ACGGACCACGGTTGCAT' *.fastq > count/B3821_Fm0.txt
agrep -0 -c 'GCAAGGGTTATCACTAT' *.fastq > count/B3825_Fm0.txt
agrep -0 -c 'GACGAGCTCAACACACC' *.fastq > count/B3826_Fm0.txt
agrep -0 -c 'GTGGTAAGTCCGGTAGG' *.fastq > count/B3827_Fm0.txt
agrep -0 -c 'CACTTCTTCGAGGTGAT' *.fastq > count/B3828_Fm0.txt
agrep -0 -c 'GTGAGACGCATTCCAGA' *.fastq > count/B3829_Fm0.txt
agrep -0 -c 'GGGCTCAGACCTTTTGT' *.fastq > count/B3830_Fm0.txt
agrep -0 -c 'CGCTCGTTATGTTGTAT' *.fastq > count/B3831_Fm0.txt
agrep -0 -c 'TCAGTGTCTTACAGCGA' *.fastq > count/B3832_Fm0.txt
agrep -0 -c 'CAGAAGCTTGTCGCGAT' *.fastq > count/B3833_Fm0.txt
agrep -0 -c 'CCTCACCGGTTCACATG' *.fastq > count/B3834_Fm0.txt
agrep -0 -c 'GGTCTTCAGATCCACCG' *.fastq > count/B3835_Fm0.txt
agrep -0 -c 'AGCTGCTGGATCTAGCT' *.fastq > count/B3836_Fm0.txt
agrep -0 -c 'ACAACTTTACACAGGAG' *.fastq > count/B3837_Fm0.txt
agrep -0 -c 'TTCGCGTCTTAGCAAGC' *.fastq > count/B3838_Fm0.txt
agrep -0 -c 'AACAGAGCTGCGGAAGC' *.fastq > count/B3839_Fm0.txt
agrep -0 -c 'TACACGATGATGTGCGC' *.fastq > count/B3840_Fm0.txt
agrep -0 -c 'TCGACTACAAAGGGTCA' *.fastq > count/B3841_Fm0.txt
agrep -0 -c 'ATGAAGCAGAAATGGTC' *.fastq > count/B3842_Fm0.txt
agrep -0 -c 'AACCTAGGCGTCCAGAT' *.fastq > count/B3843_Fm0.txt
agrep -0 -c 'GAGGCCCCCAGAGATTT' *.fastq > count/B3845_Fm0.txt
agrep -0 -c 'ACGTAACCGGTTCAGAT' *.fastq > count/B3846_Fm0.txt
agrep -0 -c 'CATTATGCTCTGCACAG' *.fastq > count/B3848_Fm0.txt
agrep -0 -c 'AATAGGTGCGGCGAATA' *.fastq > count/B3849_Fm0.txt
agrep -0 -c 'CTGTGAATGTTCCTCGT' *.fastq > count/B3850_Fm0.txt
agrep -0 -c 'ACGGTACCGGGTTGTTG' *.fastq > count/B3851_Fm0.txt
agrep -0 -c 'TGGCAAAGACGAGGAAC' *.fastq > count/B3852_Fm0.txt
agrep -0 -c 'CTTCAATTTGAGCCTGG' *.fastq > count/B3853_Fm0.txt
agrep -0 -c 'GGGAGGCTTACCGTATA' *.fastq > count/B3854_Fm0.txt
agrep -0 -c 'GGTACCCGGATCGATGT' *.fastq > count/B3855_Fm0.txt
agrep -0 -c 'CTCTAGTCCGAGTATGT' *.fastq > count/B3858_Fm0.txt
agrep -0 -c 'CGGTGCGAATTACCAAG' *.fastq > count/B3859_Fm0.txt
agrep -0 -c 'TGTCGAACACGCAGCTG' *.fastq > count/B3860_Fm0.txt
agrep -0 -c 'AGACATACGGAAGGGGC' *.fastq > count/B3862_Fm0.txt
agrep -0 -c 'TGATGCCGAGAGGGTAT' *.fastq > count/B3865_Fm0.txt
agrep -0 -c 'GTAGCTGTTCTAGGATT' *.fastq > count/B3866_Fm0.txt
agrep -0 -c 'GTAGGAGCTGTCTTAAA' *.fastq > count/B3867_Fm0.txt
agrep -0 -c 'GATCACATCCCAACTGT' *.fastq > count/B3868_Fm0.txt
agrep -0 -c 'GGGAAGCTCTCTGCGAA' *.fastq > count/B3869_Fm0.txt
agrep -0 -c 'ATACAGCTGTGCGCAAT' *.fastq > count/B3870_Fm0.txt
agrep -0 -c 'GTCTAAGCCTTATATCG' *.fastq > count/B3871_Fm0.txt
agrep -0 -c 'GGACCGTAATTCGGACC' *.fastq > count/B3872_Fm0.txt
agrep -0 -c 'GCGTATACCTTAACACC' *.fastq > count/B3873_Fm0.txt
agrep -0 -c 'TTAACATGACTTCTCGG' *.fastq > count/B3874_Fm0.txt
agrep -0 -c 'CCGGGAGCAAAAGGAAT' *.fastq > count/B3875_Fm0.txt
agrep -0 -c 'ACTCACAAGGACTGACA' *.fastq > count/B3876_Fm0.txt
agrep -0 -c 'TAGGTAAGCCGGGTAAA' *.fastq > count/B3877_Fm0.txt
agrep -0 -c 'TTAGGGCGCATTTTTCA' *.fastq > count/B3878_Fm0.txt
agrep -0 -c 'GGCACATCCCTACTTGG' *.fastq > count/B3879_Fm0.txt
agrep -0 -c 'CGATCCCCTCGTTAGGA' *.fastq > count/B3880_Fm0.txt
agrep -0 -c 'TCTGCAGCGTGAGTCTA' *.fastq > count/B3882_Fm0.txt
agrep -0 -c 'CCGTGGTTTTAGTCCCA' *.fastq > count/B3883_Fm0.txt
agrep -0 -c 'CTCTTCAAATGGCGCGA' *.fastq > count/B3884_Fm0.txt
agrep -0 -c 'TCTAGCCCAGACAGTTC' *.fastq > count/B3885_Fm0.txt
agrep -0 -c 'CAGGAGAGTCTTACTCC' *.fastq > count/B3886_Fm0.txt
agrep -0 -c 'TGACGTCCCGGGCTAAT' *.fastq > count/B3888_Fm0.txt
agrep -0 -c 'TCTAACGTGAGTCGCTA' *.fastq > count/B3889_Fm0.txt
agrep -0 -c 'AACTTCCTCCGTGGTAC' *.fastq > count/B3890_Fm0.txt
agrep -0 -c 'ATATACAGAGCGCGCGT' *.fastq > count/B3891_Fm0.txt
agrep -0 -c 'TCGGGGGGTTCAGAATG' *.fastq > count/B3892_Fm0.txt
agrep -0 -c 'GCAGTATGTGTGGGCAC' *.fastq > count/B3894_Fm0.txt
agrep -0 -c 'AATATAGCGGGAGAATC' *.fastq > count/B3895_Fm0.txt
agrep -0 -c 'CTGGCCTCCCATAAACT' *.fastq > count/B3897_Fm0.txt
agrep -0 -c 'GCCGGTATACTCATATC' *.fastq > count/B3898_Fm0.txt
agrep -0 -c 'GCGTTTCAGCCCGATGT' *.fastq > count/B3899_Fm0.txt
agrep -0 -c 'CTTACTGGGCCATATAG' *.fastq > count/B3900_Fm0.txt
agrep -0 -c 'GCGCATAAACGTTCATA' *.fastq > count/B3901_Fm0.txt
agrep -0 -c 'CTTCGACTCAGTTTCTA' *.fastq > count/B3903_Fm0.txt
agrep -0 -c 'TTCCACTGGCTTGGGCA' *.fastq > count/B3905_Fm0.txt
agrep -0 -c 'GTATCTCTCGAGGCAAT' *.fastq > count/B3906_Fm0.txt
agrep -0 -c 'GAGCAAGTTCGCATATC' *.fastq > count/B3907_Fm0.txt
agrep -0 -c 'CTCTGCCATATGAGGCG' *.fastq > count/B3908_Fm0.txt
agrep -0 -c 'CAGGCTCACTCTCATTT' *.fastq > count/B3909_Fm0.txt
agrep -0 -c 'GTAATAGGAAACCGCGA' *.fastq > count/B3910_Fm0.txt
agrep -0 -c 'ACGCAGAATTAACCGCG' *.fastq > count/B3911_Fm0.txt
agrep -0 -c 'CAGCGCCCAGAATAGCT' *.fastq > count/B3913_Fm0.txt
agrep -0 -c 'TCAGTGGACTTACCTGC' *.fastq > count/B3914_Fm0.txt
agrep -0 -c 'AACGGGCGTAATTTGAC' *.fastq > count/B3915_Fm0.txt
agrep -0 -c 'CCGATAAAGACAAAGCC' *.fastq > count/B3916_Fm0.txt
agrep -0 -c 'TCATTGAGGTCGCCTGA' *.fastq > count/B3917_Fm0.txt
agrep -0 -c 'CTCATGTAGGCACAGTC' *.fastq > count/B3918_Fm0.txt
agrep -0 -c 'TCGGAGTTCTACTGGGC' *.fastq > count/B3919_Fm0.txt
agrep -0 -c 'CCTGCGTAAACGCTAAC' *.fastq > count/B3920_Fm0.txt
agrep -0 -c 'ACCCGCTTAAGAGTGGT' *.fastq > count/B3921_Fm0.txt
agrep -0 -c 'CAAATTTGAACCGGGTG' *.fastq > count/B3922_Fm0.txt
agrep -0 -c 'ATAGCGACAAGCGAGGA' *.fastq > count/B3923_Fm0.txt
agrep -0 -c 'CGCCCGATCCTGCATTA' *.fastq > count/B3924_Fm0.txt
agrep -0 -c 'GAGTACTGGAGTACGGA' *.fastq > count/B3925_Fm0.txt
agrep -0 -c 'ATGAAGGGTGGTCCGTA' *.fastq > count/B3926_Fm0.txt
agrep -0 -c 'TGTGGCAATAGATGTTC' *.fastq > count/B3927_Fm0.txt
agrep -0 -c 'CCAAAGGGTTATGACCG' *.fastq > count/B3928_Fm0.txt
agrep -0 -c 'TGTAGGGTAGTCGCCCA' *.fastq > count/B3929_Fm0.txt
agrep -0 -c 'AAGGGGGCCTGAAAAGG' *.fastq > count/B3930_Fm0.txt
agrep -0 -c 'ACTTATTTTACCGCTCC' *.fastq > count/B3931_Fm0.txt
agrep -0 -c 'GCTTAAACTCGATTCCG' *.fastq > count/B3932_Fm0.txt
agrep -0 -c 'TCGCTCCAAGAAAGGTA' *.fastq > count/B3933_Fm0.txt
agrep -0 -c 'ACAGGGGCTTACTACCC' *.fastq > count/B3935_Fm0.txt
agrep -0 -c 'GCGTAAAGTTGGACGAT' *.fastq > count/B3936_Fm0.txt
agrep -0 -c 'GACCAGTTCGTCCGATT' *.fastq > count/B3937_Fm0.txt
agrep -0 -c 'ATTTTCGGAGCGTCGCG' *.fastq > count/B3938_Fm0.txt
agrep -0 -c 'GGTACGACAGAGGATTA' *.fastq > count/B3940_Fm0.txt
agrep -0 -c 'GTTTGGGCAGGATCGAG' *.fastq > count/B3941_Fm0.txt
agrep -0 -c 'TCAAGCTTGCTGCCTCG' *.fastq > count/B3942_Fm0.txt
agrep -0 -c 'GTTAAATTTGCACTGGC' *.fastq > count/B3943_Fm0.txt
agrep -0 -c 'TGTAAACCTCGGGAGGA' *.fastq > count/B3944_Fm0.txt
agrep -0 -c 'CGAAACATGTACGTGCC' *.fastq > count/B3945_Fm0.txt
agrep -0 -c 'TCATCGCAAAAATAGGG' *.fastq > count/B3946_Fm0.txt
agrep -0 -c 'GAGGGTTGTCTTGCGCA' *.fastq > count/B3947_Fm0.txt
agrep -0 -c 'ACCGCTAGCGTGTACAT' *.fastq > count/B3948_Fm0.txt
agrep -0 -c 'TTAGGCGTGCATGCGAA' *.fastq > count/B3949_Fm0.txt
agrep -0 -c 'CTGCTATCACTATGAGG' *.fastq > count/B3950_Fm0.txt
agrep -0 -c 'TTGCTGGATACGGTCTC' *.fastq > count/B3951_Fm0.txt
agrep -0 -c 'TCTGGACGTACAGAATA' *.fastq > count/B3952_Fm0.txt
agrep -0 -c 'CTAGGACCACTACAGTA' *.fastq > count/B3953_Fm0.txt
agrep -0 -c 'TCTTCGAAGGCACCGAT' *.fastq > count/B3954_Fm0.txt
agrep -0 -c 'GTATGGCGTCAAGTTAT' *.fastq > count/B3955_Fm0.txt
agrep -0 -c 'GGGGCAATGAATTAAAC' *.fastq > count/B3956_Fm0.txt
agrep -0 -c 'GCAACTGCTTACTGTGC' *.fastq > count/B3957_Fm0.txt
agrep -0 -c 'GTCCACATGTACACGAA' *.fastq > count/B3958_Fm0.txt
agrep -0 -c 'ATGCGTGTCCAGATGCT' *.fastq > count/B3962_Fm0.txt
agrep -0 -c 'AAGAAGTGCGGCTCATC' *.fastq > count/B3963_Fm0.txt
agrep -0 -c 'GGGTGAGCAAACGGTGT' *.fastq > count/B3964_Fm0.txt
agrep -0 -c 'GATGGACCATGCACGTC' *.fastq > count/B3965_Fm0.txt
agrep -0 -c 'TACGCTACGATCCTCAG' *.fastq > count/B3969_Fm0.txt
agrep -0 -c 'GTCAGCTCAAGAAGAAT' *.fastq > count/B3970_Fm0.txt
agrep -0 -c 'CGACGATTTAACCGCTC' *.fastq > count/B3972_Fm0.txt
agrep -0 -c 'GACGGCTAGTATGGATA' *.fastq > count/B3974_Fm0.txt
agrep -0 -c 'AATAACGAAATGCCGGC' *.fastq > count/B3975_Fm0.txt
agrep -0 -c 'ATTCGGGTAAACCTCAG' *.fastq > count/B3976_Fm0.txt
agrep -0 -c 'CCAGCGCCAGACTATTG' *.fastq > count/B3977_Fm0.txt
agrep -0 -c 'CGCAATAAGACATACGT' *.fastq > count/B3979_Fm0.txt
agrep -0 -c 'CATAAGGAACGGCTCAG' *.fastq > count/B3981_Fm0.txt
agrep -0 -c 'GTCTGGCGTATAACTGT' *.fastq > count/B3983_Fm0.txt
agrep -0 -c 'ACATGCTAGTTATGCGG' *.fastq > count/B3985_Fm0.txt
agrep -0 -c 'GGGTTTCCGCTGCAAAC' *.fastq > count/B3986_Fm0.txt
agrep -0 -c 'GTACAAGTCACCAGCCA' *.fastq > count/B3987_Fm0.txt
agrep -0 -c 'GTTCAACCGGGGAGATT' *.fastq > count/B3988_Fm0.txt
agrep -0 -c 'CGGGGATTTGCACTTTC' *.fastq > count/B3989_Fm0.txt
agrep -0 -c 'TCGCATAACCTGGGGTT' *.fastq > count/B3991_Fm0.txt
agrep -0 -c 'ATGAACACACACGCCAT' *.fastq > count/B3992_Fm0.txt
agrep -0 -c 'GCGCAGGTCAAACTCTT' *.fastq > count/B3993_Fm0.txt
agrep -0 -c 'CTTATGAGGACGATAGC' *.fastq > count/B3994_Fm0.txt
agrep -0 -c 'GCACTTGCATACATTGG' *.fastq > count/B3995_Fm0.txt
agrep -0 -c 'TAGCTTGGAGTGCCCCT' *.fastq > count/B3996_Fm0.txt
agrep -0 -c 'ACAAGGAGCATAAGCTG' *.fastq > count/B3997_Fm0.txt
agrep -0 -c 'ATGACTGAGTCACCCTA' *.fastq > count/B3998_Fm0.txt
agrep -0 -c 'TGACTTATGCTCGTGAG' *.fastq > count/B3999_Fm0.txt
agrep -0 -c 'CAATCGCAACAAACATC' *.fastq > count/B4000_Fm0.txt
agrep -0 -c 'TGTTGCCGGAGTAAATT' *.fastq > count/B4001_Fm0.txt
agrep -0 -c 'TACTTGGCGAAAGTGAT' *.fastq > count/B4002_Fm0.txt
agrep -0 -c 'GTGGCCCTTAAGAGGAA' *.fastq > count/B4003_Fm0.txt
agrep -0 -c 'ATGGACCAGTATCCCAC' *.fastq > count/B4004_Fm0.txt
agrep -0 -c 'GCGTGCTAGCGGATTGT' *.fastq > count/B4006_Fm0.txt
agrep -0 -c 'GGTACGCTGTAGACCTG' *.fastq > count/B4007_Fm0.txt
agrep -0 -c 'CCATAGGCTGCCCAATT' *.fastq > count/B4008_Fm0.txt
agrep -0 -c 'TCTATCGATTGCTGCCA' *.fastq > count/B4009_Fm0.txt
agrep -0 -c 'GGTCCAATCATTGGCAA' *.fastq > count/B4010_Fm0.txt
agrep -0 -c 'CGTTCGTTCAAGCAAGT' *.fastq > count/B4011_Fm0.txt
agrep -0 -c 'ATGGTTGAACGGAATTC' *.fastq > count/B4013_Fm0.txt
agrep -0 -c 'AGACTACACTGCAAACT' *.fastq > count/B4014_Fm0.txt
agrep -0 -c 'GTACACCCCAACACAAC' *.fastq > count/B4016_Fm0.txt
agrep -0 -c 'ACTGCAGCGTCTAATTG' *.fastq > count/B4017_Fm0.txt
agrep -0 -c 'CAGATTGTGGATCCCGG' *.fastq > count/B4018_Fm0.txt
agrep -0 -c 'GGGCAACCAACTGTTGA' *.fastq > count/B4019_Fm0.txt
agrep -0 -c 'TATATGTTCGCGGGTGG' *.fastq > count/B4020_Fm0.txt
agrep -0 -c 'TGAGTTGCAGGATCGCG' *.fastq > count/B4022_Fm0.txt
agrep -0 -c 'CCTTGACACGACGTTCC' *.fastq > count/B4023_Fm0.txt
agrep -0 -c 'GGGACATTACCTGTTGG' *.fastq > count/B4024_Fm0.txt
agrep -0 -c 'GTTAGATTGGCGTAAGG' *.fastq > count/B4025_Fm0.txt
agrep -0 -c 'GTTCTACAACCTTCGAA' *.fastq > count/B4027_Fm0.txt
agrep -0 -c 'ACCATCTGCAAGCTGCG' *.fastq > count/B4028_Fm0.txt
agrep -0 -c 'GCCGCATGGTAAATAGT' *.fastq > count/B4029_Fm0.txt
agrep -0 -c 'TGTAGGCGATACCCTTT' *.fastq > count/B4030_Fm0.txt
agrep -0 -c 'AGTAAAACCAAAACCGC' *.fastq > count/B4031_Fm0.txt
agrep -0 -c 'GTCGAGATTCCTGCAGA' *.fastq > count/B4032_Fm0.txt
agrep -0 -c 'TTGAAGGTACAGCAGAC' *.fastq > count/B4034_Fm0.txt
agrep -0 -c 'CCGATCATCGCCTATTC' *.fastq > count/B4035_Fm0.txt
agrep -0 -c 'ATTGGCACAGCCCTTCC' *.fastq > count/B4036_Fm0.txt
agrep -0 -c 'AACGCAATGGTCTAGCC' *.fastq > count/B4037_Fm0.txt
agrep -0 -c 'AATTGTGACTAGAGGAC' *.fastq > count/B4039_Fm0.txt
agrep -0 -c 'CCTTAACCACACCGAAA' *.fastq > count/B4040_Fm0.txt
agrep -0 -c 'ATTATGATGCGGGGGCC' *.fastq > count/B4041_Fm0.txt
agrep -0 -c 'TTGCGCTTGGTGAGCAC' *.fastq > count/B4042_Fm0.txt
agrep -0 -c 'GTGTTCCTTGCGTTGGT' *.fastq > count/B4043_Fm0.txt
agrep -0 -c 'TATCCAGCTCAAGATCT' *.fastq > count/B4046_Fm0.txt
agrep -0 -c 'TCGAACGTCCAGTAGGG' *.fastq > count/B4047_Fm0.txt
agrep -0 -c 'ACTCTTTCGTGGTACTT' *.fastq > count/B4048_Fm0.txt
agrep -0 -c 'TCGGTCGACAATCGCGA' *.fastq > count/B4049_Fm0.txt
agrep -0 -c 'ATCGCAGTGGGTCCTAA' *.fastq > count/B4051_Fm0.txt
agrep -0 -c 'TCTCTTGACCTGCGAGA' *.fastq > count/B4052_Fm0.txt
agrep -0 -c 'GGACCCCAGACATCAAT' *.fastq > count/B4053_Fm0.txt
agrep -0 -c 'CGCTAAATGTTCGAGAA' *.fastq > count/B4054_Fm0.txt
agrep -0 -c 'CATATGTCAGTGAGCCA' *.fastq > count/B4055_Fm0.txt
agrep -0 -c 'GTTCGCACTTACTTCCA' *.fastq > count/B4056_Fm0.txt
agrep -0 -c 'CCAATTGATTGTACCGT' *.fastq > count/B4057_Fm0.txt
agrep -0 -c 'CCAATGGGTCCCTTCGA' *.fastq > count/B4058_Fm0.txt
agrep -0 -c 'ATAGGTGACATCCGCCC' *.fastq > count/B4059_Fm0.txt
agrep -0 -c 'GTTGAACGGTTCTGAAT' *.fastq > count/B4060_Fm0.txt
agrep -0 -c 'AAGTCCATGCTCCCAAG' *.fastq > count/B4061_Fm0.txt
agrep -0 -c 'CACCAGTTGATCTCCCC' *.fastq > count/B4063_Fm0.txt
agrep -0 -c 'GGCCACAATGAGTAATC' *.fastq > count/B4066_Fm0.txt
agrep -0 -c 'ACTCAGAAACTAAGGAG' *.fastq > count/B4067_Fm0.txt
agrep -0 -c 'TGAAATGACACCCCAGC' *.fastq > count/B4068_Fm0.txt
agrep -0 -c 'CAGTGCCGAACCAATGA' *.fastq > count/B4069_Fm0.txt
agrep -0 -c 'TACCCATGTATGCCTCC' *.fastq > count/B4071_Fm0.txt
agrep -0 -c 'GCACAGAATAGAAGGGA' *.fastq > count/B4072_Fm0.txt
agrep -0 -c 'TGCCGTCGAATCATCAA' *.fastq > count/B4074_Fm0.txt
agrep -0 -c 'TGCAAAGTACGTGAAGA' *.fastq > count/B4075_Fm0.txt
agrep -0 -c 'CCAACCTTTGATTGTGG' *.fastq > count/B4076_Fm0.txt
agrep -0 -c 'AACCTTGCTCCTACTTG' *.fastq > count/B4077_Fm0.txt
agrep -0 -c 'CATGGTGGCGTTCTGTT' *.fastq > count/B4078_Fm0.txt
agrep -0 -c 'CCGCGACTTTCTACCAG' *.fastq > count/B4080_Fm0.txt
agrep -0 -c 'AATGCTCCCCAAATCGT' *.fastq > count/B4081_Fm0.txt
agrep -0 -c 'CACCTTGTTTACCCAGA' *.fastq > count/B4082_Fm0.txt
agrep -0 -c 'AGCCTAATGGTAAACCA' *.fastq > count/B4083_Fm0.txt
agrep -0 -c 'GACATATTTCGGTGGCC' *.fastq > count/B4084_Fm0.txt
agrep -0 -c 'GAGCCACCTAATGGGAA' *.fastq > count/B4085_Fm0.txt
agrep -0 -c 'AGACAGTTCTGACCACT' *.fastq > count/B4086_Fm0.txt
agrep -0 -c 'GCACTTAAGGCTGACCA' *.fastq > count/B4088_Fm0.txt
agrep -0 -c 'TTACAACTTACCTGCCA' *.fastq > count/B4089_Fm0.txt
agrep -0 -c 'GCGAGCCATCTTATCCC' *.fastq > count/B4090_Fm0.txt
agrep -0 -c 'TTGCAAAAATACCGCGG' *.fastq > count/B4091_Fm0.txt
agrep -0 -c 'TTGCTCGCGTTTAATGG' *.fastq > count/B4092_Fm0.txt
agrep -0 -c 'CCGTTCGCTCTAAGTGA' *.fastq > count/B4093_Fm0.txt
agrep -0 -c 'TGCAGCCTGACTCGAAA' *.fastq > count/B4094_Fm0.txt
agrep -0 -c 'GTGTTCACTCCACATAC' *.fastq > count/B4095_Fm0.txt
agrep -0 -c 'GTAAGATGACCTAGCTG' *.fastq > count/B4096_Fm0.txt
agrep -0 -c 'AGAAAATCGGTGCAAGC' *.fastq > count/B4097_Fm0.txt
agrep -0 -c 'GACCTTTATCGGGTATT' *.fastq > count/B4098_Fm0.txt
agrep -0 -c 'GTCTAAAGACCATGAGT' *.fastq > count/B4099_Fm0.txt
agrep -0 -c 'CCGAGCATACGCTTGCT' *.fastq > count/B4100_Fm0.txt
agrep -0 -c 'ATACAATCCAGCGCTTC' *.fastq > count/B4102_Fm0.txt
agrep -0 -c 'GGACACTCAGACAGCTC' *.fastq > count/B4103_Fm0.txt
agrep -0 -c 'TGTAAGGGGTTAAGTTG' *.fastq > count/B4104_Fm0.txt
agrep -0 -c 'AGATCACTCCGGAGTTT' *.fastq > count/B4105_Fm0.txt
agrep -0 -c 'TGACCCCTCTTATAGAC' *.fastq > count/B4106_Fm0.txt
agrep -0 -c 'GTCCACGAGTGGATTCC' *.fastq > count/B4107_Fm0.txt
agrep -0 -c 'AGTTCCGGACGAACTGT' *.fastq > count/B4108_Fm0.txt
agrep -0 -c 'AACGCACTTATTCGTAG' *.fastq > count/B4109_Fm0.txt
agrep -0 -c 'CTATCTCCGTACTGCGT' *.fastq > count/B4110_Fm0.txt
agrep -0 -c 'GCTAGTTCCTTCTCACC' *.fastq > count/B4111_Fm0.txt
agrep -0 -c 'GCAAGCAGCTCATTTCA' *.fastq > count/B4112_Fm0.txt
agrep -0 -c 'CGATTAACCCAAGAGAG' *.fastq > count/B4114_Fm0.txt
agrep -0 -c 'TACGTATCTCGCACAGT' *.fastq > count/B4115_Fm0.txt
agrep -0 -c 'GTATAGGATCTACATGG' *.fastq > count/B4117_Fm0.txt
agrep -0 -c 'GTCACGGACCTCTTTAC' *.fastq > count/B4118_Fm0.txt
agrep -0 -c 'GCTGTGAGGTGGAAACG' *.fastq > count/B4119_Fm0.txt
agrep -0 -c 'CGACCACCTGAATCCGA' *.fastq > count/B4120_Fm0.txt
agrep -0 -c 'ACGCGCTGTTCTCTTTC' *.fastq > count/B4121_Fm0.txt
agrep -0 -c 'GCGTTCATAGCTCAGAA' *.fastq > count/B4122_Fm0.txt
agrep -0 -c 'GTAGGTCAGAGTAGTCA' *.fastq > count/B4123_Fm0.txt
agrep -0 -c 'GTAGGTGTAACGACTCT' *.fastq > count/B4124_Fm0.txt
agrep -0 -c 'CCGAACAGTAGACAGAA' *.fastq > count/B4125_Fm0.txt
agrep -0 -c 'ACCGAAATTAGTAGGTC' *.fastq > count/B4126_Fm0.txt
agrep -0 -c 'ATACCACAGACGAGAGG' *.fastq > count/B4127_Fm0.txt
agrep -0 -c 'CATTGCGTCTACCTGCT' *.fastq > count/B4128_Fm0.txt
agrep -0 -c 'GCATTCGTCCCTCGTGA' *.fastq > count/B4129_Fm0.txt
agrep -0 -c 'CTCCCATACAGGTGGTG' *.fastq > count/B4130_Fm0.txt
agrep -0 -c 'TGACCCTCGCACCGATT' *.fastq > count/B4131_Fm0.txt
agrep -0 -c 'TCATGTGTCTATATCCG' *.fastq > count/B4132_Fm0.txt
agrep -0 -c 'AAGACCGATCCCCAATC' *.fastq > count/B4133_Fm0.txt
agrep -0 -c 'GACGTGTATTGGACATT' *.fastq > count/B4134_Fm0.txt
agrep -0 -c 'GGTTGTAGTCTGGGCTT' *.fastq > count/B4135_Fm0.txt
agrep -0 -c 'TAAACCGTTCACACGCC' *.fastq > count/B4137_Fm0.txt
agrep -0 -c 'GTGAAGGTCCACTCTCA' *.fastq > count/B4139_Fm0.txt
agrep -0 -c 'GCCCAAGCTAGGTTTTT' *.fastq > count/B4140_Fm0.txt
agrep -0 -c 'GGATGAGCATACAGGGC' *.fastq > count/B4141_Fm0.txt
agrep -0 -c 'GCTCTACAAGATCACAA' *.fastq > count/B4142_Fm0.txt
agrep -0 -c 'TTGGATTACAGCTCCAG' *.fastq > count/B4144_Fm0.txt
agrep -0 -c 'TGTTCCGCAGCTGACTA' *.fastq > count/B4145_Fm0.txt
agrep -0 -c 'ATAGAGTACAGTCTGTG' *.fastq > count/B4146_Fm0.txt
agrep -0 -c 'CGGTTGCATAGTGTCTG' *.fastq > count/B4147_Fm0.txt
agrep -0 -c 'TTCACTCATAGCCCCAC' *.fastq > count/B4148_Fm0.txt
agrep -0 -c 'TTAATCACCTGGTAGTG' *.fastq > count/B4149_Fm0.txt
agrep -0 -c 'CATGGCGGGATGTTTAG' *.fastq > count/B4150_Fm0.txt
agrep -0 -c 'AGCAGGAGTTACCGGGT' *.fastq > count/B4151_Fm0.txt
agrep -0 -c 'ACTCGTCAGGCTTAGGT' *.fastq > count/B4152_Fm0.txt
agrep -0 -c 'CCACCGTCAACGCATCA' *.fastq > count/B4153_Fm0.txt
agrep -0 -c 'AGTCAGGTTAATTAGCC' *.fastq > count/B4154_Fm0.txt
agrep -0 -c 'GCGGTTCCTCATATTCA' *.fastq > count/B4155_Fm0.txt
agrep -0 -c 'GGTGATCATGGCTGTTT' *.fastq > count/B4156_Fm0.txt
agrep -0 -c 'ATTTACCCGCACCGCCA' *.fastq > count/B4157_Fm0.txt
agrep -0 -c 'TATTTGGAGTCCGCCAT' *.fastq > count/B4158_Fm0.txt
agrep -0 -c 'GGCAACGCCATATCAAA' *.fastq > count/B4159_Fm0.txt
agrep -0 -c 'TGCCATTGATCTCACAT' *.fastq > count/B4160_Fm0.txt
agrep -0 -c 'TAGAACTTAACGACGGG' *.fastq > count/B4164_Fm0.txt
agrep -0 -c 'CCTCCCTTGGTTATACC' *.fastq > count/B4165_Fm0.txt
agrep -0 -c 'ATTAGCACTATCTGCCT' *.fastq > count/B4166_Fm0.txt
agrep -0 -c 'CGGCTATTAGGTCAAGC' *.fastq > count/B4167_Fm0.txt
agrep -0 -c 'GGTATTTCCTTACATGC' *.fastq > count/B4168_Fm0.txt
agrep -0 -c 'AACACTATTGCTCCCTA' *.fastq > count/B4169_Fm0.txt
agrep -0 -c 'GGGAGACGTGAAGTTTG' *.fastq > count/B4170_Fm0.txt
agrep -0 -c 'CGCAACTCTGGAACGAT' *.fastq > count/B4171_Fm0.txt
agrep -0 -c 'ATCCATTAGGAGCACTT' *.fastq > count/B4172_Fm0.txt
agrep -0 -c 'AGTATGGGACATTACCA' *.fastq > count/B4173_Fm0.txt
agrep -0 -c 'GTTGTGGATCCATACAA' *.fastq > count/B4174_Fm0.txt
agrep -0 -c 'CCACTTCGGCATTAAGG' *.fastq > count/B4175_Fm0.txt
agrep -0 -c 'GCGAAGTGATCGAAGAG' *.fastq > count/B4176_Fm0.txt
agrep -0 -c 'GTCGAGAACTGATCAGT' *.fastq > count/B4177_Fm0.txt
agrep -0 -c 'CAGAGCGCAACTGGGAA' *.fastq > count/B4178_Fm0.txt
agrep -0 -c 'AGCTTCGTCAAGATGAT' *.fastq > count/B4179_Fm0.txt
agrep -0 -c 'AGAACATCACATACCAG' *.fastq > count/B4181_Fm0.txt
agrep -0 -c 'TTGGTTACAGTCCACGT' *.fastq > count/B4182_Fm0.txt
agrep -0 -c 'CACTTCCCTTGGTGCAA' *.fastq > count/B4183_Fm0.txt
agrep -0 -c 'TAGTGGCCCTATAGTAC' *.fastq > count/B4184_Fm0.txt
agrep -0 -c 'GCATCTGGGGCCATATA' *.fastq > count/B4185_Fm0.txt
agrep -0 -c 'CTAATTAACTCCGGTGT' *.fastq > count/B4186_Fm0.txt
agrep -0 -c 'CGCCTCACAAGTATAGG' *.fastq > count/B4187_Fm0.txt
agrep -0 -c 'CCGACAATCACTAGCTA' *.fastq > count/B4188_Fm0.txt
agrep -0 -c 'TGACTATGGTGTTCTTG' *.fastq > count/B4190_Fm0.txt
agrep -0 -c 'TTGGACGGCCTTTCGAC' *.fastq > count/B4191_Fm0.txt
agrep -0 -c 'CGTCAGATTTGCCATTG' *.fastq > count/B4193_Fm0.txt
agrep -0 -c 'GCGGGTCTGGAGATTCA' *.fastq > count/B4194_Fm0.txt
agrep -0 -c 'ACCCGTTATATGTATCG' *.fastq > count/B4195_Fm0.txt
agrep -0 -c 'AACTGGACGAAACGACG' *.fastq > count/B4196_Fm0.txt
agrep -0 -c 'GTATTTCCTGTTCTACG' *.fastq > count/B4197_Fm0.txt
agrep -0 -c 'GGGAATTCGGGTGCACT' *.fastq > count/B4198_Fm0.txt
agrep -0 -c 'GTTAAAGGATCGTTGAC' *.fastq > count/B4199_Fm0.txt
agrep -0 -c 'GTGCTATAAGACTAGTC' *.fastq > count/B4200_Fm0.txt
agrep -0 -c 'CTAGCAGTGTAGCAACT' *.fastq > count/B4201_Fm0.txt
agrep -0 -c 'GCACAATACAACACGAA' *.fastq > count/B4202_Fm0.txt
agrep -0 -c 'CTACTTCATTACCGCCA' *.fastq > count/B4204_Fm0.txt
agrep -0 -c 'TACCGGTCCGGTACTTC' *.fastq > count/B4205_Fm0.txt
agrep -0 -c 'CACTGCATCAGATAGGT' *.fastq > count/B4206_Fm0.txt
agrep -0 -c 'GAGATCTCGGGCGTTAC' *.fastq > count/B4207_Fm0.txt
agrep -0 -c 'CGCTTCCCATACTGGTT' *.fastq > count/B4208_Fm0.txt
agrep -0 -c 'GTAGCATTCACGGGATC' *.fastq > count/B4209_Fm0.txt
agrep -0 -c 'CAACCAGCGACAATTTG' *.fastq > count/B4210_Fm0.txt
agrep -0 -c 'GTGAAGCTAACCAATTC' *.fastq > count/B4213_Fm0.txt
agrep -0 -c 'CGGATTTAAGCATGAAG' *.fastq > count/B4215_Fm0.txt
agrep -0 -c 'AGAAGGACGAACCGCGT' *.fastq > count/B4216_Fm0.txt
agrep -0 -c 'CAGCAACCGACGGTATC' *.fastq > count/B4217_Fm0.txt
agrep -0 -c 'ACCACTCCACGCAACGT' *.fastq > count/B4218_Fm0.txt
agrep -0 -c 'CGTGTAATGTCCGTCGA' *.fastq > count/B4219_Fm0.txt
agrep -0 -c 'GAGTGCTTAGTTTCAGA' *.fastq > count/B4220_Fm0.txt
agrep -0 -c 'GCTGTACGAAGCTAGGC' *.fastq > count/B4221_Fm0.txt
agrep -0 -c 'TTACGCGTATGGCAGAG' *.fastq > count/B4222_Fm0.txt
agrep -0 -c 'CAGCGTGACATTCCTAT' *.fastq > count/B4223_Fm0.txt
agrep -0 -c 'TTGCGCCGAACGCCAAT' *.fastq > count/B4224_Fm0.txt
agrep -0 -c 'ATAGGTGGAAACGGGAT' *.fastq > count/B4225_Fm0.txt
agrep -0 -c 'TTGTGTCAGGTCGCGTG' *.fastq > count/B4227_Fm0.txt
agrep -0 -c 'AGGGTTGGTTAAATCGA' *.fastq > count/B4228_Fm0.txt
agrep -0 -c 'TCTGTTTCCGCGTGTCA' *.fastq > count/B4229_Fm0.txt
agrep -0 -c 'TAGAGACGAAAGTCGGC' *.fastq > count/B4232_Fm0.txt
agrep -0 -c 'CAGGGCCGTTTTTACAG' *.fastq > count/B4234_Fm0.txt
agrep -0 -c 'GTAAGTCCTCAGACAGG' *.fastq > count/B4235_Fm0.txt
agrep -0 -c 'ATTCTGCGCGACCAAGG' *.fastq > count/B4237_Fm0.txt
agrep -0 -c 'GTTCTTTAACCCTCAAG' *.fastq > count/B4238_Fm0.txt
agrep -0 -c 'AGCGTACTCAAAAGTGC' *.fastq > count/B4239_Fm0.txt
agrep -0 -c 'ACACTGGATCGTAAAAC' *.fastq > count/B4240_Fm0.txt
agrep -0 -c 'TAATCTTCCGCTTAGAG' *.fastq > count/B4241_Fm0.txt
agrep -0 -c 'GTAATTACAGCGTCATC' *.fastq > count/B4243_Fm0.txt
agrep -0 -c 'CACAATATACCCGCATG' *.fastq > count/B4244_Fm0.txt
agrep -0 -c 'CTGGTAACACCCTGACT' *.fastq > count/B4245_Fm0.txt
agrep -0 -c 'GCGGAGCCCTCTTAAAT' *.fastq > count/B4246_Fm0.txt
agrep -0 -c 'TAGACATAACCTGGTGT' *.fastq > count/B4248_Fm0.txt
agrep -0 -c 'AGAATGACCATGCAGGC' *.fastq > count/B4250_Fm0.txt
agrep -0 -c 'AACTCTGTCTGAGCTCT' *.fastq > count/B4251_Fm0.txt
agrep -0 -c 'TTGACCGATACGCATAT' *.fastq > count/B4252_Fm0.txt
agrep -0 -c 'GAGCCTCCTATCGCTAC' *.fastq > count/B4253_Fm0.txt
agrep -0 -c 'ATCGCCGTAATAAGCGC' *.fastq > count/B4254_Fm0.txt
agrep -0 -c 'CTCAATCATGGTGTCGA' *.fastq > count/B4255_Fm0.txt
agrep -0 -c 'GGAGATCTTTCCGGCTA' *.fastq > count/B4256_Fm0.txt
agrep -0 -c 'TTCGAGCTCCGGTAAGC' *.fastq > count/B4257_Fm0.txt
agrep -0 -c 'TTAATTCGGTCCGGCTC' *.fastq > count/B4258_Fm0.txt
agrep -0 -c 'GCGGAATTGCGTGGTAC' *.fastq > count/B4259_Fm0.txt
agrep -0 -c 'GCCGCAGGTGAATGGTT' *.fastq > count/B4260_Fm0.txt
agrep -0 -c 'GTGTCTCGTCCATAGAA' *.fastq > count/B4261_Fm0.txt
agrep -0 -c 'ACGTCATCTGGTGTAAG' *.fastq > count/B4262_Fm0.txt
agrep -0 -c 'CTCAGTGTTCGACCTTG' *.fastq > count/B4263_Fm0.txt
agrep -0 -c 'ACTTTACGTAAGGGTGT' *.fastq > count/B4264_Fm0.txt
agrep -0 -c 'CTAGCCGGAAATACGTC' *.fastq > count/B4265_Fm0.txt
agrep -0 -c 'AGCCCAGGTTTATAAGC' *.fastq > count/B4266_Fm0.txt
agrep -0 -c 'CCACTCTTTAGAGGGTC' *.fastq > count/B4267_Fm0.txt
agrep -0 -c 'CCTATCTTGGTCGGTTT' *.fastq > count/B4268_Fm0.txt
agrep -0 -c 'TGCTGATTGCCACACGA' *.fastq > count/B4269_Fm0.txt
agrep -0 -c 'GGAGAATGTACCCGATC' *.fastq > count/B4270_Fm0.txt
agrep -0 -c 'GACACCGGGCAATGATA' *.fastq > count/B4271_Fm0.txt
agrep -0 -c 'ACATAGTAGCAGCGCGA' *.fastq > count/B4272_Fm0.txt
agrep -0 -c 'CGTATGCCGTCAGAGAC' *.fastq > count/B4274_Fm0.txt
agrep -0 -c 'ACAACGCCACACTTCTA' *.fastq > count/B4275_Fm0.txt
agrep -0 -c 'AATGCCGAAGGAGTCCT' *.fastq > count/B4276_Fm0.txt
agrep -0 -c 'CGCGGGTTTGCTTAACC' *.fastq > count/B4277_Fm0.txt
agrep -0 -c 'GTTAAGCCCTAGCAACC' *.fastq > count/B4278_Fm0.txt
agrep -0 -c 'ATGCCTTCATTGCGACG' *.fastq > count/B4279_Fm0.txt
agrep -0 -c 'CGGTTATGGAAACATTC' *.fastq > count/B4280_Fm0.txt
agrep -0 -c 'GCACACGAAGCAGCTTC' *.fastq > count/B4281_Fm0.txt
agrep -0 -c 'CACCAGCCTGTTGTGGT' *.fastq > count/B4282_Fm0.txt
agrep -0 -c 'TTCTCTCGCCTTACTCT' *.fastq > count/B4283_Fm0.txt
agrep -0 -c 'AACGAAGTGGAGAAGGT' *.fastq > count/B4284_Fm0.txt
agrep -0 -c 'TAGATATGACACGTCGG' *.fastq > count/B4285_Fm0.txt
agrep -0 -c 'AACAGTTGGGGTCAAAT' *.fastq > count/B4286_Fm0.txt
agrep -0 -c 'TCTCGGGATGAAAAATG' *.fastq > count/B4287_Fm0.txt
agrep -0 -c 'AGCTAGTGGTCCAGTTC' *.fastq > count/B4288_Fm0.txt
agrep -0 -c 'AGGTTACGATAAAGGTC' *.fastq > count/B4289_Fm0.txt
agrep -0 -c 'CCTTCGGCACCTGAATC' *.fastq > count/B4290_Fm0.txt
agrep -0 -c 'AATATCGTGTCGGTGAT' *.fastq > count/B4292_Fm0.txt
agrep -0 -c 'AGGTCCTTAACTACATC' *.fastq > count/B4295_Fm0.txt
agrep -0 -c 'AACCCGACCAGTCCTCT' *.fastq > count/B4296_Fm0.txt
agrep -0 -c 'TGGCATAACGGAGTCGT' *.fastq > count/B4297_Fm0.txt
agrep -0 -c 'TCTGTAGAGCATGCGTA' *.fastq > count/B4298_Fm0.txt
agrep -0 -c 'TTACGCTCAGCTCGACA' *.fastq > count/B4299_Fm0.txt
agrep -0 -c 'CCATGACAACCTGTGTA' *.fastq > count/B4300_Fm0.txt
agrep -0 -c 'CTCGACGAGTGGGAGAT' *.fastq > count/B4301_Fm0.txt
agrep -0 -c 'ACCGCACGTATATTCGA' *.fastq > count/B4303_Fm0.txt
agrep -0 -c 'GCATCCAGCAAGGTTAG' *.fastq > count/B4304_Fm0.txt
agrep -0 -c 'AATCGAACCTGCCCATG' *.fastq > count/B4305_Fm0.txt
agrep -0 -c 'CTCACCCGATTACAATG' *.fastq > count/B4308_Fm0.txt
agrep -0 -c 'CAGAATTGTTCCTCAGT' *.fastq > count/B4309_Fm0.txt
agrep -0 -c 'AACGAAAGTACGCCATC' *.fastq > count/B4311_Fm0.txt
agrep -0 -c 'TCAACCACGAAGTTAAG' *.fastq > count/B4313_Fm0.txt
agrep -0 -c 'GGAAGGCCGTGACATGA' *.fastq > count/B4314_Fm0.txt
agrep -0 -c 'AATACGCTATGATAGCG' *.fastq > count/B4315_Fm0.txt
agrep -0 -c 'TATAAGTCCGGCGAATC' *.fastq > count/B4316_Fm0.txt
agrep -0 -c 'CGTAGACCCCGGAGTTA' *.fastq > count/B4317_Fm0.txt
agrep -0 -c 'CTTCCGCCTATCTCTCC' *.fastq > count/B4318_Fm0.txt
agrep -0 -c 'ACGAGAAAGTGCTCATG' *.fastq > count/B4319_Fm0.txt
agrep -0 -c 'GGTCGCTATGGACTATC' *.fastq > count/B4320_Fm0.txt
agrep -0 -c 'CATACGCTTAAGGAGCC' *.fastq > count/B4321_Fm0.txt
agrep -0 -c 'CCTTTTCAGAATCGGTA' *.fastq > count/B4322_Fm0.txt
agrep -0 -c 'TCATATTGTGTACCGCG' *.fastq > count/B4323_Fm0.txt
agrep -0 -c 'ACCGCAATTTTCTGGAC' *.fastq > count/B4324_Fm0.txt
agrep -0 -c 'ATAACCCTTCGTTCACT' *.fastq > count/B4325_Fm0.txt
agrep -0 -c 'ATGAAGCACCTTAGGAA' *.fastq > count/B4326_Fm0.txt
agrep -0 -c 'ATTCGAGCCGCTAAACA' *.fastq > count/B4327_Fm0.txt
agrep -0 -c 'CCACGTCTACATAAGTT' *.fastq > count/B4328_Fm0.txt
agrep -0 -c 'AATCCGCCGACAGATCT' *.fastq > count/B4329_Fm0.txt
agrep -0 -c 'TGCGTCGTACATAATGT' *.fastq > count/B4330_Fm0.txt
agrep -0 -c 'GCGACGCTATTGCTTTA' *.fastq > count/B4331_Fm0.txt
agrep -0 -c 'CTCTGTATATCTCGAGC' *.fastq > count/B4332_Fm0.txt
agrep -0 -c 'TCGCATCCGACGTTCCT' *.fastq > count/B4333_Fm0.txt
agrep -0 -c 'AACCCGAATAAGTGAGT' *.fastq > count/B4335_Fm0.txt
agrep -0 -c 'TGAAACTACTCTGCCGG' *.fastq > count/B4336_Fm0.txt
agrep -0 -c 'TGACTCGATACAGATCA' *.fastq > count/B4337_Fm0.txt
agrep -0 -c 'CATATCCTGGTGCGATC' *.fastq > count/B4338_Fm0.txt
agrep -0 -c 'TACTACGGAAGAGCCCC' *.fastq > count/B4340_Fm0.txt
agrep -0 -c 'CCTATCTATTGCGCTGA' *.fastq > count/B4341_Fm0.txt
agrep -0 -c 'AACCGCCGAATTTAGTA' *.fastq > count/B4342_Fm0.txt
agrep -0 -c 'ATTTGACGCATGCAACT' *.fastq > count/B4343_Fm0.txt
agrep -0 -c 'TCACGTCCCGTTCATTG' *.fastq > count/B4344_Fm0.txt
agrep -0 -c 'TATGTCAGCTTGCTAGT' *.fastq > count/B4345_Fm0.txt
agrep -0 -c 'TAAAATATGGTGCCGGC' *.fastq > count/B4346_Fm0.txt
agrep -0 -c 'TTCGACAGCGGACTTGA' *.fastq > count/B4347_Fm0.txt
agrep -0 -c 'CGCAGGGTGCTAATGAG' *.fastq > count/B4348_Fm0.txt
agrep -0 -c 'CGGCTCTTGTTTCAAAC' *.fastq > count/B4350_Fm0.txt
agrep -0 -c 'ACTCGTTAACCCCATCT' *.fastq > count/B4351_Fm0.txt
agrep -0 -c 'TTAGTGAGTACTACGTC' *.fastq > count/B4352_Fm0.txt
agrep -0 -c 'ATGTCGCGATGGTCAAG' *.fastq > count/B4353_Fm0.txt
agrep -0 -c 'AACGGGCCCTGCTACTA' *.fastq > count/B4354_Fm0.txt
agrep -0 -c 'TTCGCAGCTCAAACGGT' *.fastq > count/B4356_Fm0.txt
agrep -0 -c 'CTGTCCCATGCTTAAAA' *.fastq > count/B4357_Fm0.txt
agrep -0 -c 'ATCTACGAACGGGTCGC' *.fastq > count/B4358_Fm0.txt
agrep -0 -c 'CGGAACTTGAGTAGCAT' *.fastq > count/B4359_Fm0.txt
agrep -0 -c 'TTGTGATGAATCGCACG' *.fastq > count/B4360_Fm0.txt
agrep -0 -c 'ATCCACACCGTTGACCC' *.fastq > count/B4362_Fm0.txt
agrep -0 -c 'GATGCGGTCGAACTTAT' *.fastq > count/B4363_Fm0.txt
agrep -0 -c 'ACGACTAGTTTGGCACC' *.fastq > count/B4364_Fm0.txt
agrep -0 -c 'GGGTAGTGCGGATAGAA' *.fastq > count/B4365_Fm0.txt
agrep -0 -c 'CCTGATTAGGCCTCCTT' *.fastq > count/B4366_Fm0.txt
agrep -0 -c 'TTAGACACCCAGATTGC' *.fastq > count/B4367_Fm0.txt
agrep -0 -c 'TAGTACCCTTACGCCCA' *.fastq > count/B4368_Fm0.txt
agrep -0 -c 'GTAATGCTTGGTGTTCC' *.fastq > count/B4369_Fm0.txt
agrep -0 -c 'TAGTATCGAATCTTCCC' *.fastq > count/B4370_Fm0.txt
agrep -0 -c 'AACGCTTTTCGTCCAAT' *.fastq > count/B4372_Fm0.txt
agrep -0 -c 'CCTGCCTCAGGTACAAA' *.fastq > count/B4374_Fm0.txt
agrep -0 -c 'CTAACCACAATTGCGTA' *.fastq > count/B4375_Fm0.txt
agrep -0 -c 'GTGAGTAGCCGTCACAC' *.fastq > count/B4376_Fm0.txt
agrep -0 -c 'ATCCTCGATAGTCTCCG' *.fastq > count/B4377_Fm0.txt
agrep -0 -c 'TCGATTAACCTGAGCCC' *.fastq > count/B4378_Fm0.txt
agrep -0 -c 'GGGGCCTCATCAAGTTT' *.fastq > count/B4379_Fm0.txt
agrep -0 -c 'TCGTTACCGTCATGTCT' *.fastq > count/B4380_Fm0.txt
agrep -0 -c 'CGCGAAAGATCAGCTTG' *.fastq > count/B4381_Fm0.txt
agrep -0 -c 'CAACGGAAGAACCGCTG' *.fastq > count/B4382_Fm0.txt
agrep -0 -c 'CAGCGGGACAACCTTCA' *.fastq > count/B4383_Fm0.txt
agrep -0 -c 'AACCTGCGCTATGCCAG' *.fastq > count/B4384_Fm0.txt
agrep -0 -c 'GTCGCATTTCGCAAAGA' *.fastq > count/B4386_Fm0.txt
agrep -0 -c 'GACCGAGATGTTCTAAA' *.fastq > count/B4387_Fm0.txt
agrep -0 -c 'ATTGAGTCCGTCAGCAG' *.fastq > count/B4388_Fm0.txt
agrep -0 -c 'CACTTTTTATGCTCAGG' *.fastq > count/B4389_Fm0.txt
agrep -0 -c 'GAGTTCAGATTTGGCCG' *.fastq > count/B4390_Fm0.txt
agrep -0 -c 'TCACCGTTGGTGATTTA' *.fastq > count/B4391_Fm0.txt
agrep -0 -c 'TCGGGGCTCTATGTGTA' *.fastq > count/B4393_Fm0.txt
agrep -0 -c 'TATCACCCGCAAGCTAT' *.fastq > count/B4394_Fm0.txt
agrep -0 -c 'GCGTGGCGTACTCTATA' *.fastq > count/B4396_Fm0.txt
agrep -0 -c 'GGCAACGGATGCTAATC' *.fastq > count/B4398_Fm0.txt
agrep -0 -c 'TTACAAGTAGCATCGAG' *.fastq > count/B4399_Fm0.txt
agrep -0 -c 'ACGTCAAGCCCGAATGG' *.fastq > count/B4400_Fm0.txt
agrep -0 -c 'GTTGAACCGCCCAGAAG' *.fastq > count/B4401_Fm0.txt
agrep -0 -c 'TCGTCCGTTCTGCAAAA' *.fastq > count/B4404_Fm0.txt
agrep -0 -c 'AGACCGCTCAAAGCAGG' *.fastq > count/B4405_Fm0.txt
agrep -0 -c 'GCAAGGCTTTGATCACA' *.fastq > count/B4406_Fm0.txt
agrep -0 -c 'GTATGAGCGCATCACCC' *.fastq > count/B4407_Fm0.txt
agrep -0 -c 'TACGTGCGACAGCTATT' *.fastq > count/B4409_Fm0.txt
agrep -0 -c 'GCCCGACACACAACAAA' *.fastq > count/B4411_Fm0.txt
agrep -0 -c 'ATTTGCGCTGGGGTAGC' *.fastq > count/B4412_Fm0.txt
agrep -0 -c 'CATCACCAACGGTATCG' *.fastq > count/B4415_Fm0.txt
agrep -0 -c 'CTCGCATACAATCCAGC' *.fastq > count/B4416_Fm0.txt
agrep -0 -c 'GACATGAGTCATCCGGG' *.fastq > count/B4417_Fm0.txt
agrep -0 -c 'CGGTGGTCATATAGTTT' *.fastq > count/B4418_Fm0.txt
agrep -0 -c 'ATGCCTGTACGCGAATA' *.fastq > count/B4419_Fm0.txt
agrep -0 -c 'CTGGAATGGCTACATCG' *.fastq > count/B4420_Fm0.txt
agrep -0 -c 'GTAGTGCAGGAGGCCTT' *.fastq > count/B4421_Fm0.txt
agrep -0 -c 'AGGCAAGTATCGAATCG' *.fastq > count/B4422_Fm0.txt
agrep -0 -c 'AGGACACAATCACAAGT' *.fastq > count/B4424_Fm0.txt
agrep -0 -c 'TATCATCTGACGTGTCA' *.fastq > count/B4426_Fm0.txt
agrep -0 -c 'CGCCACGTAATGCTGGA' *.fastq > count/B4427_Fm0.txt
agrep -0 -c 'TGACGCTAGTCCGATAC' *.fastq > count/B4429_Fm0.txt
agrep -0 -c 'AATTCGGCGGTCTTTAA' *.fastq > count/B4430_Fm0.txt
agrep -0 -c 'GGCTAATTGCCGAAAAT' *.fastq > count/B4431_Fm0.txt
agrep -0 -c 'TCAAGCCGGGAGCCAAT' *.fastq > count/B4432_Fm0.txt
agrep -0 -c 'GCCTTCTGGGGTTTATC' *.fastq > count/B4433_Fm0.txt
agrep -0 -c 'GTTAGGTCGGTATTGCC' *.fastq > count/B4434_Fm0.txt
agrep -0 -c 'ACGTTTCACCGTAAGTT' *.fastq > count/B4435_Fm0.txt
agrep -0 -c 'AATTGGTTCAGGCTCCG' *.fastq > count/B4437_Fm0.txt
agrep -0 -c 'CCTGTTTGTCCGACCGT' *.fastq > count/B4438_Fm0.txt
agrep -0 -c 'ATCCATTCCTGATAGCC' *.fastq > count/B4440_Fm0.txt
agrep -0 -c 'GTAATCTCCGGTAAAAC' *.fastq > count/B4441_Fm0.txt
agrep -0 -c 'CCAGATGGATATGAGTC' *.fastq > count/B4442_Fm0.txt
agrep -0 -c 'CAAGTAGTCAGTCAACA' *.fastq > count/B4443_Fm0.txt
agrep -0 -c 'AGTATTTTCAACCGCTC' *.fastq > count/B4444_Fm0.txt
agrep -0 -c 'AGGCACTCAAGACTCCC' *.fastq > count/B4445_Fm0.txt
agrep -0 -c 'AGACAATGGTGAAGCAT' *.fastq > count/B4446_Fm0.txt
agrep -0 -c 'ACTGCAATCACGTCTTA' *.fastq > count/B4447_Fm0.txt
agrep -0 -c 'GGTCAACACTATTGACA' *.fastq > count/B4448_Fm0.txt
agrep -0 -c 'GTCGAGCTGAGTACTTC' *.fastq > count/B4449_Fm0.txt
agrep -0 -c 'TGGAACCAAGACCGGAT' *.fastq > count/B4450_Fm0.txt
agrep -0 -c 'GCGTCTTGCTACGTTCT' *.fastq > count/B4452_Fm0.txt
agrep -0 -c 'AAGAACTAACCGTTCCC' *.fastq > count/B4453_Fm0.txt
agrep -0 -c 'CACCCTGTTGGGCTATC' *.fastq > count/B4455_Fm0.txt
agrep -0 -c 'TACTCGCATTGTGTCCT' *.fastq > count/B4456_Fm0.txt
agrep -0 -c 'ATGATCGCCCTTTCGTG' *.fastq > count/B4457_Fm0.txt
agrep -0 -c 'GCGTTGACAAAGTGTTA' *.fastq > count/B4458_Fm0.txt
agrep -0 -c 'ACAAGCGTTGCGGTCAA' *.fastq > count/B4459_Fm0.txt
agrep -0 -c 'CCACCTTTCGTGGTATA' *.fastq > count/B4460_Fm0.txt
agrep -0 -c 'TATGAAAGTCTCGGCGT' *.fastq > count/B4461_Fm0.txt
agrep -0 -c 'TCAGAGGGATACGATGG' *.fastq > count/B4462_Fm0.txt
agrep -0 -c 'ACAGGTGTACCAGTACG' *.fastq > count/B4463_Fm0.txt
agrep -0 -c 'TTCAATCGTTCGTTCCA' *.fastq > count/B4465_Fm0.txt
agrep -0 -c 'ACACCGATTACGACCGA' *.fastq > count/B4467_Fm0.txt
agrep -0 -c 'GTCCTCACGCGACTGAA' *.fastq > count/B4468_Fm0.txt
agrep -0 -c 'TATTGGTCAGGCAGCCT' *.fastq > count/B4469_Fm0.txt
agrep -0 -c 'ACCCCCATCAAGGTCTA' *.fastq > count/B4470_Fm0.txt
agrep -0 -c 'GTCTCTCGTATTTACGA' *.fastq > count/B4471_Fm0.txt
agrep -0 -c 'TTATCTGATGTGCCGAG' *.fastq > count/B4472_Fm0.txt
agrep -0 -c 'CTCGAAGGGTGGTTTCC' *.fastq > count/B4473_Fm0.txt
agrep -0 -c 'AGGCTCAAGCGTAAGAA' *.fastq > count/B4474_Fm0.txt
agrep -0 -c 'AGCCTGCCGACCACTAA' *.fastq > count/B4475_Fm0.txt
agrep -0 -c 'CCGCACCGTTCAAGAGT' *.fastq > count/B4476_Fm0.txt
agrep -0 -c 'ATGAGCACCGGGATACT' *.fastq > count/B4477_Fm0.txt
agrep -0 -c 'CAACTCCGCCGAAAAAG' *.fastq > count/B4478_Fm0.txt
agrep -0 -c 'TCGTACTACGCCTAGAT' *.fastq > count/B4479_Fm0.txt
agrep -0 -c 'GTATAGCGAGGACGGCA' *.fastq > count/B4481_Fm0.txt
agrep -0 -c 'CTCAGTTCATGAGTGAG' *.fastq > count/B4482_Fm0.txt
agrep -0 -c 'CAGAGTTGAACCAAACG' *.fastq > count/B4483_Fm0.txt
agrep -0 -c 'GCGCTAATCGAGCTTGG' *.fastq > count/B4485_Fm0.txt
agrep -0 -c 'AACTCCTCGTTAACCTG' *.fastq > count/B4487_Fm0.txt
agrep -0 -c 'ACTGCAAGAATCCCGGT' *.fastq > count/B4488_Fm0.txt
agrep -0 -c 'TGGATTACTCCGCAAGT' *.fastq > count/B4489_Fm0.txt
agrep -0 -c 'CTTGCCAGCGGGCAAAT' *.fastq > count/B4491_Fm0.txt
agrep -0 -c 'TTCTCCGTATTACTTCG' *.fastq > count/B4492_Fm0.txt
agrep -0 -c 'GTTTCCCGCATGTTCGG' *.fastq > count/B4494_Fm0.txt
agrep -0 -c 'AATCATGCCGCCCGTCT' *.fastq > count/B4495_Fm0.txt
agrep -0 -c 'ATGCGCTATAACCTTGG' *.fastq > count/B4496_Fm0.txt
agrep -0 -c 'GTCGTGTTATTTCCTAC' *.fastq > count/B4497_Fm0.txt
agrep -0 -c 'CCTAAAATGGGGTCGTT' *.fastq > count/B4498_Fm0.txt
agrep -0 -c 'CATTACTTCGGGCTAGA' *.fastq > count/B4499_Fm0.txt
agrep -0 -c 'AAGGGGAACTGCTCGCA' *.fastq > count/B4500_Fm0.txt
agrep -0 -c 'GTAATAGAGTATAGCCC' *.fastq > count/B4501_Fm0.txt
agrep -0 -c 'AACCGCTTGGCTTCAAA' *.fastq > count/B4502_Fm0.txt
agrep -0 -c 'ACAGCTTCTCCTCAACG' *.fastq > count/B4504_Fm0.txt
agrep -0 -c 'GCGTCGTTCGGTCTACA' *.fastq > count/B4505_Fm0.txt
agrep -0 -c 'GGTAAGACATCAAACGA' *.fastq > count/B4506_Fm0.txt
agrep -0 -c 'GTCCGATGAATCCCCAG' *.fastq > count/B4508_Fm0.txt
agrep -0 -c 'GTGGGACACTCGTAGTA' *.fastq > count/B4509_Fm0.txt
agrep -0 -c 'CTACGATAACCTGATAC' *.fastq > count/B4510_Fm0.txt
agrep -0 -c 'TCGATTGTTGCCAGAGG' *.fastq > count/B4512_Fm0.txt
agrep -0 -c 'CGTTGCTCAGTACGTCC' *.fastq > count/B4514_Fm0.txt
agrep -0 -c 'ATAAAGAGTTGGTCCGC' *.fastq > count/B4515_Fm0.txt
agrep -0 -c 'ACGCTTCGAGTACGTGT' *.fastq > count/B4517_Fm0.txt
agrep -0 -c 'GGTTCTTTGAACGCGTT' *.fastq > count/B4518_Fm0.txt
agrep -0 -c 'CTATCAAACGATAGGGT' *.fastq > count/B4519_Fm0.txt
agrep -0 -c 'CCTGTCCTTATAGATCC' *.fastq > count/B4520_Fm0.txt
agrep -0 -c 'ACTCCACTATGTCTTCT' *.fastq > count/B4522_Fm0.txt
agrep -0 -c 'TTACACCTAACCCGCCT' *.fastq > count/B4523_Fm0.txt
agrep -0 -c 'ACCCCAAAGCTAACGAG' *.fastq > count/B4525_Fm0.txt
agrep -0 -c 'TACCCTTATGGATCGGC' *.fastq > count/B4526_Fm0.txt
agrep -0 -c 'CCTTGGAGCTAATAGAG' *.fastq > count/B4527_Fm0.txt
agrep -0 -c 'CCATCAAATCAGACCAC' *.fastq > count/B4528_Fm0.txt
agrep -0 -c 'GTAAGTGCTAAACGCTG' *.fastq > count/B4529_Fm0.txt
agrep -0 -c 'GTAACGGTAACCCCTGT' *.fastq > count/B4530_Fm0.txt
agrep -0 -c 'CCTTCATGTAAAGGAGC' *.fastq > count/B4531_Fm0.txt
agrep -0 -c 'TCGGTCAGCTAATGCCA' *.fastq > count/B4532_Fm0.txt
agrep -0 -c 'GGATGCGCGGTTTGTAT' *.fastq > count/B4533_Fm0.txt
agrep -0 -c 'ACGTCGTCAGGTCGACA' *.fastq > count/B4534_Fm0.txt
agrep -0 -c 'CAAGAGAAAACAGTCTG' *.fastq > count/B4535_Fm0.txt
agrep -0 -c 'GTTCGCCAGTAGTAGCC' *.fastq > count/B4536_Fm0.txt
agrep -0 -c 'CTTGCCCAACAGGGCAT' *.fastq > count/B4537_Fm0.txt
agrep -0 -c 'ACTATGCATAGGTGTGG' *.fastq > count/B4538_Fm0.txt
agrep -0 -c 'GTACCAGCCTTATGCTG' *.fastq > count/B4539_Fm0.txt
agrep -0 -c 'AGTACAACGTGGCACTA' *.fastq > count/B4540_Fm0.txt
agrep -0 -c 'ATATAGTCTCCACGGTT' *.fastq > count/B4541_Fm0.txt
agrep -0 -c 'GGCGGTTATCATTTGCC' *.fastq > count/B4542_Fm0.txt
agrep -0 -c 'TAACCATCTCGCACCGA' *.fastq > count/B4543_Fm0.txt
agrep -0 -c 'ATATGTGACCACCGGCA' *.fastq > count/B4544_Fm0.txt
agrep -0 -c 'GGAACTTGGTAGAGCCT' *.fastq > count/B4545_Fm0.txt
agrep -0 -c 'CGGTTGACTGAACAGGC' *.fastq > count/B4547_Fm0.txt
agrep -0 -c 'TTATGAACGCCTAGGAT' *.fastq > count/B4548_Fm0.txt
agrep -0 -c 'CTCCGGACACATTTTAC' *.fastq > count/B4549_Fm0.txt
agrep -0 -c 'AATGCGACATCACGCGC' *.fastq > count/B4551_Fm0.txt
agrep -0 -c 'GCGTCCAGATTCAAAAA' *.fastq > count/B4553_Fm0.txt
agrep -0 -c 'CTACAGTACGAAGTTAC' *.fastq > count/B4554_Fm0.txt
agrep -0 -c 'CACCGCAGTACCTCCAT' *.fastq > count/B4556_Fm0.txt
agrep -0 -c 'TACCCGAGTCCAGTTAC' *.fastq > count/B4558_Fm0.txt
agrep -0 -c 'GGATACCATAGAGTGCG' *.fastq > count/B4559_Fm0.txt
agrep -0 -c 'CACTATGGTATCCCCAT' *.fastq > count/B4561_Fm0.txt
agrep -0 -c 'AACCGTGCCTACCGTTG' *.fastq > count/B4562_Fm0.txt
agrep -0 -c 'TTGTACTCGCGCGAAAT' *.fastq > count/B4563_Fm0.txt
agrep -0 -c 'GTACCGCGGTACGAATA' *.fastq > count/B4564_Fm0.txt
agrep -0 -c 'TGAAGGAACTCCAACAT' *.fastq > count/B4566_Fm0.txt
agrep -0 -c 'GATGGTTCGGTATAACT' *.fastq > count/B4567_Fm0.txt
agrep -0 -c 'GCAGTACAGCAAGGTCG' *.fastq > count/B4568_Fm0.txt
agrep -0 -c 'ATGCCATGCGCGTTAAA' *.fastq > count/B4569_Fm0.txt
agrep -0 -c 'GAGTCTGAAGAAGGTCC' *.fastq > count/B4570_Fm0.txt
agrep -0 -c 'GTTTCAGCGGATCGGTA' *.fastq > count/B4572_Fm0.txt
agrep -0 -c 'CAGGGGTGTCTTCACTT' *.fastq > count/B4574_Fm0.txt
agrep -0 -c 'CGAACGTTGGTAATGCA' *.fastq > count/B4575_Fm0.txt
agrep -0 -c 'CATGGATTATTCGAACG' *.fastq > count/B4576_Fm0.txt
agrep -0 -c 'CGATTCGGCAAACTATG' *.fastq > count/B4580_Fm0.txt
agrep -0 -c 'GATCGAGTATTCGCAGT' *.fastq > count/B4581_Fm0.txt
agrep -0 -c 'AATACGTGCGCACTTGA' *.fastq > count/B4583_Fm0.txt
agrep -0 -c 'ACTAGATTACTCAGACC' *.fastq > count/B4584_Fm0.txt
agrep -0 -c 'GGTCGTTCGTGATTCGG' *.fastq > count/B4585_Fm0.txt
agrep -0 -c 'AATTTGGGTCCTCGAAC' *.fastq > count/B4586_Fm0.txt
agrep -0 -c 'TCGTTGGACTACGCTGA' *.fastq > count/B4587_Fm0.txt
agrep -0 -c 'GACTTACTCGTGGGTTC' *.fastq > count/B4589_Fm0.txt
agrep -0 -c 'TATTAGCGCCTCGCCAC' *.fastq > count/B4590_Fm0.txt
agrep -0 -c 'ACTGATAGGAAGGCCTA' *.fastq > count/B4591_Fm0.txt
agrep -0 -c 'TGCTAACATTCACGTCG' *.fastq > count/B4592_Fm0.txt
agrep -0 -c 'CACGATCCAACGTGCCT' *.fastq > count/B4593_Fm0.txt
agrep -0 -c 'CGCAAACCGTGTACCAA' *.fastq > count/B4594_Fm0.txt
agrep -0 -c 'CGTCGCCGAAGCCTAAA' *.fastq > count/B4595_Fm0.txt
agrep -0 -c 'GATACGTACCGCGTATT' *.fastq > count/B4596_Fm0.txt
agrep -0 -c 'GTGCCCCATTGGTATTC' *.fastq > count/B4597_Fm0.txt
agrep -0 -c 'ACGGTAGAGGTAAGTAT' *.fastq > count/B4600_Fm0.txt
agrep -0 -c 'AATGTCATGACGAGGCC' *.fastq > count/B4601_Fm0.txt
agrep -0 -c 'TATATCTCAAAGCTCGC' *.fastq > count/B4602_Fm0.txt
agrep -0 -c 'TTCTTGGTATCTGGCGA' *.fastq > count/B4604_Fm0.txt
agrep -0 -c 'ACACAAAGGCCTATCTC' *.fastq > count/B4605_Fm0.txt
agrep -0 -c 'GTAGACACTGTCCTCAG' *.fastq > count/B4606_Fm0.txt
agrep -0 -c 'TTACACTAAGGCTACGG' *.fastq > count/B4607_Fm0.txt
agrep -0 -c 'AAGGGATGCAAGGACAA' *.fastq > count/B4609_Fm0.txt
agrep -0 -c 'CTGAGCACTGATCGCAG' *.fastq > count/B4610_Fm0.txt
agrep -0 -c 'ATCTAGCCCAGTTGTTT' *.fastq > count/B4611_Fm0.txt
agrep -0 -c 'CGATTGGAGTAGCTGAG' *.fastq > count/B4612_Fm0.txt
agrep -0 -c 'TGCGGCATATCGGCTAC' *.fastq > count/B4613_Fm0.txt
agrep -0 -c 'CCATTTGGATTGCCGAG' *.fastq > count/B4614_Fm0.txt
agrep -0 -c 'AGGCCGAGGAATTGAAC' *.fastq > count/B4616_Fm0.txt
agrep -0 -c 'AGCCTCGGAAGACTTAC' *.fastq > count/B4617_Fm0.txt
agrep -0 -c 'GTACCCTTGGCTTACCC' *.fastq > count/B4618_Fm0.txt
agrep -0 -c 'TCTTCTACGGATGTCAT' *.fastq > count/B4619_Fm0.txt
agrep -0 -c 'TCGAAAGTCGAAGTGTT' *.fastq > count/B4620_Fm0.txt
agrep -0 -c 'GCCCCGAAGGTAGATTT' *.fastq > count/B4621_Fm0.txt
agrep -0 -c 'GAGTGTTCGCCTACATC' *.fastq > count/B4622_Fm0.txt
agrep -0 -c 'TGAGGCATGCGTATCAA' *.fastq > count/B4623_Fm0.txt
agrep -0 -c 'ACGCGTCACGCTGGATT' *.fastq > count/B4624_Fm0.txt
agrep -0 -c 'ACCTACAGGCGATATGC' *.fastq > count/B4625_Fm0.txt
agrep -0 -c 'TGCCAAGCATTCGAGAG' *.fastq > count/B4626_Fm0.txt
agrep -0 -c 'CGACTGGAATACGACGT' *.fastq > count/B4627_Fm0.txt
agrep -0 -c 'AAGAGGATACCCAAGGT' *.fastq > count/B4628_Fm0.txt
agrep -0 -c 'GCAGTTTGCTAATGCTT' *.fastq > count/B4629_Fm0.txt
agrep -0 -c 'GCCGCCGAAGTAACTTT' *.fastq > count/B4630_Fm0.txt
agrep -0 -c 'AACAGCGATTATCCGTA' *.fastq > count/B4631_Fm0.txt
agrep -0 -c 'CATCTTTTGACGAAGAG' *.fastq > count/B4633_Fm0.txt
agrep -0 -c 'CGGGAGGCAGCAATATT' *.fastq > count/B4634_Fm0.txt
agrep -0 -c 'AGATTTTCCTGGGTGTC' *.fastq > count/B4635_Fm0.txt
agrep -0 -c 'ACTGATGGTTACCCGCT' *.fastq > count/B4636_Fm0.txt
agrep -0 -c 'CCGGTTACAGACTATAA' *.fastq > count/B4637_Fm0.txt
agrep -0 -c 'CTTCTTCCCGAATGTAC' *.fastq > count/B4639_Fm0.txt
agrep -0 -c 'ATCCAGTTGGCGGACTA' *.fastq > count/B4642_Fm0.txt
agrep -0 -c 'GTAATGTCGGACCTGGG' *.fastq > count/B4643_Fm0.txt
agrep -0 -c 'AGAGTGACGACATGGGG' *.fastq > count/B4644_Fm0.txt
agrep -0 -c 'CTCCGTAATGTCTCCGT' *.fastq > count/B4645_Fm0.txt
agrep -0 -c 'GGCCTTAGTTTTGGCCT' *.fastq > count/B4646_Fm0.txt
agrep -0 -c 'CTCGGAATATCTGCAGA' *.fastq > count/B4647_Fm0.txt
agrep -0 -c 'AGTCGGAGTTGGCATCA' *.fastq > count/B4648_Fm0.txt
agrep -0 -c 'CTGGTTACGAAGTCCGG' *.fastq > count/B4649_Fm0.txt
agrep -0 -c 'ATCATCGGGATCCACGG' *.fastq > count/B4650_Fm0.txt
agrep -0 -c 'TATCTCTAATCTTGGCG' *.fastq > count/B4651_Fm0.txt
agrep -0 -c 'AAGATGTCGGGTACCCA' *.fastq > count/B4653_Fm0.txt
agrep -0 -c 'TTAAGTCCGACGGAAAT' *.fastq > count/B4654_Fm0.txt
agrep -0 -c 'GCTCCTTAAACCAGGAC' *.fastq > count/B4655_Fm0.txt
agrep -0 -c 'ATTCATAGGCTCGACGT' *.fastq > count/B4656_Fm0.txt
agrep -0 -c 'CGTTTCACTGAGTTGAT' *.fastq > count/B4657_Fm0.txt
agrep -0 -c 'GAGATATATCTCCTGCT' *.fastq > count/B4659_Fm0.txt
agrep -0 -c 'CATCCTTGGAGTTGCGA' *.fastq > count/B4660_Fm0.txt
agrep -0 -c 'CGTCGCAACCAGATCTT' *.fastq > count/B4661_Fm0.txt
agrep -0 -c 'GATACTCCCGGTACAAT' *.fastq > count/B4662_Fm0.txt
agrep -0 -c 'TGTCAGGACCTTGATAG' *.fastq > count/B4663_Fm0.txt
agrep -0 -c 'GGAGGCATTATTCGAGT' *.fastq > count/B4665_Fm0.txt
agrep -0 -c 'TTATCGCTGGGAACATG' *.fastq > count/B4666_Fm0.txt
agrep -0 -c 'TTAACCAGTCGCACGCA' *.fastq > count/B4668_Fm0.txt
agrep -0 -c 'TGAGAATGAGTTCACGC' *.fastq > count/B4669_Fm0.txt
agrep -0 -c 'TAAAGGCAGTGGCACAC' *.fastq > count/B4671_Fm0.txt
agrep -0 -c 'GTGGAATCCATTGGGTT' *.fastq > count/B4672_Fm0.txt
agrep -0 -c 'GTTGAGGTCCGGTCCAA' *.fastq > count/B4673_Fm0.txt
agrep -0 -c 'CTTATCCCCCATGGTCA' *.fastq > count/B4674_Fm0.txt
agrep -0 -c 'ATCACTGCCGCTTTTGT' *.fastq > count/B4675_Fm0.txt
agrep -0 -c 'TGACGTCTAACTGAGGC' *.fastq > count/B4676_Fm0.txt
agrep -0 -c 'AGCGATCGCGGATTGCA' *.fastq > count/B4677_Fm0.txt
agrep -0 -c 'CGGTCATGCCGTTATGC' *.fastq > count/B4678_Fm0.txt
agrep -0 -c 'ATCTTGACCTACCTAGA' *.fastq > count/B4679_Fm0.txt
agrep -0 -c 'CTTGACTTAGGGTGGGC' *.fastq > count/B4680_Fm0.txt
agrep -0 -c 'CATGACGGACTCGTGTT' *.fastq > count/B4681_Fm0.txt
agrep -0 -c 'ACCTGTCGTTCGAGAAA' *.fastq > count/B4682_Fm0.txt
agrep -0 -c 'CGGACGTAAAGCAAGTA' *.fastq > count/B4683_Fm0.txt
agrep -0 -c 'TGTAATTGTTGGCAGCG' *.fastq > count/B4684_Fm0.txt
agrep -0 -c 'TGGCTGTGAATTAATGC' *.fastq > count/B4685_Fm0.txt
agrep -0 -c 'CCGACTGTTGGTATTGC' *.fastq > count/B4687_Fm0.txt
agrep -0 -c 'TGACTCAAACGGATCCC' *.fastq > count/B4689_Fm0.txt
agrep -0 -c 'GCTACGTACTCGTTAAA' *.fastq > count/B4690_Fm0.txt
agrep -0 -c 'TTGTAGCACTCTAGCCA' *.fastq > count/B4691_Fm0.txt
agrep -0 -c 'TAGCCCTCATGATGCAA' *.fastq > count/B4693_Fm0.txt
agrep -0 -c 'GTACACTCTGTCCAGAC' *.fastq > count/B4694_Fm0.txt
agrep -0 -c 'AAGTTATACCGCCCGTT' *.fastq > count/B4695_Fm0.txt
agrep -0 -c 'GACTTGGCTGACGGTTA' *.fastq > count/B4696_Fm0.txt
agrep -0 -c 'AATCGGGAAACGCCGAA' *.fastq > count/B4697_Fm0.txt
agrep -0 -c 'CGTCTTATTTCGCGTGC' *.fastq > count/B4698_Fm0.txt
agrep -0 -c 'CGACAATTTCTCCAATC' *.fastq > count/B4699_Fm0.txt
agrep -0 -c 'CATTCGTACGGCCACAA' *.fastq > count/B4700_Fm0.txt
agrep -0 -c 'CGCAATAAACATTCGGA' *.fastq > count/B4701_Fm0.txt
agrep -0 -c 'GGGCAAACTAGTCATCA' *.fastq > count/B4702_Fm0.txt
agrep -0 -c 'GCCATTTGTCTATGTAC' *.fastq > count/B4704_Fm0.txt
agrep -0 -c 'AGACATTGGCGCCACGA' *.fastq > count/B4705_Fm0.txt
agrep -0 -c 'GCTGCGAAAGGCATGGT' *.fastq > count/B4706_Fm0.txt
agrep -0 -c 'TGAGCGCCGTTCGTACA' *.fastq > count/B4707_Fm0.txt
agrep -0 -c 'CTACAATAGGTCACCAT' *.fastq > count/B4708_Fm0.txt
agrep -0 -c 'GCCGTTACTCAAAGACT' *.fastq > count/B4710_Fm0.txt
agrep -0 -c 'GAGTTAAGACCCCTCTA' *.fastq > count/B4712_Fm0.txt
agrep -0 -c 'CGTCAGATAATGCGAAT' *.fastq > count/B4713_Fm0.txt
agrep -0 -c 'ATTAGCGTAGCCATCTT' *.fastq > count/B4714_Fm0.txt
agrep -0 -c 'GCTAGGAGCTAACGTAC' *.fastq > count/B4716_Fm0.txt
agrep -0 -c 'GTATGGATGCGTATTGG' *.fastq > count/B4717_Fm0.txt
agrep -0 -c 'ACAAGCGACAACTCTAA' *.fastq > count/B4719_Fm0.txt
agrep -0 -c 'CGGACTTTTAGGTTTTG' *.fastq > count/B4720_Fm0.txt
agrep -0 -c 'TCTACTGACTCGCGTCA' *.fastq > count/B4721_Fm0.txt
agrep -0 -c 'TGAGCCCCAATAGATAT' *.fastq > count/B4722_Fm0.txt
agrep -0 -c 'ACGAGCGTTCTATCTAG' *.fastq > count/B4723_Fm0.txt
agrep -0 -c 'GGAGCTTTGCTAAGATA' *.fastq > count/B4724_Fm0.txt
agrep -0 -c 'TAGGAACGGTATCTTCA' *.fastq > count/B4726_Fm0.txt
agrep -0 -c 'CCGTGTCAAACTTTTCC' *.fastq > count/B4727_Fm0.txt
agrep -0 -c 'GGAATGGTGTTGGTAAA' *.fastq > count/B4728_Fm0.txt
agrep -0 -c 'CAAAGAGGCGTACCAGA' *.fastq > count/B4729_Fm0.txt
agrep -0 -c 'AAGAGACTAGTTCCATC' *.fastq > count/B4731_Fm0.txt
agrep -0 -c 'CCAGCAAATTTTAGGCG' *.fastq > count/B4732_Fm0.txt
agrep -0 -c 'CATCGCAATTGAAGTAG' *.fastq > count/B4733_Fm0.txt
agrep -0 -c 'GGATATCAGCACCACGG' *.fastq > count/B4734_Fm0.txt
agrep -0 -c 'TTGACTTCACGAACAAG' *.fastq > count/B4735_Fm0.txt
agrep -0 -c 'CATCTCATAAAGTGGCG' *.fastq > count/B4736_Fm0.txt
agrep -0 -c 'TAACCGTCCCAGACGAC' *.fastq > count/B4737_Fm0.txt
agrep -0 -c 'CACGGTTGGAGTATATG' *.fastq > count/B4738_Fm0.txt
agrep -0 -c 'GAGTATAATGGCGGCCG' *.fastq > count/B4739_Fm0.txt
agrep -0 -c 'TTAGGAAGACTTTGAGC' *.fastq > count/B4740_Fm0.txt
agrep -0 -c 'CGTTGCGCTAGCTGATA' *.fastq > count/B4741_Fm0.txt
agrep -0 -c 'GCGTAACTCTAGACCCA' *.fastq > count/B4742_Fm0.txt
agrep -0 -c 'TGCAACCGAACGTCGAG' *.fastq > count/B4743_Fm0.txt
agrep -0 -c 'AGATCACGCCAATTTTG' *.fastq > count/B4744_Fm0.txt
agrep -0 -c 'GGTAGGAAGAAGCTGAT' *.fastq > count/B4745_Fm0.txt
agrep -0 -c 'GCCTCCTAGTGTGTTGG' *.fastq > count/B4746_Fm0.txt
agrep -0 -c 'CTTCAGAGTTACACTCT' *.fastq > count/B4747_Fm0.txt
agrep -0 -c 'GATAAGTAGGGATCAAC' *.fastq > count/B4750_Fm0.txt
agrep -0 -c 'TTACGCCTTCCACTTAC' *.fastq > count/B4752_Fm0.txt
agrep -0 -c 'CGATAGGATTTGGGTCT' *.fastq > count/B4753_Fm0.txt
agrep -0 -c 'CGATCAGAACGAAGCAC' *.fastq > count/B4757_Fm0.txt
agrep -0 -c 'AATACCTGCACGTAGGT' *.fastq > count/B4758_Fm0.txt
agrep -0 -c 'CTGGTCTTGGTCGGTGA' *.fastq > count/B4759_Fm0.txt
agrep -0 -c 'AGATTCAAGGTGGCGTT' *.fastq > count/B4762_Fm0.txt
agrep -0 -c 'GCGACAGTGATTTTCTG' *.fastq > count/B4763_Fm0.txt
agrep -0 -c 'CGGTAAATCAACGCGTC' *.fastq > count/B4765_Fm0.txt
agrep -0 -c 'ACGTGTTGTCACCTTGT' *.fastq > count/B4766_Fm0.txt
agrep -0 -c 'GACCACCTGACCACATC' *.fastq > count/B4769_Fm0.txt
agrep -0 -c 'ATCGGGTTTAGCACCAT' *.fastq > count/B4770_Fm0.txt
agrep -0 -c 'GTACGGGCAAAATTCTG' *.fastq > count/B4771_Fm0.txt
agrep -0 -c 'GATTGCCTACTCTGGTT' *.fastq > count/B4772_Fm0.txt
agrep -0 -c 'GGCAAAGCACGTGATTA' *.fastq > count/B4773_Fm0.txt
agrep -0 -c 'GCGTTCTATCTGTGACA' *.fastq > count/B4774_Fm0.txt
agrep -0 -c 'TCAACTCCCGCGCTTAA' *.fastq > count/B4775_Fm0.txt
agrep -0 -c 'TACCCGGAGGAAACACA' *.fastq > count/B4776_Fm0.txt
agrep -0 -c 'GGAACCGAACTTATCAA' *.fastq > count/B4780_Fm0.txt
agrep -0 -c 'AGATGAATCGGAAACGA' *.fastq > count/B4781_Fm0.txt
agrep -0 -c 'TTCCAATCGTGGCACTG' *.fastq > count/B4782_Fm0.txt
agrep -0 -c 'CCGGGCGTGAAAGTATG' *.fastq > count/B4783_Fm0.txt
agrep -0 -c 'AGTCCGTACTTATGAGA' *.fastq > count/B4784_Fm0.txt
agrep -0 -c 'GATTCCCAACCTAGGAT' *.fastq > count/B4785_Fm0.txt
agrep -0 -c 'CTCAAAGGGCTGAACCC' *.fastq > count/B4786_Fm0.txt
agrep -0 -c 'ATCACATCGTATCCGTG' *.fastq > count/B4787_Fm0.txt
agrep -0 -c 'GACCTGCGCGGAAAATT' *.fastq > count/B4789_Fm0.txt
agrep -0 -c 'AGAGTTCCGAATAGCTT' *.fastq > count/B4790_Fm0.txt
agrep -0 -c 'GCGCTGCGAGGAAAATA' *.fastq > count/B4791_Fm0.txt
agrep -0 -c 'ATAGTAGTGTTCTGAGC' *.fastq > count/B4792_Fm0.txt
agrep -0 -c 'ATCTTGAACTCGGCTGC' *.fastq > count/B4793_Fm0.txt
agrep -0 -c 'GACACTTACCCGCCTCA' *.fastq > count/B4794_Fm0.txt
agrep -0 -c 'CTTCGGCGTCTTATACT' *.fastq > count/B4795_Fm0.txt
agrep -0 -c 'ATAACTTCTCCTGCCTT' *.fastq > count/B4796_Fm0.txt
agrep -0 -c 'AGTCACGCACCAATCCA' *.fastq > count/B4797_Fm0.txt
agrep -0 -c 'GCCTGTTCATTGAGTCC' *.fastq > count/B4799_Fm0.txt
agrep -0 -c 'CGTCCAGCACCTTCGTA' *.fastq > count/B4800_Fm0.txt
agrep -0 -c 'CGGATCGCTGCACCTTT' *.fastq > count/B4801_Fm0.txt
agrep -0 -c 'GGGAGGTTGCGAATTGT' *.fastq > count/B4802_Fm0.txt
agrep -0 -c 'GACTAAGGCAATGTTGT' *.fastq > count/B4803_Fm0.txt
agrep -0 -c 'GGAGCGACAAACACATA' *.fastq > count/B4804_Fm0.txt
agrep -0 -c 'CAACTGCCATTTCTTGA' *.fastq > count/B4806_Fm0.txt
agrep -0 -c 'CGCTTCTTAGGACGATT' *.fastq > count/B4807_Fm0.txt
agrep -0 -c 'GGTATGCAAGATACCAT' *.fastq > count/B4809_Fm0.txt
agrep -0 -c 'GGTCTACATCATGGCTT' *.fastq > count/B4810_Fm0.txt
agrep -0 -c 'GTTGGACTAGTCCCATT' *.fastq > count/B4811_Fm0.txt
agrep -0 -c 'AACGTGGGCACTAACTT' *.fastq > count/B4812_Fm0.txt
agrep -0 -c 'GTAGCATCATGGGAGAC' *.fastq > count/B4816_Fm0.txt
agrep -0 -c 'TATTCGACCATGGGCAC' *.fastq > count/B4817_Fm0.txt
agrep -0 -c 'AGTGATCCAACGGGGGA' *.fastq > count/B4818_Fm0.txt
agrep -0 -c 'CGAGCAGTATGCTCACT' *.fastq > count/B4819_Fm0.txt
agrep -0 -c 'GGAACGTAGAATACGAT' *.fastq > count/B4820_Fm0.txt
agrep -0 -c 'CACGTTGTGAAGTCCAA' *.fastq > count/B4821_Fm0.txt
agrep -0 -c 'GTTAGAAGTTGCCTTTG' *.fastq > count/B4822_Fm0.txt
agrep -0 -c 'GCAGGAGAAGTGAATAT' *.fastq > count/B4823_Fm0.txt
agrep -0 -c 'ATTTCGCCAACCTAAGA' *.fastq > count/B4825_Fm0.txt
agrep -0 -c 'GCAACTTTTTCCTCGTG' *.fastq > count/B4826_Fm0.txt
agrep -0 -c 'CTATAGGACGCCCGATA' *.fastq > count/B4827_Fm0.txt
agrep -0 -c 'TGAGCGATCTTAAATCG' *.fastq > count/B4828_Fm0.txt
agrep -0 -c 'AGACGGTTAACCTGGGG' *.fastq > count/B4829_Fm0.txt
agrep -0 -c 'AACGGCAGTCAGCACTA' *.fastq > count/B4830_Fm0.txt
agrep -0 -c 'GCGCAGAGAACCGTAAG' *.fastq > count/B4831_Fm0.txt
agrep -0 -c 'GCGTCTTCGTTACTAGA' *.fastq > count/B4833_Fm0.txt
agrep -0 -c 'AGGCCGAAACGGATCGA' *.fastq > count/B4834_Fm0.txt
agrep -0 -c 'GCTGTCCAAAAAACTGT' *.fastq > count/B4835_Fm0.txt
agrep -0 -c 'AATGCCGGGGGTAAGGA' *.fastq > count/B4836_Fm0.txt
agrep -0 -c 'GATCGGTAGCATTGATT' *.fastq > count/B4838_Fm0.txt
agrep -0 -c 'AACGCTATGCAACTCTC' *.fastq > count/B4839_Fm0.txt
agrep -0 -c 'AAGGTCGAAAATCGACC' *.fastq > count/B4840_Fm0.txt
agrep -0 -c 'ATATCCCCTAACGCATT' *.fastq > count/B4841_Fm0.txt
agrep -0 -c 'ACTCGACCTAACTTATG' *.fastq > count/B4842_Fm0.txt
agrep -0 -c 'GTGTCCATCGTTCAACG' *.fastq > count/B4844_Fm0.txt
agrep -0 -c 'CAAAGCGATTATACGCG' *.fastq > count/B4845_Fm0.txt
agrep -0 -c 'GTGGTGACTACACAGTA' *.fastq > count/B4846_Fm0.txt
agrep -0 -c 'CCAGGTTGTCCAAGAGG' *.fastq > count/B4847_Fm0.txt
agrep -0 -c 'CGCCAGTGTTACGTTCG' *.fastq > count/B4848_Fm0.txt
agrep -0 -c 'CCGTCGGATAAGGACGT' *.fastq > count/B4850_Fm0.txt
agrep -0 -c 'TACTTATGCCTTCCTCG' *.fastq > count/B4851_Fm0.txt
agrep -0 -c 'ATTACGGACAGGATTCG' *.fastq > count/B4852_Fm0.txt
agrep -0 -c 'TTCACGCGGTTTGTCGA' *.fastq > count/B4854_Fm0.txt
agrep -0 -c 'TATCAGAGCGAGAAGTG' *.fastq > count/B4855_Fm0.txt
agrep -0 -c 'GCCAGCTCACGATGAGT' *.fastq > count/B4856_Fm0.txt
agrep -0 -c 'CGGAACCCAATATACGG' *.fastq > count/B4857_Fm0.txt
agrep -0 -c 'CCGAATCTAAGTGGGGG' *.fastq > count/B4859_Fm0.txt
agrep -0 -c 'CGAGGGACAAAATTGGA' *.fastq > count/B4860_Fm0.txt
agrep -0 -c 'CTAGTGACCCTTACCGT' *.fastq > count/B4861_Fm0.txt
agrep -0 -c 'GATCGATAGCCATGACG' *.fastq > count/B4862_Fm0.txt
agrep -0 -c 'CGCACTGAGATAGGAAC' *.fastq > count/B4863_Fm0.txt
agrep -0 -c 'ACAACGAGAGTTGTTTC' *.fastq > count/B4865_Fm0.txt
agrep -0 -c 'CAATAGGTGGCTACTTT' *.fastq > count/B4866_Fm0.txt
agrep -0 -c 'CTCGGCTACTAAGTACG' *.fastq > count/B4867_Fm0.txt
agrep -0 -c 'CTCCGGTTGCTGTTTCC' *.fastq > count/B4868_Fm0.txt
agrep -0 -c 'TCAGGTCTAGTAGATGT' *.fastq > count/B4869_Fm0.txt
agrep -0 -c 'GTCTCCGATCTGGAGTA' *.fastq > count/B4871_Fm0.txt
agrep -0 -c 'TTAGGAGGAACTGGTGT' *.fastq > count/B4872_Fm0.txt
agrep -0 -c 'ACATTCCGCTCCCATCA' *.fastq > count/B4873_Fm0.txt
agrep -0 -c 'CAGCGGTTTAACGAAGA' *.fastq > count/B4875_Fm0.txt
agrep -0 -c 'GCTACCTTAATACAAGC' *.fastq > count/B4876_Fm0.txt
agrep -0 -c 'GTGTCACCTGTACGAGC' *.fastq > count/B4877_Fm0.txt
agrep -0 -c 'CCAAACGCTCCCTCACT' *.fastq > count/B4878_Fm0.txt
agrep -0 -c 'GGAGAATTACGCTTCAG' *.fastq > count/B4879_Fm0.txt
agrep -0 -c 'GCGAATCCATGTCAGGT' *.fastq > count/B4881_Fm0.txt
agrep -0 -c 'GGGTCTACTGAATCCTA' *.fastq > count/B4882_Fm0.txt
agrep -0 -c 'ACTCATATAGAGGCGTT' *.fastq > count/B4883_Fm0.txt
agrep -0 -c 'AGGAAGATGCACTCTAA' *.fastq > count/B4884_Fm0.txt
agrep -0 -c 'GTTCCGAACGGGATTTT' *.fastq > count/B4885_Fm0.txt
agrep -0 -c 'GTCACGAGTAGTTCCCA' *.fastq > count/B4886_Fm0.txt
agrep -0 -c 'TGACTCGACTAGATTCG' *.fastq > count/B4887_Fm0.txt
agrep -0 -c 'TCATACACGATCTGATC' *.fastq > count/B4888_Fm0.txt
agrep -0 -c 'AAGAACGTCGCGGTTTG' *.fastq > count/B4889_Fm0.txt
agrep -0 -c 'GTGGATTCCACGAGAGC' *.fastq > count/B4890_Fm0.txt
agrep -0 -c 'AGCCAATAAGTCCGGAT' *.fastq > count/B4891_Fm0.txt
agrep -0 -c 'CTTGGCAGTCTCGATCC' *.fastq > count/B4892_Fm0.txt
agrep -0 -c 'GGCCCGCGTTGACTTAT' *.fastq > count/B4894_Fm0.txt
agrep -0 -c 'TCTAACTTTATCGAGCG' *.fastq > count/B4896_Fm0.txt
agrep -0 -c 'AATTCCCCGTAGCAGCT' *.fastq > count/B4897_Fm0.txt
agrep -0 -c 'CTGACGCAGAGAATCGC' *.fastq > count/B4898_Fm0.txt
agrep -0 -c 'CTTCCACTCTCAGAACG' *.fastq > count/B4899_Fm0.txt
agrep -0 -c 'CACATGGGATACAACAC' *.fastq > count/B4900_Fm0.txt
agrep -0 -c 'GTTGACACTCGTGAGAA' *.fastq > count/B4901_Fm0.txt
agrep -0 -c 'GCGAGACGGTCTAGTTT' *.fastq > count/B4902_Fm0.txt
agrep -0 -c 'GTTCGTCGTCAGCTTAG' *.fastq > count/B4904_Fm0.txt
agrep -0 -c 'ACGTAAACAACGGCGTT' *.fastq > count/B4905_Fm0.txt
agrep -0 -c 'AGCCATGTAAAACCAAG' *.fastq > count/B4906_Fm0.txt
agrep -0 -c 'TAAGACGTCCATGAATG' *.fastq > count/B4907_Fm0.txt
agrep -0 -c 'CCGAGCACGTAACAGGT' *.fastq > count/B4909_Fm0.txt
agrep -0 -c 'CCTAGTACCCAATTGTA' *.fastq > count/B4910_Fm0.txt
agrep -0 -c 'TAGAGTTGCTTTCGGCC' *.fastq > count/B4911_Fm0.txt
agrep -0 -c 'CACCAGTTATAAGCGCA' *.fastq > count/B4912_Fm0.txt
agrep -0 -c 'TGTGGCTGCATTATACT' *.fastq > count/B4913_Fm0.txt
agrep -0 -c 'ATACGTTCAGCGACGAC' *.fastq > count/B4914_Fm0.txt
agrep -0 -c 'TACTCCCGGTCCTTCTC' *.fastq > count/B4915_Fm0.txt
agrep -0 -c 'ACGGCGGCAATCCTACT' *.fastq > count/B4916_Fm0.txt
agrep -0 -c 'GTACCTCGCAATACTAT' *.fastq > count/B4918_Fm0.txt
agrep -0 -c 'AACGATGACAGGGCCGA' *.fastq > count/B4919_Fm0.txt
agrep -0 -c 'CGTCGAATGCAGCCTTT' *.fastq > count/B4920_Fm0.txt
agrep -0 -c 'ACAGCATCCCCGCTTTT' *.fastq > count/B4921_Fm0.txt
agrep -0 -c 'CAAGGCGAATTAGTTGC' *.fastq > count/B4922_Fm0.txt
agrep -0 -c 'GCCCGTTTCCTAAAGCA' *.fastq > count/B4923_Fm0.txt
agrep -0 -c 'TAGCGCACACCTGTTCG' *.fastq > count/B4924_Fm0.txt
agrep -0 -c 'AACCGCCAGTGTATCGA' *.fastq > count/B4925_Fm0.txt
agrep -0 -c 'TTGCCTTACCCGGTAAT' *.fastq > count/B4926_Fm0.txt
agrep -0 -c 'CACAATCTACCAGCCTC' *.fastq > count/B4927_Fm0.txt
agrep -0 -c 'GGTTAGATTGCTGCAAT' *.fastq > count/B4928_Fm0.txt
agrep -0 -c 'CTAACCTGCATTCCTAT' *.fastq > count/B4929_Fm0.txt
agrep -0 -c 'GGCATGATCGGACTCAA' *.fastq > count/B4930_Fm0.txt
agrep -0 -c 'TGATGACCTTGTAGATG' *.fastq > count/B4932_Fm0.txt
agrep -0 -c 'CTTGGTCACTTAGCGGA' *.fastq > count/B4933_Fm0.txt
agrep -0 -c 'GGTGACTACCTAATGTG' *.fastq > count/B4936_Fm0.txt
agrep -0 -c 'CAACACCGTAAGAAGGC' *.fastq > count/B4937_Fm0.txt
agrep -0 -c 'GTCGAACCCTCCCTCAT' *.fastq > count/B4938_Fm0.txt
agrep -0 -c 'CAGTCTCACAACATCCC' *.fastq > count/B4939_Fm0.txt
agrep -0 -c 'AGTTGGACGTCCTGTGT' *.fastq > count/B4940_Fm0.txt
agrep -0 -c 'TCTTAAGTTCCTTCCCG' *.fastq > count/B4941_Fm0.txt
agrep -0 -c 'TCAAAAAATTCCGGCGA' *.fastq > count/B4942_Fm0.txt
agrep -0 -c 'TGAGCTCAGTTTGGCAA' *.fastq > count/B4943_Fm0.txt
agrep -0 -c 'AACCGTGAGATATGTAC' *.fastq > count/B4944_Fm0.txt
agrep -0 -c 'GGAGTACCATTGCGTAC' *.fastq > count/B4945_Fm0.txt
agrep -0 -c 'CAACTAGCGAAGGAAAT' *.fastq > count/B4946_Fm0.txt
agrep -0 -c 'AGCAACTAGTCCCGGTC' *.fastq > count/B4947_Fm0.txt
agrep -0 -c 'ACCTCCCACTTGATGGT' *.fastq > count/B4948_Fm0.txt
agrep -0 -c 'GACTCATCGTATGGATT' *.fastq > count/B4950_Fm0.txt
agrep -0 -c 'CAGAAGAATGCCCGGAT' *.fastq > count/B4951_Fm0.txt
agrep -0 -c 'ATACTGACCGCCGTCAA' *.fastq > count/B4952_Fm0.txt
agrep -0 -c 'CGACTTGCCTAGTAGCT' *.fastq > count/B4954_Fm0.txt
agrep -0 -c 'CAATTCATGAAGAGCAG' *.fastq > count/B4955_Fm0.txt
agrep -0 -c 'ACGTTGAAAGAGGCTAG' *.fastq > count/B4956_Fm0.txt
agrep -0 -c 'TGCAAGCGAAACTAGTG' *.fastq > count/B4958_Fm0.txt
agrep -0 -c 'AGTACGTACGACATGTT' *.fastq > count/B4959_Fm0.txt
agrep -0 -c 'ACTTGGCTTATGTGGTC' *.fastq > count/B4960_Fm0.txt
agrep -0 -c 'TCGTGAAAGATTGACGT' *.fastq > count/B4962_Fm0.txt
agrep -0 -c 'ACAACTTGAGCGATCCG' *.fastq > count/B4963_Fm0.txt
agrep -0 -c 'CAGCCCGTGCTAACGTT' *.fastq > count/B4964_Fm0.txt
agrep -0 -c 'GTTCCCAATCCTACTGC' *.fastq > count/B4965_Fm0.txt
agrep -0 -c 'TCTGCGGAAATGCGTAT' *.fastq > count/B4966_Fm0.txt
agrep -0 -c 'GGATTGGCACTACGTAA' *.fastq > count/B4968_Fm0.txt
agrep -0 -c 'CGCTACAAAATATCACG' *.fastq > count/B4969_Fm0.txt
agrep -0 -c 'CGACTTTCTTTTTGCCC' *.fastq > count/B4970_Fm0.txt
agrep -0 -c 'GATGTACATCGGACTTA' *.fastq > count/B4971_Fm0.txt
agrep -0 -c 'AGTAAAAGGGCGTCGGC' *.fastq > count/B4972_Fm0.txt
agrep -0 -c 'GCCAAGTCAATGAATGC' *.fastq > count/B4974_Fm0.txt
agrep -0 -c 'AGTGCCTGATCGGCCTA' *.fastq > count/B4975_Fm0.txt
agrep -0 -c 'TTGGCACACTTCTATCA' *.fastq > count/B4976_Fm0.txt
agrep -0 -c 'TATTACCCGCGAGCAGA' *.fastq > count/B4977_Fm0.txt
agrep -0 -c 'CTAGCTATGATCGTGTA' *.fastq > count/B4978_Fm0.txt
agrep -0 -c 'AACCCACGACAAAGACT' *.fastq > count/B4979_Fm0.txt
agrep -0 -c 'TGTAGGCTTGGTCTTTG' *.fastq > count/B4980_Fm0.txt
agrep -0 -c 'GCGACTCGTAATGTCCG' *.fastq > count/B4981_Fm0.txt
agrep -0 -c 'GTACTGGCTTCGTATAG' *.fastq > count/B4983_Fm0.txt
agrep -0 -c 'CCTAAGTTGACAAACCT' *.fastq > count/B4986_Fm0.txt
agrep -0 -c 'AGCAATCGTCCTCAGTT' *.fastq > count/B4987_Fm0.txt
agrep -0 -c 'CACGGCCAATCGTCAAA' *.fastq > count/B4989_Fm0.txt
agrep -0 -c 'TGCTATCCACAGAAGTA' *.fastq > count/B4990_Fm0.txt
agrep -0 -c 'ATGGATAACGGAGTCCT' *.fastq > count/B4991_Fm0.txt
agrep -0 -c 'CACAGACCCTAATGGGC' *.fastq > count/B4992_Fm0.txt
agrep -0 -c 'AACGTATCGCTGGGTCG' *.fastq > count/B4993_Fm0.txt
agrep -0 -c 'ACGGCTACAGTTCCAGG' *.fastq > count/B4995_Fm0.txt
agrep -0 -c 'CTCACAAGTGCTTCTCA' *.fastq > count/B4996_Fm0.txt
agrep -0 -c 'TAAACCTGGCCCCGTAG' *.fastq > count/B4997_Fm0.txt
agrep -0 -c 'CGGAATCGCTTCACATT' *.fastq > count/B4998_Fm0.txt
agrep -0 -c 'ATTGGTATCGTCACCAT' *.fastq > count/B4999_Fm0.txt
agrep -0 -c 'GGAATGTGAAAGGCCGC' *.fastq > count/B5001_Fm0.txt
agrep -0 -c 'GCCTCGCAAGTTTGATC' *.fastq > count/B5002_Fm0.txt
agrep -0 -c 'CACAGGTAGGGTCGTAC' *.fastq > count/B5003_Fm0.txt
agrep -0 -c 'CCTTCAAGGTATCTGCA' *.fastq > count/B5004_Fm0.txt
agrep -0 -c 'CCAACTTCTCAACTAGT' *.fastq > count/B5005_Fm0.txt
agrep -0 -c 'TGCCCTCGTTCGGGTAA' *.fastq > count/B5007_Fm0.txt
agrep -0 -c 'TACGACAAATGACACGA' *.fastq > count/B5009_Fm0.txt
agrep -0 -c 'ATGGTTCCCATCCCTAA' *.fastq > count/B5010_Fm0.txt
agrep -0 -c 'GATAGACTTGACAGGTT' *.fastq > count/B5011_Fm0.txt
agrep -0 -c 'CGCCAGATGCAACGCTA' *.fastq > count/B5012_Fm0.txt
agrep -0 -c 'GGTCGTTTTAGTACCTT' *.fastq > count/B5013_Fm0.txt
agrep -0 -c 'GTTCCGGGAGCAAGATG' *.fastq > count/B5014_Fm0.txt
agrep -0 -c 'GGATAAGCCTCCTCAGT' *.fastq > count/B5019_Fm0.txt
agrep -0 -c 'CCGGATGCTATGGCAGA' *.fastq > count/B5020_Fm0.txt
agrep -0 -c 'CTACCCGTAATCTCCGG' *.fastq > count/B5021_Fm0.txt
agrep -0 -c 'ACTCGATCCTCTCGGTA' *.fastq > count/B5022_Fm0.txt
agrep -0 -c 'GCAAGTCCAACTTCAGG' *.fastq > count/B5023_Fm0.txt
agrep -0 -c 'GTCTCATAGTGACAGTG' *.fastq > count/B5025_Fm0.txt
agrep -0 -c 'GTTCGTAATCAGTAACG' *.fastq > count/B5026_Fm0.txt
agrep -0 -c 'ATATCTCCGTGATTCGT' *.fastq > count/B5027_Fm0.txt
agrep -0 -c 'TTCCGTCTCCTTAGCTG' *.fastq > count/B5028_Fm0.txt
agrep -0 -c 'AGCTATGTAGCTGCTAC' *.fastq > count/B5029_Fm0.txt
agrep -0 -c 'GGATTCCGTAAGCCTGT' *.fastq > count/B5030_Fm0.txt
agrep -0 -c 'CTTCGCCAGTACCAGAG' *.fastq > count/B5031_Fm0.txt
agrep -0 -c 'GCGCCTATACAATTCAG' *.fastq > count/B5032_Fm0.txt
agrep -0 -c 'CCTTCACCTAAGTAGGC' *.fastq > count/B5034_Fm0.txt
agrep -0 -c 'ACGGGTAAATTCCTCTG' *.fastq > count/B5035_Fm0.txt
agrep -0 -c 'ATCCGGTTCAAGTCGAG' *.fastq > count/B5037_Fm0.txt
agrep -0 -c 'AAGGCGTACATGGTAAG' *.fastq > count/B5038_Fm0.txt
agrep -0 -c 'AGGGTCCTTCAGGCAAT' *.fastq > count/B5040_Fm0.txt
agrep -0 -c 'GAGAAACCGTACAAAAG' *.fastq > count/B5041_Fm0.txt
agrep -0 -c 'TCTGGGCCCCGAATAAA' *.fastq > count/B5042_Fm0.txt
agrep -0 -c 'TTCAGAAGGTGTCCATG' *.fastq > count/B5045_Fm0.txt
agrep -0 -c 'GCTCGGTCACTACAGGT' *.fastq > count/B5046_Fm0.txt
agrep -0 -c 'GTTAGCATGTGTAATGC' *.fastq > count/B5048_Fm0.txt
agrep -0 -c 'GACACGCTTATGCAATT' *.fastq > count/B5049_Fm0.txt
agrep -0 -c 'ATGCTCCTTATGTCCCC' *.fastq > count/B5050_Fm0.txt
agrep -0 -c 'GATTGTGGTTTCTGGAC' *.fastq > count/B5051_Fm0.txt
agrep -0 -c 'TGATACGAGAGCTTCCT' *.fastq > count/B5052_Fm0.txt
agrep -0 -c 'GAGGGCAGGACCAATTT' *.fastq > count/B5053_Fm0.txt
agrep -0 -c 'GACTAAGATCCGGCAGA' *.fastq > count/B5054_Fm0.txt
agrep -0 -c 'ACTGGGTGTCGTTGGCA' *.fastq > count/B5055_Fm0.txt
agrep -0 -c 'AGTGCTGGGCCAAAAAA' *.fastq > count/B5058_Fm0.txt
agrep -0 -c 'TAGTTCGATAAAGCCGC' *.fastq > count/B5062_Fm0.txt
agrep -0 -c 'CGCGATTACTAAGTCGA' *.fastq > count/B5063_Fm0.txt
agrep -0 -c 'CTAATGCGTCGATTACC' *.fastq > count/B5064_Fm0.txt
agrep -0 -c 'AGTTAAGCGGGCCTTCT' *.fastq > count/B5065_Fm0.txt
agrep -0 -c 'TTAACCCACTGGCAGTA' *.fastq > count/B5066_Fm0.txt
agrep -0 -c 'TGTACGTGCCCTCAGAC' *.fastq > count/B5067_Fm0.txt
agrep -0 -c 'GTCGGGTGTTATGTTGC' *.fastq > count/B5068_Fm0.txt
agrep -0 -c 'GATGGAACGGGAACCAC' *.fastq > count/B5069_Fm0.txt
agrep -0 -c 'CACGGGAAATGCAAGAT' *.fastq > count/B5070_Fm0.txt
agrep -0 -c 'CATCAGTCATCCAGCGA' *.fastq > count/B5071_Fm0.txt
agrep -0 -c 'AGAGTCCACTCGGTACA' *.fastq > count/B5072_Fm0.txt
agrep -0 -c 'ATGCGTAACAGGGCGGA' *.fastq > count/B5075_Fm0.txt
agrep -0 -c 'TGAGTACAGTACCTGGG' *.fastq > count/B5076_Fm0.txt
agrep -0 -c 'GAGGTAGTACTTCGGCT' *.fastq > count/B5077_Fm0.txt
agrep -0 -c 'ACGATGTACACCCTGCG' *.fastq > count/B5078_Fm0.txt
agrep -0 -c 'GCAATAACGTGTCCAAG' *.fastq > count/B5079_Fm0.txt
agrep -0 -c 'CAGATGGATACGTGCAA' *.fastq > count/B5080_Fm0.txt
agrep -0 -c 'CGTGCCAGGTCCACAAA' *.fastq > count/B5081_Fm0.txt
agrep -0 -c 'AAGCATATCTCTCGGGT' *.fastq > count/B5083_Fm0.txt
agrep -0 -c 'TGACCGGGAGGAATACT' *.fastq > count/B5084_Fm0.txt
agrep -0 -c 'ATCTACCACTCCCTATT' *.fastq > count/B5085_Fm0.txt
agrep -0 -c 'GGAATGCCTCCGATCAC' *.fastq > count/B5086_Fm0.txt
agrep -0 -c 'CCTACGGATAGTACCAG' *.fastq > count/B5087_Fm0.txt
agrep -0 -c 'CGCATGGTTTAATTCCT' *.fastq > count/B5088_Fm0.txt
agrep -0 -c 'TCTTGATGCATAGCTGG' *.fastq > count/B5089_Fm0.txt
agrep -0 -c 'GGCAACTTTAGGATCTG' *.fastq > count/B5090_Fm0.txt
agrep -0 -c 'TATTCGCTTTCCGGACA' *.fastq > count/B5091_Fm0.txt
agrep -0 -c 'CGGGAATCCAGTTATAC' *.fastq > count/B5092_Fm0.txt
agrep -0 -c 'CTTCGACCGCATAGTCG' *.fastq > count/B5093_Fm0.txt
agrep -0 -c 'TTATTCGCTGAAGCCTG' *.fastq > count/B5094_Fm0.txt
agrep -0 -c 'GTGAACTGAGCGGAGTT' *.fastq > count/B5095_Fm0.txt
agrep -0 -c 'CTGTATCGCAGGACGAC' *.fastq > count/B5096_Fm0.txt
agrep -0 -c 'CCGTTCCCAAACCCCTT' *.fastq > count/B5097_Fm0.txt
agrep -0 -c 'GCCGATGTCCTCGACTA' *.fastq > count/B5098_Fm0.txt
agrep -0 -c 'CACATTAGATCCGCGGC' *.fastq > count/B5099_Fm0.txt
agrep -0 -c 'GTCATCGATTCTAGCTC' *.fastq > count/B5100_Fm0.txt
agrep -0 -c 'TTATGGGGTCTTCATCG' *.fastq > count/B5101_Fm0.txt
agrep -0 -c 'TGCACTTTGCTTGGAAG' *.fastq > count/B5102_Fm0.txt
agrep -0 -c 'CGTGATCTTGCATATAC' *.fastq > count/B5103_Fm0.txt
agrep -0 -c 'GTTGAATCCGCACTACG' *.fastq > count/B5104_Fm0.txt
agrep -0 -c 'ACGGTGCGGAGAAAGTT' *.fastq > count/B5106_Fm0.txt
agrep -0 -c 'ATTAGGCGAGAAGTGCG' *.fastq > count/B5107_Fm0.txt
agrep -0 -c 'GTACTGACAGAGCACTC' *.fastq > count/B5108_Fm0.txt
agrep -0 -c 'TAGGGCGAATGACGTGC' *.fastq > count/B5109_Fm0.txt
agrep -0 -c 'CTAATCCTTCCGAGTAG' *.fastq > count/B5110_Fm0.txt
agrep -0 -c 'TATCGAGACGATACACA' *.fastq > count/B5111_Fm0.txt
agrep -0 -c 'GACGGCGCATAGGCAAA' *.fastq > count/B5113_Fm0.txt
agrep -0 -c 'TTACGGCTAGCGAGGTT' *.fastq > count/B5114_Fm0.txt
agrep -0 -c 'CGAGAACGTCTTAGCCG' *.fastq > count/B5115_Fm0.txt
agrep -0 -c 'TACTGGAATCGCGTTGC' *.fastq > count/B5116_Fm0.txt
agrep -0 -c 'ACGTGATGTCCGCAGCT' *.fastq > count/B5118_Fm0.txt
agrep -0 -c 'TTCAGTTGCGGAAACCT' *.fastq > count/B5119_Fm0.txt
agrep -0 -c 'CACATGAACAGCCGCGA' *.fastq > count/B5120_Fm0.txt
agrep -0 -c 'TCGAGTCACGGTAATGG' *.fastq > count/B5121_Fm0.txt
agrep -0 -c 'AGCCAGCTCCCTAATGT' *.fastq > count/B5122_Fm0.txt
agrep -0 -c 'TTCCGGTTTCGCTACGA' *.fastq > count/B5123_Fm0.txt
agrep -0 -c 'CACGGTGTTCGAAGGAT' *.fastq > count/B5124_Fm0.txt
agrep -0 -c 'CTCGGGCGCTTGTATTG' *.fastq > count/B5125_Fm0.txt
agrep -0 -c 'TCTATTTGCGCGGGAGT' *.fastq > count/B5126_Fm0.txt
agrep -0 -c 'TATAGCCGAGCTCCCTG' *.fastq > count/B5127_Fm0.txt
agrep -0 -c 'TCTTCACAGGCTGCAAG' *.fastq > count/B5128_Fm0.txt
agrep -0 -c 'GTATCTATTCGTTGGAG' *.fastq > count/B5129_Fm0.txt
agrep -0 -c 'AAGTACCGTACTCGAAG' *.fastq > count/B5131_Fm0.txt
agrep -0 -c 'AGAGCGTACCTTATGTT' *.fastq > count/B5132_Fm0.txt
agrep -0 -c 'TACACGATCTGGTCTAG' *.fastq > count/B5133_Fm0.txt
agrep -0 -c 'ATATTAGCTGTCCGATG' *.fastq > count/B5134_Fm0.txt
agrep -0 -c 'CAAATACAGATCGATGC' *.fastq > count/B5135_Fm0.txt
agrep -0 -c 'TAACAACCCGAAGTACT' *.fastq > count/B5136_Fm0.txt
agrep -0 -c 'CGCATATCTAGGGTCGT' *.fastq > count/B5137_Fm0.txt
agrep -0 -c 'GTGTGGTCTCATTGGCG' *.fastq > count/B5138_Fm0.txt
agrep -0 -c 'CGATCCCGTTATCGGAA' *.fastq > count/B5139_Fm0.txt
agrep -0 -c 'AGCCAGTTTGGAGTCGG' *.fastq > count/B5140_Fm0.txt
agrep -0 -c 'GGTTATTGACGACGAAA' *.fastq > count/B5141_Fm0.txt
agrep -0 -c 'GGTATAATACATGCCAC' *.fastq > count/B5142_Fm0.txt
agrep -0 -c 'ACAGTCGGTGATCTTTC' *.fastq > count/B5144_Fm0.txt
agrep -0 -c 'GCGCAGTGCTATATCGG' *.fastq > count/B5147_Fm0.txt
agrep -0 -c 'CAAAAGCCGACCCAACG' *.fastq > count/B5148_Fm0.txt
agrep -0 -c 'ACTGCAGTGATGTACGA' *.fastq > count/B5149_Fm0.txt
agrep -0 -c 'ACACGGGTGCTCAAATG' *.fastq > count/B5150_Fm0.txt
agrep -0 -c 'CCTGTGTAGTCTCACGT' *.fastq > count/B5151_Fm0.txt
agrep -0 -c 'CTAACACGGTGTCGTAC' *.fastq > count/B5152_Fm0.txt
agrep -0 -c 'CCTTGCCCGCTACTGAA' *.fastq > count/B5153_Fm0.txt
agrep -0 -c 'AGCGCGTGAGGAAGTAT' *.fastq > count/B5154_Fm0.txt
agrep -0 -c 'TTGTCGCTCTGTAGTAA' *.fastq > count/B5155_Fm0.txt
agrep -0 -c 'CTGTATCGAACTGCGGG' *.fastq > count/B5156_Fm0.txt
agrep -0 -c 'TAATAACGATGCCGGTC' *.fastq > count/B5158_Fm0.txt
agrep -0 -c 'TTAGCCCGCCATTTAAC' *.fastq > count/B5159_Fm0.txt
agrep -0 -c 'GTTAGTCTCCCCAACGG' *.fastq > count/B5160_Fm0.txt
agrep -0 -c 'ACGTTGACCGGTACGCA' *.fastq > count/B5161_Fm0.txt
agrep -0 -c 'GTAGGCTTGACCCAAGT' *.fastq > count/B5163_Fm0.txt
agrep -0 -c 'TAGAAACCTCGCTCATG' *.fastq > count/B5164_Fm0.txt
agrep -0 -c 'GGCTTGTCTGCGGTGTT' *.fastq > count/B5166_Fm0.txt
agrep -0 -c 'GTCACAGACGTATAGTG' *.fastq > count/B5168_Fm0.txt
agrep -0 -c 'TATTGATGGTGGAGCTC' *.fastq > count/B5169_Fm0.txt
agrep -0 -c 'ACCCATGCGGCAATCTA' *.fastq > count/B5170_Fm0.txt
agrep -0 -c 'TGAACTTGCCTTAGATC' *.fastq > count/B5171_Fm0.txt
agrep -0 -c 'GATACCCGGACTGCACA' *.fastq > count/B5172_Fm0.txt
agrep -0 -c 'TTACCGACTAATACCTG' *.fastq > count/B5174_Fm0.txt
agrep -0 -c 'ACCGACTCTAAGGATGA' *.fastq > count/B5176_Fm0.txt
agrep -0 -c 'GTTTCTAGAACTGGTCT' *.fastq > count/B5177_Fm0.txt
agrep -0 -c 'GCACAGTTACAACGAGT' *.fastq > count/B5180_Fm0.txt
agrep -0 -c 'GCGGGTCTTTCAAATCC' *.fastq > count/B5182_Fm0.txt
agrep -0 -c 'TGACCAGTACGTTGCTT' *.fastq > count/B5183_Fm0.txt
agrep -0 -c 'TACTCCAAGACCAACAG' *.fastq > count/B5184_Fm0.txt
agrep -0 -c 'ACACAAAGTGTCCTGGC' *.fastq > count/B5185_Fm0.txt
agrep -0 -c 'GAGCTGACAACTTTGCA' *.fastq > count/B5188_Fm0.txt
agrep -0 -c 'TGACGGAGATTACGTGT' *.fastq > count/B5189_Fm0.txt
agrep -0 -c 'CTTACTAGTCAGTACGG' *.fastq > count/B5190_Fm0.txt
agrep -0 -c 'CGGGCTTCGATATCAAT' *.fastq > count/B5191_Fm0.txt
agrep -0 -c 'AACCTTCAAAGTACGTC' *.fastq > count/B5192_Fm0.txt
agrep -0 -c 'TTACACGCATGCTGGAC' *.fastq > count/B5194_Fm0.txt
agrep -0 -c 'CATTTATCTCACCGGAG' *.fastq > count/B5195_Fm0.txt
agrep -0 -c 'TCATCAGTTGGTGTAAG' *.fastq > count/B5196_Fm0.txt
agrep -0 -c 'GTTTCGGACTTCAGCTT' *.fastq > count/B5197_Fm0.txt
agrep -0 -c 'GGTGTAACCCAGTATAG' *.fastq > count/B5198_Fm0.txt
agrep -0 -c 'AGACGTGTTCCATAGAT' *.fastq > count/B5199_Fm0.txt
agrep -0 -c 'AGGTCGTGGTCTGTTCC' *.fastq > count/B5200_Fm0.txt
agrep -0 -c 'GGGAGGACATCAGCACA' *.fastq > count/B5201_Fm0.txt
agrep -0 -c 'AATCTGCACGGGGTGGA' *.fastq > count/B5202_Fm0.txt
agrep -0 -c 'AGGGGACGCTGTCTAGT' *.fastq > count/B5203_Fm0.txt
agrep -0 -c 'GATACTACCTGAACGAA' *.fastq > count/B5204_Fm0.txt
agrep -0 -c 'GTATACGACCATACGCG' *.fastq > count/B5205_Fm0.txt
agrep -0 -c 'ATCATGAGATGACGGTC' *.fastq > count/B5206_Fm0.txt
agrep -0 -c 'CAGACGGACCTGAAACT' *.fastq > count/B5207_Fm0.txt
agrep -0 -c 'AGAGTAGTGAGCATTCA' *.fastq > count/B5209_Fm0.txt
agrep -0 -c 'CCTGGCATCGTTCCAAT' *.fastq > count/B5210_Fm0.txt
agrep -0 -c 'TTGGACTCTAATTTCGC' *.fastq > count/B5211_Fm0.txt
agrep -0 -c 'TGCCTCTTAACCGGCAA' *.fastq > count/B5212_Fm0.txt
agrep -0 -c 'CACGATATTCTGAGTTG' *.fastq > count/B5214_Fm0.txt
agrep -0 -c 'CGTTTGCTCCCAGAGTC' *.fastq > count/B5215_Fm0.txt
agrep -0 -c 'AAGGTAAGTGTAGACAG' *.fastq > count/B5216_Fm0.txt
agrep -0 -c 'AGAGACTAGATGTTGTG' *.fastq > count/B5217_Fm0.txt
agrep -0 -c 'ACGGGGTAGACAATAAA' *.fastq > count/B5218_Fm0.txt
agrep -0 -c 'CAGCATAGGACGGGAAC' *.fastq > count/B5220_Fm0.txt
agrep -0 -c 'TGACACTCTAAACACGT' *.fastq > count/B5221_Fm0.txt
agrep -0 -c 'ATAGGGTGGCACCAAGT' *.fastq > count/B5222_Fm0.txt
agrep -0 -c 'GGGCAAATCTACAGGTG' *.fastq > count/B5224_Fm0.txt
agrep -0 -c 'TGCATTCCCGGACTTAT' *.fastq > count/B5225_Fm0.txt
agrep -0 -c 'GGGAGTTTAGCGTTTAT' *.fastq > count/B5227_Fm0.txt
agrep -0 -c 'GATCCATACGTCCAGAT' *.fastq > count/B5228_Fm0.txt
agrep -0 -c 'CAAGCTAGTACGCGCAT' *.fastq > count/B5229_Fm0.txt
agrep -0 -c 'AGTTCAAGCGACGGTCA' *.fastq > count/B5230_Fm0.txt
agrep -0 -c 'CAGGCACGACTATCTTT' *.fastq > count/B5231_Fm0.txt
agrep -0 -c 'ATCGACATTCTAACCCG' *.fastq > count/B5232_Fm0.txt
agrep -0 -c 'CGATGGATAGCTAGGGA' *.fastq > count/B5233_Fm0.txt
agrep -0 -c 'AGTGGGGTACCGTCATT' *.fastq > count/B5234_Fm0.txt
agrep -0 -c 'CCGACAAATCGGCATTA' *.fastq > count/B5236_Fm0.txt
agrep -0 -c 'GATAGGGTAACGGTTAG' *.fastq > count/B5239_Fm0.txt
agrep -0 -c 'TAGCCCCCATTCGCGAA' *.fastq > count/B5240_Fm0.txt
agrep -0 -c 'ACCACCCTACTGAGGCT' *.fastq > count/B5241_Fm0.txt
agrep -0 -c 'TCGTAGGCGTAACCTGA' *.fastq > count/B5243_Fm0.txt
agrep -0 -c 'TGACGGATGCCAAATTG' *.fastq > count/B5244_Fm0.txt
agrep -0 -c 'GACCGTTCCCCTCAACT' *.fastq > count/B5245_Fm0.txt
agrep -0 -c 'GGCCTCCTCATTACCAG' *.fastq > count/B5246_Fm0.txt
agrep -0 -c 'GACTATCACATCGGGCG' *.fastq > count/B5248_Fm0.txt
agrep -0 -c 'GTACTGACCAATAAGCT' *.fastq > count/B5249_Fm0.txt
agrep -0 -c 'GACGCACTTGTCTATAT' *.fastq > count/B5250_Fm0.txt
agrep -0 -c 'GAGAGAATTCCGTACGC' *.fastq > count/B5252_Fm0.txt
agrep -0 -c 'TCACACAATTGTGTCAG' *.fastq > count/B5253_Fm0.txt
agrep -0 -c 'CGCCCGATCACTTAGTC' *.fastq > count/B5254_Fm0.txt
agrep -0 -c 'ACGGTAAACCTTGGTTC' *.fastq > count/B5255_Fm0.txt
agrep -0 -c 'GGGTGGCATCTAGATAT' *.fastq > count/B5256_Fm0.txt
agrep -0 -c 'ATGACATATGTGCGTAG' *.fastq > count/B5257_Fm0.txt
agrep -0 -c 'TCGGAAACAGGCACTGG' *.fastq > count/B5258_Fm0.txt
agrep -0 -c 'ACTGGGCAATCACCTTA' *.fastq > count/B5259_Fm0.txt
agrep -0 -c 'TCTGGTATCTATCAGGA' *.fastq > count/B5261_Fm0.txt
agrep -0 -c 'TGCGGTGTGGGTAGTTA' *.fastq > count/B5265_Fm0.txt
agrep -0 -c 'ACCTCTCATGTCAAGCG' *.fastq > count/B5266_Fm0.txt
agrep -0 -c 'CAGGAAGATATGGGCGG' *.fastq > count/B5267_Fm0.txt
agrep -0 -c 'TACCGAAAAGGTTGGTT' *.fastq > count/B5268_Fm0.txt
agrep -0 -c 'CCTAATCTTAATGCCCT' *.fastq > count/B5269_Fm0.txt
agrep -0 -c 'AGAGGCGAAATCGCAGA' *.fastq > count/B5270_Fm0.txt
agrep -0 -c 'CGTGGGCGGACAGATAA' *.fastq > count/B5271_Fm0.txt
agrep -0 -c 'TTGTTAACGGCGCTCTA' *.fastq > count/B5272_Fm0.txt
agrep -0 -c 'GATACGAAGGTCCTGCT' *.fastq > count/B5273_Fm0.txt
agrep -0 -c 'CACCGAACTTACGTATC' *.fastq > count/B5274_Fm0.txt
agrep -0 -c 'AAGAGACGATGTCTCTT' *.fastq > count/B5275_Fm0.txt
agrep -0 -c 'GCGTGTGGCAGCTAAGA' *.fastq > count/B5276_Fm0.txt
agrep -0 -c 'GTATACCCGAGATACTA' *.fastq > count/B5278_Fm0.txt
agrep -0 -c 'GCTCACATTCATACTCC' *.fastq > count/B5280_Fm0.txt
agrep -0 -c 'GTAATGACATGTTCAGC' *.fastq > count/B5281_Fm0.txt
agrep -0 -c 'TAGTCAAGCGCCAATAT' *.fastq > count/B5282_Fm0.txt
agrep -0 -c 'TCTTCTGGTTAGTTCCG' *.fastq > count/B5283_Fm0.txt
agrep -0 -c 'CGATTCCCTAGTTGGCG' *.fastq > count/B5284_Fm0.txt
agrep -0 -c 'GTCGTATTACCTCCGGG' *.fastq > count/B5285_Fm0.txt
agrep -0 -c 'CGAGGCAGCACCTTTAC' *.fastq > count/B5286_Fm0.txt
agrep -0 -c 'GTGTAATTCGGGGTGGA' *.fastq > count/B5289_Fm0.txt
agrep -0 -c 'TATCGATCTGGGCCAGC' *.fastq > count/B5290_Fm0.txt
agrep -0 -c 'GGTGGAGCGTGACATTA' *.fastq > count/B5294_Fm0.txt
agrep -0 -c 'CCAACTCTGCCACTGTA' *.fastq > count/B5295_Fm0.txt
agrep -0 -c 'CTAGGGGCTCTCAATTC' *.fastq > count/B5296_Fm0.txt
agrep -0 -c 'GCGTTTGGCTTCCTATT' *.fastq > count/B5297_Fm0.txt
agrep -0 -c 'TTAGACGGTATCAGGGG' *.fastq > count/B5298_Fm0.txt
agrep -0 -c 'CCGTATGGATCGATGAA' *.fastq > count/B5299_Fm0.txt
agrep -0 -c 'CACTTTCTTTTTGGTCG' *.fastq > count/B5300_Fm0.txt
agrep -0 -c 'CGGCGGGCTTTTAACCA' *.fastq > count/B5301_Fm0.txt
agrep -0 -c 'TCGATGGACTTCTCGGC' *.fastq > count/B5302_Fm0.txt
agrep -0 -c 'TTCCCTCCATTGCTAGC' *.fastq > count/B5303_Fm0.txt
agrep -0 -c 'ACCCGTTGCGCACTTGA' *.fastq > count/B5304_Fm0.txt
agrep -0 -c 'CGCCAGTTTCTACAGGG' *.fastq > count/B5305_Fm0.txt
agrep -0 -c 'GGCCTTAACAACGACGC' *.fastq > count/B5306_Fm0.txt
agrep -0 -c 'CGTCTGAACTGTGAGCG' *.fastq > count/B5307_Fm0.txt
agrep -0 -c 'GCATGCACCTGCTGAAG' *.fastq > count/B5308_Fm0.txt
agrep -0 -c 'AGAGCTGGCTTTGGCGA' *.fastq > count/B5310_Fm0.txt
agrep -0 -c 'AGCTTTAGTTACGTTCC' *.fastq > count/B5311_Fm0.txt
agrep -0 -c 'GAGCGTAGGTAAGCGTT' *.fastq > count/B5312_Fm0.txt
agrep -0 -c 'CACGATCGTGACGGAGA' *.fastq > count/B5313_Fm0.txt
agrep -0 -c 'TCTTGTGCCACTCATGA' *.fastq > count/B5314_Fm0.txt
agrep -0 -c 'ACAGCATAGTCCAGGAC' *.fastq > count/B5315_Fm0.txt
agrep -0 -c 'AGACGCTAGTTCCTATT' *.fastq > count/B5316_Fm0.txt
agrep -0 -c 'CCTCGTTCAGGAAGTAT' *.fastq > count/B5317_Fm0.txt
agrep -0 -c 'CACGTTAGTGCATACGA' *.fastq > count/B5318_Fm0.txt
agrep -0 -c 'GTACGTCCCGACTGTCA' *.fastq > count/B5320_Fm0.txt
agrep -0 -c 'CTAACTCTCGCTCCGGA' *.fastq > count/B5323_Fm0.txt
agrep -0 -c 'ATTAGCGAGTGACTGGA' *.fastq > count/B5324_Fm0.txt
agrep -0 -c 'GCGAGACAATGGTCAAC' *.fastq > count/B5325_Fm0.txt
agrep -0 -c 'CCTGTTTAAGAGTAGTC' *.fastq > count/B5326_Fm0.txt
agrep -0 -c 'CGCAGTATACTTTCAGA' *.fastq > count/B5327_Fm0.txt
agrep -0 -c 'ACTGACCCTTCGTTTGT' *.fastq > count/B5330_Fm0.txt
agrep -0 -c 'CGTCATTCCCGTACATA' *.fastq > count/B5331_Fm0.txt
agrep -0 -c 'GATTGAATGGTAACCGA' *.fastq > count/B5332_Fm0.txt
agrep -0 -c 'GCGCGCTCTCACTTTCT' *.fastq > count/B5333_Fm0.txt
agrep -0 -c 'AATACGTCGAGAGGACT' *.fastq > count/B5334_Fm0.txt
agrep -0 -c 'CGGTCCGACATATCATA' *.fastq > count/B5335_Fm0.txt
agrep -0 -c 'GGTTAGCCATTTGACCA' *.fastq > count/B5338_Fm0.txt
agrep -0 -c 'ATGCCAAGGCAGTCCAC' *.fastq > count/B5340_Fm0.txt
agrep -0 -c 'GTGATCTTGACTTCTCA' *.fastq > count/B5341_Fm0.txt
agrep -0 -c 'CATCCCATCCGGTAAAT' *.fastq > count/B5342_Fm0.txt
agrep -0 -c 'AGGTATTGGAAGCGATT' *.fastq > count/B5343_Fm0.txt
agrep -0 -c 'TTCGAGGCTAGCAGAAC' *.fastq > count/B5344_Fm0.txt
agrep -0 -c 'GACCATTGTGCAAGAAA' *.fastq > count/B5345_Fm0.txt
agrep -0 -c 'ATGCTTCAGTGTGATCT' *.fastq > count/B5347_Fm0.txt
agrep -0 -c 'TAGCAATGGAGCGCAGG' *.fastq > count/B5348_Fm0.txt
agrep -0 -c 'CCTAAAGACGAGTAACA' *.fastq > count/B5349_Fm0.txt
agrep -0 -c 'GTGATGATTGACACCCC' *.fastq > count/B5350_Fm0.txt
agrep -0 -c 'AATGGTTCGTACCGTGT' *.fastq > count/B5352_Fm0.txt
agrep -0 -c 'ACCTTGATCGCTGCACA' *.fastq > count/B5353_Fm0.txt
agrep -0 -c 'TCTTGCAACCCTCCAGT' *.fastq > count/B5355_Fm0.txt
agrep -0 -c 'AAGTACCCCTTGATTCC' *.fastq > count/B5356_Fm0.txt
agrep -0 -c 'ACGGACGTCCACTACTG' *.fastq > count/B5357_Fm0.txt
agrep -0 -c 'AACTTCTTCGCTTGCAG' *.fastq > count/B5358_Fm0.txt
agrep -0 -c 'TAAGACGGAACGCCTTT' *.fastq > count/B5359_Fm0.txt
agrep -0 -c 'ACATGAATTTTGGGCGA' *.fastq > count/B5360_Fm0.txt
agrep -0 -c 'TGGACGCGAATGGCTAA' *.fastq > count/B5361_Fm0.txt
agrep -0 -c 'GTGACATTGTCGATTAC' *.fastq > count/B5362_Fm0.txt
agrep -0 -c 'TCGCCGTTTCATATCGG' *.fastq > count/B5363_Fm0.txt
agrep -0 -c 'GCTCCACAAGAGCTCTT' *.fastq > count/B5365_Fm0.txt
agrep -0 -c 'CTTGCGATCAACTTCCC' *.fastq > count/B5366_Fm0.txt
agrep -0 -c 'TAGCTCCGCTAACCTTC' *.fastq > count/B5367_Fm0.txt
agrep -0 -c 'GCGTGATATGCAGTACT' *.fastq > count/B5368_Fm0.txt
agrep -0 -c 'CGGTATAGAATCGGGTG' *.fastq > count/B5369_Fm0.txt
agrep -0 -c 'ATGGAAGCTCGCCTACT' *.fastq > count/B5370_Fm0.txt
agrep -0 -c 'ACGTACAACTCAAACCG' *.fastq > count/B5371_Fm0.txt
agrep -0 -c 'TCGACAGCGAATCTCTT' *.fastq > count/B5372_Fm0.txt
agrep -0 -c 'CCTAAATAAGTGGCCAG' *.fastq > count/B5374_Fm0.txt
agrep -0 -c 'ACTCCCACTTGACTAAG' *.fastq > count/B5375_Fm0.txt
agrep -0 -c 'GTACTGCCAGAGCTGAC' *.fastq > count/B5376_Fm0.txt
agrep -0 -c 'CACGTTGGTACCAATGG' *.fastq > count/B5377_Fm0.txt
agrep -0 -c 'GATGTTGATGACGTTTC' *.fastq > count/B5378_Fm0.txt
agrep -0 -c 'ATATGGCCCCAGCCTAC' *.fastq > count/B5379_Fm0.txt
agrep -0 -c 'GGACTCCAGCCATGAAA' *.fastq > count/B5380_Fm0.txt
agrep -0 -c 'GACTCTAAATGACCCCG' *.fastq > count/B5381_Fm0.txt
agrep -0 -c 'AGCAGATGACTCCACGT' *.fastq > count/B5382_Fm0.txt
agrep -0 -c 'TTCATGTGCCTCGTTAC' *.fastq > count/B5384_Fm0.txt
agrep -0 -c 'TAGGAATGTCCCGGGGT' *.fastq > count/B5385_Fm0.txt
agrep -0 -c 'CACATCCACTAGATCTA' *.fastq > count/B5386_Fm0.txt
agrep -0 -c 'TATCGTAAGAAGGCGTA' *.fastq > count/B5387_Fm0.txt
agrep -0 -c 'CGAAGGAGACCTATCGA' *.fastq > count/B5388_Fm0.txt
agrep -0 -c 'CGCCAAAATGTACCGAT' *.fastq > count/B5389_Fm0.txt
agrep -0 -c 'TAGACGTCTGTTAGCTC' *.fastq > count/B5390_Fm0.txt
agrep -0 -c 'GGCGAACTCGATTTTGC' *.fastq > count/B5391_Fm0.txt
agrep -0 -c 'TAAGACCCTTCCTAATC' *.fastq > count/B5393_Fm0.txt
agrep -0 -c 'AGACGTACCTCGCGGAA' *.fastq > count/B5394_Fm0.txt
agrep -0 -c 'CGCTCATAATTGGATCT' *.fastq > count/B5395_Fm0.txt
agrep -0 -c 'AACTGCCGCATAGGTAG' *.fastq > count/B5397_Fm0.txt
agrep -0 -c 'CGTTATAATTGACCTCC' *.fastq > count/B5398_Fm0.txt
agrep -0 -c 'TAATGCCAGTGATCCTG' *.fastq > count/B5399_Fm0.txt
agrep -0 -c 'GCTTGGTACCGATGAAG' *.fastq > count/B5400_Fm0.txt
agrep -0 -c 'GACGATGTGCCTCACAA' *.fastq > count/B5401_Fm0.txt
agrep -0 -c 'TCTGTTGTCGTTGATCC' *.fastq > count/B5402_Fm0.txt
agrep -0 -c 'CGACAACACGCAATCAC' *.fastq > count/B5405_Fm0.txt
agrep -0 -c 'ACACTTCGTTGGACTAC' *.fastq > count/B5406_Fm0.txt
agrep -0 -c 'CCAGGCCAATTGTCGTC' *.fastq > count/B5407_Fm0.txt
agrep -0 -c 'ATCCTCTTATCGTAGGT' *.fastq > count/B5408_Fm0.txt
agrep -0 -c 'CGACCGGAAAACTCGCT' *.fastq > count/B5410_Fm0.txt
agrep -0 -c 'TGTAACCGCTAACCGAG' *.fastq > count/B5411_Fm0.txt
agrep -0 -c 'TGATGAGGTCCGCTAAC' *.fastq > count/B5412_Fm0.txt
agrep -0 -c 'GCCATTCATCGATCTTC' *.fastq > count/B5413_Fm0.txt
agrep -0 -c 'AGTGTATCTGTGCTTCG' *.fastq > count/B5414_Fm0.txt
agrep -0 -c 'TCGTCCTTTAGTACAGA' *.fastq > count/B5415_Fm0.txt
agrep -0 -c 'GTCACAGGTCGATGTTT' *.fastq > count/B5416_Fm0.txt
agrep -0 -c 'AAGGGATGAACACACGC' *.fastq > count/B5417_Fm0.txt
agrep -0 -c 'ATATGTCTAAGGGGTCA' *.fastq > count/B5418_Fm0.txt
agrep -0 -c 'TACTCTTTTACGTGCCA' *.fastq > count/B5420_Fm0.txt
agrep -0 -c 'GCAGTTTGCAATTCGCG' *.fastq > count/B5421_Fm0.txt
agrep -0 -c 'GGATAACGACATCGAAG' *.fastq > count/B5422_Fm0.txt
agrep -0 -c 'CGGTTATAGCGCAACGA' *.fastq > count/B5423_Fm0.txt
agrep -0 -c 'ATGGTGTTCAAGACCCG' *.fastq > count/B5424_Fm0.txt
agrep -0 -c 'CCTATCACGACCGCAAA' *.fastq > count/B5425_Fm0.txt
agrep -0 -c 'TGAAGTACCAGTTTAGC' *.fastq > count/B5426_Fm0.txt
agrep -0 -c 'ACGCGTTTACCACTCCC' *.fastq > count/B5429_Fm0.txt
agrep -0 -c 'GACGTAAATTCGGCCTT' *.fastq > count/B5431_Fm0.txt
agrep -0 -c 'TGAATCTGGCGAGAATC' *.fastq > count/B5432_Fm0.txt
agrep -0 -c 'ACGTTGCGTGCTCTGGA' *.fastq > count/B5433_Fm0.txt
agrep -0 -c 'CAATTCGTTCCTCTCAC' *.fastq > count/B5435_Fm0.txt
agrep -0 -c 'CTGAGTTACCTCAGAGG' *.fastq > count/B5436_Fm0.txt
agrep -0 -c 'CATTAGTTCCCACGGAT' *.fastq > count/B5437_Fm0.txt
agrep -0 -c 'GCTTCAATTGTGGAAGG' *.fastq > count/B5439_Fm0.txt
agrep -0 -c 'ACGAGATTCATTGGCGT' *.fastq > count/B5440_Fm0.txt
agrep -0 -c 'CCGAGTATTGTCCCTCT' *.fastq > count/B5442_Fm0.txt
agrep -0 -c 'ATCGCCCTAGCATAGAG' *.fastq > count/B5443_Fm0.txt
agrep -0 -c 'CGCAAATCACAACGCAG' *.fastq > count/B5444_Fm0.txt
agrep -0 -c 'TACCATACCCCGGATAG' *.fastq > count/B5445_Fm0.txt
agrep -0 -c 'TCATCCGCTTCAGCATA' *.fastq > count/B5447_Fm0.txt
agrep -0 -c 'AAGTTTATGCAGACCGC' *.fastq > count/B5448_Fm0.txt
agrep -0 -c 'CAGGTAAGTTAGAAAGG' *.fastq > count/B5449_Fm0.txt
agrep -0 -c 'TAGCATTCAAGTCGCTC' *.fastq > count/B5450_Fm0.txt
agrep -0 -c 'TTCTGGTTCGTGCAGTT' *.fastq > count/B5452_Fm0.txt
agrep -0 -c 'ATCCACGAATGTCGATC' *.fastq > count/B5453_Fm0.txt
agrep -0 -c 'AGGGAGACACACCTCGT' *.fastq > count/B5454_Fm0.txt
agrep -0 -c 'TGCCCACTCGATAGAGT' *.fastq > count/B5455_Fm0.txt
agrep -0 -c 'ATGGTTTAAAGGTGCGC' *.fastq > count/B5456_Fm0.txt
agrep -0 -c 'CTACTCACGTAGCCAGT' *.fastq > count/B5457_Fm0.txt
agrep -0 -c 'TATCCGCTATTGCCAAA' *.fastq > count/B5458_Fm0.txt
agrep -0 -c 'ATGGGAGTGACCACGTC' *.fastq > count/B5459_Fm0.txt
agrep -0 -c 'CATAAACGTGCTCCGGC' *.fastq > count/B5460_Fm0.txt
agrep -0 -c 'CTAAGAGCAGCGGAGAA' *.fastq > count/B5462_Fm0.txt
agrep -0 -c 'ACACAAGAGGGTTTCAT' *.fastq > count/B5463_Fm0.txt
agrep -0 -c 'ATTTGGAACTGCGGCAG' *.fastq > count/B5464_Fm0.txt
agrep -0 -c 'CGCTATTACTGAATCCG' *.fastq > count/B5465_Fm0.txt
agrep -0 -c 'CTCAACCGACTTTCCTT' *.fastq > count/B5466_Fm0.txt
agrep -0 -c 'TGAATGTCCCGAATCCG' *.fastq > count/B5467_Fm0.txt
agrep -0 -c 'GAGCTGTAACTCCCGCT' *.fastq > count/B5468_Fm0.txt
agrep -0 -c 'ACGCGTTAAGCCTCCAC' *.fastq > count/B5470_Fm0.txt
agrep -0 -c 'GCTGGATATTCAATGCT' *.fastq > count/B5471_Fm0.txt
agrep -0 -c 'ACGATCGGATCCTAGTC' *.fastq > count/B5472_Fm0.txt
agrep -0 -c 'TTAGCCGAGCGATAGGC' *.fastq > count/B5473_Fm0.txt
agrep -0 -c 'TAACGTAATCCGGTCCG' *.fastq > count/B5474_Fm0.txt
agrep -0 -c 'ACTTCGGAGTGTCCGAA' *.fastq > count/B5475_Fm0.txt
agrep -0 -c 'AAGTTGAAGTCCCTTCA' *.fastq > count/B5476_Fm0.txt
agrep -0 -c 'CTTGCTAGCGTGGGAAC' *.fastq > count/B5478_Fm0.txt
agrep -0 -c 'GCTAGGACACGACTTCC' *.fastq > count/B5479_Fm0.txt
agrep -0 -c 'ATCGCAAAACTAGGGTT' *.fastq > count/B5480_Fm0.txt
agrep -0 -c 'TTACCGGAGAGCAGACC' *.fastq > count/B5482_Fm0.txt
agrep -0 -c 'GCAGGTAACTATCGTTA' *.fastq > count/B5483_Fm0.txt
agrep -0 -c 'CAAAATGGTCACCGATT' *.fastq > count/B5484_Fm0.txt
agrep -0 -c 'CCACTGACGGTTTATCG' *.fastq > count/B5485_Fm0.txt
agrep -0 -c 'GACAATCAGGAAGAACT' *.fastq > count/B5486_Fm0.txt
agrep -0 -c 'CAGTGTAGAGATGCCGC' *.fastq > count/B5487_Fm0.txt
agrep -0 -c 'ACCTTAACTCCGTAGAA' *.fastq > count/B5488_Fm0.txt
agrep -0 -c 'CAGGTCAATACGGCATA' *.fastq > count/B5489_Fm0.txt
agrep -0 -c 'ACTTGCTGCCATATGGG' *.fastq > count/B5491_Fm0.txt
agrep -0 -c 'AGTCCCTGTTGGCATAT' *.fastq > count/B5492_Fm0.txt
agrep -0 -c 'GCCTGATGGTATGGAAC' *.fastq > count/B5493_Fm0.txt
agrep -0 -c 'ATACGATGGCTAAATGC' *.fastq > count/B5494_Fm0.txt
agrep -0 -c 'CAGTGTCGCACTAGATA' *.fastq > count/B5496_Fm0.txt
agrep -0 -c 'AGCCTGGTGGATGCGTA' *.fastq > count/B5497_Fm0.txt
agrep -0 -c 'TCGGCAATCGATTGGGT' *.fastq > count/B5500_Fm0.txt
agrep -0 -c 'CTTCACACCGGTTACGG' *.fastq > count/B5501_Fm0.txt
agrep -0 -c 'AGGTGTCAGTGCAAGCC' *.fastq > count/B5502_Fm0.txt
agrep -0 -c 'GAGCCGTAAAATCCAGA' *.fastq > count/B5503_Fm0.txt
agrep -0 -c 'TAAACTAAGGACGAGAG' *.fastq > count/B5504_Fm0.txt
agrep -0 -c 'CAATCCCTTCCGTATTT' *.fastq > count/B5505_Fm0.txt
agrep -0 -c 'CGGTTACCGCTATGTAC' *.fastq > count/B5507_Fm0.txt
agrep -0 -c 'GGTCAATAGCATACATG' *.fastq > count/B5508_Fm0.txt
agrep -0 -c 'TCGGATAAAGACGCTAT' *.fastq > count/B5510_Fm0.txt
agrep -0 -c 'GGTGCCCATTGATCATG' *.fastq > count/B5511_Fm0.txt
agrep -0 -c 'GGATCCTTCGGTGAAGC' *.fastq > count/B5512_Fm0.txt
agrep -0 -c 'CAATCATAGCAACACTC' *.fastq > count/B5513_Fm0.txt
agrep -0 -c 'GTCCAGCGTAAGACCTA' *.fastq > count/B5514_Fm0.txt
agrep -0 -c 'CGAATTCCTCGACACTT' *.fastq > count/B5515_Fm0.txt
agrep -0 -c 'CACCGAGTTGTGTAACG' *.fastq > count/B5516_Fm0.txt
agrep -0 -c 'GTGATTTAGTTCCCCAA' *.fastq > count/B5518_Fm0.txt
agrep -0 -c 'CATGTCAATCACTCCGC' *.fastq > count/B5520_Fm0.txt
agrep -0 -c 'TTCGTATCTACGCACGA' *.fastq > count/B5522_Fm0.txt
agrep -0 -c 'CTAAGGATTCGCATTGC' *.fastq > count/B5523_Fm0.txt
agrep -0 -c 'GTGCTGAAATCAATGCG' *.fastq > count/B5524_Fm0.txt
agrep -0 -c 'TATGTCTGTCGTAAGGG' *.fastq > count/B5525_Fm0.txt
agrep -0 -c 'CATGTAGTAAGTCTGGA' *.fastq > count/B5526_Fm0.txt
agrep -0 -c 'CGTGCAGCGAGACGTAA' *.fastq > count/B5527_Fm0.txt
agrep -0 -c 'CGGGCTGATTATCAAAA' *.fastq > count/B5530_Fm0.txt
agrep -0 -c 'GTTCGGGTAACGGGCAA' *.fastq > count/B5531_Fm0.txt
agrep -0 -c 'GTGAGCTTTAGTGAATC' *.fastq > count/B5532_Fm0.txt
agrep -0 -c 'AATCGGCTAGCGCAGCT' *.fastq > count/B5533_Fm0.txt
agrep -0 -c 'TACCAGGTGCTGATGTA' *.fastq > count/B5537_Fm0.txt
agrep -0 -c 'TTACACCTATCGAGGCC' *.fastq > count/B5538_Fm0.txt
agrep -0 -c 'GTCATGTTAGCGCATCC' *.fastq > count/B5539_Fm0.txt
agrep -0 -c 'CTGGGAGTCACTATGAT' *.fastq > count/B5540_Fm0.txt
agrep -0 -c 'AATAGGTTCCACCGCAT' *.fastq > count/B5541_Fm0.txt
agrep -0 -c 'CATAGTCACTCAATCCA' *.fastq > count/B5542_Fm0.txt
agrep -0 -c 'GATTAGGGCGCTTTACG' *.fastq > count/B5543_Fm0.txt
agrep -0 -c 'GTCGCCAACTCAAGTGG' *.fastq > count/B5544_Fm0.txt
agrep -0 -c 'ATCGGCCAGATAGCATC' *.fastq > count/B5545_Fm0.txt
agrep -0 -c 'CACGGCGAATTCACTGA' *.fastq > count/B5546_Fm0.txt
agrep -0 -c 'ATAGTTGCCGACTCTAG' *.fastq > count/B5549_Fm0.txt
agrep -0 -c 'AGCCAACACGCTTACTG' *.fastq > count/B5550_Fm0.txt
agrep -0 -c 'GTGCCTTCGTGTGTCTG' *.fastq > count/B5551_Fm0.txt
agrep -0 -c 'TAATGGTACGTATCCCG' *.fastq > count/B5552_Fm0.txt
agrep -0 -c 'GGAAGGTAATAGACGGC' *.fastq > count/B5553_Fm0.txt
agrep -0 -c 'GGCGGGTGTCTATCAAC' *.fastq > count/B5554_Fm0.txt
agrep -0 -c 'CAACCTCCAACACGGTG' *.fastq > count/B5555_Fm0.txt
agrep -0 -c 'GATCTATTCCTAGCCCA' *.fastq > count/B5556_Fm0.txt
agrep -0 -c 'ACTGCATGTTCTCCAAC' *.fastq > count/B5557_Fm0.txt
agrep -0 -c 'CTGAGTAGTGGTCAGGC' *.fastq > count/B5559_Fm0.txt
agrep -0 -c 'AGACACGAGTCCTACAA' *.fastq > count/B5560_Fm0.txt
agrep -0 -c 'TGCCCTTCGATTTAGAG' *.fastq > count/B5562_Fm0.txt
agrep -0 -c 'TGATCTAGTTACCCTCT' *.fastq > count/B5563_Fm0.txt
agrep -0 -c 'CCTAGCCATCGTCAATG' *.fastq > count/B5564_Fm0.txt
agrep -0 -c 'GCGAGAAAGAATTGCAG' *.fastq > count/B5565_Fm0.txt
agrep -0 -c 'AGCCTAGGATGCCTTTC' *.fastq > count/B5566_Fm0.txt
agrep -0 -c 'CTATGACACGGTATCTC' *.fastq > count/B5567_Fm0.txt
agrep -0 -c 'AGATTTCGAGCAGATAC' *.fastq > count/B5571_Fm0.txt
agrep -0 -c 'CTTCGTCCCACCACTAT' *.fastq > count/B5572_Fm0.txt
agrep -0 -c 'ACGTGTGAACTAATAGG' *.fastq > count/B5573_Fm0.txt
agrep -0 -c 'AGGATAGCAGCGTGACT' *.fastq > count/B5574_Fm0.txt
agrep -0 -c 'TATCGTTAGGTAACTGC' *.fastq > count/B5576_Fm0.txt
agrep -0 -c 'CCGAATTCTACATGCAC' *.fastq > count/B5577_Fm0.txt
agrep -0 -c 'TCAGTGTGGTGTCCGAA' *.fastq > count/B5578_Fm0.txt
agrep -0 -c 'ATTTATGCGGCCTCTCC' *.fastq > count/B5579_Fm0.txt
agrep -0 -c 'TGTTCCCGCGACTTAAT' *.fastq > count/B5580_Fm0.txt
agrep -0 -c 'AGCGATGCTATGGACAA' *.fastq > count/B5581_Fm0.txt
agrep -0 -c 'CTTCTCGTGCATGAGTA' *.fastq > count/B5582_Fm0.txt
agrep -0 -c 'TTGCGGTCCTCCCACAT' *.fastq > count/B5585_Fm0.txt
agrep -0 -c 'GGTCGTACGCTGACGTA' *.fastq > count/B5586_Fm0.txt
agrep -0 -c 'CTTCGCAACCATTAGGC' *.fastq > count/B5587_Fm0.txt
agrep -0 -c 'CACCGTTAATTTCGCAC' *.fastq > count/B5588_Fm0.txt
agrep -0 -c 'TTAATTCCGCCTACCAG' *.fastq > count/B5591_Fm0.txt
agrep -0 -c 'CTGCCGCGATCGTTATA' *.fastq > count/B5592_Fm0.txt
agrep -0 -c 'ATCTAGATGCGGGATGG' *.fastq > count/B5593_Fm0.txt
agrep -0 -c 'TACCTAGTATACAGAGG' *.fastq > count/B5595_Fm0.txt
agrep -0 -c 'GCTGAAGGGGGTTTCTC' *.fastq > count/B5596_Fm0.txt
agrep -0 -c 'CCACCTCCCGTCATTAA' *.fastq > count/B5597_Fm0.txt
agrep -0 -c 'AGGTGCTGTACAACTCC' *.fastq > count/B5599_Fm0.txt
agrep -0 -c 'TACCCCAGAAATCCGAG' *.fastq > count/B5600_Fm0.txt
agrep -0 -c 'TAGTTGGAAATTCCCCT' *.fastq > count/B5601_Fm0.txt
agrep -0 -c 'CTCCACTGTACTAGCTA' *.fastq > count/B5602_Fm0.txt
agrep -0 -c 'AGTGTAACTCGCGAGAA' *.fastq > count/B5603_Fm0.txt
agrep -0 -c 'AGGTGGTTACATACACG' *.fastq > count/B5604_Fm0.txt
agrep -0 -c 'TATGGTCTCCGTGTCCG' *.fastq > count/B5606_Fm0.txt
agrep -0 -c 'AAGCCATGGTGTCTACG' *.fastq > count/B5607_Fm0.txt
agrep -0 -c 'TTCAGTCCACAGGATTA' *.fastq > count/B5608_Fm0.txt
agrep -0 -c 'GCACGAACGTGAATTCT' *.fastq > count/B5609_Fm0.txt
agrep -0 -c 'AGCATGGAAGACTGGTC' *.fastq > count/B5610_Fm0.txt
agrep -0 -c 'GGAGGTTCTTAAGGGCA' *.fastq > count/B5611_Fm0.txt
agrep -0 -c 'CCGGTCATCTATCGTCA' *.fastq > count/B5612_Fm0.txt
agrep -0 -c 'ATCAATTGTGGCCCGTG' *.fastq > count/B5614_Fm0.txt
agrep -0 -c 'GTGAAATTCATCGGAAC' *.fastq > count/B5615_Fm0.txt
agrep -0 -c 'TTGTGCGTAGTCGGAGA' *.fastq > count/B5616_Fm0.txt
agrep -0 -c 'ACCCGAATAGAGCATCT' *.fastq > count/B5617_Fm0.txt
agrep -0 -c 'ATGGAAGTGGGACGTTA' *.fastq > count/B5618_Fm0.txt
agrep -0 -c 'CCATGTCTAACCCGTAC' *.fastq > count/B5621_Fm0.txt
agrep -0 -c 'GTGTCCGTTTGCGACAG' *.fastq > count/B5622_Fm0.txt
agrep -0 -c 'TGTAGGGGGAGTATTTG' *.fastq > count/B5623_Fm0.txt
agrep -0 -c 'GTGGACTCGTTCGGTTT' *.fastq > count/B5624_Fm0.txt
agrep -0 -c 'ACAACGCGGGTATTTTA' *.fastq > count/B5625_Fm0.txt
agrep -0 -c 'GGCCACCAGCACAATAA' *.fastq > count/B5626_Fm0.txt
agrep -0 -c 'TAAAGTGAAGTAGTGCG' *.fastq > count/B5627_Fm0.txt
agrep -0 -c 'ACCCGATCCATTCATTA' *.fastq > count/B5629_Fm0.txt
agrep -0 -c 'CAGTGTTTCGATCATCA' *.fastq > count/B5630_Fm0.txt
agrep -0 -c 'AGCACGGGCTTATCGTG' *.fastq > count/B5631_Fm0.txt
agrep -0 -c 'TTCGCGGCCCATTCCAT' *.fastq > count/B5632_Fm0.txt
agrep -0 -c 'TGTGCGCGAATTCCTGC' *.fastq > count/B5634_Fm0.txt
agrep -0 -c 'CACCAGTTTCTTGTACG' *.fastq > count/B5635_Fm0.txt
agrep -0 -c 'CGCATCCATTAGTGATT' *.fastq > count/B5636_Fm0.txt
agrep -0 -c 'CAGCTGGTTGTATGCGA' *.fastq > count/B5637_Fm0.txt
agrep -0 -c 'TCAGACCACCTTATGTC' *.fastq > count/B5638_Fm0.txt
agrep -0 -c 'GGTGTGAAGGAATAGGT' *.fastq > count/B5639_Fm0.txt
agrep -0 -c 'TAGAGGTCATGCACTGA' *.fastq > count/B5641_Fm0.txt
agrep -0 -c 'AACCGTAACCTGGGTCG' *.fastq > count/B5642_Fm0.txt
agrep -0 -c 'CTACTTTCCTAGTGTGC' *.fastq > count/B5643_Fm0.txt
agrep -0 -c 'CGTAACTCATTTACCTG' *.fastq > count/B5645_Fm0.txt
agrep -0 -c 'TAGTGAGCTCGGGTAAC' *.fastq > count/B5646_Fm0.txt
agrep -0 -c 'GCATGGTCGCTTGTGAA' *.fastq > count/B5647_Fm0.txt
agrep -0 -c 'CAGCCGGCAAATAAGGG' *.fastq > count/B5648_Fm0.txt
agrep -0 -c 'CAGGCATGAGCCGTTAT' *.fastq > count/B5649_Fm0.txt
agrep -0 -c 'TCGGATAGCGTCAAGGT' *.fastq > count/B5650_Fm0.txt
agrep -0 -c 'CGACGCTCTAGTCTCCT' *.fastq > count/B5651_Fm0.txt
agrep -0 -c 'GATTGCACCATCATTCC' *.fastq > count/B5652_Fm0.txt
agrep -0 -c 'GGGGCCGACACTATGAA' *.fastq > count/B5653_Fm0.txt
agrep -0 -c 'CATGACTCGTATCGATG' *.fastq > count/B5655_Fm0.txt
agrep -0 -c 'GCCCTAACAGTCGATGC' *.fastq > count/B5658_Fm0.txt
agrep -0 -c 'CCATTCAAGCTCGAATT' *.fastq > count/B5659_Fm0.txt
agrep -0 -c 'GTAGAAAGTTACAGCGC' *.fastq > count/B5660_Fm0.txt
agrep -0 -c 'CCGTACGCCTTCGTCTA' *.fastq > count/B5661_Fm0.txt
agrep -0 -c 'CTCTACAAACTAGTTGC' *.fastq > count/B5662_Fm0.txt
agrep -0 -c 'CAGTTTTTAGGAGGTGT' *.fastq > count/B5663_Fm0.txt
agrep -0 -c 'TTATGGAGTTGATTGCC' *.fastq > count/B5664_Fm0.txt
agrep -0 -c 'TAGTGAAAGAGTGGCAA' *.fastq > count/B5665_Fm0.txt
agrep -0 -c 'AGAACGGTGACTAGAGT' *.fastq > count/B5666_Fm0.txt
agrep -0 -c 'ACTACGCTAGGTTGGTA' *.fastq > count/B5668_Fm0.txt
agrep -0 -c 'TGCACACGACCTCATAC' *.fastq > count/B5669_Fm0.txt
agrep -0 -c 'CGAGCTCACTCAAACAG' *.fastq > count/B5670_Fm0.txt
agrep -0 -c 'CTGTTACCCGATTCGTG' *.fastq > count/B5671_Fm0.txt
agrep -0 -c 'AGACCACTACCTGTGTA' *.fastq > count/B5672_Fm0.txt
agrep -0 -c 'ACAGCGACGCTTCAAAG' *.fastq > count/B5673_Fm0.txt
agrep -0 -c 'TGGCTCAGGTCGGGTTT' *.fastq > count/B5674_Fm0.txt
agrep -0 -c 'CCACCGATTCCTACTTG' *.fastq > count/B5675_Fm0.txt
agrep -0 -c 'CGTATTGCAACGACCCT' *.fastq > count/B5676_Fm0.txt
agrep -0 -c 'TACACAGATAGCGGGCT' *.fastq > count/B5677_Fm0.txt
agrep -0 -c 'AACCCTCTGACGCCACT' *.fastq > count/B5678_Fm0.txt
agrep -0 -c 'AGCCCACTATCTTGCTC' *.fastq > count/B5679_Fm0.txt
agrep -0 -c 'TTCCGCTTCTGGCCATC' *.fastq > count/B5680_Fm0.txt
agrep -0 -c 'CCATGGCCGAGCAAAAC' *.fastq > count/B5681_Fm0.txt
agrep -0 -c 'GCAGGAGGAAAGCGATA' *.fastq > count/B5683_Fm0.txt
agrep -0 -c 'CCGGATACATCGTTGTA' *.fastq > count/B5684_Fm0.txt
agrep -0 -c 'CGAGTGTAGAATCTCCA' *.fastq > count/B5687_Fm0.txt
agrep -0 -c 'TCGGAGAGATCCTTCCA' *.fastq > count/B5689_Fm0.txt
agrep -0 -c 'GCCCCTGTGCAATTTTG' *.fastq > count/B5690_Fm0.txt
agrep -0 -c 'CGACTATTGATAATGCC' *.fastq > count/B5691_Fm0.txt
agrep -0 -c 'TAAGTCTGTGCCCAGCA' *.fastq > count/B5692_Fm0.txt
agrep -0 -c 'CCGGTGTCACATCAACA' *.fastq > count/B5693_Fm0.txt
agrep -0 -c 'GGCTGTCCCATTAGTCG' *.fastq > count/B5694_Fm0.txt
agrep -0 -c 'CCTACTATGCGAGGAGG' *.fastq > count/B5697_Fm0.txt
agrep -0 -c 'ACAGGTATGAAACCCGG' *.fastq > count/B5698_Fm0.txt
agrep -0 -c 'GGACCCTTGAGAATTGG' *.fastq > count/B5699_Fm0.txt
agrep -0 -c 'GGATTATAGTCACGATC' *.fastq > count/B5700_Fm0.txt
agrep -0 -c 'GGGACACAAGAACTCCA' *.fastq > count/B5701_Fm0.txt
agrep -0 -c 'GGCATGCCTTGGGGATA' *.fastq > count/B5702_Fm0.txt
agrep -0 -c 'AACTAGATTGGTCCGGG' *.fastq > count/B5703_Fm0.txt
agrep -0 -c 'TGGCCTCAGTGTCGCTA' *.fastq > count/B5704_Fm0.txt
agrep -0 -c 'CGTGTACTCCCATGGCT' *.fastq > count/B5705_Fm0.txt
agrep -0 -c 'TATACGGGGAAGACTCC' *.fastq > count/B5706_Fm0.txt
agrep -0 -c 'GCGGAAAACTGCAGGCA' *.fastq > count/B5707_Fm0.txt
agrep -0 -c 'TCGACCTCAATCAGTTA' *.fastq > count/B5709_Fm0.txt
agrep -0 -c 'AGTTGCGAGTTAGGCGT' *.fastq > count/B5710_Fm0.txt
agrep -0 -c 'GTCAGGTATTCCATGGC' *.fastq > count/B5712_Fm0.txt
agrep -0 -c 'GCACCGTGTGATGGTTA' *.fastq > count/B5714_Fm0.txt
agrep -0 -c 'GGCACACTGTCGAAACC' *.fastq > count/B5715_Fm0.txt
agrep -0 -c 'TAACCGCTCTATACTCC' *.fastq > count/B5716_Fm0.txt
agrep -0 -c 'ACGCATTCTCTCAAGGT' *.fastq > count/B5717_Fm0.txt
agrep -0 -c 'AACGAGCGCAGGGATTT' *.fastq > count/B5718_Fm0.txt
agrep -0 -c 'ACCCCGCTTATTCCGTT' *.fastq > count/B5719_Fm0.txt
agrep -0 -c 'TCATCGCGGCGTTTTAA' *.fastq > count/B5720_Fm0.txt
agrep -0 -c 'TAGTTGTGATCATCTCG' *.fastq > count/B5721_Fm0.txt
agrep -0 -c 'CCAGTCCGCACGTAATC' *.fastq > count/B5722_Fm0.txt
agrep -0 -c 'GGTATAATACCTGCTCT' *.fastq > count/B5723_Fm0.txt
agrep -0 -c 'CCGTAACTCAGCCTCGA' *.fastq > count/B5725_Fm0.txt
agrep -0 -c 'TGCGTCATCAAAAGCTT' *.fastq > count/B5726_Fm0.txt
agrep -0 -c 'CCTCATTACCAGGCGCT' *.fastq > count/B5727_Fm0.txt
agrep -0 -c 'CGATCAGCTTGACATCG' *.fastq > count/B5728_Fm0.txt
agrep -0 -c 'ACCTAATTGAACTGCCG' *.fastq > count/B5729_Fm0.txt
agrep -0 -c 'GGTTTATCTTCTGCATG' *.fastq > count/B5730_Fm0.txt
agrep -0 -c 'CGAAACCAGCGGCAATC' *.fastq > count/B5731_Fm0.txt
agrep -0 -c 'TTAGCGCTCTATCGCTT' *.fastq > count/B5732_Fm0.txt
agrep -0 -c 'TCTTACTACTGGTGTCC' *.fastq > count/B5734_Fm0.txt
agrep -0 -c 'CGAAAAGGTCGTTGCTC' *.fastq > count/B5735_Fm0.txt
agrep -0 -c 'TTCACCCCGGTAACTGC' *.fastq > count/B5736_Fm0.txt
agrep -0 -c 'CACCCTAGCACGTCGAT' *.fastq > count/B5737_Fm0.txt
agrep -0 -c 'AGAAGAAACGCTCCCAC' *.fastq > count/B5738_Fm0.txt
agrep -0 -c 'AGCATTCGTCTTAACAC' *.fastq > count/B5739_Fm0.txt
agrep -0 -c 'GGCTTACAACGTATTCA' *.fastq > count/B5740_Fm0.txt
agrep -0 -c 'GTCCAGCGGAGTGTTAC' *.fastq > count/B5741_Fm0.txt
agrep -0 -c 'TAATCGCCCGAGATTGA' *.fastq > count/B5742_Fm0.txt
agrep -0 -c 'GGATAGGAACCAATCCA' *.fastq > count/B5743_Fm0.txt
agrep -0 -c 'GCGTTGGATCGAGTTTG' *.fastq > count/B5746_Fm0.txt
agrep -0 -c 'TGATATCCGTGATCAGG' *.fastq > count/B5747_Fm0.txt
agrep -0 -c 'GGATTTCGACTATAGGG' *.fastq > count/B5749_Fm0.txt
agrep -0 -c 'AATGCCAGAGAGGAGTG' *.fastq > count/B5750_Fm0.txt
agrep -0 -c 'GTCCGCTCTTGGGGTTA' *.fastq > count/B5751_Fm0.txt
agrep -0 -c 'TTCCGGCGATCGACGTT' *.fastq > count/B5752_Fm0.txt
agrep -0 -c 'TAGTTGAGTCGGCCTAT' *.fastq > count/B5753_Fm0.txt
agrep -0 -c 'ATTCGCCAATAAGTCGG' *.fastq > count/B5754_Fm0.txt
agrep -0 -c 'AATCGCTTGTGGCCAAG' *.fastq > count/B5755_Fm0.txt
agrep -0 -c 'ATAGCTAGCCTGGTGAT' *.fastq > count/B5756_Fm0.txt
agrep -0 -c 'ATGAGCGTACCTTCTCC' *.fastq > count/B5757_Fm0.txt
agrep -0 -c 'AAGGCGCTTTCGTTGAT' *.fastq > count/B5758_Fm0.txt
agrep -0 -c 'TGAACCTGCCGCTATTC' *.fastq > count/B5759_Fm0.txt
agrep -0 -c 'ACCAGGATAGACGCCTT' *.fastq > count/B5760_Fm0.txt
agrep -0 -c 'GAGACAAGGACGGTATC' *.fastq > count/B5762_Fm0.txt
agrep -0 -c 'GTGTCTTGCCGTAAGTC' *.fastq > count/B5763_Fm0.txt
agrep -0 -c 'ACTAGTAGACCAGGAGG' *.fastq > count/B5764_Fm0.txt
agrep -0 -c 'AGCCATAACCCAAGAAA' *.fastq > count/B5765_Fm0.txt
agrep -0 -c 'TCTGTTCGTCTTTAGCC' *.fastq > count/B5767_Fm0.txt
agrep -0 -c 'AATGAGTCACCACAGGA' *.fastq > count/B5768_Fm0.txt
agrep -0 -c 'TCGGTCACATACAAGAC' *.fastq > count/B5769_Fm0.txt
agrep -0 -c 'TAACCGAATGTCTAGCT' *.fastq > count/B5770_Fm0.txt
agrep -0 -c 'AGTATGGGTACCTCCTA' *.fastq > count/B5771_Fm0.txt
agrep -0 -c 'CCATATCTCACGCGGCA' *.fastq > count/B5772_Fm0.txt
agrep -0 -c 'TCACATCCAGCTCGGAA' *.fastq > count/B5773_Fm0.txt
agrep -0 -c 'TAATCTAAGGCCGTGGG' *.fastq > count/B5774_Fm0.txt
agrep -0 -c 'TTGTAGGGGATCAAGAA' *.fastq > count/B5775_Fm0.txt
agrep -0 -c 'ACTGTTGCTCAGAGGTA' *.fastq > count/B5776_Fm0.txt
agrep -0 -c 'CCGTTGCTTGCGCCTTT' *.fastq > count/B5777_Fm0.txt
agrep -0 -c 'CCTCGCCCTTTGATGGA' *.fastq > count/B5778_Fm0.txt
agrep -0 -c 'TCACTACCACGGCGCAT' *.fastq > count/B5779_Fm0.txt
agrep -0 -c 'ACCTCTCCCTATCGGTT' *.fastq > count/B5780_Fm0.txt
agrep -0 -c 'GGAACTGGTTCGCTTAC' *.fastq > count/B5781_Fm0.txt
agrep -0 -c 'TTATCAGGATCCGACTG' *.fastq > count/B5782_Fm0.txt
agrep -0 -c 'CTTACAAAAGCACTACG' *.fastq > count/B5783_Fm0.txt
agrep -0 -c 'ATAAAGCGAATGGGCAT' *.fastq > count/B5785_Fm0.txt
agrep -0 -c 'GAGGAACCCGTATCTCC' *.fastq > count/B5786_Fm0.txt
agrep -0 -c 'TTCTAACCTTCGCGACG' *.fastq > count/B5787_Fm0.txt
agrep -0 -c 'ACAAAACGATGGTTAGG' *.fastq > count/B5789_Fm0.txt
agrep -0 -c 'CGTGGACGTTTGAAATC' *.fastq > count/B5790_Fm0.txt
agrep -0 -c 'GGGCAGACACTAGTGTT' *.fastq > count/B5792_Fm0.txt
agrep -0 -c 'GGGCCTCTGGAAAACGT' *.fastq > count/B5793_Fm0.txt
agrep -0 -c 'CGAGACTTTGTCTGCCT' *.fastq > count/B5795_Fm0.txt
agrep -0 -c 'TATCAAAGCCTTAGCGA' *.fastq > count/B5797_Fm0.txt
agrep -0 -c 'TACCGCTATTCCCTAGC' *.fastq > count/B5798_Fm0.txt
agrep -0 -c 'TCGTAGAGATTTCAGGG' *.fastq > count/B5799_Fm0.txt
agrep -0 -c 'CAAGTGCGATCAAGCGA' *.fastq > count/B5800_Fm0.txt
agrep -0 -c 'CTTGAATACCCGGCAAC' *.fastq > count/B5801_Fm0.txt
agrep -0 -c 'GCGATCATTGCTCTTGG' *.fastq > count/B5802_Fm0.txt
agrep -0 -c 'AACCTAGCAGTCAACGT' *.fastq > count/B5803_Fm0.txt
agrep -0 -c 'ACCACATAATACTACCG' *.fastq > count/B5804_Fm0.txt
agrep -0 -c 'TCTCCGCGCAGTAGATA' *.fastq > count/B5805_Fm0.txt
agrep -0 -c 'CTAGACCCTAGCTGCAA' *.fastq > count/B5806_Fm0.txt
agrep -0 -c 'TAGGCTAAGCAACACGG' *.fastq > count/B5807_Fm0.txt
agrep -0 -c 'AGGACCTCTCTGACCTC' *.fastq > count/B5808_Fm0.txt
agrep -0 -c 'AATGCCACTCATTATCG' *.fastq > count/B5809_Fm0.txt
agrep -0 -c 'CATTGGGTGCCCTGTTC' *.fastq > count/B5810_Fm0.txt
agrep -0 -c 'TCTGGGACTGAATCGTT' *.fastq > count/B5811_Fm0.txt
agrep -0 -c 'CCGTTGTATACGGATCA' *.fastq > count/B5812_Fm0.txt
agrep -0 -c 'TTGATTCCAACGTCAGG' *.fastq > count/B5813_Fm0.txt
agrep -0 -c 'AGTCCTTATGCAATGAG' *.fastq > count/B5814_Fm0.txt
agrep -0 -c 'CGGTCTAAACCGTGTCG' *.fastq > count/B5815_Fm0.txt
agrep -0 -c 'CCGGCTCGTTTCTGAGT' *.fastq > count/B5816_Fm0.txt
agrep -0 -c 'ATGCGGCGACTTTATGC' *.fastq > count/B5817_Fm0.txt
agrep -0 -c 'TAACATGTCTCGTTCAG' *.fastq > count/B5818_Fm0.txt
agrep -0 -c 'GATTGTTAGGTATGCGC' *.fastq > count/B5821_Fm0.txt
agrep -0 -c 'GGCCTAAATTGTTGGAA' *.fastq > count/B5822_Fm0.txt
agrep -0 -c 'CCAGATATCGATGTGGG' *.fastq > count/B5823_Fm0.txt
agrep -0 -c 'TAAGTTCTGCGTCGAGA' *.fastq > count/B5824_Fm0.txt
agrep -0 -c 'TCGCACTCGAAACGAGT' *.fastq > count/B5825_Fm0.txt
agrep -0 -c 'TCGTCCAGCCAACTGAA' *.fastq > count/B5826_Fm0.txt
agrep -0 -c 'GTCAGTGCCGCTTGATG' *.fastq > count/B5827_Fm0.txt
agrep -0 -c 'CTCTAAGGTATCGGCTC' *.fastq > count/B5828_Fm0.txt
agrep -0 -c 'TATTGGCAACCAGTGTA' *.fastq > count/B5829_Fm0.txt
agrep -0 -c 'TAGCGTTGGAACCACGG' *.fastq > count/B5830_Fm0.txt
agrep -0 -c 'ATTGTGACGAACTCTGC' *.fastq > count/B5831_Fm0.txt
agrep -0 -c 'GTCACCGTAACAGACCT' *.fastq > count/B5833_Fm0.txt
agrep -0 -c 'CCGAGTAATTTCACCAC' *.fastq > count/B5834_Fm0.txt
agrep -0 -c 'GCGGCGATGGATCCTAA' *.fastq > count/B5835_Fm0.txt
agrep -0 -c 'CCGTTCGTTCGAAATGA' *.fastq > count/B5836_Fm0.txt
agrep -0 -c 'TCTCAACAGGGACATAT' *.fastq > count/B5837_Fm0.txt
agrep -0 -c 'CGAAGATGGTTACCGAC' *.fastq > count/B5838_Fm0.txt
agrep -0 -c 'CTGAATCCCCATATCCG' *.fastq > count/B5839_Fm0.txt
agrep -0 -c 'CCGCCTGATATCGACTT' *.fastq > count/B5840_Fm0.txt
agrep -0 -c 'CGACTTCAACACGTATT' *.fastq > count/B5841_Fm0.txt
agrep -0 -c 'TGCCAAATGTACCCTAA' *.fastq > count/B5842_Fm0.txt
agrep -0 -c 'TATCTCACGGTCAGGTG' *.fastq > count/B5843_Fm0.txt
agrep -0 -c 'CGATCCCAATATGATGT' *.fastq > count/B5844_Fm0.txt
agrep -0 -c 'GCATGTGAGACAATCAG' *.fastq > count/B5847_Fm0.txt
agrep -0 -c 'TCGACGTAATCCTACTC' *.fastq > count/B5848_Fm0.txt
agrep -0 -c 'GTTGGAGTCCAGCCTAC' *.fastq > count/B5849_Fm0.txt
agrep -0 -c 'GGATGCGAACTAGCTCA' *.fastq > count/B5850_Fm0.txt
agrep -0 -c 'ATGCGATAGATTCCGGG' *.fastq > count/B5851_Fm0.txt
agrep -0 -c 'GCAAACAGCCCGGTATA' *.fastq > count/B5852_Fm0.txt
agrep -0 -c 'TGACCGCCCATTTGATG' *.fastq > count/B5853_Fm0.txt
agrep -0 -c 'TACTATACCCGCCTAAG' *.fastq > count/B5854_Fm0.txt
agrep -0 -c 'ATCAGCCTTGCCAACAT' *.fastq > count/B5855_Fm0.txt
agrep -0 -c 'CTAACACAGACAGAGAT' *.fastq > count/B5856_Fm0.txt
agrep -0 -c 'GCTCCGTCCTCTAATTA' *.fastq > count/B5858_Fm0.txt
agrep -0 -c 'CTTCTCGTGGGTTCCTG' *.fastq > count/B5859_Fm0.txt
agrep -0 -c 'GTATTTAGGGTGCCCCC' *.fastq > count/B5860_Fm0.txt
agrep -0 -c 'AGTGAGTCAACAAAGTG' *.fastq > count/B5861_Fm0.txt
agrep -0 -c 'CCAGGTCCATGAATCAG' *.fastq > count/B5862_Fm0.txt
agrep -0 -c 'GAGCCGGGTTTATGTCA' *.fastq > count/B5863_Fm0.txt
agrep -0 -c 'TCAACTCATTGACCCGG' *.fastq > count/B5864_Fm0.txt
agrep -0 -c 'CGCGCATTCATGATTGC' *.fastq > count/B5865_Fm0.txt
agrep -0 -c 'ACTGCACCATGAATAGT' *.fastq > count/B5866_Fm0.txt
agrep -0 -c 'AATGCCTAGCCATGACA' *.fastq > count/B5867_Fm0.txt
agrep -0 -c 'GTTTCTAAGACTGGCTC' *.fastq > count/B5868_Fm0.txt
agrep -0 -c 'AGTCGTTAAACGCGCGC' *.fastq > count/B5869_Fm0.txt
agrep -0 -c 'CGAATACAGAACGGGAT' *.fastq > count/B5870_Fm0.txt
agrep -0 -c 'TCAAATCCAACACAGCG' *.fastq > count/B5871_Fm0.txt
agrep -0 -c 'CGCGCTCTACTCTTATA' *.fastq > count/B5873_Fm0.txt
agrep -0 -c 'AAGTAAGGGATTCGGGA' *.fastq > count/B5874_Fm0.txt
agrep -0 -c 'CGGTTTTGACTGAGACT' *.fastq > count/B5876_Fm0.txt
agrep -0 -c 'GAGTTGACTAGCTGATT' *.fastq > count/B5877_Fm0.txt
agrep -0 -c 'GTTCTAGCGATCACTGT' *.fastq > count/B5878_Fm0.txt
agrep -0 -c 'CATCCGTAGCATCTAGA' *.fastq > count/B5879_Fm0.txt
agrep -0 -c 'ATCCGTAGCAAGTCCGT' *.fastq > count/B5880_Fm0.txt
agrep -0 -c 'CGTGGCTATTTTCAGTG' *.fastq > count/B5882_Fm0.txt
agrep -0 -c 'AGTTATATCGCCCGCTT' *.fastq > count/B5884_Fm0.txt
agrep -0 -c 'CAGCAGGTAGTATCGTC' *.fastq > count/B5885_Fm0.txt
agrep -0 -c 'CTCGCAGCAAGCATACC' *.fastq > count/B5886_Fm0.txt
agrep -0 -c 'ATGCGTGGCTCCATTGT' *.fastq > count/B5887_Fm0.txt
agrep -0 -c 'AAGTCTGTAGCAGGCAT' *.fastq > count/B5888_Fm0.txt
agrep -0 -c 'CACCTGAACGCAAAAGG' *.fastq > count/B5889_Fm0.txt
agrep -0 -c 'TCTCTAACCATGGCCGT' *.fastq > count/B5890_Fm0.txt
agrep -0 -c 'GTCTAGTCTGCGTCCAG' *.fastq > count/B5891_Fm0.txt
agrep -0 -c 'GCCTGACTATGGTGTGC' *.fastq > count/B5893_Fm0.txt
agrep -0 -c 'TCGACAAGTCAATGCTT' *.fastq > count/B5894_Fm0.txt
agrep -0 -c 'CAGCGAAATATATGGCG' *.fastq > count/B5895_Fm0.txt
agrep -0 -c 'AGGCGTGGTTGACAGTA' *.fastq > count/B5897_Fm0.txt
agrep -0 -c 'GTAAGTTACGTCAGTCG' *.fastq > count/B5898_Fm0.txt
agrep -0 -c 'TCGGAGCGTATTAATTG' *.fastq > count/B5899_Fm0.txt
agrep -0 -c 'CGCTGTCATTTCAAAAC' *.fastq > count/B5900_Fm0.txt
agrep -0 -c 'TCGTGCTAAGTAGTCAA' *.fastq > count/B5901_Fm0.txt
agrep -0 -c 'ATTCAGTTGTAGCGTTC' *.fastq > count/B5902_Fm0.txt
agrep -0 -c 'GGCATTCCGTTACTCAG' *.fastq > count/B5903_Fm0.txt
agrep -0 -c 'CTACCGTACCCTAAGCG' *.fastq > count/B5904_Fm0.txt
agrep -0 -c 'TAGTAATGACTTGTGCG' *.fastq > count/B5905_Fm0.txt
agrep -0 -c 'ACTCCGCGGCTCCTTAA' *.fastq > count/B5906_Fm0.txt
agrep -0 -c 'ACATGTTGAAGCCACTT' *.fastq > count/B5907_Fm0.txt
agrep -0 -c 'CGTTGAGTGTCTGTGTG' *.fastq > count/B5908_Fm0.txt
agrep -0 -c 'ACAGCCCCTTACCATAA' *.fastq > count/B5909_Fm0.txt
agrep -0 -c 'AGCCATGAAAGCTTCCC' *.fastq > count/B5910_Fm0.txt
agrep -0 -c 'GTTCTCTAGTACCAGGA' *.fastq > count/B5911_Fm0.txt
agrep -0 -c 'ATACCACCCAGGGGGAA' *.fastq > count/B5912_Fm0.txt
agrep -0 -c 'GCGGAGTACTAATGCCC' *.fastq > count/B5913_Fm0.txt
agrep -0 -c 'GCTAGGGTGGGATCGTT' *.fastq > count/B5915_Fm0.txt
agrep -0 -c 'CGCGCTGAGTGTCAACT' *.fastq > count/B5917_Fm0.txt
agrep -0 -c 'GACTTCAGAACCAAGAA' *.fastq > count/B5918_Fm0.txt
agrep -0 -c 'CGTTACTGGCTACAGGT' *.fastq > count/B5919_Fm0.txt
agrep -0 -c 'AACTGCTCTGACGACTT' *.fastq > count/B5920_Fm0.txt
agrep -0 -c 'CTGCCGTTCCATCCCAT' *.fastq > count/B5921_Fm0.txt
agrep -0 -c 'AGCTGGCCTACGAACAA' *.fastq > count/B5922_Fm0.txt
agrep -0 -c 'CGCTACCGGGATACACT' *.fastq > count/B5924_Fm0.txt
agrep -0 -c 'CTATCTTGCATTGAGCC' *.fastq > count/B5926_Fm0.txt
agrep -0 -c 'AATAGTTCGCGGGCTAA' *.fastq > count/B5927_Fm0.txt
agrep -0 -c 'AAGGGGCAATATCGTTT' *.fastq > count/B5928_Fm0.txt
agrep -0 -c 'CGACTCTAACTGTGAAC' *.fastq > count/B5929_Fm0.txt
agrep -0 -c 'TCTGGTCTACCTATACG' *.fastq > count/B5930_Fm0.txt
agrep -0 -c 'TAACCCACTCTGTCGGA' *.fastq > count/B5931_Fm0.txt
agrep -0 -c 'GCTCGGCTTTATGCCGT' *.fastq > count/B5932_Fm0.txt
agrep -0 -c 'ACGGGTCCTAACGCAAT' *.fastq > count/B5933_Fm0.txt
agrep -0 -c 'TTCCGGAGTTTAGGGAC' *.fastq > count/B5934_Fm0.txt
agrep -0 -c 'AGCATAGTTGCTCCCAA' *.fastq > count/B5935_Fm0.txt
agrep -0 -c 'GATATCACATCCCGACC' *.fastq > count/B5936_Fm0.txt
agrep -0 -c 'ATTGGCTTTAGCTCCAT' *.fastq > count/B5937_Fm0.txt
agrep -0 -c 'GGCATCAGAGTTACTCG' *.fastq > count/B5939_Fm0.txt
agrep -0 -c 'AATCACCGAGTAGCCGC' *.fastq > count/B5940_Fm0.txt
agrep -0 -c 'TTCGACGGCTAATTCGT' *.fastq > count/B5941_Fm0.txt
agrep -0 -c 'CTAGCTGTTGCTTTTCG' *.fastq > count/B5943_Fm0.txt
agrep -0 -c 'AGCTTCACTCGCAAATG' *.fastq > count/B5944_Fm0.txt
agrep -0 -c 'CTATATCACCCCAAACG' *.fastq > count/B5945_Fm0.txt
agrep -0 -c 'CAGCGCACACTCCTTAT' *.fastq > count/B5946_Fm0.txt
agrep -0 -c 'GTAGTCGACACGGAATT' *.fastq > count/B5949_Fm0.txt
agrep -0 -c 'TATGTGATGCGTGTCGT' *.fastq > count/B5950_Fm0.txt
agrep -0 -c 'TGCGCACTCGATCGCAA' *.fastq > count/B5952_Fm0.txt
agrep -0 -c 'TGCTAATGCTGTCTTTG' *.fastq > count/B5953_Fm0.txt
agrep -0 -c 'ACCGCGAATGTGGGCTT' *.fastq > count/B5954_Fm0.txt
agrep -0 -c 'CTCAGATAACGGAAGCT' *.fastq > count/B5955_Fm0.txt
agrep -0 -c 'GCCATCATCACGCGCAA' *.fastq > count/B5957_Fm0.txt
agrep -0 -c 'ATACACATGGGGGGTGC' *.fastq > count/B5958_Fm0.txt
agrep -0 -c 'CGAAAACGACCCCCTTC' *.fastq > count/B5959_Fm0.txt
agrep -0 -c 'TTGGTGTGGTACAGACC' *.fastq > count/B5960_Fm0.txt
agrep -0 -c 'TCGCCCGTGCATAAGAG' *.fastq > count/B5961_Fm0.txt
agrep -0 -c 'AGTTTGGCTCCTCTACC' *.fastq > count/B5962_Fm0.txt
agrep -0 -c 'CACCTCCAACCTACGTT' *.fastq > count/B5963_Fm0.txt
agrep -0 -c 'GTTAAATTCCCCCGCCT' *.fastq > count/B5964_Fm0.txt
agrep -0 -c 'TCAAACCGGAGTACTGA' *.fastq > count/B5968_Fm0.txt
agrep -0 -c 'TGAGCGTGGACTGAATC' *.fastq > count/B5970_Fm0.txt
agrep -0 -c 'CTGCCATGAGGAGCACT' *.fastq > count/B5971_Fm0.txt
agrep -0 -c 'CAACAATTTGATCGGTC' *.fastq > count/B5972_Fm0.txt
agrep -0 -c 'AGACACAGTCCTGTTTT' *.fastq > count/B5973_Fm0.txt
agrep -0 -c 'AGCCGTGTACTAATTCA' *.fastq > count/B5974_Fm0.txt
agrep -0 -c 'TAGTCCGTCTTAGCTAA' *.fastq > count/B5975_Fm0.txt
agrep -0 -c 'TAAGGTCACGCTGAACA' *.fastq > count/B5976_Fm0.txt
agrep -0 -c 'GAGTGAGTTCTACGTAT' *.fastq > count/B5977_Fm0.txt
agrep -0 -c 'ATTCAGAGATGCTATCG' *.fastq > count/B5978_Fm0.txt
agrep -0 -c 'TCAGCATAGGGGCACTA' *.fastq > count/B5979_Fm0.txt
agrep -0 -c 'GCATATATGTATCCGCA' *.fastq > count/B5980_Fm0.txt
agrep -0 -c 'TCACTCTTTGCGACCAG' *.fastq > count/B5981_Fm0.txt
agrep -0 -c 'TGTCCTTTACTCTTGTG' *.fastq > count/B5982_Fm0.txt
agrep -0 -c 'TCGTGTTCTCAGCGGTT' *.fastq > count/B5983_Fm0.txt
agrep -0 -c 'GACGCTCGAGGTTATGC' *.fastq > count/B5984_Fm0.txt
agrep -0 -c 'GAGTGTCCAATGATCGA' *.fastq > count/B5985_Fm0.txt
agrep -0 -c 'ACTGCCGGAGGTACACT' *.fastq > count/B5986_Fm0.txt
agrep -0 -c 'TGAGACAAGCCTCCTGA' *.fastq > count/B5987_Fm0.txt
agrep -0 -c 'CATGCCCTACAGTTTAA' *.fastq > count/B5988_Fm0.txt
agrep -0 -c 'TCGCGACAGGAAGATAC' *.fastq > count/B5989_Fm0.txt
agrep -0 -c 'CAAGCTACATAACCTGA' *.fastq > count/B5990_Fm0.txt
agrep -0 -c 'TAAGACAAGCCTGAGTC' *.fastq > count/B5991_Fm0.txt
agrep -0 -c 'GTTAGTAGCAACGTGCA' *.fastq > count/B5993_Fm0.txt
agrep -0 -c 'TCTGGACAATGGGTCGT' *.fastq > count/B5994_Fm0.txt
agrep -0 -c 'CTAGGAATACCCTAAGA' *.fastq > count/B5995_Fm0.txt
agrep -0 -c 'CCATTTGCCCGCGTTAA' *.fastq > count/B5996_Fm0.txt
agrep -0 -c 'GGGCCGGCAATAACAAT' *.fastq > count/B5999_Fm0.txt
agrep -0 -c 'AGAGGTGGTATCTCTCC' *.fastq > count/B6000_Fm0.txt
agrep -0 -c 'AATATATTGCCGGAGGA' *.fastq > count/B6001_Fm0.txt
agrep -0 -c 'CCAGATTGGCACCTGGA' *.fastq > count/B6002_Fm0.txt
agrep -0 -c 'AATCGGGTGCGCATGTT' *.fastq > count/B6003_Fm0.txt
agrep -0 -c 'CCATTGATTGCCTACTT' *.fastq > count/B6004_Fm0.txt
agrep -0 -c 'CATCGCGACATATAACT' *.fastq > count/B6005_Fm0.txt
agrep -0 -c 'CAGGATCATGCACAAGC' *.fastq > count/B6007_Fm0.txt
agrep -0 -c 'GCAAATGTCAATGAGGG' *.fastq > count/B6008_Fm0.txt
agrep -0 -c 'GATACCATTACCAGGGC' *.fastq > count/B6009_Fm0.txt
agrep -0 -c 'GCTATGAAGTAGATGCC' *.fastq > count/B6011_Fm0.txt
agrep -0 -c 'TTGCCTAGAGAACCTGC' *.fastq > count/B6012_Fm0.txt
agrep -0 -c 'ATCCGCAGGTTTGAGTA' *.fastq > count/B6013_Fm0.txt
agrep -0 -c 'CCGACCATTCGAGTTAA' *.fastq > count/B6014_Fm0.txt
agrep -0 -c 'TGTCGCTGCCATCTACG' *.fastq > count/B6015_Fm0.txt
agrep -0 -c 'CTCCAAGCCTCCTTAAC' *.fastq > count/B6018_Fm0.txt
agrep -0 -c 'CGCAAGATTCCCGAACC' *.fastq > count/B6019_Fm0.txt
agrep -0 -c 'GGAGGAGCTCATAGGTC' *.fastq > count/B6021_Fm0.txt
agrep -0 -c 'TGTACCAGCGGAGAAAG' *.fastq > count/B6022_Fm0.txt
agrep -0 -c 'GGGGGGACAAATTTGTA' *.fastq > count/B6024_Fm0.txt
agrep -0 -c 'TGCTCTGCCAATGGACT' *.fastq > count/B6025_Fm0.txt
agrep -0 -c 'CGAACCTACGATTTCCT' *.fastq > count/B6026_Fm0.txt
agrep -0 -c 'CTTATGACAAACGCTCC' *.fastq > count/B6027_Fm0.txt
agrep -0 -c 'GGATATAGTCGACGCAA' *.fastq > count/B6028_Fm0.txt
agrep -0 -c 'ACCTGACCACGATGACC' *.fastq > count/B6030_Fm0.txt
agrep -0 -c 'ATGATTGCGATCGGCCA' *.fastq > count/B6031_Fm0.txt
agrep -0 -c 'CATACTCATTGCGAGAT' *.fastq > count/B6032_Fm0.txt
agrep -0 -c 'CGCAATGGGGGCTTATC' *.fastq > count/B6034_Fm0.txt
agrep -0 -c 'TTCATCGGGTAGCCATG' *.fastq > count/B6036_Fm0.txt
agrep -0 -c 'CGGTCTAGGGTTTGGTC' *.fastq > count/B6037_Fm0.txt
agrep -0 -c 'ATGAAGAGGCGAATGCG' *.fastq > count/B6038_Fm0.txt
agrep -0 -c 'AGGTTTCTCGCTATGGT' *.fastq > count/B6040_Fm0.txt
agrep -0 -c 'AACGGTGACGCAATCGA' *.fastq > count/B6041_Fm0.txt
agrep -0 -c 'CTCGTTAACACTGCTTG' *.fastq > count/B6042_Fm0.txt
agrep -0 -c 'AAGAATGCCGTACACTC' *.fastq > count/B6043_Fm0.txt
agrep -0 -c 'TATGGCACGCAAAGTGC' *.fastq > count/B6044_Fm0.txt
agrep -0 -c 'ATGTGATGACCGGGAAC' *.fastq > count/B6045_Fm0.txt
agrep -0 -c 'AACCTAGTCAACTGCTT' *.fastq > count/B6046_Fm0.txt
agrep -0 -c 'ATCTGTTCTCCGTCATG' *.fastq > count/B6047_Fm0.txt
agrep -0 -c 'CGGTCGTATCACTATTG' *.fastq > count/B6048_Fm0.txt
agrep -0 -c 'GTAGAGCGTCGAAGGTA' *.fastq > count/B6049_Fm0.txt
agrep -0 -c 'CGACTTTCTGATTTAGC' *.fastq > count/B6050_Fm0.txt
agrep -0 -c 'TGATAGACCCTATCCGC' *.fastq > count/B6051_Fm0.txt
agrep -0 -c 'TTATTTCGCTCGCATTC' *.fastq > count/B6052_Fm0.txt
agrep -0 -c 'AATGGAGCACACGTTGG' *.fastq > count/B6053_Fm0.txt
agrep -0 -c 'TCTACTGAGTCTACGAA' *.fastq > count/B6054_Fm0.txt
agrep -0 -c 'GTCCTATTCCTTACACG' *.fastq > count/B6055_Fm0.txt
agrep -0 -c 'GTGCACATGGGCAATAC' *.fastq > count/B6056_Fm0.txt
agrep -0 -c 'GGCTCGTATTTCCCGGT' *.fastq > count/B6057_Fm0.txt
agrep -0 -c 'AGTAGTTCTGAGTCTCT' *.fastq > count/B6058_Fm0.txt
agrep -0 -c 'CGCAAGAGAAGTAATGG' *.fastq > count/B6059_Fm0.txt
agrep -0 -c 'ATCTGCGTCATAAAAGG' *.fastq > count/B6060_Fm0.txt
agrep -0 -c 'GTATAGCTCTGTCACCA' *.fastq > count/B6061_Fm0.txt
agrep -0 -c 'TGGATAATGATCCAGGC' *.fastq > count/B6062_Fm0.txt
agrep -0 -c 'CATGAGGGTGCACGAAG' *.fastq > count/B6063_Fm0.txt
agrep -0 -c 'CGGGGCAGTTTTTATAC' *.fastq > count/B6064_Fm0.txt
agrep -0 -c 'AGACCCATGGAATCACA' *.fastq > count/B6065_Fm0.txt
agrep -0 -c 'ACCTAACGATACACTGG' *.fastq > count/B6066_Fm0.txt
agrep -0 -c 'TTCGGTCTTACTCTGTG' *.fastq > count/B6068_Fm0.txt
agrep -0 -c 'TAACAGAGTGACACACC' *.fastq > count/B6069_Fm0.txt
agrep -0 -c 'AAGCCATGAAACGTTGA' *.fastq > count/B6070_Fm0.txt
agrep -0 -c 'GCAATCGTTCACGAGTG' *.fastq > count/B6072_Fm0.txt
agrep -0 -c 'GTAGATTTCGTATCCGG' *.fastq > count/B6073_Fm0.txt
agrep -0 -c 'CAAGTGAGATCGATCGT' *.fastq > count/B6074_Fm0.txt
agrep -0 -c 'AACACAGGTCAAGGCCG' *.fastq > count/B6075_Fm0.txt
agrep -0 -c 'ATCGCCGTCATTACACG' *.fastq > count/B6076_Fm0.txt
agrep -0 -c 'CATCCTTCCCAAGTTAC' *.fastq > count/B6077_Fm0.txt
agrep -0 -c 'CTTCTAAAGTCAGGATC' *.fastq > count/B6079_Fm0.txt
agrep -0 -c 'AGTCATGGTGACTACCG' *.fastq > count/B6080_Fm0.txt
agrep -0 -c 'CATTACTACGCCACACC' *.fastq > count/B6081_Fm0.txt
agrep -0 -c 'GCGATTCAGGATTCGGA' *.fastq > count/B6083_Fm0.txt
agrep -0 -c 'AGGATTAACCACACCGG' *.fastq > count/B6084_Fm0.txt
agrep -0 -c 'GTGACGACGAATGTACT' *.fastq > count/B6085_Fm0.txt
agrep -0 -c 'TGCGCAGTAAGGGTGAG' *.fastq > count/B6086_Fm0.txt
agrep -0 -c 'TCACGTTTCCGAGAAAC' *.fastq > count/B6087_Fm0.txt
agrep -0 -c 'AATAGACAACACCCCCT' *.fastq > count/B6090_Fm0.txt
agrep -0 -c 'ATACTCGGGACCACAGA' *.fastq > count/B6091_Fm0.txt
agrep -0 -c 'ATGCTCCGAACATCGAC' *.fastq > count/B6093_Fm0.txt
agrep -0 -c 'GACTCTACTCACGCTGC' *.fastq > count/B6094_Fm0.txt
agrep -0 -c 'GCAGCGGCAACGTTTGA' *.fastq > count/B6095_Fm0.txt
agrep -0 -c 'TACCACTCACAGGTAAA' *.fastq > count/B6096_Fm0.txt
agrep -0 -c 'GGGACATTAGAATGTCT' *.fastq > count/B6097_Fm0.txt
agrep -0 -c 'GGAGGATCGACTTCGTG' *.fastq > count/B6098_Fm0.txt
agrep -0 -c 'ACTCGGTCGAACGCAAC' *.fastq > count/B6099_Fm0.txt
agrep -0 -c 'CTCAGTTGTTCAGGCGC' *.fastq > count/B6100_Fm0.txt
agrep -0 -c 'CTGCCTACACTAAAGGT' *.fastq > count/B6103_Fm0.txt
agrep -0 -c 'CATAAGGCGTCCCTCTA' *.fastq > count/B6104_Fm0.txt
agrep -0 -c 'TGTCCATCAGATACGGC' *.fastq > count/B6105_Fm0.txt
agrep -0 -c 'ACTGTTCGAGTGTGCAT' *.fastq > count/B6106_Fm0.txt
agrep -0 -c 'GTCTGTGGCGTATTAAA' *.fastq > count/B6107_Fm0.txt
agrep -0 -c 'GCGCTAACACCTTGACT' *.fastq > count/B6110_Fm0.txt
agrep -0 -c 'TACACGTATCGCAGTCA' *.fastq > count/B6111_Fm0.txt
agrep -0 -c 'GCTTCTGGGACGTCTAC' *.fastq > count/B6112_Fm0.txt
agrep -0 -c 'CTATAGGACGCTGTTCG' *.fastq > count/B6113_Fm0.txt
agrep -0 -c 'TCTAGTTGTTGGGCCGC' *.fastq > count/B6114_Fm0.txt
agrep -0 -c 'GTGGAAGCAACTTCATC' *.fastq > count/B6115_Fm0.txt
agrep -0 -c 'TTGCGTTCACAGGTCGC' *.fastq > count/B6116_Fm0.txt
agrep -0 -c 'ACACAACGAACCTGCCC' *.fastq > count/B6117_Fm0.txt
agrep -0 -c 'GTTAGCCACCTATGTAC' *.fastq > count/B6118_Fm0.txt
agrep -0 -c 'AGCCCTCTTTTTATGCA' *.fastq > count/B6119_Fm0.txt
agrep -0 -c 'GGTGGCGTTGTTAACGT' *.fastq > count/B6121_Fm0.txt
agrep -0 -c 'GTCGAGAGTTCGTTCTT' *.fastq > count/B6122_Fm0.txt
agrep -0 -c 'CTTAACAGACCTCTCAT' *.fastq > count/B6123_Fm0.txt
agrep -0 -c 'GCGTACTAGTCATGTGA' *.fastq > count/B6124_Fm0.txt
agrep -0 -c 'GGATACGGAGGCTACTC' *.fastq > count/B6126_Fm0.txt
agrep -0 -c 'CATAGCGTTGTTGTAAG' *.fastq > count/B6127_Fm0.txt
agrep -0 -c 'CGGTGTATTGCTATAGG' *.fastq > count/B6128_Fm0.txt
agrep -0 -c 'TGTACTATGTCGCTAGG' *.fastq > count/B6129_Fm0.txt
agrep -0 -c 'AAGGAGTTGCGGACGTA' *.fastq > count/B6131_Fm0.txt
agrep -0 -c 'TACCCATTGGTCGATGA' *.fastq > count/B6132_Fm0.txt
agrep -0 -c 'CGTACTCTTGCGTCACG' *.fastq > count/B6133_Fm0.txt
agrep -0 -c 'AGCCTGTCAGTGCTCGT' *.fastq > count/B6134_Fm0.txt
agrep -0 -c 'TGGAAAGGCAAGGGCGT' *.fastq > count/B6135_Fm0.txt
agrep -0 -c 'GGACCTAAAAAGCGTCA' *.fastq > count/B6136_Fm0.txt
agrep -0 -c 'GTTACCCATGGCAAATA' *.fastq > count/B6137_Fm0.txt
agrep -0 -c 'AGTCTACAAGTATGGTG' *.fastq > count/B6138_Fm0.txt
agrep -0 -c 'CCGTTGACATGCAATGT' *.fastq > count/B6139_Fm0.txt
agrep -0 -c 'CCAGACGGCATGCTGAA' *.fastq > count/B6140_Fm0.txt
agrep -0 -c 'TGACACAGACCGATCAT' *.fastq > count/B6141_Fm0.txt
agrep -0 -c 'AGTTACACACGACTGAA' *.fastq > count/B6143_Fm0.txt
agrep -0 -c 'TAGTGTACTGTCAAACG' *.fastq > count/B6144_Fm0.txt
agrep -0 -c 'GGTCCTATCAACCACAT' *.fastq > count/B6145_Fm0.txt
agrep -0 -c 'CACTCTAGGTGTCTACC' *.fastq > count/B6146_Fm0.txt
agrep -0 -c 'CTGTCATACGTGTGCAG' *.fastq > count/B6147_Fm0.txt
agrep -0 -c 'CCTCACCCCCATAGCAA' *.fastq > count/B6148_Fm0.txt
agrep -0 -c 'GACCTTTGTGGGCATCG' *.fastq > count/B6149_Fm0.txt
agrep -0 -c 'TCTTGGCGAACTGCTCT' *.fastq > count/B6150_Fm0.txt
agrep -0 -c 'CCGTCTAGTATGCAACG' *.fastq > count/B6151_Fm0.txt
agrep -0 -c 'TCTAGTATCCCCATGGT' *.fastq > count/B6152_Fm0.txt
agrep -0 -c 'GGCAACTCCTAGACCAT' *.fastq > count/B6153_Fm0.txt
agrep -0 -c 'AAGGACCACGGCTCACT' *.fastq > count/B6155_Fm0.txt
agrep -0 -c 'CGCGTTTAGCGTTATGT' *.fastq > count/B6156_Fm0.txt
agrep -0 -c 'CCAACTCCTAACGCCGA' *.fastq > count/B6157_Fm0.txt
agrep -0 -c 'TCGGGTTATACCTGCGG' *.fastq > count/B6158_Fm0.txt
agrep -0 -c 'GGCAGTCCCATCAGATC' *.fastq > count/B6160_Fm0.txt
agrep -0 -c 'AACGACAGCGTACTAGA' *.fastq > count/B6161_Fm0.txt
agrep -0 -c 'TGCTTATATGGGCTATC' *.fastq > count/B6162_Fm0.txt
agrep -0 -c 'TATAACGGCATCCGTTT' *.fastq > count/B6163_Fm0.txt
agrep -0 -c 'TTCTGGGCTTAAAATCC' *.fastq > count/B6164_Fm0.txt
agrep -0 -c 'GCTGTCGACGTACATCG' *.fastq > count/B6165_Fm0.txt
agrep -0 -c 'TCGAACCACGCTACAGC' *.fastq > count/B6166_Fm0.txt
agrep -0 -c 'TGCACCCGAAGGTGACT' *.fastq > count/B6167_Fm0.txt
agrep -0 -c 'AACTAAGGGTTGACTGC' *.fastq > count/B6168_Fm0.txt
agrep -0 -c 'GTCAAAACGCATACCCC' *.fastq > count/B6169_Fm0.txt
agrep -0 -c 'GGCAATATGAGTGACAA' *.fastq > count/B6170_Fm0.txt
agrep -0 -c 'ATTGTCGGGCTTTTTCG' *.fastq > count/B6171_Fm0.txt
agrep -0 -c 'GCAGGTGCTGTAAGCGT' *.fastq > count/B6172_Fm0.txt
agrep -0 -c 'CGAAGTACAGGAAGCGA' *.fastq > count/B6173_Fm0.txt
agrep -0 -c 'CGATCTCGGTGGACATC' *.fastq > count/B6174_Fm0.txt
agrep -0 -c 'TTCGACGAATACGGACG' *.fastq > count/B6175_Fm0.txt
agrep -0 -c 'ACACGTGGGTATGTGTA' *.fastq > count/B6177_Fm0.txt
agrep -0 -c 'CGCTACATGTCGACGTT' *.fastq > count/B6178_Fm0.txt
agrep -0 -c 'TAATCGGATTCATGCCC' *.fastq > count/B6180_Fm0.txt
agrep -0 -c 'AAGTTATCGCCTTGTAC' *.fastq > count/B6182_Fm0.txt
agrep -0 -c 'AGTTTTCACTATGCACG' *.fastq > count/B6183_Fm0.txt
agrep -0 -c 'TGCAGGCATCGCTGGTA' *.fastq > count/B6184_Fm0.txt
agrep -0 -c 'GATCCGACCCGAAAGGA' *.fastq > count/B6185_Fm0.txt
agrep -0 -c 'AGAAATGAAACAGCGGC' *.fastq > count/B6186_Fm0.txt
agrep -0 -c 'AGACTTCAACACATGCG' *.fastq > count/B6187_Fm0.txt
agrep -0 -c 'TGAAGGGCGTTAGACCG' *.fastq > count/B6188_Fm0.txt
agrep -0 -c 'TGAACACTGGTAAACGA' *.fastq > count/B6189_Fm0.txt
agrep -0 -c 'ATAGATTGCGCGACCGG' *.fastq > count/B6190_Fm0.txt
agrep -0 -c 'GGATAACGGATTCCGAT' *.fastq > count/B6191_Fm0.txt
agrep -0 -c 'AGGCATCATAGCTTTCT' *.fastq > count/B6193_Fm0.txt
agrep -0 -c 'ATATCGGCAGGATTAGT' *.fastq > count/B6194_Fm0.txt
agrep -0 -c 'CGTAGGCCGCTTACTTC' *.fastq > count/B6195_Fm0.txt
agrep -0 -c 'GATAGTTACGGGGGCCT' *.fastq > count/B6196_Fm0.txt
agrep -0 -c 'TCAACCGATATGACACA' *.fastq > count/B6197_Fm0.txt
agrep -0 -c 'GATTCGACCTCTACGCT' *.fastq > count/B6198_Fm0.txt
agrep -0 -c 'TAGTACTAAGCCGTTAG' *.fastq > count/B6199_Fm0.txt
agrep -0 -c 'CTCTTACCGCACCTGTC' *.fastq > count/B6200_Fm0.txt
agrep -0 -c 'ATGGGGCTAATCGTTCC' *.fastq > count/B6201_Fm0.txt
agrep -0 -c 'CTGGTAATCTGAATCTG' *.fastq > count/B6202_Fm0.txt
agrep -0 -c 'TCAAGGGTAGGATGTCC' *.fastq > count/B6203_Fm0.txt
agrep -0 -c 'GTCGTCTTCAAGTAGGC' *.fastq > count/B6204_Fm0.txt
agrep -0 -c 'AGTGATGAACACGGCGT' *.fastq > count/B6205_Fm0.txt
agrep -0 -c 'GCAGCTTACTGTGAATC' *.fastq > count/B6206_Fm0.txt
agrep -0 -c 'AAGATCTCTTACACGCG' *.fastq > count/B6208_Fm0.txt
agrep -0 -c 'AACGGGCAACATCGAAA' *.fastq > count/B6209_Fm0.txt
agrep -0 -c 'CTGATAGTCCGGACCAG' *.fastq > count/B6212_Fm0.txt
agrep -0 -c 'GCAGCGATAAATTTCAC' *.fastq > count/B6213_Fm0.txt
agrep -0 -c 'CGCCATTCAAACCATCC' *.fastq > count/B6214_Fm0.txt
agrep -0 -c 'TTAGAATGAACGCAACG' *.fastq > count/B6215_Fm0.txt
agrep -0 -c 'AGTCGCAGTGAGAATAA' *.fastq > count/B6216_Fm0.txt
agrep -0 -c 'TGTAAAGCTAGTCCGTA' *.fastq > count/B6217_Fm0.txt
agrep -0 -c 'TGTACTAACCCTTCTCG' *.fastq > count/B6219_Fm0.txt
agrep -0 -c 'ATCCTCGGTAGTAACTT' *.fastq > count/B6220_Fm0.txt
agrep -0 -c 'TATACGCCCAAGGTAAG' *.fastq > count/B6224_Fm0.txt
agrep -0 -c 'TCTATAGGGGTTTACTG' *.fastq > count/B6225_Fm0.txt
agrep -0 -c 'CATCGTCGCAACTTACC' *.fastq > count/B6226_Fm0.txt
agrep -0 -c 'ACCAACACCGCTTGACG' *.fastq > count/B6227_Fm0.txt
agrep -0 -c 'TCGTAGCGGGTAAAAAA' *.fastq > count/B6228_Fm0.txt
agrep -0 -c 'GGCGATGTACTAAAGCC' *.fastq > count/B6229_Fm0.txt
agrep -0 -c 'GGGGCTATGTAGCTCCA' *.fastq > count/B6230_Fm0.txt
agrep -0 -c 'CACCTGGCATAGAGCGA' *.fastq > count/B6231_Fm0.txt
agrep -0 -c 'TTCTGATACCACTCGCG' *.fastq > count/B6232_Fm0.txt
agrep -0 -c 'ATGCGGATGCCAGTTAA' *.fastq > count/B6233_Fm0.txt
agrep -0 -c 'GATTTATGCCAAGGCAT' *.fastq > count/B6234_Fm0.txt
agrep -0 -c 'TTGCCCCACTAGACCTA' *.fastq > count/B6235_Fm0.txt
agrep -0 -c 'GGGAACAGTACTCACAC' *.fastq > count/B6238_Fm0.txt
agrep -0 -c 'AGAGTCCTCGGACAACT' *.fastq > count/B6239_Fm0.txt
agrep -0 -c 'GTCGGCGAAGCACACAT' *.fastq > count/B6240_Fm0.txt
agrep -0 -c 'CCTCCAGATGGCGTCTT' *.fastq > count/B6241_Fm0.txt
agrep -0 -c 'TAGTTCTCGTACCCTGG' *.fastq > count/B6242_Fm0.txt
agrep -0 -c 'ATTCAATCCGGACCAAT' *.fastq > count/B6243_Fm0.txt
agrep -0 -c 'CGCAATCATGCTGTTGG' *.fastq > count/B6244_Fm0.txt
agrep -0 -c 'CGTGTTCATGATCGTAT' *.fastq > count/B6246_Fm0.txt
agrep -0 -c 'ATTGACCAGCTACCGCG' *.fastq > count/B6247_Fm0.txt
agrep -0 -c 'AGGGAGATGAACGCCGA' *.fastq > count/B6248_Fm0.txt
agrep -0 -c 'GAGATTGACTCACTACG' *.fastq > count/B6249_Fm0.txt
agrep -0 -c 'AGTGCATCCGGTAGTGT' *.fastq > count/B6250_Fm0.txt
agrep -0 -c 'CCACAAAGTAATGGCAG' *.fastq > count/B6251_Fm0.txt
agrep -0 -c 'ATTTCACCTGCTACCCA' *.fastq > count/B6252_Fm0.txt
agrep -0 -c 'CCTTTGGGAACTCTTAA' *.fastq > count/B6253_Fm0.txt
agrep -0 -c 'GATCAATGCGAACAATC' *.fastq > count/B6255_Fm0.txt
agrep -0 -c 'TACACGCACGGACCTGA' *.fastq > count/B6256_Fm0.txt
agrep -0 -c 'TACGAAGTACTGGAAGT' *.fastq > count/B6257_Fm0.txt
agrep -0 -c 'CGCCGAAAACTGTGTCG' *.fastq > count/B6258_Fm0.txt
agrep -0 -c 'GTCAAATTGTGTCCGGT' *.fastq > count/B6259_Fm0.txt
agrep -0 -c 'CAAACGTTTGGCTAGGC' *.fastq > count/B6260_Fm0.txt
agrep -0 -c 'GGTGACGAGTATGCTAC' *.fastq > count/B6261_Fm0.txt
agrep -0 -c 'GATCTTTGCCGTGCACG' *.fastq > count/B6263_Fm0.txt
agrep -0 -c 'TTGAAGGACTCCATGGA' *.fastq > count/B6264_Fm0.txt
agrep -0 -c 'CGCCAACCTCCACCAAA' *.fastq > count/B6265_Fm0.txt
agrep -0 -c 'ACGGTAGATTATCCAGG' *.fastq > count/B6266_Fm0.txt
agrep -0 -c 'AGCGTAGTCTACTCCCC' *.fastq > count/B6267_Fm0.txt
agrep -0 -c 'CTCTTGCGGTAGCCAAA' *.fastq > count/B6268_Fm0.txt
agrep -0 -c 'GTGAGCCTATTGAAAGG' *.fastq > count/B6270_Fm0.txt
agrep -0 -c 'GATTCCGATGAGCTAGA' *.fastq > count/B6271_Fm0.txt
agrep -0 -c 'TGGCAACTCATGAACAA' *.fastq > count/B6272_Fm0.txt
agrep -0 -c 'CGCTCCTATTTCGTCAT' *.fastq > count/B6273_Fm0.txt
agrep -0 -c 'CGTATAGTAGCCTAGCG' *.fastq > count/B6274_Fm0.txt
agrep -0 -c 'CACGAGTACCGCCTTAG' *.fastq > count/B6275_Fm0.txt
agrep -0 -c 'GGGTTAACCATAGATCA' *.fastq > count/B6276_Fm0.txt
agrep -0 -c 'GTTCAAGGTCGACGTGT' *.fastq > count/B6277_Fm0.txt
agrep -0 -c 'ATGGAAGAGTCGTTTGA' *.fastq > count/B6278_Fm0.txt
agrep -0 -c 'CAAATTCATCATGTCCG' *.fastq > count/B6279_Fm0.txt
agrep -0 -c 'GAGTAAGTCTCCAGGTC' *.fastq > count/B6280_Fm0.txt
agrep -0 -c 'TCTAATAGGGGTATGTC' *.fastq > count/B6281_Fm0.txt
agrep -0 -c 'CTGCCGCACAATACGTT' *.fastq > count/B6282_Fm0.txt
agrep -0 -c 'GGGGCTCGTTATTACAG' *.fastq > count/B6283_Fm0.txt
agrep -0 -c 'CGAATGCTAGGGTTCAC' *.fastq > count/B6285_Fm0.txt
agrep -0 -c 'GTAAGACACCGGTTCAA' *.fastq > count/B6286_Fm0.txt
agrep -0 -c 'GTGGTCGATTTCTGAAG' *.fastq > count/B6288_Fm0.txt
agrep -0 -c 'AGTCAAAAGCGGACACG' *.fastq > count/B6289_Fm0.txt
agrep -0 -c 'CGAAAGATGTATAGCGA' *.fastq > count/B6290_Fm0.txt
agrep -0 -c 'TCAAGACCCCTCACAGG' *.fastq > count/B6291_Fm0.txt
agrep -0 -c 'GCGCCACCGAAAAGATC' *.fastq > count/B6293_Fm0.txt
agrep -0 -c 'AAGGGCACGGAGTAAAT' *.fastq > count/B6295_Fm0.txt
agrep -0 -c 'GTCTGATCTCATGCATC' *.fastq > count/B6296_Fm0.txt
agrep -0 -c 'ATACTGCCGTTTCTGGT' *.fastq > count/B6297_Fm0.txt
agrep -0 -c 'ATTTTCGGCTTTTGGGT' *.fastq > count/B6299_Fm0.txt
agrep -0 -c 'ATCTGTGATAAGTCGGT' *.fastq > count/B6301_Fm0.txt
agrep -0 -c 'TAGTTTCGCACCGCAGT' *.fastq > count/B6302_Fm0.txt
agrep -0 -c 'CATGTCGGAGAGGTGTC' *.fastq > count/B6304_Fm0.txt
agrep -0 -c 'AACCCGTTATAGGGGTT' *.fastq > count/B6306_Fm0.txt
agrep -0 -c 'GCAAGCGAGCTAGACTA' *.fastq > count/B6307_Fm0.txt
agrep -0 -c 'TAGACGTTAAGGACCGA' *.fastq > count/B6308_Fm0.txt
agrep -0 -c 'GACTCGTCAAGCAAAGG' *.fastq > count/B6309_Fm0.txt
agrep -0 -c 'GTTGACGCGGTCCTACA' *.fastq > count/B6310_Fm0.txt
agrep -0 -c 'TTCAGTCCGTGCCTTTT' *.fastq > count/B6311_Fm0.txt
agrep -0 -c 'AAGTCCTCGTCATTTCT' *.fastq > count/B6312_Fm0.txt
agrep -0 -c 'TGAAAGGGGGCACAATT' *.fastq > count/B6313_Fm0.txt
agrep -0 -c 'GAGGGTTCATAGTAAGG' *.fastq > count/B6314_Fm0.txt
agrep -0 -c 'TCATGTGGGGGTTAATA' *.fastq > count/B6315_Fm0.txt
agrep -0 -c 'GTGAGCTTGTCGCACAC' *.fastq > count/B6316_Fm0.txt
agrep -0 -c 'AGTCTTAGCGTCGGGGT' *.fastq > count/B6317_Fm0.txt
agrep -0 -c 'TGACCTAGCGGTGAGGA' *.fastq > count/B6318_Fm0.txt
agrep -0 -c 'GCTGGCTATCAAATGGA' *.fastq > count/B6319_Fm0.txt
agrep -0 -c 'CGCAAATCTTCAGTAGC' *.fastq > count/B6320_Fm0.txt
agrep -0 -c 'TTCCAGCATAAGAGGAA' *.fastq > count/B6321_Fm0.txt
agrep -0 -c 'GTTAAGATTCCGTTGCG' *.fastq > count/B6322_Fm0.txt
agrep -0 -c 'CCTATCGTAGTTCATGT' *.fastq > count/B6323_Fm0.txt
agrep -0 -c 'TGCCAACCTTCGACAAT' *.fastq > count/B6324_Fm0.txt
agrep -0 -c 'ACATAAAGTAACCCTCG' *.fastq > count/B6325_Fm0.txt
agrep -0 -c 'GATGATTAGGTACTCGA' *.fastq > count/B6326_Fm0.txt
agrep -0 -c 'AGCTTCATACCAAGTCT' *.fastq > count/B6327_Fm0.txt
agrep -0 -c 'CTTCGACCAATAACAGC' *.fastq > count/B6328_Fm0.txt
agrep -0 -c 'AAGTTACATGTGCCTGA' *.fastq > count/B6329_Fm0.txt
agrep -0 -c 'TATTCTAAAGGGAAGGG' *.fastq > count/B6331_Fm0.txt
agrep -0 -c 'CTACGCCAACATCTCTT' *.fastq > count/B6332_Fm0.txt
agrep -0 -c 'CGATATCCTGTCATGGG' *.fastq > count/B6333_Fm0.txt
agrep -0 -c 'CGGAAACTAGTAGGTCC' *.fastq > count/B6334_Fm0.txt
agrep -0 -c 'CGCACACGGAGCATTTT' *.fastq > count/B6335_Fm0.txt
agrep -0 -c 'ATAATGCACTTGGCCGC' *.fastq > count/B6336_Fm0.txt
agrep -0 -c 'CGGCGACATCGTTAAAA' *.fastq > count/B6338_Fm0.txt
agrep -0 -c 'ACCTGGCATTTGTTCGT' *.fastq > count/B6339_Fm0.txt
agrep -0 -c 'TCGCGGAAGATCTGCCT' *.fastq > count/B6340_Fm0.txt
agrep -0 -c 'GACTTATGGAGTGTCGA' *.fastq > count/B6341_Fm0.txt
agrep -0 -c 'TCTATGAACCGGCCTAT' *.fastq > count/B6342_Fm0.txt
agrep -0 -c 'CTGCTAGCCTAATGGTC' *.fastq > count/B6343_Fm0.txt
agrep -0 -c 'GTAGGGCACTAATCCCG' *.fastq > count/B6344_Fm0.txt
agrep -0 -c 'CAAAGAAACGACCCGTT' *.fastq > count/B6345_Fm0.txt
agrep -0 -c 'TACACTAACTAGCCACC' *.fastq > count/B6346_Fm0.txt
agrep -0 -c 'TTCGACGCCATAGGAGT' *.fastq > count/B6347_Fm0.txt
agrep -0 -c 'AGAGAACCCGCACAGTC' *.fastq > count/B6348_Fm0.txt
agrep -0 -c 'GTTTTATGTGCGCTAGC' *.fastq > count/B6349_Fm0.txt
agrep -0 -c 'TAGGTCCCGGACATAAT' *.fastq > count/B6350_Fm0.txt
agrep -0 -c 'ACAAGTGATCACGCCAG' *.fastq > count/B6351_Fm0.txt
agrep -0 -c 'TACTCGGACTGTAGACA' *.fastq > count/B6352_Fm0.txt
agrep -0 -c 'TATCATTACTAGGCCAG' *.fastq > count/B6353_Fm0.txt
agrep -0 -c 'CCTCCGTAAGGGATCGT' *.fastq > count/B6354_Fm0.txt
agrep -0 -c 'AATAATCGTGCCACCAG' *.fastq > count/B6355_Fm0.txt
agrep -0 -c 'GGTCAAAGCGCAATAAT' *.fastq > count/B6356_Fm0.txt
agrep -0 -c 'ACCACCGGCTAGATGTG' *.fastq > count/B6359_Fm0.txt
agrep -0 -c 'GGCAACTGCGCGTTTAA' *.fastq > count/B6361_Fm0.txt
agrep -0 -c 'TATCCATGCATGCACGT' *.fastq > count/B6362_Fm0.txt
agrep -0 -c 'AAGGGCTCTGCCTAAAC' *.fastq > count/B6363_Fm0.txt
agrep -0 -c 'ACCAAGGCTTAAGGACA' *.fastq > count/B6364_Fm0.txt
agrep -0 -c 'GGTATGTGACGCGGATA' *.fastq > count/B6365_Fm0.txt
agrep -0 -c 'CCATGTTAACGACAAGA' *.fastq > count/B6366_Fm0.txt
agrep -0 -c 'CTTGGAAAGAGATGTCT' *.fastq > count/B6368_Fm0.txt
agrep -0 -c 'GGTCAAGGATGTGGACA' *.fastq > count/B6369_Fm0.txt
agrep -0 -c 'GGGAATGATGCTTCGAG' *.fastq > count/B6370_Fm0.txt
agrep -0 -c 'CGATAGCATGCTCGAGG' *.fastq > count/B6372_Fm0.txt
agrep -0 -c 'GATGCGCTTTTCCGGTT' *.fastq > count/B6373_Fm0.txt
agrep -0 -c 'TGGAATGTGGCTCGACG' *.fastq > count/B6374_Fm0.txt
agrep -0 -c 'TCAGTCGGCGTCTCGTA' *.fastq > count/B6375_Fm0.txt
agrep -0 -c 'GCAGTCTGAATGTCACC' *.fastq > count/B6376_Fm0.txt
agrep -0 -c 'CTACGAGCCGAATATGT' *.fastq > count/B6377_Fm0.txt
agrep -0 -c 'ATCTTAGTAGCGCGTAG' *.fastq > count/B6379_Fm0.txt
agrep -0 -c 'AGGTGACATTAGGTCGC' *.fastq > count/B6380_Fm0.txt
agrep -0 -c 'CCGTGGAGGACTTAAGG' *.fastq > count/B6381_Fm0.txt
agrep -0 -c 'CCGGCCAGAAATGTCTC' *.fastq > count/B6382_Fm0.txt
agrep -0 -c 'TCGGGAGGTGTTTTAGA' *.fastq > count/B6384_Fm0.txt
agrep -0 -c 'TAGCGATATCTGTGGCC' *.fastq > count/B6385_Fm0.txt
agrep -0 -c 'GGCGTAGTCTTTACGCG' *.fastq > count/B6386_Fm0.txt
agrep -0 -c 'TATTCGACTTCCATGTC' *.fastq > count/B6388_Fm0.txt
agrep -0 -c 'GGCGGCTAGTAATAGCC' *.fastq > count/B6389_Fm0.txt
agrep -0 -c 'TTGACCAGCGGACACTT' *.fastq > count/B6390_Fm0.txt
agrep -0 -c 'AAGTATTCTCCCCGACG' *.fastq > count/B6391_Fm0.txt
agrep -0 -c 'TATCGTCGAGGCGCATT' *.fastq > count/B6392_Fm0.txt
agrep -0 -c 'AAGTCGTCACGGTATGC' *.fastq > count/B6393_Fm0.txt
agrep -0 -c 'GGAGTATCAACAAAGTC' *.fastq > count/B6394_Fm0.txt
agrep -0 -c 'ACAAACCCCTTAAAGCC' *.fastq > count/B6395_Fm0.txt
agrep -0 -c 'TTGAGTGGTCGTTGATC' *.fastq > count/B6396_Fm0.txt
agrep -0 -c 'CCGGTGCGAGCTTTGAA' *.fastq > count/B6397_Fm0.txt
agrep -0 -c 'GGGAACACTGTACTCTC' *.fastq > count/B6398_Fm0.txt
agrep -0 -c 'GTTTGGCGATTCGCCTC' *.fastq > count/B6399_Fm0.txt
agrep -0 -c 'GTAGCCTAGTATCCACG' *.fastq > count/B6401_Fm0.txt
agrep -0 -c 'GACACCCATGGTCGATT' *.fastq > count/B6402_Fm0.txt
agrep -0 -c 'AGGTGACTCCATACTCG' *.fastq > count/B6403_Fm0.txt
agrep -0 -c 'GCGAACGCTTGAGTCTT' *.fastq > count/B6404_Fm0.txt
agrep -0 -c 'TTATATTGATCTGGCGG' *.fastq > count/B6405_Fm0.txt
agrep -0 -c 'GTTCCTCATGTGCAGCG' *.fastq > count/B6407_Fm0.txt
agrep -0 -c 'AGCTGATACAGTGCGCA' *.fastq > count/B6408_Fm0.txt
agrep -0 -c 'CGTCGCTAAATCTCACC' *.fastq > count/B6409_Fm0.txt
agrep -0 -c 'AACAGCAAGCCATAGTC' *.fastq > count/B6411_Fm0.txt
agrep -0 -c 'TGTCGGACTAGATGATT' *.fastq > count/B6412_Fm0.txt
agrep -0 -c 'GGCTAAAGTTATGAACG' *.fastq > count/B6413_Fm0.txt
agrep -0 -c 'AACGGAACAGGCTATTG' *.fastq > count/B6414_Fm0.txt
agrep -0 -c 'ATGAGCTAGCTTTTCCC' *.fastq > count/B6415_Fm0.txt
agrep -0 -c 'TTCCTATAAGCGCGTGA' *.fastq > count/B6416_Fm0.txt
agrep -0 -c 'AGGGACCTAGTGGATAC' *.fastq > count/B6418_Fm0.txt
agrep -0 -c 'AGCCTTTCAGCGCCAAC' *.fastq > count/B6420_Fm0.txt
agrep -0 -c 'CTTATCCAATCGGAGAT' *.fastq > count/B6421_Fm0.txt
agrep -0 -c 'TGTGTAAGGTCCAGCGC' *.fastq > count/B6422_Fm0.txt
agrep -0 -c 'CTCTGAACGTCGTACGC' *.fastq > count/B6423_Fm0.txt
agrep -0 -c 'GCGTTATATGCTGCCAA' *.fastq > count/B6424_Fm0.txt
agrep -0 -c 'AAGTAGGAAAGGCATTG' *.fastq > count/B6425_Fm0.txt
agrep -0 -c 'GTCTGAAGTAGTACGCT' *.fastq > count/B6426_Fm0.txt
agrep -0 -c 'GATTGCAAGCTTAACGG' *.fastq > count/B6427_Fm0.txt
agrep -0 -c 'CATTCTAGGTTTTCGCT' *.fastq > count/B6429_Fm0.txt
agrep -0 -c 'ATCGATAGGGTCTCTCG' *.fastq > count/B6430_Fm0.txt
agrep -0 -c 'ATCGTGCTTCATCGCAA' *.fastq > count/B6432_Fm0.txt
agrep -0 -c 'AGCACGAACTATCAAGT' *.fastq > count/B6433_Fm0.txt
agrep -0 -c 'GACTAGCAACTGCCGTA' *.fastq > count/B6435_Fm0.txt
agrep -0 -c 'TCTGTCCGCTGGAATCG' *.fastq > count/B6436_Fm0.txt
agrep -0 -c 'CACTTTACGTCCTCTCT' *.fastq > count/B6437_Fm0.txt
agrep -0 -c 'GTGGTCGTTACTGCGTG' *.fastq > count/B6439_Fm0.txt
agrep -0 -c 'TGCCGCAATAGGGAGAC' *.fastq > count/B6440_Fm0.txt
agrep -0 -c 'GGGGGACTTCCGTTTTT' *.fastq > count/B6441_Fm0.txt
agrep -0 -c 'GTCGCGTCATTGTAGCA' *.fastq > count/B6442_Fm0.txt
agrep -0 -c 'CGAGCATGTTGGATATT' *.fastq > count/B6443_Fm0.txt
agrep -0 -c 'TGAGGCCCTTCGATACG' *.fastq > count/B6444_Fm0.txt
agrep -0 -c 'CTGATCGTACGCATATG' *.fastq > count/B6445_Fm0.txt
agrep -0 -c 'GAGTCCAGGCGTGCTAT' *.fastq > count/B6446_Fm0.txt
agrep -0 -c 'GTTTCGCGCGTTACCAG' *.fastq > count/B6447_Fm0.txt
agrep -0 -c 'TAAGCTCCTGAAGGTTT' *.fastq > count/B6449_Fm0.txt
agrep -0 -c 'TATCATGGCCGGTATAT' *.fastq > count/B6450_Fm0.txt
agrep -0 -c 'ACCATGCGTGCAAACAC' *.fastq > count/B6451_Fm0.txt
agrep -0 -c 'GCGATCTTCGGCGCAAT' *.fastq > count/B6452_Fm0.txt
agrep -0 -c 'TTACAGTCGCCGAAGTG' *.fastq > count/B6453_Fm0.txt
agrep -0 -c 'GGTGTCAGCCTCAACTG' *.fastq > count/B6454_Fm0.txt
agrep -0 -c 'GCCCGAGGACTATTACG' *.fastq > count/B6455_Fm0.txt
agrep -0 -c 'CCGTTTGGTATTGGGCA' *.fastq > count/B6457_Fm0.txt
agrep -0 -c 'GGATCAAACGGAAAAGG' *.fastq > count/B6458_Fm0.txt
agrep -0 -c 'AGGAACTCTAGACCCAA' *.fastq > count/B6459_Fm0.txt
agrep -0 -c 'AGATGTAGACAAACGTG' *.fastq > count/B6460_Fm0.txt
agrep -0 -c 'TAAGAACCTCGGTAGCG' *.fastq > count/B6461_Fm0.txt
agrep -0 -c 'TATCTAACGTGGGCAAG' *.fastq > count/B6462_Fm0.txt
agrep -0 -c 'GCTAAGGATCTTGGCGT' *.fastq > count/B6463_Fm0.txt
agrep -0 -c 'GTCTTAGCGCCCAGTTC' *.fastq > count/B6464_Fm0.txt
agrep -0 -c 'CAGGCTCGTACGAAATC' *.fastq > count/B6465_Fm0.txt
agrep -0 -c 'CCAGACCGAGACAACAT' *.fastq > count/B6466_Fm0.txt
agrep -0 -c 'CAGGTATCCCTTAAACT' *.fastq > count/B6468_Fm0.txt
agrep -0 -c 'CAAACAAGGAACGACAT' *.fastq > count/B6469_Fm0.txt
agrep -0 -c 'GAGTGAATCGTTACATC' *.fastq > count/B6471_Fm0.txt
agrep -0 -c 'TTGCCCTTGTAAACAGT' *.fastq > count/B6472_Fm0.txt
agrep -0 -c 'GCAAAGATACTGCCTAT' *.fastq > count/B6473_Fm0.txt
agrep -0 -c 'CTACGAAAGGACCCGAT' *.fastq > count/B6474_Fm0.txt
agrep -0 -c 'CGCCCATATTGAAACCA' *.fastq > count/B6477_Fm0.txt
agrep -0 -c 'ACAGTCGTAAGGAGTTC' *.fastq > count/B6478_Fm0.txt
agrep -0 -c 'CTGTCCGCAGCATACGA' *.fastq > count/B6479_Fm0.txt
agrep -0 -c 'CTACGATATGACCCTGA' *.fastq > count/B6480_Fm0.txt
agrep -0 -c 'GGAACCGATATGAATAC' *.fastq > count/B6483_Fm0.txt
agrep -0 -c 'GGAGCCATTTATGTCGT' *.fastq > count/B6484_Fm0.txt
agrep -0 -c 'CATCATAGCACGCTGAA' *.fastq > count/B6485_Fm0.txt
agrep -0 -c 'AGTAAGCGAGCAGACTC' *.fastq > count/B6486_Fm0.txt
agrep -0 -c 'GGAAGGGGGGGAGATAA' *.fastq > count/B6487_Fm0.txt
agrep -0 -c 'AGACGATGTTTGACTGG' *.fastq > count/B6488_Fm0.txt
agrep -0 -c 'GGTCTAAACTTTCAGGC' *.fastq > count/B6489_Fm0.txt
agrep -0 -c 'CCTGTCGGGACAGTCTT' *.fastq > count/B6490_Fm0.txt
agrep -0 -c 'TGAATACAGCGACAACA' *.fastq > count/B6492_Fm0.txt
agrep -0 -c 'AGCCTAGGACCTTTTCA' *.fastq > count/B6493_Fm0.txt
agrep -0 -c 'ACCTCGCTGTCACACAG' *.fastq > count/B6494_Fm0.txt
agrep -0 -c 'AGACCCAATCCCGACAG' *.fastq > count/B6495_Fm0.txt
agrep -0 -c 'ACATACGTGCTATGTCA' *.fastq > count/B6496_Fm0.txt
agrep -0 -c 'AGCACAGGTTAAGTGAA' *.fastq > count/B6497_Fm0.txt
agrep -0 -c 'AGGGTTACTGGGTCTGC' *.fastq > count/B6498_Fm0.txt
agrep -0 -c 'TGGATACAATGGGCTCT' *.fastq > count/B6499_Fm0.txt
agrep -0 -c 'AGGGCCTACCTATCACA' *.fastq > count/B6500_Fm0.txt
agrep -0 -c 'GTGAGCGCAAGACGATA' *.fastq > count/B6501_Fm0.txt
agrep -0 -c 'TTGCAGTTGTAACCCTA' *.fastq > count/B6502_Fm0.txt
agrep -0 -c 'GATCCGTTCACCATAAG' *.fastq > count/B6504_Fm0.txt
agrep -0 -c 'AAGACCTGAGGGTTGCT' *.fastq > count/B6505_Fm0.txt
agrep -0 -c 'CAGTGCACTGCTCCAGA' *.fastq > count/B6506_Fm0.txt
agrep -0 -c 'TAACTCCGCACAGGCAT' *.fastq > count/B6508_Fm0.txt
agrep -0 -c 'TCTGAAGCGATGCCAAC' *.fastq > count/B6509_Fm0.txt
agrep -0 -c 'GGTCACGTCTCAAAGCG' *.fastq > count/B6510_Fm0.txt
agrep -0 -c 'TATGTGCTATGGGCAAA' *.fastq > count/B6511_Fm0.txt
agrep -0 -c 'TGCGAAGTCACTACTTA' *.fastq > count/B6514_Fm0.txt
agrep -0 -c 'CTTACGCGGAGGTCGAA' *.fastq > count/B6515_Fm0.txt
agrep -0 -c 'ATTCTAGTTAGCGCGAA' *.fastq > count/B6516_Fm0.txt
agrep -0 -c 'CTTAAAAGTGTGTGCCC' *.fastq > count/B6517_Fm0.txt
agrep -0 -c 'TGAGTGTTACACAGTTC' *.fastq > count/B6518_Fm0.txt
agrep -0 -c 'CATACGTCCACTGCTAC' *.fastq > count/B6520_Fm0.txt
agrep -0 -c 'GTTAGCTGGGATGCCAT' *.fastq > count/B6521_Fm0.txt
agrep -0 -c 'TATGGCACACTTGGCGG' *.fastq > count/B6522_Fm0.txt
agrep -0 -c 'CGAGTATCTTTCTTCCC' *.fastq > count/B6523_Fm0.txt
agrep -0 -c 'TAGAGGTGTCGCACAGT' *.fastq > count/B6524_Fm0.txt
agrep -0 -c 'ACCATAATTCAACGTGC' *.fastq > count/B6525_Fm0.txt
agrep -0 -c 'ACTCGACTCAGCGGCTT' *.fastq > count/B6526_Fm0.txt
agrep -0 -c 'TATGATGCCAACCAGAG' *.fastq > count/B6527_Fm0.txt
agrep -0 -c 'ATACGGTTCCGAGACGT' *.fastq > count/B6528_Fm0.txt
agrep -0 -c 'GCACTAACCCTACAGAG' *.fastq > count/B6529_Fm0.txt
agrep -0 -c 'ACGATACTTAACGGCCG' *.fastq > count/B6531_Fm0.txt
agrep -0 -c 'TTCCGTCGCGAGGAAAC' *.fastq > count/B6532_Fm0.txt
agrep -0 -c 'TGTAGTCTTTGGTTGCC' *.fastq > count/B6534_Fm0.txt
agrep -0 -c 'GGTTGGCCCTTGATCTC' *.fastq > count/B6536_Fm0.txt
agrep -0 -c 'GACAACAGCATTAAGCA' *.fastq > count/B6537_Fm0.txt
agrep -0 -c 'TTCCTTTAGGGTGACCA' *.fastq > count/B6538_Fm0.txt
agrep -0 -c 'CGAGGACTGCGATATGG' *.fastq > count/B6540_Fm0.txt
agrep -0 -c 'TAGTCTGCCATTAGACA' *.fastq > count/B6541_Fm0.txt
agrep -0 -c 'TACGCCCTAGGTTTGAG' *.fastq > count/B6542_Fm0.txt
agrep -0 -c 'GGTTCAGAACTGCGCAG' *.fastq > count/B6543_Fm0.txt
agrep -0 -c 'ATTGGGTGATCGTTTGT' *.fastq > count/B6544_Fm0.txt
agrep -0 -c 'TACTGTCCGAGACGCAA' *.fastq > count/B6545_Fm0.txt
agrep -0 -c 'TGCCGTTCATGTTACGA' *.fastq > count/B6546_Fm0.txt
agrep -0 -c 'CTGCGATACTGCAAGCA' *.fastq > count/B6547_Fm0.txt
agrep -0 -c 'GTCCTTACCAAAAGTAG' *.fastq > count/B6548_Fm0.txt
agrep -0 -c 'TTACGTTGCAGTGGAAA' *.fastq > count/B6549_Fm0.txt
agrep -0 -c 'CAGACCACGTACACATC' *.fastq > count/B6550_Fm0.txt
agrep -0 -c 'AAGAGCTGTTACGAGCA' *.fastq > count/B6552_Fm0.txt
agrep -0 -c 'AAGTACGTTCGTAAGGG' *.fastq > count/B6553_Fm0.txt
agrep -0 -c 'GATACCGCTTGGAATAC' *.fastq > count/B6555_Fm0.txt
agrep -0 -c 'ACTGAGCGATGGCTCCT' *.fastq > count/B6556_Fm0.txt
agrep -0 -c 'TGCAAAAATAGGCGTCG' *.fastq > count/B6557_Fm0.txt
agrep -0 -c 'CGACTGATTTTGATCAG' *.fastq > count/B6558_Fm0.txt
agrep -0 -c 'GCAATGTACCTGCAATA' *.fastq > count/B6559_Fm0.txt
agrep -0 -c 'GGTGGACAAACTGTTAC' *.fastq > count/B6560_Fm0.txt
agrep -0 -c 'CATTCCCGTGATCCCCA' *.fastq > count/B6561_Fm0.txt
agrep -0 -c 'ACCATGTCCCCTTCAGG' *.fastq > count/B6562_Fm0.txt
agrep -0 -c 'GCCTCGGCTAACTTGTA' *.fastq > count/B6563_Fm0.txt
agrep -0 -c 'TTGCTTGACGCACATTC' *.fastq > count/B6564_Fm0.txt
agrep -0 -c 'GCAGGGAATTGTCTCGC' *.fastq > count/B6565_Fm0.txt
agrep -0 -c 'TTCGTCCCACGCGTTTT' *.fastq > count/B6567_Fm0.txt
agrep -0 -c 'TTCAGGCAACGTGTATC' *.fastq > count/B6568_Fm0.txt
agrep -0 -c 'CTTGTAGCGCCTTTGAT' *.fastq > count/B6569_Fm0.txt
agrep -0 -c 'GGACATAGGTTTGTAGC' *.fastq > count/B6570_Fm0.txt
agrep -0 -c 'GCTCAAAGTGGTTACGC' *.fastq > count/B6571_Fm0.txt
agrep -0 -c 'ACCTCTAAATCGAACCT' *.fastq > count/B6572_Fm0.txt
agrep -0 -c 'GATGTCATGGACGTTCA' *.fastq > count/B6573_Fm0.txt
agrep -0 -c 'TACCCAGTGCTGGACTA' *.fastq > count/B6575_Fm0.txt
agrep -0 -c 'CCACCTTAGGCACTCTG' *.fastq > count/B6576_Fm0.txt
agrep -0 -c 'ATCGTCTTAGCCAACCA' *.fastq > count/B6577_Fm0.txt
agrep -0 -c 'GCGTTTTCCTGTGGTGG' *.fastq > count/B6578_Fm0.txt
agrep -0 -c 'TGTGAGTCTTTGTGCGA' *.fastq > count/B6579_Fm0.txt
agrep -0 -c 'GGAGCGAAGTTAACGCT' *.fastq > count/B6580_Fm0.txt
agrep -0 -c 'GTTTTGGGCCCACAAGA' *.fastq > count/B6581_Fm0.txt
agrep -0 -c 'CAACCCACCAGTTTTTA' *.fastq > count/B6585_Fm0.txt
agrep -0 -c 'CCGCATTTGATTTGGCT' *.fastq > count/B6586_Fm0.txt
agrep -0 -c 'ATACCGTTTTAGGGCTT' *.fastq > count/B6587_Fm0.txt
agrep -0 -c 'TATAGTATAGGCGCGTA' *.fastq > count/B6589_Fm0.txt
agrep -0 -c 'CCTATGACGCAAACATC' *.fastq > count/B6591_Fm0.txt
agrep -0 -c 'ACCGCCAATCCAAAACC' *.fastq > count/B6592_Fm0.txt
agrep -0 -c 'AAGTGTAGTACGGACCG' *.fastq > count/B6593_Fm0.txt
agrep -0 -c 'ACTGGGTTGACGTATCC' *.fastq > count/B6594_Fm0.txt
agrep -0 -c 'GCTGGGTGGTGATCCAA' *.fastq > count/B6597_Fm0.txt
agrep -0 -c 'ACGACTGACCTTGCATT' *.fastq > count/B6598_Fm0.txt
agrep -0 -c 'AATCCTCGTGAGAACTG' *.fastq > count/B6599_Fm0.txt
agrep -0 -c 'GACGGAATGGGCTTCGT' *.fastq > count/B6600_Fm0.txt
agrep -0 -c 'TGCTTAGGGTCGATTCC' *.fastq > count/B6601_Fm0.txt
agrep -0 -c 'AGATACTCTAGCATGTG' *.fastq > count/B6602_Fm0.txt
agrep -0 -c 'CCAGTTACCTTGCAAGG' *.fastq > count/B6604_Fm0.txt
agrep -0 -c 'AGGCTCCGCGTGCATAA' *.fastq > count/B6606_Fm0.txt
agrep -0 -c 'AGACACTTACCCCAGGG' *.fastq > count/B6607_Fm0.txt
agrep -0 -c 'AAGGCAAAAACTAGTCG' *.fastq > count/B6608_Fm0.txt
agrep -0 -c 'TGTCATCGACGATACGT' *.fastq > count/B6609_Fm0.txt
agrep -0 -c 'AGACGTGGACCCATGAT' *.fastq > count/B6610_Fm0.txt
agrep -0 -c 'CAAAGCCATCCAGAGGT' *.fastq > count/B6611_Fm0.txt
agrep -0 -c 'CAGTGTTCTTGACTACG' *.fastq > count/B6612_Fm0.txt
agrep -0 -c 'GCGAAAGTATCCCTCTA' *.fastq > count/B6613_Fm0.txt
agrep -0 -c 'CAACGTTGAATAGTAGC' *.fastq > count/B6614_Fm0.txt
agrep -0 -c 'AGGAGCGAAAAGCGGGA' *.fastq > count/B6615_Fm0.txt
agrep -0 -c 'GACATCTCTTGAGACGA' *.fastq > count/B6617_Fm0.txt
agrep -0 -c 'CTAGCTGGTTAGCAGGG' *.fastq > count/B6619_Fm0.txt
agrep -0 -c 'ACGATCCCGATTGACCC' *.fastq > count/B6621_Fm0.txt
agrep -0 -c 'CGAGACAAGTGACCAGC' *.fastq > count/B6624_Fm0.txt
agrep -0 -c 'AGGGAGCCGACTGAATT' *.fastq > count/B6625_Fm0.txt
agrep -0 -c 'ACATGGTGTAGCATCGT' *.fastq > count/B6626_Fm0.txt
agrep -0 -c 'TTCCGCTGACTACGTGC' *.fastq > count/B6627_Fm0.txt
agrep -0 -c 'GCATACAGCTGATGGAA' *.fastq > count/B6628_Fm0.txt
agrep -0 -c 'CATGGTTGAACAAGCTT' *.fastq > count/B6629_Fm0.txt
agrep -0 -c 'GGGGCCTGCTTTAAGTC' *.fastq > count/B6630_Fm0.txt
agrep -0 -c 'AGTGCGCGGGATTTCGA' *.fastq > count/B6633_Fm0.txt
agrep -0 -c 'CGGAAATGCTAAAGACT' *.fastq > count/B6634_Fm0.txt
agrep -0 -c 'TTCATTGCCCTTAGCCC' *.fastq > count/B6635_Fm0.txt
agrep -0 -c 'GTTGATACACATCGATC' *.fastq > count/B6636_Fm0.txt
agrep -0 -c 'GCTAGACGCCGTAAACT' *.fastq > count/B6637_Fm0.txt
agrep -0 -c 'AACTGCGTGCGGGTCTA' *.fastq > count/B6639_Fm0.txt
agrep -0 -c 'ATCCGTACTAGGCGTAT' *.fastq > count/B6641_Fm0.txt
agrep -0 -c 'TCAAGATCACCTGCGTG' *.fastq > count/B6642_Fm0.txt
agrep -0 -c 'TGTAGCTACGCGTAGCC' *.fastq > count/B6645_Fm0.txt
agrep -0 -c 'GAGAAATACCGCAGCTG' *.fastq > count/B6646_Fm0.txt
agrep -0 -c 'GGTGTACGCTTTGGTTC' *.fastq > count/B6647_Fm0.txt
agrep -0 -c 'CACTGTACGTTTGCATA' *.fastq > count/B6648_Fm0.txt
agrep -0 -c 'AACGGAGGCTAAGGGAT' *.fastq > count/B6649_Fm0.txt
agrep -0 -c 'GATTATTGTACCTCAGC' *.fastq > count/B6650_Fm0.txt
agrep -0 -c 'CGGTTTGTAGGAGCCTC' *.fastq > count/B6652_Fm0.txt
agrep -0 -c 'AACACTATGCGTCATCA' *.fastq > count/B6653_Fm0.txt
agrep -0 -c 'TCAGAGACATGCTACCG' *.fastq > count/B6655_Fm0.txt
agrep -0 -c 'TAGCGCGAGGGTAAACA' *.fastq > count/B6657_Fm0.txt
agrep -0 -c 'ACCATATCGTCAACTGC' *.fastq > count/B6659_Fm0.txt
agrep -0 -c 'TGCCGGTACATTCGTAG' *.fastq > count/B6660_Fm0.txt
agrep -0 -c 'CGAGACAAAATAGAGGT' *.fastq > count/B6661_Fm0.txt
agrep -0 -c 'AGTGCAGTGATGCGTGA' *.fastq > count/B6662_Fm0.txt
agrep -0 -c 'CTCGGAGACAAGCTATC' *.fastq > count/B6663_Fm0.txt
agrep -0 -c 'CGTAGGCATACTCCCAC' *.fastq > count/B6664_Fm0.txt
agrep -0 -c 'GACCACGGGACAATCAA' *.fastq > count/B6666_Fm0.txt
agrep -0 -c 'TGTGACTTCGCGGAGCA' *.fastq > count/B6667_Fm0.txt
agrep -0 -c 'GTATAGGCTCGTATTGT' *.fastq > count/B6668_Fm0.txt
agrep -0 -c 'CAGTGGGGCCTTCTATG' *.fastq > count/B6669_Fm0.txt
agrep -0 -c 'GAGTTACCGTGGAACAG' *.fastq > count/B6670_Fm0.txt
agrep -0 -c 'GTCTTAGTAAAGGCTTG' *.fastq > count/B6671_Fm0.txt
agrep -0 -c 'CATACCTTCGATTCCGC' *.fastq > count/B6672_Fm0.txt
agrep -0 -c 'GATGCACTCGAGATTCA' *.fastq > count/B6673_Fm0.txt
agrep -0 -c 'CGACTTATCGAGCGCTG' *.fastq > count/B6674_Fm0.txt
agrep -0 -c 'TCGGGATGATCAGCGAA' *.fastq > count/B6675_Fm0.txt
agrep -0 -c 'GCTGCAATCCCAGAACA' *.fastq > count/B6676_Fm0.txt
agrep -0 -c 'CGTTTGCGGGTCACTAT' *.fastq > count/B6677_Fm0.txt
agrep -0 -c 'TAACACCCTATCATTGG' *.fastq > count/B6678_Fm0.txt
agrep -0 -c 'GTATCACCTTGGCGGTT' *.fastq > count/B6679_Fm0.txt
agrep -0 -c 'GGTAGTGAGGTTAGTAG' *.fastq > count/B6680_Fm0.txt
agrep -0 -c 'AGAGTCTGTCTATGGCA' *.fastq > count/B6681_Fm0.txt
agrep -0 -c 'TATAACTCGGATCCACA' *.fastq > count/B6682_Fm0.txt
agrep -0 -c 'AGTAAAGCGGTGACGGT' *.fastq > count/B6683_Fm0.txt
agrep -0 -c 'GTGCTTGGGTCGAGCTA' *.fastq > count/B6684_Fm0.txt
agrep -0 -c 'GATAATGGTAGCAACGG' *.fastq > count/B6685_Fm0.txt
agrep -0 -c 'TCGGGCCTACCAGCAAA' *.fastq > count/B6687_Fm0.txt
agrep -0 -c 'CATAATTATGGCACGGC' *.fastq > count/B6688_Fm0.txt
agrep -0 -c 'TACCCGAATGGATGAGG' *.fastq > count/B6689_Fm0.txt
agrep -0 -c 'AGCCTCCATTCGTACCA' *.fastq > count/B6690_Fm0.txt
agrep -0 -c 'GTGCGTCCACGTACTTG' *.fastq > count/B6692_Fm0.txt
agrep -0 -c 'TGAGGAAGATCGTAGAG' *.fastq > count/B6693_Fm0.txt
agrep -0 -c 'GGGATTCTTATCTTGGC' *.fastq > count/B6694_Fm0.txt
agrep -0 -c 'TGAAGGCATACCTTGCT' *.fastq > count/B6696_Fm0.txt
agrep -0 -c 'CGGCCATTTACACAATC' *.fastq > count/B6697_Fm0.txt
agrep -0 -c 'CTGGAAAAGACGTAGGG' *.fastq > count/B6698_Fm0.txt
agrep -0 -c 'CACCTGATCACACGTAC' *.fastq > count/B6699_Fm0.txt
agrep -0 -c 'CGAAGTTGCTTGACAAG' *.fastq > count/B6700_Fm0.txt
agrep -0 -c 'CCAATATCCACCGGCTT' *.fastq > count/B6701_Fm0.txt
agrep -0 -c 'GGCTACTATGTATGTGG' *.fastq > count/B6702_Fm0.txt
agrep -0 -c 'CAGTCACTGACTTCCCG' *.fastq > count/B6703_Fm0.txt
agrep -0 -c 'TGCATGTCACGTTATTG' *.fastq > count/B6704_Fm0.txt
agrep -0 -c 'AGCCTAACTCGGTGCGA' *.fastq > count/B6705_Fm0.txt
agrep -0 -c 'CTAGAGGTATACATAGG' *.fastq > count/B6706_Fm0.txt
agrep -0 -c 'TTGATTACCCCATGAAC' *.fastq > count/B6707_Fm0.txt
agrep -0 -c 'CGGGCATAGTTTTGAGA' *.fastq > count/B6708_Fm0.txt
agrep -0 -c 'AGCAGGTACAATTCGAT' *.fastq > count/B6709_Fm0.txt
agrep -0 -c 'AAGACATTCGGTATCTG' *.fastq > count/B6710_Fm0.txt
agrep -0 -c 'GTATGGCGCTTCATCTC' *.fastq > count/B6711_Fm0.txt
agrep -0 -c 'CATTGGTTTCCAACGGC' *.fastq > count/B6712_Fm0.txt
agrep -0 -c 'TTGTATAACCTGACGCA' *.fastq > count/B6713_Fm0.txt
agrep -0 -c 'TCGTCGCCAGTATTGAC' *.fastq > count/B6714_Fm0.txt
agrep -0 -c 'ATGCTCACAAACCGTGC' *.fastq > count/B6715_Fm0.txt
agrep -0 -c 'GTAACAGCATTGCTCTA' *.fastq > count/B6717_Fm0.txt
agrep -0 -c 'GGAAGCTTGGCAAGAAG' *.fastq > count/B6718_Fm0.txt
agrep -0 -c 'CCTTTGAAAGCTGCATT' *.fastq > count/B6719_Fm0.txt
agrep -0 -c 'TACGGCCATGCGGCTTT' *.fastq > count/B6720_Fm0.txt
agrep -0 -c 'TAGAGCCGTTTGATAGG' *.fastq > count/B6721_Fm0.txt
agrep -0 -c 'CTCCGAGGATAGAACCT' *.fastq > count/B6722_Fm0.txt
agrep -0 -c 'CAGCAGGACTAACCGAG' *.fastq > count/B6723_Fm0.txt
agrep -0 -c 'GGCGATATTCGATTACC' *.fastq > count/B6724_Fm0.txt
agrep -0 -c 'CAGCGATTGGGGTCCTT' *.fastq > count/B6726_Fm0.txt
agrep -0 -c 'CGCTTTACTGTGACAAC' *.fastq > count/B6727_Fm0.txt
agrep -0 -c 'GTGTTACCTTCCACACT' *.fastq > count/B6728_Fm0.txt
agrep -0 -c 'CTCCCGCCCAAGGATAT' *.fastq > count/B6729_Fm0.txt
agrep -0 -c 'AAGTTCGCCAGTGATGC' *.fastq > count/B6730_Fm0.txt
agrep -0 -c 'TCGGATTTGAGACTGTC' *.fastq > count/B6731_Fm0.txt
agrep -0 -c 'ATGTCGTAAAGGCGCGG' *.fastq > count/B6733_Fm0.txt
agrep -0 -c 'CAACTCTGATGCCCCTT' *.fastq > count/B6734_Fm0.txt
agrep -0 -c 'ACCCCCGCAACTATACA' *.fastq > count/B6735_Fm0.txt
agrep -0 -c 'TTGCTCACCCTACTCCT' *.fastq > count/B6736_Fm0.txt
agrep -0 -c 'AGATGGCGGTAGAGTCC' *.fastq > count/B6738_Fm0.txt
agrep -0 -c 'CTCGGGCGGTATTCATG' *.fastq > count/B6739_Fm0.txt
agrep -0 -c 'GCCTTGGCTCTGATCTG' *.fastq > count/B6741_Fm0.txt
agrep -0 -c 'ATTGGCGATCAGCAGTC' *.fastq > count/B6742_Fm0.txt
agrep -0 -c 'CCATCAGAAATTTTCCG' *.fastq > count/B6743_Fm0.txt
agrep -0 -c 'ATGACGCTGCACGAGGA' *.fastq > count/B6745_Fm0.txt
agrep -0 -c 'GTAAGGAGCCACACCCT' *.fastq > count/B6746_Fm0.txt
agrep -0 -c 'GCCGCTTTGGTTCAGCT' *.fastq > count/B6747_Fm0.txt
agrep -0 -c 'GCGGACTCAACCGGTTT' *.fastq > count/B6748_Fm0.txt
agrep -0 -c 'GTTTAGTCCGGGATGAA' *.fastq > count/B6749_Fm0.txt
agrep -0 -c 'GATCGCTGTGACAGTCT' *.fastq > count/B6750_Fm0.txt
agrep -0 -c 'GTAATCTATGAGGGTAC' *.fastq > count/B6751_Fm0.txt
agrep -0 -c 'GCATTTGGCCTGAGCGA' *.fastq > count/B6752_Fm0.txt
agrep -0 -c 'CATGACCACCGATACTG' *.fastq > count/B6753_Fm0.txt
agrep -0 -c 'CAATGCGTACGTAAGGC' *.fastq > count/B6754_Fm0.txt
agrep -0 -c 'GATCGGGAGATCGTCCA' *.fastq > count/B6755_Fm0.txt
agrep -0 -c 'ATATTCGCGAATCAGGG' *.fastq > count/B6756_Fm0.txt
agrep -0 -c 'TCTAGCGAGACCAAACG' *.fastq > count/B6758_Fm0.txt
agrep -0 -c 'ATCGCCTAGCAGTTATC' *.fastq > count/B6759_Fm0.txt
agrep -0 -c 'GATGTGATGATGCTCCC' *.fastq > count/B6760_Fm0.txt
agrep -0 -c 'CAGTCATGATCTCGACC' *.fastq > count/B6761_Fm0.txt
agrep -0 -c 'CAACGGCAACACTAGGT' *.fastq > count/B6762_Fm0.txt
agrep -0 -c 'TTCACGACCATTGTAGG' *.fastq > count/B6763_Fm0.txt
agrep -0 -c 'TTCTAGTCCAAAACCGC' *.fastq > count/B6764_Fm0.txt
agrep -0 -c 'AGTCGCCTGCTTACCCT' *.fastq > count/B6765_Fm0.txt
agrep -0 -c 'AGGGTACCATCACGTTA' *.fastq > count/B6766_Fm0.txt
agrep -0 -c 'GATGTGGCCGTTAGGCT' *.fastq > count/B6767_Fm0.txt
agrep -0 -c 'CGCATCTAATGGCACAT' *.fastq > count/B6768_Fm0.txt
agrep -0 -c 'CGTATACGACTCTGTCA' *.fastq > count/B6769_Fm0.txt
agrep -0 -c 'TGGCGTTGTTGCCCAGA' *.fastq > count/B6770_Fm0.txt
agrep -0 -c 'AAGGATGGCCTATCGGC' *.fastq > count/B6771_Fm0.txt
agrep -0 -c 'GGCACAACTGACAGGTG' *.fastq > count/B6772_Fm0.txt
agrep -0 -c 'TTAGAATACATCGCCCG' *.fastq > count/B6773_Fm0.txt
agrep -0 -c 'TCACAGTGGAAACGGGG' *.fastq > count/B6775_Fm0.txt
agrep -0 -c 'ACCTACGCTCAAGAGCG' *.fastq > count/B6776_Fm0.txt
agrep -0 -c 'GTATCCGGTCGTTTATA' *.fastq > count/B6778_Fm0.txt
agrep -0 -c 'GGAAGTGTGTTCGTCAT' *.fastq > count/B6779_Fm0.txt
agrep -0 -c 'CTGTAGACTACATCTGA' *.fastq > count/B6780_Fm0.txt
agrep -0 -c 'TGCCCCGACATTGATGC' *.fastq > count/B6781_Fm0.txt
agrep -0 -c 'GGACATAATCACGACAT' *.fastq > count/B6782_Fm0.txt
agrep -0 -c 'CAATTGTGGGAGTAAAG' *.fastq > count/B6784_Fm0.txt
agrep -0 -c 'GCGTTTGTCCCCACCTT' *.fastq > count/B6787_Fm0.txt
agrep -0 -c 'CAAGAGCGAAATGTTCT' *.fastq > count/B6788_Fm0.txt
agrep -0 -c 'GCACGCTAAAAACGGGC' *.fastq > count/B6789_Fm0.txt
agrep -0 -c 'ACGCTACGATGAGGTAG' *.fastq > count/B6790_Fm0.txt
agrep -0 -c 'TTCTAGCAATGGGTCCG' *.fastq > count/B6791_Fm0.txt
agrep -0 -c 'CCATCGCCCAAGTCCAA' *.fastq > count/B6792_Fm0.txt
agrep -0 -c 'TACACGTGATGTCGAGA' *.fastq > count/B6793_Fm0.txt
agrep -0 -c 'CTAGGATTGGAGCCGTT' *.fastq > count/B6794_Fm0.txt
agrep -0 -c 'CAAACTCGCTTACAGCG' *.fastq > count/B6795_Fm0.txt
agrep -0 -c 'GGTCGATAAAGTTACTC' *.fastq > count/B6796_Fm0.txt
agrep -0 -c 'TTGACGTTGCGGGTAGT' *.fastq > count/B6800_Fm0.txt
agrep -0 -c 'TCGAAGGTCGTTCGTAC' *.fastq > count/B6801_Fm0.txt
agrep -0 -c 'CGCCTTGTTATGTCATA' *.fastq > count/B6802_Fm0.txt
agrep -0 -c 'TAAGAGTTGGTCTGACC' *.fastq > count/B6803_Fm0.txt
agrep -0 -c 'CCTTATTCGGTGTCGCC' *.fastq > count/B6804_Fm0.txt
agrep -0 -c 'TGCAGTTCCGATGTGAC' *.fastq > count/B6806_Fm0.txt
agrep -0 -c 'TATACACCGTGTGCAGG' *.fastq > count/B6807_Fm0.txt
agrep -0 -c 'CTGACATTGAGACGGCT' *.fastq > count/B6810_Fm0.txt
agrep -0 -c 'TCTGTTTGGCGCTTAGC' *.fastq > count/B6811_Fm0.txt
agrep -0 -c 'ACAAGCGCAGTATTTCT' *.fastq > count/B6812_Fm0.txt
agrep -0 -c 'CGGAATACTTCTGCGCT' *.fastq > count/B6813_Fm0.txt
agrep -0 -c 'GTATCGAATGCACTGGA' *.fastq > count/B6814_Fm0.txt
agrep -0 -c 'AGTGGGTACAAACGAAT' *.fastq > count/B6815_Fm0.txt
agrep -0 -c 'TTGCTCACAGAAAGCGG' *.fastq > count/B6816_Fm0.txt
agrep -0 -c 'CGTAACAGTCCTGGATT' *.fastq > count/B6817_Fm0.txt
agrep -0 -c 'GCCAACAGGCGATCTTG' *.fastq > count/B6818_Fm0.txt
agrep -0 -c 'GGCTCATGTTTGTCTTC' *.fastq > count/B6819_Fm0.txt
agrep -0 -c 'ACGCTTTGTAGCAAGCT' *.fastq > count/B6821_Fm0.txt
agrep -0 -c 'AGGTCGGACTAACGCAA' *.fastq > count/B6822_Fm0.txt
agrep -0 -c 'TGAAAAAGGGGAAACGT' *.fastq > count/B6824_Fm0.txt
agrep -0 -c 'AGTCCGAACTGACACCT' *.fastq > count/B6826_Fm0.txt
agrep -0 -c 'CAGGCCGTAACACATCC' *.fastq > count/B6828_Fm0.txt
agrep -0 -c 'GTCCATAATTGGCGCCA' *.fastq > count/B6830_Fm0.txt
agrep -0 -c 'AGCCGCTATTCTAACGG' *.fastq > count/B6831_Fm0.txt
agrep -0 -c 'ACAGCTCGGAGTCGAGT' *.fastq > count/B6832_Fm0.txt
agrep -0 -c 'TACGAAATGACCTGTGG' *.fastq > count/B6833_Fm0.txt
agrep -0 -c 'CACGCCCATTCAGGTCT' *.fastq > count/B6835_Fm0.txt
agrep -0 -c 'CAATCCTACTACGCCAC' *.fastq > count/B6837_Fm0.txt
agrep -0 -c 'CCGCAGTACGAGCATGA' *.fastq > count/B6838_Fm0.txt
agrep -0 -c 'GGATAGTTTAGGGCGCC' *.fastq > count/B6839_Fm0.txt
agrep -0 -c 'CTATGTGCGAGACTGGG' *.fastq > count/B6841_Fm0.txt
agrep -0 -c 'AGTGTTTTCACGGACCG' *.fastq > count/B6842_Fm0.txt
agrep -0 -c 'CGTTGCTCGAAACATCC' *.fastq > count/B6843_Fm0.txt
agrep -0 -c 'AGATCGAAAATTGCCGT' *.fastq > count/B6844_Fm0.txt
agrep -0 -c 'TGATGCAAAACGCTGTA' *.fastq > count/B6845_Fm0.txt
agrep -0 -c 'GCAATAAGCGATCTGCA' *.fastq > count/B6846_Fm0.txt
agrep -0 -c 'CGCGTTCTGACCTCGAA' *.fastq > count/B6847_Fm0.txt
agrep -0 -c 'ACAGGAGTAGTCCGAAG' *.fastq > count/B6848_Fm0.txt
agrep -0 -c 'AACAATGGCTCGAATTC' *.fastq > count/B6849_Fm0.txt
agrep -0 -c 'GTCCCCATAACGCGTCA' *.fastq > count/B6851_Fm0.txt
agrep -0 -c 'GTGGTGGAACAATGTAA' *.fastq > count/B6853_Fm0.txt
agrep -0 -c 'TACGCTTAGATCCATCA' *.fastq > count/B6854_Fm0.txt
agrep -0 -c 'TACCTTAGGCAATAGCC' *.fastq > count/B6855_Fm0.txt
agrep -0 -c 'AGGGAATAAAATCCGTC' *.fastq > count/B6856_Fm0.txt
agrep -0 -c 'CACGTGCACGCAGACTA' *.fastq > count/B6857_Fm0.txt
agrep -0 -c 'GACGTTGAACTTGCGAG' *.fastq > count/B6858_Fm0.txt
agrep -0 -c 'CTTGACCAACAGCACGT' *.fastq > count/B6859_Fm0.txt
agrep -0 -c 'ACAGCCATATCGACGTT' *.fastq > count/B6861_Fm0.txt
agrep -0 -c 'CTGGATTAGTCCCTGAT' *.fastq > count/B6862_Fm0.txt
agrep -0 -c 'AGTATAATCAGCCCGGA' *.fastq > count/B6863_Fm0.txt
agrep -0 -c 'ACACCATGGAGTCGAGC' *.fastq > count/B6865_Fm0.txt
agrep -0 -c 'AACATTAATTACCCCGC' *.fastq > count/B6866_Fm0.txt
agrep -0 -c 'TATACTGACTGGCGTTG' *.fastq > count/B6867_Fm0.txt
agrep -0 -c 'CCATCTTTCGCAGCTAC' *.fastq > count/B6868_Fm0.txt
agrep -0 -c 'CAACATGGATTGTGACG' *.fastq > count/B6869_Fm0.txt
agrep -0 -c 'CGCTTGGACATACTATG' *.fastq > count/B6871_Fm0.txt
agrep -0 -c 'ATCACTGAATGGGCCAA' *.fastq > count/B6872_Fm0.txt
agrep -0 -c 'GGGATTAGAGGGCCAAA' *.fastq > count/B6873_Fm0.txt
agrep -0 -c 'ATGAAAGAGGGTTTGCA' *.fastq > count/B6874_Fm0.txt
agrep -0 -c 'TCTCGCACATATAGAGG' *.fastq > count/B6875_Fm0.txt
agrep -0 -c 'TTCGAGGAGAACACATG' *.fastq > count/B6876_Fm0.txt
agrep -0 -c 'TGGCTTTTGACCTCCAA' *.fastq > count/B6878_Fm0.txt
agrep -0 -c 'ATGTTACTACCCGGACG' *.fastq > count/B6880_Fm0.txt
agrep -0 -c 'ATTCCACTTGTGCAGTA' *.fastq > count/B6881_Fm0.txt
agrep -0 -c 'GGTCCGCTACGCTTTAA' *.fastq > count/B6883_Fm0.txt
agrep -0 -c 'CTCCGATCGCGAATGTG' *.fastq > count/B6884_Fm0.txt
agrep -0 -c 'GGACTGGCGATCTAAGT' *.fastq > count/B6886_Fm0.txt
agrep -0 -c 'CACTTGATCCGAGGGAG' *.fastq > count/B6887_Fm0.txt
agrep -0 -c 'CTTGAGACTAATGAAGG' *.fastq > count/B6888_Fm0.txt
agrep -0 -c 'TACGACTTCAGGTTTGT' *.fastq > count/B6889_Fm0.txt
agrep -0 -c 'TCGTGTTATGCCCATCG' *.fastq > count/B6890_Fm0.txt
agrep -0 -c 'AGAGTTCTCACATGCCA' *.fastq > count/B6891_Fm0.txt
agrep -0 -c 'TAAGGTAGACGAAAGAG' *.fastq > count/B6893_Fm0.txt
agrep -0 -c 'TCACGGATTCTATGTGG' *.fastq > count/B6894_Fm0.txt
agrep -0 -c 'CGCAGAGACAATTGTAA' *.fastq > count/B6896_Fm0.txt
agrep -0 -c 'CGTCTGACGATATACTA' *.fastq > count/B6898_Fm0.txt
agrep -0 -c 'GTTATAGTACCACTAGC' *.fastq > count/B6899_Fm0.txt
agrep -0 -c 'GACACTCCTGGCGAAGT' *.fastq > count/B6900_Fm0.txt
agrep -0 -c 'AGCGCGTTGAACCTGGT' *.fastq > count/B6902_Fm0.txt
agrep -0 -c 'TTGCACATTCGCGACTG' *.fastq > count/B6903_Fm0.txt
agrep -0 -c 'TCTACGCTCGGTAATGC' *.fastq > count/B6905_Fm0.txt
agrep -0 -c 'TCGAACGCTCGACCTGA' *.fastq > count/B6907_Fm0.txt
agrep -0 -c 'TTCTGTTAAACCTTCCG' *.fastq > count/B6908_Fm0.txt
agrep -0 -c 'GAGACTTCGTAAACCTG' *.fastq > count/B6909_Fm0.txt
agrep -0 -c 'GTCCGTCGCAGAATGCA' *.fastq > count/B6910_Fm0.txt
agrep -0 -c 'ATTCCTTTGGTCTAGAG' *.fastq > count/B6911_Fm0.txt
agrep -0 -c 'CAACTATGGGCTTGTTC' *.fastq > count/B6912_Fm0.txt
agrep -0 -c 'ATGTACCGGGTCGTTTC' *.fastq > count/B6913_Fm0.txt
agrep -0 -c 'TAAAACGGACATCCGCG' *.fastq > count/B6914_Fm0.txt
agrep -0 -c 'ATGGATTGCGGACACAC' *.fastq > count/B6915_Fm0.txt
agrep -0 -c 'GGTCCGTGGATATTGTG' *.fastq > count/B6916_Fm0.txt
agrep -0 -c 'AGAACGGTGGGTTGCTT' *.fastq > count/B6917_Fm0.txt
agrep -0 -c 'GGTTGTGGGCCATACTC' *.fastq > count/B6918_Fm0.txt
agrep -0 -c 'GCGTGGCAAATTTGCAG' *.fastq > count/B6919_Fm0.txt
agrep -0 -c 'AAGCTGCTAGAGTTCGA' *.fastq > count/B6920_Fm0.txt
agrep -0 -c 'AGAATCGGCCGATTTTA' *.fastq > count/B6921_Fm0.txt
agrep -0 -c 'ATCCTGGAGCTGGTATA' *.fastq > count/B6922_Fm0.txt
agrep -0 -c 'CGATTTCCTAAGTCCGT' *.fastq > count/B6923_Fm0.txt
agrep -0 -c 'TAACCCCTTTCTGTACG' *.fastq > count/B6924_Fm0.txt
agrep -0 -c 'CCTTAAGACCCATTGCA' *.fastq > count/B6925_Fm0.txt
agrep -0 -c 'CACGAGTACCAAGTGGA' *.fastq > count/B6926_Fm0.txt
agrep -0 -c 'GGTGCTTCAGATCTAGA' *.fastq > count/B6927_Fm0.txt
agrep -0 -c 'CATCTGCCACAATCGCT' *.fastq > count/B6928_Fm0.txt
agrep -0 -c 'CACCAATCGCATGAATC' *.fastq > count/B6929_Fm0.txt
agrep -0 -c 'GGCCAATCTCACAACGT' *.fastq > count/B6930_Fm0.txt
agrep -0 -c 'GTCAATCGGACAACAAT' *.fastq > count/B6931_Fm0.txt
agrep -0 -c 'ATATACGGCTCAGGATT' *.fastq > count/B6932_Fm0.txt
agrep -0 -c 'TGCGATACTTAGGCTTG' *.fastq > count/B6933_Fm0.txt
agrep -0 -c 'ATGAACTGACCCAAGTT' *.fastq > count/B6934_Fm0.txt
agrep -0 -c 'CTCCCATTGTGCAATCG' *.fastq > count/B6938_Fm0.txt
agrep -0 -c 'GGAGATGAGTTGACTAC' *.fastq > count/B6939_Fm0.txt
agrep -0 -c 'ATGCGAGGCCTATGTCT' *.fastq > count/B6942_Fm0.txt
agrep -0 -c 'CAGATGCTTGTCACGGC' *.fastq > count/B6943_Fm0.txt
agrep -0 -c 'GCCTCGTCTCACTGTAC' *.fastq > count/B6944_Fm0.txt
agrep -0 -c 'GTAGTCTGGTCACGAAT' *.fastq > count/B6946_Fm0.txt
agrep -0 -c 'TCACTCAACGCTCTGCA' *.fastq > count/B6947_Fm0.txt
agrep -0 -c 'CAGTGGCTCGAACATGA' *.fastq > count/B6948_Fm0.txt
agrep -0 -c 'GTACCGACGAACTGAAC' *.fastq > count/B6950_Fm0.txt
agrep -0 -c 'GTGGCTCCGAAATGTTT' *.fastq > count/B6951_Fm0.txt
agrep -0 -c 'CTCACGCTATGAGCGAA' *.fastq > count/B6952_Fm0.txt
agrep -0 -c 'GGAAGTTCCACTCACCC' *.fastq > count/B6953_Fm0.txt
agrep -0 -c 'ATACGGGGGTAATGGTA' *.fastq > count/B6954_Fm0.txt
agrep -0 -c 'ATAGAACCTGCTCTTCG' *.fastq > count/B6955_Fm0.txt
agrep -0 -c 'GAGATTCGAAGAAGTTC' *.fastq > count/B6957_Fm0.txt
agrep -0 -c 'TAATGCGTCTAGGAGTC' *.fastq > count/B6958_Fm0.txt
agrep -0 -c 'CTCGGAGTATCTAAACA' *.fastq > count/B6959_Fm0.txt
agrep -0 -c 'CTCCCTTACCCAGTAGG' *.fastq > count/B6960_Fm0.txt
agrep -0 -c 'TGCTGCTTTTTAGGTTC' *.fastq > count/B6961_Fm0.txt
agrep -0 -c 'ATGTAGACGATGCTGTA' *.fastq > count/B6962_Fm0.txt
agrep -0 -c 'TAGGTTGCACAACCGGC' *.fastq > count/B6963_Fm0.txt
agrep -0 -c 'TGTATGTAACAGTGCCG' *.fastq > count/B6964_Fm0.txt
agrep -0 -c 'TGTGAACCCTGGAGCAC' *.fastq > count/B6967_Fm0.txt
agrep -0 -c 'AATCCCGCACTTTGAAC' *.fastq > count/B6968_Fm0.txt
agrep -0 -c 'CTGCCACCAGCCAACTA' *.fastq > count/B6969_Fm0.txt
agrep -0 -c 'CAATCACGCCTGGATGT' *.fastq > count/B6970_Fm0.txt
agrep -0 -c 'CTGGGGTGATCCTAGGA' *.fastq > count/B6971_Fm0.txt
agrep -0 -c 'GCAGGTCTTTTCGAGAC' *.fastq > count/B6972_Fm0.txt
agrep -0 -c 'CTGCTTACCGATGTAAC' *.fastq > count/B6974_Fm0.txt
agrep -0 -c 'GGTTCCATAGAGCCACG' *.fastq > count/B6975_Fm0.txt
agrep -0 -c 'TACACTTCGACCTTCGA' *.fastq > count/B6976_Fm0.txt
agrep -0 -c 'GCCGTGCAGCAGATTTG' *.fastq > count/B6977_Fm0.txt
agrep -0 -c 'TCGCACGTCAGCAAACC' *.fastq > count/B6979_Fm0.txt
agrep -0 -c 'GGCATGGCAGGCTTAAT' *.fastq > count/B6980_Fm0.txt
agrep -0 -c 'GATACAGCGTCGAGTAC' *.fastq > count/B6981_Fm0.txt
agrep -0 -c 'GCGAACTCTAGGATGAG' *.fastq > count/B6982_Fm0.txt
agrep -0 -c 'GATTACGGCACCGTGTC' *.fastq > count/B6983_Fm0.txt
agrep -0 -c 'GATCTTGTTACAGTCGA' *.fastq > count/B6984_Fm0.txt
agrep -0 -c 'AGTCGAAGTGGCTTTCT' *.fastq > count/B6985_Fm0.txt
agrep -0 -c 'GATATCAGCATACGGTC' *.fastq > count/B6986_Fm0.txt
agrep -0 -c 'AGTCCTGGTAGAAGTGG' *.fastq > count/B6989_Fm0.txt
agrep -0 -c 'CGTTTAACCTCTGGACT' *.fastq > count/B6991_Fm0.txt
agrep -0 -c 'CGACTTCTTCTACTAGA' *.fastq > count/B6992_Fm0.txt
agrep -0 -c 'CAACGTACACACGAATA' *.fastq > count/B6993_Fm0.txt
agrep -0 -c 'TTAAGAGGTTACCCGGT' *.fastq > count/B6994_Fm0.txt
agrep -0 -c 'TGCCCTGGTTGTGATAC' *.fastq > count/B6996_Fm0.txt
agrep -0 -c 'ATTAGGTCAGCGACTTC' *.fastq > count/B6997_Fm0.txt
agrep -0 -c 'CCGAGACCCCTGAACTT' *.fastq > count/B7000_Fm0.txt
agrep -0 -c 'GCACCCCCATCAAACTT' *.fastq > count/B7001_Fm0.txt
agrep -0 -c 'AGGTGCCGCGTTTGCAA' *.fastq > count/B7002_Fm0.txt
agrep -0 -c 'TATCGTATACGTAGTCG' *.fastq > count/B7003_Fm0.txt
agrep -0 -c 'TGACACAGAAATCCTGG' *.fastq > count/B7004_Fm0.txt
agrep -0 -c 'ATATCGCTAGCTCTAGC' *.fastq > count/B7007_Fm0.txt
agrep -0 -c 'TGCCGATGAGAGCAACA' *.fastq > count/B7011_Fm0.txt
agrep -0 -c 'CAATGCTCTAGGCCTAT' *.fastq > count/B7012_Fm0.txt
agrep -0 -c 'GACCAATGGCGATTTGC' *.fastq > count/B7013_Fm0.txt
agrep -0 -c 'CCGCCAGCAATGTTCCA' *.fastq > count/B7014_Fm0.txt
agrep -0 -c 'CTATCCTAGAGTCCTAA' *.fastq > count/B7015_Fm0.txt
agrep -0 -c 'CAGTATCAGGGGAATCG' *.fastq > count/B7016_Fm0.txt
agrep -0 -c 'TTAGCCTCCGAGACCAG' *.fastq > count/B7017_Fm0.txt
agrep -0 -c 'ATCGGCGGAACATTCCG' *.fastq > count/B7018_Fm0.txt
agrep -0 -c 'GGCTACCGGAGTATACA' *.fastq > count/B7020_Fm0.txt
agrep -0 -c 'GCCCAATCAGTGAAGTG' *.fastq > count/B7021_Fm0.txt
agrep -0 -c 'GGGTCGAGCACATCCAA' *.fastq > count/B7022_Fm0.txt
agrep -0 -c 'AGTCAAGCCTCCTTCAA' *.fastq > count/B7023_Fm0.txt
agrep -0 -c 'GGTCGTTTTAAGCCCAC' *.fastq > count/B7024_Fm0.txt
agrep -0 -c 'ACGTAGAAGGCTTGTGC' *.fastq > count/B7026_Fm0.txt
agrep -0 -c 'ACCATGCTTGTACTTTG' *.fastq > count/B7027_Fm0.txt
agrep -0 -c 'GGGCTTTAATCGATCTC' *.fastq > count/B7029_Fm0.txt
agrep -0 -c 'ATCCCGACGACAACGTG' *.fastq > count/B7031_Fm0.txt
agrep -0 -c 'CGTGAGACCAAATGCCG' *.fastq > count/B7032_Fm0.txt
agrep -0 -c 'AGTAGTCTGAAGCGTCC' *.fastq > count/B7034_Fm0.txt
agrep -0 -c 'CTAATATCGGCGCAGGC' *.fastq > count/B7035_Fm0.txt
agrep -0 -c 'AACGAGCCCCAGATTCT' *.fastq > count/B7036_Fm0.txt
agrep -0 -c 'GCGAAGTTATCGTCAAT' *.fastq > count/B7037_Fm0.txt
agrep -0 -c 'GGAAGCATGATAACCTT' *.fastq > count/B7038_Fm0.txt
agrep -0 -c 'GGTAATCTCAGGTCGTG' *.fastq > count/B7039_Fm0.txt
agrep -0 -c 'GGAGGAGATTGTGTCGG' *.fastq > count/B7040_Fm0.txt
agrep -0 -c 'TCAGAGAAGCATGCTGA' *.fastq > count/B7041_Fm0.txt
agrep -0 -c 'CCTGCGAATTAGGAGGA' *.fastq > count/B7042_Fm0.txt
agrep -0 -c 'CGAGTGAAGAGAAAAGT' *.fastq > count/B7043_Fm0.txt
agrep -0 -c 'TTCTACCAGACGGAAGA' *.fastq > count/B7044_Fm0.txt
agrep -0 -c 'TTGGACCGGTGCTACTC' *.fastq > count/B7046_Fm0.txt
agrep -0 -c 'GAGCGACCATCACCAGT' *.fastq > count/B7048_Fm0.txt
agrep -0 -c 'CGCAACAAGACTGGGAG' *.fastq > count/B7049_Fm0.txt
agrep -0 -c 'ATTGGAGAAACGACTGG' *.fastq > count/B7050_Fm0.txt
agrep -0 -c 'GTTCAAGCGTTCGATAT' *.fastq > count/B7051_Fm0.txt
agrep -0 -c 'GGTCACACTATACACGC' *.fastq > count/B7052_Fm0.txt
agrep -0 -c 'AAGGGATAACGGCCGAT' *.fastq > count/B7053_Fm0.txt
agrep -0 -c 'AATGATGACGTGTCCCC' *.fastq > count/B7054_Fm0.txt
agrep -0 -c 'TGTCTCACCTGACAACC' *.fastq > count/B7055_Fm0.txt
agrep -0 -c 'AGGGCTTGACTAAGTGT' *.fastq > count/B7056_Fm0.txt
agrep -0 -c 'CCGTCTCGGATGTAATA' *.fastq > count/B7057_Fm0.txt
agrep -0 -c 'ATAGACAGGACACTCCC' *.fastq > count/B7059_Fm0.txt
agrep -0 -c 'CATCATGCTAAACCGAC' *.fastq > count/B7061_Fm0.txt
agrep -0 -c 'ATAGAGCCCAAGTTAGT' *.fastq > count/B7062_Fm0.txt
agrep -0 -c 'CAACAGCTCTCATCGTC' *.fastq > count/B7063_Fm0.txt
agrep -0 -c 'GGTACGAGTAAGGATGC' *.fastq > count/B7064_Fm0.txt
agrep -0 -c 'GAGAGGGGGATACACGT' *.fastq > count/B7065_Fm0.txt
agrep -0 -c 'ACCTAGGGCTTGAGAAT' *.fastq > count/B7066_Fm0.txt
agrep -0 -c 'GCACTTCGGTGTTAATC' *.fastq > count/B7067_Fm0.txt
agrep -0 -c 'GTCGGGTAGAATTCACA' *.fastq > count/B7068_Fm0.txt
agrep -0 -c 'GGCACTACCTTGACCTC' *.fastq > count/B7070_Fm0.txt
agrep -0 -c 'CGCGACATTTTCGATAG' *.fastq > count/B7071_Fm0.txt
agrep -0 -c 'AGTGAGTATTGACAGAC' *.fastq > count/B7072_Fm0.txt
agrep -0 -c 'GGCACTATTACCTCTTT' *.fastq > count/B7075_Fm0.txt
agrep -0 -c 'CACGAGAACGCGAGTTT' *.fastq > count/B7076_Fm0.txt
agrep -0 -c 'ACTTAGGGGGCATGCTA' *.fastq > count/B7077_Fm0.txt
agrep -0 -c 'CTTACAAACCGCGTGTC' *.fastq > count/B7078_Fm0.txt
agrep -0 -c 'AATGGAAGGTACGATAG' *.fastq > count/B7079_Fm0.txt
agrep -0 -c 'AAGGTAATCAGTGCGGG' *.fastq > count/B7080_Fm0.txt
agrep -0 -c 'AATTCAGCGGATTGCTA' *.fastq > count/B7081_Fm0.txt
agrep -0 -c 'TTGTATGGCCCTTCGTG' *.fastq > count/B7082_Fm0.txt
agrep -0 -c 'CGACGAGCAACTCAAAA' *.fastq > count/B7083_Fm0.txt
agrep -0 -c 'AAGAGCCATAGGTAGCC' *.fastq > count/B7085_Fm0.txt
agrep -0 -c 'CTTGCCTAATCTGAGGG' *.fastq > count/B7086_Fm0.txt
agrep -0 -c 'GGTTATAGTCCGTAGAC' *.fastq > count/B7087_Fm0.txt
agrep -0 -c 'CGGCAGCTATGGACTTA' *.fastq > count/B7088_Fm0.txt
agrep -0 -c 'ACGCTAGAGTGTTTGAG' *.fastq > count/B7089_Fm0.txt
agrep -0 -c 'GCCGCCGGTTGCTATTA' *.fastq > count/B7090_Fm0.txt
agrep -0 -c 'TAAGAGACTGGCACAAC' *.fastq > count/B7091_Fm0.txt
agrep -0 -c 'CACACTCGAACCACTTG' *.fastq > count/B7092_Fm0.txt
agrep -0 -c 'ACGCCTGCCCGATATCA' *.fastq > count/B7093_Fm0.txt
agrep -0 -c 'GTGTCAACCACTGGGAA' *.fastq > count/B7094_Fm0.txt
agrep -0 -c 'GTAATAGTACTAGTCGC' *.fastq > count/B7095_Fm0.txt
agrep -0 -c 'TAGCACCTTACCAGTGA' *.fastq > count/B7097_Fm0.txt
agrep -0 -c 'TTACTACATTGTGCCGA' *.fastq > count/B7098_Fm0.txt
agrep -0 -c 'TATGTCAGGTGCGGTTG' *.fastq > count/B7099_Fm0.txt
agrep -0 -c 'TCGTACTCCAAGACCTA' *.fastq > count/B7100_Fm0.txt
agrep -0 -c 'ACAGTCGGCTACACTCG' *.fastq > count/B7101_Fm0.txt
agrep -0 -c 'TTGCATGGTGAAAGTCT' *.fastq > count/B7103_Fm0.txt
agrep -0 -c 'CCACACGTTACCCTAGT' *.fastq > count/B7104_Fm0.txt
agrep -0 -c 'CTAGTTCTTTCACGCCA' *.fastq > count/B7105_Fm0.txt
agrep -0 -c 'GCAGGTATCGGGTCACT' *.fastq > count/B7106_Fm0.txt
agrep -0 -c 'AGTGGCGAGCAGTACAG' *.fastq > count/B7107_Fm0.txt
agrep -0 -c 'ACCATTGTCGGTATCGT' *.fastq > count/B7108_Fm0.txt
agrep -0 -c 'AGAGCGGCGCACTTATG' *.fastq > count/B7109_Fm0.txt
agrep -0 -c 'GGGAGAAAGGTGTAACC' *.fastq > count/B7110_Fm0.txt
agrep -0 -c 'ACGAAGCTGGAACTCCT' *.fastq > count/B7111_Fm0.txt
agrep -0 -c 'TTAATCAGCATCTGAGG' *.fastq > count/B7112_Fm0.txt
agrep -0 -c 'TGACTCATTAAGGTGAG' *.fastq > count/B7113_Fm0.txt
agrep -0 -c 'CATAGATTGGAACGCCA' *.fastq > count/B7114_Fm0.txt
agrep -0 -c 'CAACGTGTATCACTGCT' *.fastq > count/B7115_Fm0.txt
agrep -0 -c 'CGAGGCTAATAACTAGG' *.fastq > count/B7116_Fm0.txt
agrep -0 -c 'TCGACAAAGAGGGGAGT' *.fastq > count/B7117_Fm0.txt
agrep -0 -c 'GTGATACTATGGCGTTC' *.fastq > count/B7118_Fm0.txt
agrep -0 -c 'CCGAAGACTGACTCCTA' *.fastq > count/B7119_Fm0.txt
agrep -0 -c 'TGCGATAGTTCAGAAGG' *.fastq > count/B7120_Fm0.txt
agrep -0 -c 'GGCTCGTGGGATCAAAA' *.fastq > count/B7121_Fm0.txt
agrep -0 -c 'ACCGATCTCCAATTCCA' *.fastq > count/B7122_Fm0.txt
agrep -0 -c 'GGGTAAGATATGGGTTC' *.fastq > count/B7123_Fm0.txt
agrep -0 -c 'CACCTTTGTAACTACCC' *.fastq > count/B7124_Fm0.txt
agrep -0 -c 'CATAGTCTATAGACTCG' *.fastq > count/B7125_Fm0.txt
agrep -0 -c 'CTCTCAGCGTACCGATG' *.fastq > count/B7126_Fm0.txt
agrep -0 -c 'ACGCTTGGCCGTACTAG' *.fastq > count/B7127_Fm0.txt
agrep -0 -c 'TTACTCCTTGTGCGATC' *.fastq > count/B7128_Fm0.txt
agrep -0 -c 'GTAGAGGTCTATTCAGA' *.fastq > count/B7131_Fm0.txt
agrep -0 -c 'ACCTGGGCCATTTCATT' *.fastq > count/B7132_Fm0.txt
agrep -0 -c 'AGCACAAGTGGACAACC' *.fastq > count/B7133_Fm0.txt
agrep -0 -c 'ATGTGGGCTCTTAACCT' *.fastq > count/B7134_Fm0.txt
agrep -0 -c 'CCATCTCACCATGATCC' *.fastq > count/B7135_Fm0.txt
agrep -0 -c 'ATTATCGAGACCCACCA' *.fastq > count/B7136_Fm0.txt
agrep -0 -c 'ATTCCTTGACATGCTGA' *.fastq > count/B7137_Fm0.txt
agrep -0 -c 'CCTCCTAATGCAATCAC' *.fastq > count/B7138_Fm0.txt
agrep -0 -c 'TGATCCACACTTGCGCC' *.fastq > count/B7140_Fm0.txt
agrep -0 -c 'GGCTGGCGTATATTCCC' *.fastq > count/B7141_Fm0.txt
agrep -0 -c 'GGTACACGTACTGAAGT' *.fastq > count/B7142_Fm0.txt
agrep -0 -c 'CTGCCAACTACATACTG' *.fastq > count/B7143_Fm0.txt
agrep -0 -c 'CGCGGTAACGTATGGTG' *.fastq > count/B7144_Fm0.txt
agrep -0 -c 'GTACACTTCGTTCGTGT' *.fastq > count/B7145_Fm0.txt
agrep -0 -c 'GCGACCATGTACGAACG' *.fastq > count/B7146_Fm0.txt
agrep -0 -c 'CAATGGAATGTGGCCGG' *.fastq > count/B7148_Fm0.txt
agrep -0 -c 'CTCCGTTAAGACTTGAC' *.fastq > count/B7149_Fm0.txt
agrep -0 -c 'GTCATCACATCAGGGGA' *.fastq > count/B7150_Fm0.txt
agrep -0 -c 'AGGGTGAAAGCTTACAC' *.fastq > count/B7151_Fm0.txt
agrep -0 -c 'AGAATCGCTGATGCCTA' *.fastq > count/B7153_Fm0.txt
agrep -0 -c 'TAACGCTACTTTTTCGC' *.fastq > count/B7154_Fm0.txt
agrep -0 -c 'TACAGGACCGTAACCCT' *.fastq > count/B7155_Fm0.txt
agrep -0 -c 'CGCTGGTAATCCTAACT' *.fastq > count/B7156_Fm0.txt
agrep -0 -c 'CAGCGGTGGACAGAATT' *.fastq > count/B7158_Fm0.txt
agrep -0 -c 'AGTGTTCCGTAGTCACC' *.fastq > count/B7159_Fm0.txt
agrep -0 -c 'ACTACATACCGTACCAC' *.fastq > count/B7160_Fm0.txt
agrep -0 -c 'CCACACCGTCCAGAAGT' *.fastq > count/B7161_Fm0.txt
agrep -0 -c 'TATCACCGTTTATGGAG' *.fastq > count/B7162_Fm0.txt
agrep -0 -c 'TCTACTCTCAGAAGACT' *.fastq > count/B7163_Fm0.txt
agrep -0 -c 'CTCTCACAGGGTATAGT' *.fastq > count/B7164_Fm0.txt
agrep -0 -c 'ATTCAACCCTTCCTACA' *.fastq > count/B7165_Fm0.txt
agrep -0 -c 'GCGCCCAGGGTATACTT' *.fastq > count/B7167_Fm0.txt
agrep -0 -c 'GGACTCAACGCTAGACT' *.fastq > count/B7169_Fm0.txt
agrep -0 -c 'TCTTTTAGGTCAACGAG' *.fastq > count/B7170_Fm0.txt
agrep -0 -c 'TCGAGCGTCACCTAATA' *.fastq > count/B7171_Fm0.txt
agrep -0 -c 'TTAGAAAACTTCCGAGG' *.fastq > count/B7173_Fm0.txt
agrep -0 -c 'ATGCCGTCGCGTTGAGA' *.fastq > count/B7175_Fm0.txt
agrep -0 -c 'TTGTTCAGGGCTGGAGG' *.fastq > count/B7176_Fm0.txt
agrep -0 -c 'ATATGTCTACGCTCGGT' *.fastq > count/B7177_Fm0.txt
agrep -0 -c 'CGGGAAGGTTACTCTTC' *.fastq > count/B7178_Fm0.txt
agrep -0 -c 'TGTCGCGCATATCCAGG' *.fastq > count/B7180_Fm0.txt
agrep -0 -c 'ATCGGGTCCTTTCTAGC' *.fastq > count/B7181_Fm0.txt
agrep -0 -c 'AATAAGTGACGCAGTCA' *.fastq > count/B7183_Fm0.txt
agrep -0 -c 'GTGTAAAGTCCTGTTCG' *.fastq > count/B7185_Fm0.txt
agrep -0 -c 'GCATGACGTACCCTAAA' *.fastq > count/B7186_Fm0.txt
agrep -0 -c 'CAACACAAGGCAAGCGG' *.fastq > count/B7187_Fm0.txt
agrep -0 -c 'GTTCCCGATGTCAAGCA' *.fastq > count/B7188_Fm0.txt
agrep -0 -c 'GCCAGCTCGGAAATCCT' *.fastq > count/B7189_Fm0.txt
agrep -0 -c 'ATACGTGCGAATTGTTC' *.fastq > count/B7190_Fm0.txt
agrep -0 -c 'CAGAGGACCCTCTGACA' *.fastq > count/B7191_Fm0.txt
agrep -0 -c 'GACTCAAAGTCTACGGA' *.fastq > count/B7193_Fm0.txt
agrep -0 -c 'CAACTAGCTCATGCCCT' *.fastq > count/B7194_Fm0.txt
agrep -0 -c 'GCCACAGCCCCTAATTA' *.fastq > count/B7195_Fm0.txt
agrep -0 -c 'TATGGTCTGAACACGAC' *.fastq > count/B7196_Fm0.txt
agrep -0 -c 'ATTACCGGCTAGCCCGA' *.fastq > count/B7197_Fm0.txt
agrep -0 -c 'ACAGGTCTTTAACCAGA' *.fastq > count/B7200_Fm0.txt
agrep -0 -c 'GGGATACATGTGCACTG' *.fastq > count/B7201_Fm0.txt
agrep -0 -c 'TCTTTGACCACATTGGG' *.fastq > count/B7202_Fm0.txt
agrep -0 -c 'AGGACTTATCGCAGCCA' *.fastq > count/B7203_Fm0.txt
agrep -0 -c 'CATACAGGGCTACAACT' *.fastq > count/B7204_Fm0.txt
agrep -0 -c 'AGCGTGGGCTAAGTCAG' *.fastq > count/B7205_Fm0.txt
agrep -0 -c 'CGATCGAGCTGGCTGAT' *.fastq > count/B7207_Fm0.txt
agrep -0 -c 'ATTAAAACCCCAACCAG' *.fastq > count/B7208_Fm0.txt
agrep -0 -c 'ATACTCCACCACGTTGA' *.fastq > count/B7210_Fm0.txt
agrep -0 -c 'CTGATCCAGCGAGCGTT' *.fastq > count/B7211_Fm0.txt
agrep -0 -c 'GCCAGATATTGTGGCCC' *.fastq > count/B7214_Fm0.txt
agrep -0 -c 'AGCGTTCAGTTGCAGGA' *.fastq > count/B7215_Fm0.txt
agrep -0 -c 'CCGCCCCTATACATTAC' *.fastq > count/B7217_Fm0.txt
agrep -0 -c 'TCGATCGATAAGCAGTC' *.fastq > count/B7218_Fm0.txt
agrep -0 -c 'TCGAACGTCTTTCACCG' *.fastq > count/B7219_Fm0.txt
agrep -0 -c 'ACCATCTGAAATGTGCT' *.fastq > count/B7220_Fm0.txt
agrep -0 -c 'GCTGTCGTATCGACATA' *.fastq > count/B7222_Fm0.txt
agrep -0 -c 'CTCGAACTGTGAATACC' *.fastq > count/B7223_Fm0.txt
agrep -0 -c 'GTCTGACTTAACCCAGC' *.fastq > count/B7224_Fm0.txt
agrep -0 -c 'TGGCTGTTGTGCTATTG' *.fastq > count/B7226_Fm0.txt
agrep -0 -c 'CGTCATTGAAGGGTTGC' *.fastq > count/B7228_Fm0.txt
agrep -0 -c 'TTACTACGCCGGCGTTT' *.fastq > count/B7229_Fm0.txt
agrep -0 -c 'CGGTAAGCTAGTTCCCC' *.fastq > count/B7230_Fm0.txt
agrep -0 -c 'CTCACGGCAGATACTGA' *.fastq > count/B7232_Fm0.txt
agrep -0 -c 'AACCAGAACGATCAAGT' *.fastq > count/B7233_Fm0.txt
agrep -0 -c 'CGAGGCGATTGCAATGA' *.fastq > count/B7234_Fm0.txt
agrep -0 -c 'GTAGAGGAGCAAGTCCG' *.fastq > count/B7236_Fm0.txt
agrep -0 -c 'ACCCTCCCAGGCTATTC' *.fastq > count/B7237_Fm0.txt
agrep -0 -c 'ACAGGCTACGGGATTTT' *.fastq > count/B7239_Fm0.txt
agrep -0 -c 'CCTGGCGGATGTGAATG' *.fastq > count/B7240_Fm0.txt
agrep -0 -c 'TGCGTGACCGATAGGTG' *.fastq > count/B7241_Fm0.txt
agrep -0 -c 'TACCGGCGTCGGAATTC' *.fastq > count/B7242_Fm0.txt
agrep -0 -c 'GACTCTACACTACCACG' *.fastq > count/B7243_Fm0.txt
agrep -0 -c 'ATTTGGGCTTAGCCCCA' *.fastq > count/B7244_Fm0.txt
agrep -0 -c 'TTCGTGCGGTGAACCCA' *.fastq > count/B7245_Fm0.txt
agrep -0 -c 'ACCCTAGACGCTAGGAC' *.fastq > count/B7246_Fm0.txt
agrep -0 -c 'GCTTATGCTTGGCAACA' *.fastq > count/B7247_Fm0.txt
agrep -0 -c 'TGAGTTGCTTTGGCCGG' *.fastq > count/B7248_Fm0.txt
agrep -0 -c 'GCGGTACGGAGTACTCA' *.fastq > count/B7249_Fm0.txt
agrep -0 -c 'TGTTCATGAGTGGCAGA' *.fastq > count/B7250_Fm0.txt
agrep -0 -c 'GCGTCAGAACGCCTACA' *.fastq > count/B7251_Fm0.txt
agrep -0 -c 'AGGACATTGTAACCTCA' *.fastq > count/B7252_Fm0.txt
agrep -0 -c 'CTATTATGTCTCGGGTC' *.fastq > count/B7253_Fm0.txt
agrep -0 -c 'TAAGCGGAGAAGATCAA' *.fastq > count/B7255_Fm0.txt
agrep -0 -c 'AGGACGGTGAGATGAGA' *.fastq > count/B7256_Fm0.txt
agrep -0 -c 'ACGGTGAATGCACTCAG' *.fastq > count/B7257_Fm0.txt
agrep -0 -c 'GTTAGGTAGGCGCAATT' *.fastq > count/B7258_Fm0.txt
agrep -0 -c 'TGTGCCGTCTTCCTAAA' *.fastq > count/B7259_Fm0.txt
agrep -0 -c 'TGCCTCTACTGGACCGA' *.fastq > count/B7260_Fm0.txt
agrep -0 -c 'CGAATTACTTCAGCAGT' *.fastq > count/B7261_Fm0.txt
agrep -0 -c 'TATTAGCGTGCCGAATC' *.fastq > count/B7262_Fm0.txt
agrep -0 -c 'AGGTGCTACCGCTGATT' *.fastq > count/B7263_Fm0.txt
agrep -0 -c 'GAGGGACTAGGTACGAA' *.fastq > count/B7264_Fm0.txt
agrep -0 -c 'GATCACTACTGATCCAT' *.fastq > count/B7265_Fm0.txt
agrep -0 -c 'CTCGACCTTTTCCAAAC' *.fastq > count/B7266_Fm0.txt
agrep -0 -c 'GTAATCGAGTATCGATG' *.fastq > count/B7267_Fm0.txt
agrep -0 -c 'TCGCCTAAAAGCCGCAA' *.fastq > count/B7268_Fm0.txt
agrep -0 -c 'AAGAAGGGCTCGAAATG' *.fastq > count/B7269_Fm0.txt
agrep -0 -c 'AGTAAGCGAGGCCAAGC' *.fastq > count/B7270_Fm0.txt
agrep -0 -c 'TTGAGGGAATTAACTGC' *.fastq > count/B7271_Fm0.txt
agrep -0 -c 'GATCTGAACGCTGGAAG' *.fastq > count/B7272_Fm0.txt
agrep -0 -c 'ATACGGTCCCAACAAGC' *.fastq > count/B7273_Fm0.txt
agrep -0 -c 'CACGGTCTTAAAGACCT' *.fastq > count/B7274_Fm0.txt
agrep -0 -c 'GATTGATCGCCTTTCAA' *.fastq > count/B7275_Fm0.txt
agrep -0 -c 'TAGGACTACTAGAGGAG' *.fastq > count/B7276_Fm0.txt
agrep -0 -c 'TTACCGGAGCTGTCGTG' *.fastq > count/B7277_Fm0.txt
agrep -0 -c 'TGATACACCAAGGACTG' *.fastq > count/B7278_Fm0.txt
agrep -0 -c 'TCAGCATCGCGTCTGGA' *.fastq > count/B7279_Fm0.txt
agrep -0 -c 'AGGCGGGGTGAATTATG' *.fastq > count/B7280_Fm0.txt
agrep -0 -c 'CCTTGCACAAGGTATGG' *.fastq > count/B7281_Fm0.txt
agrep -0 -c 'GTGCCTGCGATAGTCCA' *.fastq > count/B7282_Fm0.txt
agrep -0 -c 'GTTAGACGGTTGGGGCT' *.fastq > count/B7283_Fm0.txt
agrep -0 -c 'GTACTGCTAAGCAGCGA' *.fastq > count/B7284_Fm0.txt
agrep -0 -c 'GACGGAGGTTGTAGTTA' *.fastq > count/B7285_Fm0.txt
agrep -0 -c 'AGGAGAACCCTTTTGCT' *.fastq > count/B7286_Fm0.txt
agrep -0 -c 'AGGGGCGGCAATACGTA' *.fastq > count/B7287_Fm0.txt
agrep -0 -c 'AGAAGCCCTTACCGTTA' *.fastq > count/B7288_Fm0.txt
agrep -0 -c 'GGTTCTAGTTAGCGTCG' *.fastq > count/B7289_Fm0.txt
agrep -0 -c 'TGAGTTGAACATGAAGG' *.fastq > count/B7291_Fm0.txt
agrep -0 -c 'TGGACTAACATGGAATC' *.fastq > count/B7292_Fm0.txt
agrep -0 -c 'GCAGGGAATTAGGATGT' *.fastq > count/B7293_Fm0.txt
agrep -0 -c 'TTGCCGTCGGAAGCCAT' *.fastq > count/B7295_Fm0.txt
agrep -0 -c 'CTATTGTGGCTTCTATC' *.fastq > count/B7296_Fm0.txt
agrep -0 -c 'ATCCCCAACTGATCTTA' *.fastq > count/B7299_Fm0.txt
agrep -0 -c 'ATCGTATATGGCGGGGT' *.fastq > count/B7300_Fm0.txt
agrep -0 -c 'TGGACTTCTTGGCATAG' *.fastq > count/B7302_Fm0.txt
agrep -0 -c 'TTACTGTGCTCAGAATC' *.fastq > count/B7303_Fm0.txt
agrep -0 -c 'GGGGTTGGCTAGAACCT' *.fastq > count/B7304_Fm0.txt
agrep -0 -c 'ACTCCCAGCAGTCCTAG' *.fastq > count/B7305_Fm0.txt
agrep -0 -c 'AGGATCGAGTGACGTGT' *.fastq > count/B7306_Fm0.txt
agrep -0 -c 'TTCTGATCTCCGTCGAG' *.fastq > count/B7309_Fm0.txt
agrep -0 -c 'GCCGGTAATCTAGCAAT' *.fastq > count/B7311_Fm0.txt
agrep -0 -c 'TCGACTAGAATCAGGCT' *.fastq > count/B7312_Fm0.txt
agrep -0 -c 'GTACACCAGATGTGGGG' *.fastq > count/B7313_Fm0.txt
agrep -0 -c 'TGGACCTGTTTGCTGAC' *.fastq > count/B7314_Fm0.txt
agrep -0 -c 'GTCTTGAAAAAGAGCCT' *.fastq > count/B7315_Fm0.txt
agrep -0 -c 'ATTTCGAGTGCGAGCGC' *.fastq > count/B7318_Fm0.txt
agrep -0 -c 'AGAAGAGCGACCCAAGA' *.fastq > count/B7319_Fm0.txt
agrep -0 -c 'GTCGTTCAGAGTAGTCC' *.fastq > count/B7320_Fm0.txt
agrep -0 -c 'GCTCGATACGCATGCAA' *.fastq > count/B7321_Fm0.txt
agrep -0 -c 'GTAAGGCTATGGGGACG' *.fastq > count/B7322_Fm0.txt
agrep -0 -c 'CTAGCGTGAACTGCGGA' *.fastq > count/B7323_Fm0.txt
agrep -0 -c 'CAGGATTTCGACTCGTG' *.fastq > count/B7324_Fm0.txt
agrep -0 -c 'CCAGCCTAGTAGTATGC' *.fastq > count/B7325_Fm0.txt
agrep -0 -c 'GGAATTGAGCCTATCCC' *.fastq > count/B7326_Fm0.txt
agrep -0 -c 'AGGGGATAAACTGTTAG' *.fastq > count/B7328_Fm0.txt
agrep -0 -c 'GTGCACGAAGGGTAGGT' *.fastq > count/B7329_Fm0.txt
agrep -0 -c 'GCTAGCAGTCCGAACCA' *.fastq > count/B7330_Fm0.txt
agrep -0 -c 'TTGCTACGTCGGTGTCT' *.fastq > count/B7333_Fm0.txt
agrep -0 -c 'AGTCCAAGCAGGGTCGT' *.fastq > count/B7334_Fm0.txt
agrep -0 -c 'AGCTTTCGCGGTATGGC' *.fastq > count/B7335_Fm0.txt
agrep -0 -c 'TCAGCTAATCGCGCGCT' *.fastq > count/B7337_Fm0.txt
agrep -0 -c 'AAGGTCGTAACAAGCCG' *.fastq > count/B7338_Fm0.txt
agrep -0 -c 'ATACGGATCGGCGTACT' *.fastq > count/B7339_Fm0.txt
agrep -0 -c 'CCAAATTGGACGGGCCA' *.fastq > count/B7340_Fm0.txt
agrep -0 -c 'GGAAGAAATTGGGCGCT' *.fastq > count/B7341_Fm0.txt
agrep -0 -c 'GTATTCCAGAACCGACA' *.fastq > count/B7343_Fm0.txt
agrep -0 -c 'ATAAACCTGTTGGCGAA' *.fastq > count/B7346_Fm0.txt
agrep -0 -c 'ATGTTTGTAGCGCTAGG' *.fastq > count/B7347_Fm0.txt
agrep -0 -c 'TTGAATGTAATCGCCCG' *.fastq > count/B7348_Fm0.txt
agrep -0 -c 'GCGCTATATAAGGAAGT' *.fastq > count/B7350_Fm0.txt
agrep -0 -c 'TACCCGAAGATCCGTGT' *.fastq > count/B7351_Fm0.txt
agrep -0 -c 'CATGCTCATCGTACTAG' *.fastq > count/B7352_Fm0.txt
agrep -0 -c 'TCATCAGGTGAGATCCC' *.fastq > count/B7353_Fm0.txt
agrep -0 -c 'TTCTGTAGTCACCCCGC' *.fastq > count/B7354_Fm0.txt
agrep -0 -c 'TTCGCAATGTCGTTTCC' *.fastq > count/B7355_Fm0.txt
agrep -0 -c 'GGATAGGGTAGTAAGGA' *.fastq > count/B7356_Fm0.txt
agrep -0 -c 'TGGAGTAATTCGTTCGG' *.fastq > count/B7357_Fm0.txt
agrep -0 -c 'ATAGAAGTTAGGGGGCA' *.fastq > count/B7358_Fm0.txt
agrep -0 -c 'CGAAGCCCTTGAAAGGT' *.fastq > count/B7359_Fm0.txt
agrep -0 -c 'GCGTTCTCTACCTGAAT' *.fastq > count/B7360_Fm0.txt
agrep -0 -c 'ATGGCCGTTAGCACTAC' *.fastq > count/B7361_Fm0.txt
agrep -0 -c 'AGAATTTACTGAGGGCC' *.fastq > count/B7362_Fm0.txt
agrep -0 -c 'TAGTACGCCTAGGGAAT' *.fastq > count/B7363_Fm0.txt
agrep -0 -c 'ATCGCAACGATTTCAAG' *.fastq > count/B7364_Fm0.txt
agrep -0 -c 'TACTTCTGTGTTCAGGT' *.fastq > count/B7365_Fm0.txt
agrep -0 -c 'TAGCGCCCACATCGACA' *.fastq > count/B7368_Fm0.txt
agrep -0 -c 'TGAGGCAGTACGGAGTC' *.fastq > count/B7369_Fm0.txt
agrep -0 -c 'CATCAGGTGTACCACTC' *.fastq > count/B7370_Fm0.txt
agrep -0 -c 'TTGGATCAAAAAGTCGC' *.fastq > count/B7371_Fm0.txt
agrep -0 -c 'TCACGTCAATAGACCGA' *.fastq > count/B7373_Fm0.txt
agrep -0 -c 'TGAGTGGCTTGCGGCTA' *.fastq > count/B7374_Fm0.txt
agrep -0 -c 'AGCATGGTGTAGTGGTG' *.fastq > count/B7375_Fm0.txt
agrep -0 -c 'GATTGTCAGAAATCTCG' *.fastq > count/B7378_Fm0.txt
agrep -0 -c 'CATAGTTGATAGCCGAC' *.fastq > count/B7379_Fm0.txt
agrep -0 -c 'GCATCAGATTCGCAGTG' *.fastq > count/B7380_Fm0.txt
agrep -0 -c 'TGATCGCCCTTAGCACA' *.fastq > count/B7381_Fm0.txt
agrep -0 -c 'TGATGCAATTTTCGCTG' *.fastq > count/B7382_Fm0.txt
agrep -0 -c 'CTACTCTGCTTCACCGA' *.fastq > count/B7383_Fm0.txt
agrep -0 -c 'GAGCGCTGTAAACCCTA' *.fastq > count/B7384_Fm0.txt
agrep -0 -c 'CTCGAAGGTTTTTGTCC' *.fastq > count/B7385_Fm0.txt
agrep -0 -c 'CGCACGATAGTCTCGAC' *.fastq > count/B7386_Fm0.txt
agrep -0 -c 'CTTGGTCTATACGGAGA' *.fastq > count/B7387_Fm0.txt
agrep -0 -c 'CCGGATTCGAGTTGTAG' *.fastq > count/B7388_Fm0.txt
agrep -0 -c 'ACGACAGTAGCACGTTA' *.fastq > count/B7389_Fm0.txt
agrep -0 -c 'CGCCGTTATTTACGATA' *.fastq > count/B7390_Fm0.txt
agrep -0 -c 'GTGTCAAGTGACAAGAC' *.fastq > count/B7391_Fm0.txt
agrep -0 -c 'CCATGCACACGGGAATC' *.fastq > count/B7392_Fm0.txt
agrep -0 -c 'CGAGAAGCGTGCACAAT' *.fastq > count/B7393_Fm0.txt
agrep -0 -c 'GTGGTTTCGAAAGTCAC' *.fastq > count/B7394_Fm0.txt
agrep -0 -c 'CACTTCTAAGTAATCGC' *.fastq > count/B7395_Fm0.txt
agrep -0 -c 'ACTTTGCCATCTCCGGA' *.fastq > count/B7397_Fm0.txt
agrep -0 -c 'GAGGGTCCATTCCATAG' *.fastq > count/B7399_Fm0.txt
agrep -0 -c 'CACTCCCAGGGACTTAT' *.fastq > count/B7402_Fm0.txt
agrep -0 -c 'TCAGAGGGAGCCACATA' *.fastq > count/B7403_Fm0.txt
agrep -0 -c 'GACGTCTTTTCCAGGAG' *.fastq > count/B7404_Fm0.txt
agrep -0 -c 'TGAGACACCCTATGGCC' *.fastq > count/B7406_Fm0.txt
agrep -0 -c 'TAAACGTCAGCATACCG' *.fastq > count/B7407_Fm0.txt
agrep -0 -c 'TCGCTACTACGCTACTC' *.fastq > count/B7408_Fm0.txt
agrep -0 -c 'GGGTTAACCGCGTTACT' *.fastq > count/B7409_Fm0.txt
agrep -0 -c 'CAACTACACGCTCCCAT' *.fastq > count/B7410_Fm0.txt
agrep -0 -c 'ATCGATCCACGACTCTG' *.fastq > count/B7411_Fm0.txt
agrep -0 -c 'GTGTGGTAAGTCTTCAA' *.fastq > count/B7412_Fm0.txt
agrep -0 -c 'CGAATCAGAGTTACCCG' *.fastq > count/B7413_Fm0.txt
agrep -0 -c 'CGCCAGATCGGTCTTTA' *.fastq > count/B7415_Fm0.txt
agrep -0 -c 'TCGTGGTCTTTTGACTT' *.fastq > count/B7416_Fm0.txt
agrep -0 -c 'CACTCCATGGGAAAGGA' *.fastq > count/B7417_Fm0.txt
agrep -0 -c 'CTGAATCTCTGAATGCC' *.fastq > count/B7418_Fm0.txt
agrep -0 -c 'GACAAAGGCTCAACTGC' *.fastq > count/B7419_Fm0.txt
agrep -0 -c 'CACTTGTGTACGGTATT' *.fastq > count/B7420_Fm0.txt
agrep -0 -c 'TAGTCATCGGCCACCTA' *.fastq > count/B7422_Fm0.txt
agrep -0 -c 'TTAGCAAATCAACGCGC' *.fastq > count/B7423_Fm0.txt
agrep -0 -c 'GGTCCTCACTTGTCGTG' *.fastq > count/B7424_Fm0.txt
agrep -0 -c 'GAGCTATACAACTACTG' *.fastq > count/B7426_Fm0.txt
agrep -0 -c 'TGTCTTTTTGATGTCCC' *.fastq > count/B7427_Fm0.txt
agrep -0 -c 'CTCACAGGTCTCATCTA' *.fastq > count/B7428_Fm0.txt
agrep -0 -c 'AATGTTAATAGCCGAGC' *.fastq > count/B7429_Fm0.txt
agrep -0 -c 'TTCACTGTATGGGTACG' *.fastq > count/B7430_Fm0.txt
agrep -0 -c 'GCGGCTTACGAGTGGTA' *.fastq > count/B7431_Fm0.txt
agrep -0 -c 'ATTGCCGAAGGTCCTTT' *.fastq > count/B7432_Fm0.txt
agrep -0 -c 'AGTAGCCGCTTCGTTCC' *.fastq > count/B7433_Fm0.txt
agrep -0 -c 'GTAGAGGTGTCGCGGTT' *.fastq > count/B7434_Fm0.txt
agrep -0 -c 'CGCTCTCGCTTTTTCAG' *.fastq > count/B7435_Fm0.txt
agrep -0 -c 'TAGGGAGGCGTTCAGAG' *.fastq > count/B7437_Fm0.txt
agrep -0 -c 'TTGTAGCGATCTCCGAC' *.fastq > count/B7438_Fm0.txt
agrep -0 -c 'CTCTTGAGATTGACCGT' *.fastq > count/B7439_Fm0.txt
agrep -0 -c 'CTTGGGGCCAGTATTCG' *.fastq > count/B7443_Fm0.txt
agrep -0 -c 'GCCAGTGGTATACTCCG' *.fastq > count/B7444_Fm0.txt
agrep -0 -c 'GTGACGATCCAACTCGC' *.fastq > count/B7445_Fm0.txt
agrep -0 -c 'ATCCAATCCCGCGGAGT' *.fastq > count/B7447_Fm0.txt
agrep -0 -c 'GTTCTCGGGCTTGCAAA' *.fastq > count/B7448_Fm0.txt
agrep -0 -c 'GGCAATACTCTATTCGT' *.fastq > count/B7449_Fm0.txt
agrep -0 -c 'GGATAGCTGGGGTCGTT' *.fastq > count/B7450_Fm0.txt
agrep -0 -c 'TTAGCCAGTCATGACAT' *.fastq > count/B7451_Fm0.txt
agrep -0 -c 'TCACTGTTAACCTGGGC' *.fastq > count/B7452_Fm0.txt
agrep -0 -c 'AGGTGTTTTTCGATGCA' *.fastq > count/B7453_Fm0.txt
agrep -0 -c 'AGCTGCAGTAGTGACAC' *.fastq > count/B7454_Fm0.txt
agrep -0 -c 'GTCCGACGTTGCTACAC' *.fastq > count/B7455_Fm0.txt
agrep -0 -c 'AATGCAAGCTACTTGCA' *.fastq > count/B7456_Fm0.txt
agrep -0 -c 'TTCAGTCGTTGACATAC' *.fastq > count/B7457_Fm0.txt
agrep -0 -c 'ACTAAATGGCTCTACTG' *.fastq > count/B7458_Fm0.txt
agrep -0 -c 'TTGTCGGTAGCGCTATC' *.fastq > count/B7459_Fm0.txt
agrep -0 -c 'CACCTATCCAGATAGTT' *.fastq > count/B7460_Fm0.txt
agrep -0 -c 'TGGCACATATATCGCAT' *.fastq > count/B7461_Fm0.txt
agrep -0 -c 'AGAGAGTTCGTCGAACT' *.fastq > count/B7462_Fm0.txt
agrep -0 -c 'CTTCACCGGTTAGGAGG' *.fastq > count/B7463_Fm0.txt
agrep -0 -c 'ATGGCTGTCGCTCTAAA' *.fastq > count/B7464_Fm0.txt
agrep -0 -c 'ATCGAACGGTTGGCATG' *.fastq > count/B7466_Fm0.txt
agrep -0 -c 'AACGACACCGTGCTTTT' *.fastq > count/B7467_Fm0.txt
agrep -0 -c 'GACGAAGATAGACTGGC' *.fastq > count/B7468_Fm0.txt
agrep -0 -c 'GGGTGTCGACGTTTTTA' *.fastq > count/B7469_Fm0.txt
agrep -0 -c 'AGGGCCTAAGGCCACAA' *.fastq > count/B7470_Fm0.txt
agrep -0 -c 'CATTAGACCAACGTGGC' *.fastq > count/B7471_Fm0.txt
agrep -0 -c 'CCACACGTGTGTTAGCG' *.fastq > count/B7472_Fm0.txt
agrep -0 -c 'ACGATACTTCCTGACTA' *.fastq > count/B7473_Fm0.txt
agrep -0 -c 'TAGACCCATATGACTGT' *.fastq > count/B7474_Fm0.txt
agrep -0 -c 'AAGATCTGGCCGACGAG' *.fastq > count/B7475_Fm0.txt
agrep -0 -c 'CTACCTTACTCTTAGCC' *.fastq > count/B7476_Fm0.txt
agrep -0 -c 'CCTGGACAACCGTTCTA' *.fastq > count/B7477_Fm0.txt
agrep -0 -c 'GGGGTACTCTGCTTTTG' *.fastq > count/B7478_Fm0.txt
agrep -0 -c 'GTCAGACAAACACTGAT' *.fastq > count/B7479_Fm0.txt
agrep -0 -c 'GGGATACGAAGGCACAC' *.fastq > count/B7480_Fm0.txt
agrep -0 -c 'AGGAAGCTTGGTCGCAT' *.fastq > count/B7481_Fm0.txt
agrep -0 -c 'GTGGTAAGCGGTCAGTG' *.fastq > count/B7482_Fm0.txt
agrep -0 -c 'CCGTTGATAACAATCTG' *.fastq > count/B7483_Fm0.txt
agrep -0 -c 'AGCGCTAATAACTCTTG' *.fastq > count/B7484_Fm0.txt
agrep -0 -c 'GCGATAACTGTAACATG' *.fastq > count/B7485_Fm0.txt
agrep -0 -c 'CCGTCTTAATGCAATCT' *.fastq > count/B7487_Fm0.txt
agrep -0 -c 'GCGCTTTAGTTCAAACC' *.fastq > count/B7488_Fm0.txt
agrep -0 -c 'CATAGCAGCGACTGATA' *.fastq > count/B7489_Fm0.txt
agrep -0 -c 'GGTCGAGGAATTAAAAG' *.fastq > count/B7490_Fm0.txt
agrep -0 -c 'CAATGGTGTCCGATTAC' *.fastq > count/B7491_Fm0.txt
agrep -0 -c 'TGCTCGCGAGACCGAAA' *.fastq > count/B7492_Fm0.txt
agrep -0 -c 'TGCCAACAGGACGAGTC' *.fastq > count/B7493_Fm0.txt
agrep -0 -c 'CTAAAGCATCGATGGGG' *.fastq > count/B7496_Fm0.txt
agrep -0 -c 'AAGAGCTCCTATGACGA' *.fastq > count/B7497_Fm0.txt
agrep -0 -c 'GGAGCATTCTTTCGGGC' *.fastq > count/B7498_Fm0.txt
agrep -0 -c 'CATCCCATTGCCCTACG' *.fastq > count/B7501_Fm0.txt
agrep -0 -c 'ATGGGCGACTGTATTGG' *.fastq > count/B7502_Fm0.txt
agrep -0 -c 'TAGCGCGCCATTACGTC' *.fastq > count/B7503_Fm0.txt
agrep -0 -c 'TCGACAGAGATGCGAGA' *.fastq > count/B7504_Fm0.txt
agrep -0 -c 'CCGTTTACGTACAATGG' *.fastq > count/B7507_Fm0.txt
agrep -0 -c 'TAATAGGGAACGTAACC' *.fastq > count/B7508_Fm0.txt
agrep -0 -c 'TCGTCTATAACAAGTGC' *.fastq > count/B7509_Fm0.txt
agrep -0 -c 'GGAGGGAATCTGTTAAT' *.fastq > count/B7510_Fm0.txt
agrep -0 -c 'ACCGCTGTGGTCAGAAT' *.fastq > count/B7511_Fm0.txt
agrep -0 -c 'CCTTTGGGAACCTTATG' *.fastq > count/B7512_Fm0.txt
agrep -0 -c 'ACAAGAGATCGGGTCTT' *.fastq > count/B7513_Fm0.txt
agrep -0 -c 'AATGTGGGCCCTTCGAC' *.fastq > count/B7514_Fm0.txt
agrep -0 -c 'GTTGCGATCTTTGCTTG' *.fastq > count/B7515_Fm0.txt
agrep -0 -c 'TATAGTTCTAGGACCCT' *.fastq > count/B7516_Fm0.txt
agrep -0 -c 'TGGAAACATTGGAGTAG' *.fastq > count/B7517_Fm0.txt
agrep -0 -c 'TCGATGACGGCCTATAC' *.fastq > count/B7518_Fm0.txt
agrep -0 -c 'GATTCAGACGGTAAAAC' *.fastq > count/B7519_Fm0.txt
agrep -0 -c 'GTCTGTATTCACTAGGG' *.fastq > count/B7521_Fm0.txt
agrep -0 -c 'TTACTCGGCCATCTTAA' *.fastq > count/B7522_Fm0.txt
agrep -0 -c 'GCTATGGTTTGACACTT' *.fastq > count/B7523_Fm0.txt
agrep -0 -c 'TCAAACCCTTAATTGCC' *.fastq > count/B7524_Fm0.txt
agrep -0 -c 'GCTCATACGTAGAACAC' *.fastq > count/B7525_Fm0.txt
agrep -0 -c 'GTTCCGAATCGAAGTTC' *.fastq > count/B7526_Fm0.txt
agrep -0 -c 'GCCTAATAGCGGGTAGT' *.fastq > count/B7527_Fm0.txt
agrep -0 -c 'GTCACTTTTAGGCATGA' *.fastq > count/B7528_Fm0.txt
agrep -0 -c 'ACGCGGAGCTAAAGTGA' *.fastq > count/B7529_Fm0.txt
agrep -0 -c 'ATACTCATCGCTAACCT' *.fastq > count/B7531_Fm0.txt
agrep -0 -c 'AGAGGGTACCTCCTCCT' *.fastq > count/B7532_Fm0.txt
agrep -0 -c 'TACTGACTCACGCAGAA' *.fastq > count/B7533_Fm0.txt
agrep -0 -c 'AGAGTAACCAGCGATGC' *.fastq > count/B7534_Fm0.txt
agrep -0 -c 'CCTGACAAATTGCCGGA' *.fastq > count/B7536_Fm0.txt
agrep -0 -c 'TTGTACCGAGCAAGCGA' *.fastq > count/B7537_Fm0.txt
agrep -0 -c 'ATCGAGGGGTAAGCGCA' *.fastq > count/B7538_Fm0.txt
agrep -0 -c 'CGTTATCGGTACACTTA' *.fastq > count/B7539_Fm0.txt
agrep -0 -c 'ACTAACGGGAGGCATCA' *.fastq > count/B7540_Fm0.txt
agrep -0 -c 'GCTAGTCAGTGCCCACT' *.fastq > count/B7541_Fm0.txt
agrep -0 -c 'GAGAGTTTTACCCCGGG' *.fastq > count/B7542_Fm0.txt
agrep -0 -c 'CAGCGGGTTGAATTGCC' *.fastq > count/B7543_Fm0.txt
agrep -0 -c 'TTCAGAGTGACACTCTA' *.fastq > count/B7544_Fm0.txt
agrep -0 -c 'TCAGGCAATCGTTCCTT' *.fastq > count/B7546_Fm0.txt
agrep -0 -c 'CTGGCGTATCACACGCT' *.fastq > count/B7547_Fm0.txt
agrep -0 -c 'ACGGACCATACAGTCTT' *.fastq > count/B7548_Fm0.txt
agrep -0 -c 'ATGCGAAAACGGAGGTT' *.fastq > count/B7550_Fm0.txt
agrep -0 -c 'TGACCGCCTAACATTCG' *.fastq > count/B7551_Fm0.txt
agrep -0 -c 'CAAAAAGCCGGACACAC' *.fastq > count/B7552_Fm0.txt
agrep -0 -c 'ATATCGCGGAGGTGGGT' *.fastq > count/B7553_Fm0.txt
agrep -0 -c 'ACTGGGGCGATCAACCT' *.fastq > count/B7555_Fm0.txt
agrep -0 -c 'TATTTACAGGCGCACCC' *.fastq > count/B7556_Fm0.txt
agrep -0 -c 'GACCAAACGGAGATCAC' *.fastq > count/B7561_Fm0.txt
agrep -0 -c 'TTCCCGTAGTCGTTAGA' *.fastq > count/B7562_Fm0.txt
agrep -0 -c 'ACTCAAAGGGAACTCAG' *.fastq > count/B7563_Fm0.txt
agrep -0 -c 'CCTGAGCGTTTAGAATG' *.fastq > count/B7565_Fm0.txt
agrep -0 -c 'AAGCAGCGAACTTATGT' *.fastq > count/B7566_Fm0.txt
agrep -0 -c 'CCGATTGGGCTCGTATT' *.fastq > count/B7568_Fm0.txt
agrep -0 -c 'GTTAAGCCGTCAAGATA' *.fastq > count/B7569_Fm0.txt
agrep -0 -c 'ATTCGTTCTCTTCCTTC' *.fastq > count/B7570_Fm0.txt
agrep -0 -c 'GGGTACTCATCTAGGAC' *.fastq > count/B7571_Fm0.txt
agrep -0 -c 'ATCAACGACGGCCACGA' *.fastq > count/B7572_Fm0.txt
agrep -0 -c 'CTAAGAACATGCGTTTG' *.fastq > count/B7573_Fm0.txt
agrep -0 -c 'GTTAGGTCCATGCATAC' *.fastq > count/B7574_Fm0.txt
agrep -0 -c 'AACATTCTGACGCCATA' *.fastq > count/B7576_Fm0.txt
agrep -0 -c 'TTAGCCCCTGAGGTAAG' *.fastq > count/B7578_Fm0.txt
agrep -0 -c 'CGAATTCAGGACTTACC' *.fastq > count/B7579_Fm0.txt
agrep -0 -c 'GTCTCCAGCGGAATCTC' *.fastq > count/B7580_Fm0.txt
agrep -0 -c 'TGGAGTGTATGACTCTA' *.fastq > count/B7582_Fm0.txt
agrep -0 -c 'GACGCGATTTGTCACCC' *.fastq > count/B7583_Fm0.txt
agrep -0 -c 'TACTAAACCGGCGGAAG' *.fastq > count/B7585_Fm0.txt
agrep -0 -c 'TATGCGACTGCCGAAGA' *.fastq > count/B7586_Fm0.txt
agrep -0 -c 'GGCCTTACTATCTGAAA' *.fastq > count/B7588_Fm0.txt
agrep -0 -c 'CGTCACAACAATGCCGG' *.fastq > count/B7589_Fm0.txt
agrep -0 -c 'ACCAGCGCCCTCGTTAA' *.fastq > count/B7590_Fm0.txt
agrep -0 -c 'AACCGAAGCGTGCTCTT' *.fastq > count/B7591_Fm0.txt
agrep -0 -c 'ATGGCTCAGACCCTTCG' *.fastq > count/B7592_Fm0.txt
agrep -0 -c 'TGTCGCCACTTTGATTC' *.fastq > count/B7593_Fm0.txt
agrep -0 -c 'CATAAAGTCGACATGAG' *.fastq > count/B7594_Fm0.txt
agrep -0 -c 'CGACTGAATGATGATCC' *.fastq > count/B7595_Fm0.txt
agrep -0 -c 'AATTATAGCAGGGCTGT' *.fastq > count/B7596_Fm0.txt
agrep -0 -c 'GTATACCCTGTGGTATC' *.fastq > count/B7597_Fm0.txt
agrep -0 -c 'GCCCTAACTGTCTCGGT' *.fastq > count/B7598_Fm0.txt
agrep -0 -c 'CGAGCTGTAGTTGAAGC' *.fastq > count/B7599_Fm0.txt
agrep -0 -c 'ACCCTGAGAAGGTCAGC' *.fastq > count/B7600_Fm0.txt
agrep -0 -c 'GTAATTACGTCACGTAC' *.fastq > count/B7601_Fm0.txt
agrep -0 -c 'TCGACGCCTCTCTAATC' *.fastq > count/B7602_Fm0.txt
agrep -0 -c 'GATGTGACTGACCCGTT' *.fastq > count/B7605_Fm0.txt
agrep -0 -c 'CCAAAGGATTACCCAAG' *.fastq > count/B7606_Fm0.txt
agrep -0 -c 'GTGAGTTGTGTGCCCCT' *.fastq > count/B7607_Fm0.txt
agrep -0 -c 'TGCCGGATTACGATTGG' *.fastq > count/B7608_Fm0.txt
agrep -0 -c 'GGTCCTGCAACTTGAAG' *.fastq > count/B7609_Fm0.txt
agrep -0 -c 'TGGCATCAACAATACGC' *.fastq > count/B7610_Fm0.txt
agrep -0 -c 'TTACGCGCCATTTCAGG' *.fastq > count/B7611_Fm0.txt
agrep -0 -c 'TCACGACGAGAAGTGAC' *.fastq > count/B7612_Fm0.txt
agrep -0 -c 'GGTGTGGCTGGCATCAT' *.fastq > count/B7613_Fm0.txt
agrep -0 -c 'GCAGATGGGCCATATAA' *.fastq > count/B7614_Fm0.txt
agrep -0 -c 'GATTCACGGCCCGAATC' *.fastq > count/B7616_Fm0.txt
agrep -0 -c 'CCGAAGTTGCTATCGCT' *.fastq > count/B7619_Fm0.txt
agrep -0 -c 'TGAGTTTCGGATCCGTG' *.fastq > count/B7620_Fm0.txt
agrep -0 -c 'CATGGACAACCGAATAG' *.fastq > count/B7621_Fm0.txt
agrep -0 -c 'ACGTTGCAACCAAGTTG' *.fastq > count/B7622_Fm0.txt
agrep -0 -c 'AGTAAGTCCCGGAGTGT' *.fastq > count/B7623_Fm0.txt
agrep -0 -c 'TCGGTCAGAGGATCAAT' *.fastq > count/B7625_Fm0.txt
agrep -0 -c 'TAGACTGTTCATGCGTC' *.fastq > count/B7626_Fm0.txt
agrep -0 -c 'TGCAGTCGGGAATCACG' *.fastq > count/B7627_Fm0.txt
agrep -0 -c 'CCGGTGAGACAAATACA' *.fastq > count/B7628_Fm0.txt
agrep -0 -c 'ACCTCGTCGCAAAGCGA' *.fastq > count/B7629_Fm0.txt
agrep -0 -c 'GGCCAAACATCTGCGTG' *.fastq > count/B7630_Fm0.txt
agrep -0 -c 'CTAGTTTCGATCCCACT' *.fastq > count/B7631_Fm0.txt
agrep -0 -c 'TCACGTATGGGAGATTC' *.fastq > count/B7632_Fm0.txt
agrep -0 -c 'CTCTGCTGACCGAAAAG' *.fastq > count/B7634_Fm0.txt
agrep -0 -c 'TCGCATGCCTTACCCTT' *.fastq > count/B7635_Fm0.txt
agrep -0 -c 'TAGCATAGGATCGATGA' *.fastq > count/B7636_Fm0.txt
agrep -0 -c 'TAAGGCGGCAATTGACT' *.fastq > count/B7637_Fm0.txt
agrep -0 -c 'ATGACGGTTTGTGACAT' *.fastq > count/B7638_Fm0.txt
agrep -0 -c 'CTAATATCAGAACGGGC' *.fastq > count/B7640_Fm0.txt
agrep -0 -c 'GTTAGTAGGGATTAGGA' *.fastq > count/B7641_Fm0.txt
agrep -0 -c 'GCAGTACCTATGTCTTG' *.fastq > count/B7643_Fm0.txt
agrep -0 -c 'TTAGGTGGGTATAGGCA' *.fastq > count/B7644_Fm0.txt
agrep -0 -c 'GACACCGGTGATTTTTA' *.fastq > count/B7647_Fm0.txt
agrep -0 -c 'AACAATCCTTTGGTGAG' *.fastq > count/B7648_Fm0.txt
agrep -0 -c 'ACACGTCTTACTACCTG' *.fastq > count/B7649_Fm0.txt
agrep -0 -c 'GTGGGTTAGTTCATGGA' *.fastq > count/B7650_Fm0.txt
agrep -0 -c 'GCGCCTCGTTTAATGTA' *.fastq > count/B7652_Fm0.txt
agrep -0 -c 'CCAATGCCCAATGGCCA' *.fastq > count/B7653_Fm0.txt
agrep -0 -c 'CAGAAGAGGCTTACGGA' *.fastq > count/B7654_Fm0.txt
agrep -0 -c 'CGGGGAAATCAGGATGA' *.fastq > count/B7655_Fm0.txt
agrep -0 -c 'TTGGTATTACCCCGGTT' *.fastq > count/B7656_Fm0.txt
agrep -0 -c 'CCTTTGTTCACTGGGCG' *.fastq > count/B7657_Fm0.txt
agrep -0 -c 'TTAGTTCCGCACCCGTT' *.fastq > count/B7658_Fm0.txt
agrep -0 -c 'GCTAGATCTACCCAATA' *.fastq > count/B7659_Fm0.txt
agrep -0 -c 'CACGCTAGTAAGCTGTT' *.fastq > count/B7660_Fm0.txt
agrep -0 -c 'ACCGGATATGGCAGCTA' *.fastq > count/B7661_Fm0.txt
agrep -0 -c 'AAGTTGCATACTCGTGC' *.fastq > count/B7662_Fm0.txt
agrep -0 -c 'TGACCGCCTCTGGATCA' *.fastq > count/B7663_Fm0.txt
agrep -0 -c 'GGAAGCGGCGGAAATAG' *.fastq > count/B7664_Fm0.txt
agrep -0 -c 'TGAATGAGATCAACTGG' *.fastq > count/B7665_Fm0.txt
agrep -0 -c 'GATTCCTGCAGGGCGAA' *.fastq > count/B7666_Fm0.txt
agrep -0 -c 'CCGGCAGGTACTGAAAT' *.fastq > count/B7667_Fm0.txt
agrep -0 -c 'CATCGATTTGGGTAAGC' *.fastq > count/B7668_Fm0.txt
agrep -0 -c 'ATAATGATGTACCTGCG' *.fastq > count/B7669_Fm0.txt
agrep -0 -c 'GGTCGTGGCCCTGAAAT' *.fastq > count/B7671_Fm0.txt
agrep -0 -c 'TATCGTTTTAGGCCAAC' *.fastq > count/B7673_Fm0.txt
agrep -0 -c 'ACGGTGGTCCAGTAACG' *.fastq > count/B7674_Fm0.txt
agrep -0 -c 'GCAGGAAAGGCGGATGT' *.fastq > count/B7676_Fm0.txt
agrep -0 -c 'ATACTGGCCTGTTCGTT' *.fastq > count/B7677_Fm0.txt
agrep -0 -c 'ACGTCGTAAGGATCGAA' *.fastq > count/B7678_Fm0.txt
agrep -0 -c 'ACTGCGATGTCGATTGG' *.fastq > count/B7679_Fm0.txt
agrep -0 -c 'CTCACCACATTCCGATT' *.fastq > count/B7680_Fm0.txt
agrep -0 -c 'GACCGCGATTCATGGAC' *.fastq > count/B7681_Fm0.txt
agrep -0 -c 'CGCAATTCAGAGGGTCT' *.fastq > count/B7682_Fm0.txt
agrep -0 -c 'CTTGCTCCCATGTTCGC' *.fastq > count/B7683_Fm0.txt
agrep -0 -c 'CGCAGATTTGCGGATGT' *.fastq > count/B7684_Fm0.txt
agrep -0 -c 'GTCTTTGCAGAGTCTAG' *.fastq > count/B7685_Fm0.txt
agrep -0 -c 'TTAGTTAACGGACGGCC' *.fastq > count/B7687_Fm0.txt
agrep -0 -c 'ACGGTTAGGGCGCAACT' *.fastq > count/B7688_Fm0.txt
agrep -0 -c 'AGCGGCCATCTTCATGA' *.fastq > count/B7689_Fm0.txt
agrep -0 -c 'ATCGAGTTCCAACGGCG' *.fastq > count/B7690_Fm0.txt
agrep -0 -c 'TACAACGTGTCCGCGGA' *.fastq > count/B7692_Fm0.txt
agrep -0 -c 'AATGCCCTAATACCACG' *.fastq > count/B7693_Fm0.txt
agrep -0 -c 'CCTGCAACTTGATAACG' *.fastq > count/B7694_Fm0.txt
agrep -0 -c 'TCGAACACGTTAGGTAA' *.fastq > count/B7695_Fm0.txt
agrep -0 -c 'GGGTCCAGGCATAATGC' *.fastq > count/B7696_Fm0.txt
agrep -0 -c 'CACGAGACTTGCCGGTT' *.fastq > count/B7698_Fm0.txt
agrep -0 -c 'CTACGTCAGGGAACTCG' *.fastq > count/B7699_Fm0.txt
agrep -0 -c 'ACACTTGGGTTCTGACT' *.fastq > count/B7701_Fm0.txt
agrep -0 -c 'GTAGGGCTTAACCAGTT' *.fastq > count/B7702_Fm0.txt
agrep -0 -c 'AGCTTCATCTTTGGCGA' *.fastq > count/B7703_Fm0.txt
agrep -0 -c 'AGTTAACGTCCCTTGGG' *.fastq > count/B7704_Fm0.txt
agrep -0 -c 'AGAAGATACGTGTGGGA' *.fastq > count/B7706_Fm0.txt
agrep -0 -c 'TAGGTCTGGCAATGAGC' *.fastq > count/B7707_Fm0.txt
agrep -0 -c 'CGCTTAGCAGGGAACGT' *.fastq > count/B7708_Fm0.txt
agrep -0 -c 'GGGTAGGAAAACCTTCA' *.fastq > count/B7711_Fm0.txt
agrep -0 -c 'GGAGTAACTAACGACTT' *.fastq > count/B7712_Fm0.txt
agrep -0 -c 'TGATGGCGGTCGTAGCT' *.fastq > count/B7713_Fm0.txt
agrep -0 -c 'AGAAGGTCCAGTTTGTA' *.fastq > count/B7714_Fm0.txt
agrep -0 -c 'CATTAGGGGGCTAGCTA' *.fastq > count/B7715_Fm0.txt
agrep -0 -c 'ATTATGAACATGGTCGG' *.fastq > count/B7716_Fm0.txt
agrep -0 -c 'CATTGCATTTCGCCCAT' *.fastq > count/B7717_Fm0.txt
agrep -0 -c 'GATCGTTCACAGTCGAG' *.fastq > count/B7718_Fm0.txt
agrep -0 -c 'CTCGTAACCCCGTATAT' *.fastq > count/B7719_Fm0.txt
agrep -0 -c 'TCTGGAGCATCGAACTA' *.fastq > count/B7720_Fm0.txt
agrep -0 -c 'ATGTCGCCGTAACGGTC' *.fastq > count/B7721_Fm0.txt
agrep -0 -c 'GCTCATCATCTACTGGA' *.fastq > count/B7723_Fm0.txt
agrep -0 -c 'TCTTACCGGTAGGTGAC' *.fastq > count/B7724_Fm0.txt
agrep -0 -c 'TGATGCTAAGTCAGAGC' *.fastq > count/B7725_Fm0.txt
agrep -0 -c 'GGTTAATAGAAGCCGTT' *.fastq > count/B7728_Fm0.txt
agrep -0 -c 'ATCTGCTCAAGAAGTCA' *.fastq > count/B7730_Fm0.txt
agrep -0 -c 'GAGGATTGTTCTAAGCC' *.fastq > count/B7731_Fm0.txt
agrep -0 -c 'ACGCGGGACACGCATTT' *.fastq > count/B7732_Fm0.txt
agrep -0 -c 'GCCTAGAGGAGATTGCC' *.fastq > count/B7733_Fm0.txt
agrep -0 -c 'CCATCAAATGTGGGGAA' *.fastq > count/B7734_Fm0.txt
agrep -0 -c 'GTGCGGGTGGAATCTTT' *.fastq > count/B7736_Fm0.txt
agrep -0 -c 'CACGCCACACAAGATTA' *.fastq > count/B7737_Fm0.txt
agrep -0 -c 'GTCCAGAATGGCTTAAT' *.fastq > count/B7738_Fm0.txt
agrep -0 -c 'TCAATGCTAAGGGGAGA' *.fastq > count/B7739_Fm0.txt
agrep -0 -c 'AAGTTTTTGTCCCGACG' *.fastq > count/B7740_Fm0.txt
agrep -0 -c 'GCCGCTATTCCATAGTT' *.fastq > count/B7741_Fm0.txt
agrep -0 -c 'AAGTGTCTTCCGGAGCT' *.fastq > count/B7742_Fm0.txt
agrep -0 -c 'GGTGGATAACCTGACTG' *.fastq > count/B7743_Fm0.txt
agrep -0 -c 'AGGAAACGGTACGTTAA' *.fastq > count/B7744_Fm0.txt
agrep -0 -c 'CTGCGACACTGATGACT' *.fastq > count/B7745_Fm0.txt
agrep -0 -c 'CGCGGATTTTTCCGTCT' *.fastq > count/B7746_Fm0.txt
agrep -0 -c 'GGATTTCAGGATACGGC' *.fastq > count/B7747_Fm0.txt
agrep -0 -c 'ACCCGTAATGATGAGCC' *.fastq > count/B7748_Fm0.txt
agrep -0 -c 'GAGCGGGCAGATAAAGG' *.fastq > count/B7749_Fm0.txt
agrep -0 -c 'CAGTCAACGGCCTATGT' *.fastq > count/B7750_Fm0.txt
agrep -0 -c 'CTCGCAGGTGAGAGGAA' *.fastq > count/B7751_Fm0.txt
agrep -0 -c 'TCAATGTTGCCTTACGT' *.fastq > count/B7752_Fm0.txt
agrep -0 -c 'CGTTGTCAGCCGTTCGA' *.fastq > count/B7753_Fm0.txt
agrep -0 -c 'AGATGGAAGGGCTTTAT' *.fastq > count/B7754_Fm0.txt
agrep -0 -c 'ACGGATAAGGCTTGATG' *.fastq > count/B7755_Fm0.txt
agrep -0 -c 'CACGCCTCATATGGAGT' *.fastq > count/B7758_Fm0.txt
agrep -0 -c 'TATTGCACCCGGGGTTG' *.fastq > count/B7759_Fm0.txt
agrep -0 -c 'ACCAAGTAGTATCTCTG' *.fastq > count/B7760_Fm0.txt
agrep -0 -c 'CAAGTTCTTGCTACCTG' *.fastq > count/B7761_Fm0.txt
agrep -0 -c 'GGGTTGCATATTGGGGG' *.fastq > count/B7762_Fm0.txt
agrep -0 -c 'TCGAACAACGTTTACGG' *.fastq > count/B7763_Fm0.txt
agrep -0 -c 'CCTGGGAGCGTATACGA' *.fastq > count/B7764_Fm0.txt
agrep -0 -c 'CAGACAGGGTTTACACG' *.fastq > count/B7765_Fm0.txt
agrep -0 -c 'TCACGGAGTCGCACTAT' *.fastq > count/B7766_Fm0.txt
agrep -0 -c 'ACATTTGTAGCGCGTGG' *.fastq > count/B7767_Fm0.txt
agrep -0 -c 'AACTTGTTCAGGTCGCG' *.fastq > count/B7768_Fm0.txt
agrep -0 -c 'GGAATCCTAACCAAGTA' *.fastq > count/B7769_Fm0.txt
agrep -0 -c 'ACGAGCTAGTTCTTGCC' *.fastq > count/B7770_Fm0.txt
agrep -0 -c 'GCAACGTGCTTTACTAC' *.fastq > count/B7771_Fm0.txt
agrep -0 -c 'ATCGCACGCGGTTGACT' *.fastq > count/B7772_Fm0.txt
agrep -0 -c 'CTGGTCCCCGTCTGTTA' *.fastq > count/B7773_Fm0.txt
agrep -0 -c 'ATACGATCTTTGCGGGT' *.fastq > count/B7774_Fm0.txt
agrep -0 -c 'CCTGTCGGCTATTTTTC' *.fastq > count/B7775_Fm0.txt
agrep -0 -c 'ACGTTATCTACGATCTC' *.fastq > count/B7778_Fm0.txt
agrep -0 -c 'GTGGACCGTCGGAACTA' *.fastq > count/B7779_Fm0.txt
agrep -0 -c 'CCGGACACGTAGCAAAG' *.fastq > count/B7780_Fm0.txt
agrep -0 -c 'TGCGTCGGGTACACACT' *.fastq > count/B7781_Fm0.txt
agrep -0 -c 'TAACAGTGCACGAAGCG' *.fastq > count/B7784_Fm0.txt
agrep -0 -c 'AAGTGGATTGCACATGG' *.fastq > count/B7785_Fm0.txt
agrep -0 -c 'TCTTGCTAAGGTACCGT' *.fastq > count/B7786_Fm0.txt
agrep -0 -c 'GGATACACCGGCAATTA' *.fastq > count/B7787_Fm0.txt
agrep -0 -c 'TTATCCTCTCGACTACT' *.fastq > count/B7788_Fm0.txt
agrep -0 -c 'CGACCTAAGAGCGGTCT' *.fastq > count/B7789_Fm0.txt
agrep -0 -c 'TATTAGATTCTCCGGTG' *.fastq > count/B7790_Fm0.txt
agrep -0 -c 'CGGCTGAAAATTACACG' *.fastq > count/B7791_Fm0.txt
agrep -0 -c 'GACACGCTCACGTGAAC' *.fastq > count/B7792_Fm0.txt
agrep -0 -c 'GCGCTACTGATTTTTGA' *.fastq > count/B7794_Fm0.txt
agrep -0 -c 'AAGGTTCTCCATCGAAG' *.fastq > count/B7796_Fm0.txt
agrep -0 -c 'AAGGTTCTCCCGACCTA' *.fastq > count/B7797_Fm0.txt
agrep -0 -c 'CATGATTGGTGGGGTAT' *.fastq > count/B7799_Fm0.txt
agrep -0 -c 'GCAAAATGTTTTCTGCC' *.fastq > count/B7800_Fm0.txt
agrep -0 -c 'CCGTAATGACGTCAGAC' *.fastq > count/B7801_Fm0.txt
agrep -0 -c 'GGAACAACCGCCATTCT' *.fastq > count/B7802_Fm0.txt
agrep -0 -c 'GCGATTACGTGACTAGG' *.fastq > count/B7803_Fm0.txt
agrep -0 -c 'GTATTAGTGGAGATTCG' *.fastq > count/B7804_Fm0.txt
agrep -0 -c 'TCGGTTGATGGTCGATT' *.fastq > count/B7805_Fm0.txt
agrep -0 -c 'TCTTGTGGCACAAGCAG' *.fastq > count/B7806_Fm0.txt
agrep -0 -c 'TGTGGTGCTCGTTAGAG' *.fastq > count/B7807_Fm0.txt
agrep -0 -c 'TAACCCACCTCGACCTT' *.fastq > count/B7808_Fm0.txt
agrep -0 -c 'CCTCATCGGGTCACTAC' *.fastq > count/B7809_Fm0.txt
agrep -0 -c 'TGGCCCGTCCATTCGTA' *.fastq > count/B7810_Fm0.txt
agrep -0 -c 'GGGTTACTGGGATTATC' *.fastq > count/B7811_Fm0.txt
agrep -0 -c 'AGGCGCAAGAGTTGTTC' *.fastq > count/B7812_Fm0.txt
agrep -0 -c 'TGATAGCGTAAGGCGTA' *.fastq > count/B7813_Fm0.txt
agrep -0 -c 'GGCAAAAATTGCTGAGC' *.fastq > count/B7814_Fm0.txt
agrep -0 -c 'GGAGAGGCTCAGCATTG' *.fastq > count/B7815_Fm0.txt
agrep -0 -c 'TTAGAAGGTGACTAACG' *.fastq > count/B7816_Fm0.txt
agrep -0 -c 'TGTGAAGTCGCCCGCAA' *.fastq > count/B7817_Fm0.txt
agrep -0 -c 'ACAGTTCTATGCTAACG' *.fastq > count/B7818_Fm0.txt
agrep -0 -c 'GGGTTTGGAGAATTGAT' *.fastq > count/B7819_Fm0.txt
agrep -0 -c 'TCATCGCGCTCTACGCT' *.fastq > count/B7820_Fm0.txt
agrep -0 -c 'CGCGTTACGTGGAGTCT' *.fastq > count/B7821_Fm0.txt
agrep -0 -c 'TAATTTCGCACTTCAGG' *.fastq > count/B7822_Fm0.txt
agrep -0 -c 'GTCCTCCAGGTTCCAAT' *.fastq > count/B7823_Fm0.txt
agrep -0 -c 'GCGATTGAGCGCTCTCA' *.fastq > count/B7824_Fm0.txt
agrep -0 -c 'TCATCCAAGCTTTAGGG' *.fastq > count/B7825_Fm0.txt
agrep -0 -c 'CCAGGAGAGCTTATTTC' *.fastq > count/B7826_Fm0.txt
agrep -0 -c 'GATGTTAAGCAACAAGG' *.fastq > count/B7827_Fm0.txt
agrep -0 -c 'CTTCACTATCTCCGCAA' *.fastq > count/B7828_Fm0.txt
agrep -0 -c 'AGATACAAGCTTTGCCG' *.fastq > count/B7829_Fm0.txt
agrep -0 -c 'CAGGCACGGTAACCATT' *.fastq > count/B7830_Fm0.txt
agrep -0 -c 'CCGATGTGGAGGGTCTA' *.fastq > count/B7831_Fm0.txt
agrep -0 -c 'GCGTATCAAGACAATCC' *.fastq > count/B7832_Fm0.txt
agrep -0 -c 'TTGTGAGGGCCTTGTCA' *.fastq > count/B7834_Fm0.txt
agrep -0 -c 'ACATCAGCCACGACACA' *.fastq > count/B7835_Fm0.txt
agrep -0 -c 'AGTTAGTTCCTCCCCTG' *.fastq > count/B7836_Fm0.txt
agrep -0 -c 'GGCTCCAATTCAGGCTC' *.fastq > count/B7837_Fm0.txt
agrep -0 -c 'GTGGCACGTCCATAGAG' *.fastq > count/B7838_Fm0.txt
agrep -0 -c 'AGGGGACTGGGACACTA' *.fastq > count/B7839_Fm0.txt
agrep -0 -c 'ATTCCTTTGTCCCGGGG' *.fastq > count/B7840_Fm0.txt
agrep -0 -c 'TCATTGAATCACACTCC' *.fastq > count/B7841_Fm0.txt
agrep -0 -c 'GGGCATAATGATCATCG' *.fastq > count/B7843_Fm0.txt
agrep -0 -c 'CTCGAGAGACACCAGTT' *.fastq > count/B7844_Fm0.txt
agrep -0 -c 'TGTGATGGAGCGATCCT' *.fastq > count/B7845_Fm0.txt
agrep -0 -c 'GGAGCTCAAGAAGGGGA' *.fastq > count/B7846_Fm0.txt
agrep -0 -c 'CGCTTACAAGAAGCTTT' *.fastq > count/B7847_Fm0.txt
agrep -0 -c 'AAGTGGCCAGCTAGTTT' *.fastq > count/B7850_Fm0.txt
agrep -0 -c 'GACCCCTACCAGAGCAT' *.fastq > count/B7851_Fm0.txt
agrep -0 -c 'CTAGTAGGACTGTAAAC' *.fastq > count/B7852_Fm0.txt
agrep -0 -c 'TTCCGTCCCACTAATTA' *.fastq > count/B7853_Fm0.txt
agrep -0 -c 'GCATCCGATAATGCTAA' *.fastq > count/B7854_Fm0.txt
agrep -0 -c 'ACGGGACCAGGAATAAA' *.fastq > count/B7855_Fm0.txt
agrep -0 -c 'AGTTTTGGTGATACCCG' *.fastq > count/B7858_Fm0.txt
agrep -0 -c 'ACATCGCACGAGTACAG' *.fastq > count/B7859_Fm0.txt
agrep -0 -c 'AGCAGCGAAAATTACGC' *.fastq > count/B7860_Fm0.txt
agrep -0 -c 'TCGGTGTGACATGTGAC' *.fastq > count/B7861_Fm0.txt
agrep -0 -c 'CTAGAAACTTTCTCTCG' *.fastq > count/B7862_Fm0.txt
agrep -0 -c 'AATGCGCTCGTAAAGTC' *.fastq > count/B7863_Fm0.txt
agrep -0 -c 'GGATAGTTGGTCATCTC' *.fastq > count/B7864_Fm0.txt
agrep -0 -c 'GTATGGTCTCAGGGATC' *.fastq > count/B7865_Fm0.txt
agrep -0 -c 'CAATTCCTGTCTCCACG' *.fastq > count/B7866_Fm0.txt
agrep -0 -c 'CAAACTTACGACCTTAC' *.fastq > count/B7867_Fm0.txt
agrep -0 -c 'TGTCATTGGCGAAGCCC' *.fastq > count/B7868_Fm0.txt
agrep -0 -c 'ACGAATGATGGACGACG' *.fastq > count/B7869_Fm0.txt
agrep -0 -c 'ACAGGCGAGACAGCAAT' *.fastq > count/B7870_Fm0.txt
agrep -0 -c 'CCAGGCTTGTAAGTGGC' *.fastq > count/B7871_Fm0.txt
agrep -0 -c 'AAGCGAATCGGGATGAC' *.fastq > count/B7872_Fm0.txt
agrep -0 -c 'ATGTGGTAGGAGGTCTT' *.fastq > count/B7873_Fm0.txt
agrep -0 -c 'TGAAGAGTTAGGCTTTG' *.fastq > count/B7875_Fm0.txt
agrep -0 -c 'TATACGCTTGAGTAGTC' *.fastq > count/B7876_Fm0.txt
agrep -0 -c 'ACTTCGTCCGGCTGTTA' *.fastq > count/B7877_Fm0.txt
agrep -0 -c 'CAATCGAAACCACTGCT' *.fastq > count/B7878_Fm0.txt
agrep -0 -c 'AATTGGGTTCTCTGGTC' *.fastq > count/B7879_Fm0.txt
agrep -0 -c 'CGCGGAACTACCAGTCA' *.fastq > count/B7880_Fm0.txt
agrep -0 -c 'GACGAAGGGCAAGTGTC' *.fastq > count/B7882_Fm0.txt
agrep -0 -c 'GGGCGTCAAGATCTATA' *.fastq > count/B7883_Fm0.txt
agrep -0 -c 'TATGTTCCGGGAGGTTG' *.fastq > count/B7884_Fm0.txt
agrep -0 -c 'GACTTGATTCATGGCGT' *.fastq > count/B7885_Fm0.txt
agrep -0 -c 'ACTTGATTCCGTCAGAC' *.fastq > count/B7887_Fm0.txt
agrep -0 -c 'CTCTTCCCAAGATGTGG' *.fastq > count/B7888_Fm0.txt
agrep -0 -c 'GTGCCTACTCTGCGTTT' *.fastq > count/B7889_Fm0.txt
agrep -0 -c 'ACCCAAGAAGGCAACGC' *.fastq > count/B7891_Fm0.txt
agrep -0 -c 'CAGGCTGCGGTTAACTA' *.fastq > count/B7893_Fm0.txt
agrep -0 -c 'AACCAAAGCTGAACGGC' *.fastq > count/B7894_Fm0.txt
agrep -0 -c 'GGGTCATATCCTGCGGT' *.fastq > count/B7895_Fm0.txt
agrep -0 -c 'ATACATACATGGAGCCT' *.fastq > count/B7896_Fm0.txt
agrep -0 -c 'CCGAATTTCCTAACTCC' *.fastq > count/B7897_Fm0.txt
agrep -0 -c 'TACGACCTCTAATCTAC' *.fastq > count/B7898_Fm0.txt
agrep -0 -c 'TGCACTTAAGATACGCA' *.fastq > count/B7899_Fm0.txt
agrep -0 -c 'TTAAACGGCCTTCCTGA' *.fastq > count/B7900_Fm0.txt
agrep -0 -c 'GAGCAGACCCATTGAGG' *.fastq > count/B7902_Fm0.txt
agrep -0 -c 'GCACTAGTGTATACGAT' *.fastq > count/B7903_Fm0.txt
agrep -0 -c 'TACTAAGGATCTTGGAG' *.fastq > count/B7904_Fm0.txt
agrep -0 -c 'TCGTCCGATCATCAAAA' *.fastq > count/B7905_Fm0.txt
agrep -0 -c 'ATAACATGTCGAGCAGA' *.fastq > count/B7907_Fm0.txt
agrep -0 -c 'GTACCTCTGTTGGCATC' *.fastq > count/B7911_Fm0.txt
agrep -0 -c 'GATGAAACCTAAGCTCC' *.fastq > count/B7912_Fm0.txt
agrep -0 -c 'TTGCGCACGGTTCGCAT' *.fastq > count/B7913_Fm0.txt
agrep -0 -c 'GCCAGACAACCGGCAAT' *.fastq > count/B7914_Fm0.txt
agrep -0 -c 'CGTATAGGGGCACTACG' *.fastq > count/B7915_Fm0.txt
agrep -0 -c 'GCTGCGTCTAGTTTTAG' *.fastq > count/B7916_Fm0.txt
agrep -0 -c 'TGGCAGATACCAAATCG' *.fastq > count/B7918_Fm0.txt
agrep -0 -c 'TGTACGTGACCGCGAAA' *.fastq > count/B7920_Fm0.txt
agrep -0 -c 'TGGACTGCATACGGCAC' *.fastq > count/B7921_Fm0.txt
agrep -0 -c 'CGTGATAGCGCTGTTTC' *.fastq > count/B7924_Fm0.txt
agrep -0 -c 'TAGAAGCTCAGCACGTT' *.fastq > count/B7925_Fm0.txt
agrep -0 -c 'ATTACGGTATAGTCTGG' *.fastq > count/B7926_Fm0.txt
agrep -0 -c 'GGGACAGGTGTACTGAT' *.fastq > count/B7928_Fm0.txt
agrep -0 -c 'AGCCGTAACTGCCGTCT' *.fastq > count/B7929_Fm0.txt
agrep -0 -c 'TAGACCTGAGTGCTGGC' *.fastq > count/B7930_Fm0.txt
agrep -0 -c 'ATACCTGAACCTACCCG' *.fastq > count/B7932_Fm0.txt
agrep -0 -c 'CTGGCTTGCGATTCCCT' *.fastq > count/B7934_Fm0.txt
agrep -0 -c 'CATTCTTAATCACCGCC' *.fastq > count/B7935_Fm0.txt
agrep -0 -c 'GGATCGGCTAAGCACAG' *.fastq > count/B7936_Fm0.txt
agrep -0 -c 'ACATCAATCTTGGTTGG' *.fastq > count/B7937_Fm0.txt
agrep -0 -c 'TTAGTGATCGCTGGACT' *.fastq > count/B7938_Fm0.txt
agrep -0 -c 'ATTAGCGCAATTCCCGT' *.fastq > count/B7939_Fm0.txt
agrep -0 -c 'CACCAGTCACTCGGGTA' *.fastq > count/B7940_Fm0.txt
agrep -0 -c 'CGACTCAATGTACCAAG' *.fastq > count/B7941_Fm0.txt
agrep -0 -c 'GGTTACGGTAAATTGGC' *.fastq > count/B7942_Fm0.txt
agrep -0 -c 'GTCCCCAGATGTATCCC' *.fastq > count/B7943_Fm0.txt
agrep -0 -c 'AACCCCCCATGATGCAG' *.fastq > count/B7944_Fm0.txt
agrep -0 -c 'ATACCAACGACATAACC' *.fastq > count/B7945_Fm0.txt
agrep -0 -c 'AGGCCGGTACGATAGAT' *.fastq > count/B7946_Fm0.txt
agrep -0 -c 'ACGCTCTCCACGAATGT' *.fastq > count/B7947_Fm0.txt
agrep -0 -c 'AGAGGTTATTGTACACG' *.fastq > count/B7948_Fm0.txt
agrep -0 -c 'CATCGACAGATTTGACA' *.fastq > count/B7950_Fm0.txt
agrep -0 -c 'TGTGCGAGTGATAGACA' *.fastq > count/B7951_Fm0.txt
agrep -0 -c 'GGAAGGTAGATCACGCA' *.fastq > count/B7952_Fm0.txt
agrep -0 -c 'TGAGGTGGTGAAGTACC' *.fastq > count/B7953_Fm0.txt
agrep -0 -c 'GTATGTAGACGGCGCTT' *.fastq > count/B7955_Fm0.txt
agrep -0 -c 'TACGGGGATAGCCTACA' *.fastq > count/B7956_Fm0.txt
agrep -0 -c 'ACTGTAACGCCCGAATG' *.fastq > count/B7957_Fm0.txt
agrep -0 -c 'GATAGTGAAATCGGTGC' *.fastq > count/B7958_Fm0.txt
agrep -0 -c 'ATGCTGACCCGAAACCT' *.fastq > count/B7959_Fm0.txt
agrep -0 -c 'CCGTGAGATTTTACGGC' *.fastq > count/B7960_Fm0.txt
agrep -0 -c 'GGCTGACGCTTAAGGTT' *.fastq > count/B7961_Fm0.txt
agrep -0 -c 'GTTAAAGGGGTGCTACG' *.fastq > count/B7967_Fm0.txt
agrep -0 -c 'CATCTTATCAGCGGTAT' *.fastq > count/B7968_Fm0.txt
agrep -0 -c 'TCATGTGCGATGTTCTG' *.fastq > count/B7969_Fm0.txt
agrep -0 -c 'CAACTTGCCATTTAGAG' *.fastq > count/B7970_Fm0.txt
agrep -0 -c 'AGCGCTTGTTAGCTTGA' *.fastq > count/B7971_Fm0.txt
agrep -0 -c 'GATTTGAACTACATCCC' *.fastq > count/B7972_Fm0.txt
agrep -0 -c 'TACATGTGACAAGGTGT' *.fastq > count/B7973_Fm0.txt
agrep -0 -c 'TCTGAGGTAACGTAGGA' *.fastq > count/B7974_Fm0.txt
agrep -0 -c 'GATTGCCCTGGTAGTCA' *.fastq > count/B7975_Fm0.txt
agrep -0 -c 'TAGCAGTAAAGATACCG' *.fastq > count/B7976_Fm0.txt
agrep -0 -c 'GTATAGTTGCCTAGCGG' *.fastq > count/B7977_Fm0.txt
agrep -0 -c 'GTCTAACCCGCACCTTG' *.fastq > count/B7978_Fm0.txt
agrep -0 -c 'CTTCGTTGCCACGACAG' *.fastq > count/B7979_Fm0.txt
agrep -0 -c 'ATCTAGGGTACCTACAA' *.fastq > count/B7980_Fm0.txt
agrep -0 -c 'CTGCCATAACAGTCATA' *.fastq > count/B7981_Fm0.txt
agrep -0 -c 'GCGTTACTGTAACCGCT' *.fastq > count/B7982_Fm0.txt
agrep -0 -c 'ACCTGTCCCGTAAAGTC' *.fastq > count/B7983_Fm0.txt
agrep -0 -c 'TCTCTGAATCTTCGAAC' *.fastq > count/B7984_Fm0.txt
agrep -0 -c 'CTGCTATATTCAAGCCA' *.fastq > count/B7985_Fm0.txt
agrep -0 -c 'TGCTCCTACCGATACTA' *.fastq > count/B7986_Fm0.txt
agrep -0 -c 'CGGACACCGGAGTCTAA' *.fastq > count/B7987_Fm0.txt
agrep -0 -c 'ACGAGTATTTCAAGAGG' *.fastq > count/B7989_Fm0.txt
agrep -0 -c 'CTTATAGGTCTTTCGGG' *.fastq > count/B7990_Fm0.txt
agrep -0 -c 'CAAGAAGCGCTTGCGCT' *.fastq > count/B7991_Fm0.txt
agrep -0 -c 'CTGGTAGTGGGTAACTA' *.fastq > count/B7992_Fm0.txt
agrep -0 -c 'AGATAATACTCGAGCCA' *.fastq > count/B7993_Fm0.txt
agrep -0 -c 'GATGATTATCGATTGCG' *.fastq > count/B7994_Fm0.txt
agrep -0 -c 'GCGGTTTCCCTACTTGG' *.fastq > count/B7995_Fm0.txt
agrep -0 -c 'GCGTTGTGCGCGTAGTA' *.fastq > count/B7997_Fm0.txt
agrep -0 -c 'CGTACCGTGGTACTTTA' *.fastq > count/B7998_Fm0.txt
agrep -0 -c 'CGACCACGCTAAAGGAC' *.fastq > count/B7999_Fm0.txt
agrep -0 -c 'ACTTGGCGCATCTCCTT' *.fastq > count/B8000_Fm0.txt
agrep -0 -c 'CAAAACCTCGATGACGC' *.fastq > count/B8001_Fm0.txt
agrep -0 -c 'TAGCGAACCCTGAGAAA' *.fastq > count/B8002_Fm0.txt
agrep -0 -c 'CTGGAACGTAGTACTGA' *.fastq > count/B8003_Fm0.txt
agrep -0 -c 'AACTCCCGATAGATCAT' *.fastq > count/B8004_Fm0.txt
agrep -0 -c 'TCGATGTGATTCCCAAT' *.fastq > count/B8005_Fm0.txt
agrep -0 -c 'TGTTTCAGCGTGTTGAG' *.fastq > count/B8006_Fm0.txt
agrep -0 -c 'ATTTGGTACCCGTGTCG' *.fastq > count/B8007_Fm0.txt
agrep -0 -c 'CTAGTGAACAGCAGACT' *.fastq > count/B8008_Fm0.txt
agrep -0 -c 'AACTTTGACCGGAAAAG' *.fastq > count/B8009_Fm0.txt
agrep -0 -c 'TGCGTTCACCTCTCCTT' *.fastq > count/B8010_Fm0.txt
agrep -0 -c 'ATGATTGAGTTCTCACC' *.fastq > count/B8011_Fm0.txt
agrep -0 -c 'TGAGTACTGCGATCTGA' *.fastq > count/B8012_Fm0.txt
agrep -0 -c 'GGGGTGCGGCATTAACA' *.fastq > count/B8013_Fm0.txt
agrep -0 -c 'CGATATGGGCAAACGGT' *.fastq > count/B8014_Fm0.txt
agrep -0 -c 'GTAACGGACCTGGTATC' *.fastq > count/B8015_Fm0.txt
agrep -0 -c 'CGTTAGACTTTCGCTGT' *.fastq > count/B8016_Fm0.txt
agrep -0 -c 'AGACCCGTGTTAGCCAG' *.fastq > count/B8017_Fm0.txt
agrep -0 -c 'CATGCAGGTACTAAGCT' *.fastq > count/B8018_Fm0.txt
agrep -0 -c 'TATCAGACTAACCAGCT' *.fastq > count/B8019_Fm0.txt
agrep -0 -c 'CTAGGAGTCAAGAGACG' *.fastq > count/B8020_Fm0.txt
agrep -0 -c 'TAATGCTCGGATAGTGG' *.fastq > count/B8023_Fm0.txt
agrep -0 -c 'GCGAACTAACAGCTCGG' *.fastq > count/B8025_Fm0.txt
agrep -0 -c 'ACATTTCCGCGGTAGGC' *.fastq > count/B8026_Fm0.txt
agrep -0 -c 'CAAGCGAGACTGGAATG' *.fastq > count/B8027_Fm0.txt
agrep -0 -c 'GTATACGAAGACAGTAC' *.fastq > count/B8028_Fm0.txt
agrep -0 -c 'TACCTAGAGGCAGACCG' *.fastq > count/B8030_Fm0.txt
agrep -0 -c 'AGAGTATGCAGAAGTCC' *.fastq > count/B8031_Fm0.txt
agrep -0 -c 'TGATCCGAACGAACAGC' *.fastq > count/B8032_Fm0.txt
agrep -0 -c 'AGTTACGGGTCCGCGAT' *.fastq > count/B8033_Fm0.txt
agrep -0 -c 'GACGGGGTAGGAACGTT' *.fastq > count/B8034_Fm0.txt
agrep -0 -c 'CTTCAGAAGATGGCGTT' *.fastq > count/B8035_Fm0.txt
agrep -0 -c 'CTCGGTCTCAAACACCA' *.fastq > count/B8036_Fm0.txt
agrep -0 -c 'GCCCTTTTACTTACTAC' *.fastq > count/B8037_Fm0.txt
agrep -0 -c 'CGCATCGAATTCAGTAA' *.fastq > count/B8038_Fm0.txt
agrep -0 -c 'GGACAATGAGTGCGGTA' *.fastq > count/B8039_Fm0.txt
agrep -0 -c 'CGTCGCCAAATAGTAGT' *.fastq > count/B8040_Fm0.txt
agrep -0 -c 'ACATAGCCTGCAAGCTC' *.fastq > count/B8041_Fm0.txt
agrep -0 -c 'GGCGGGATTCTACGTAT' *.fastq > count/B8045_Fm0.txt
agrep -0 -c 'GTTGAGCGAGCACGATA' *.fastq > count/B8046_Fm0.txt
agrep -0 -c 'CAATTCGTGATGCCACC' *.fastq > count/B8048_Fm0.txt
agrep -0 -c 'ACTGTTACGTCGAGACC' *.fastq > count/B8049_Fm0.txt
agrep -0 -c 'AATTTCGCCAGAGCACC' *.fastq > count/B8050_Fm0.txt
agrep -0 -c 'AACGACCTGTTGGAAGA' *.fastq > count/B8051_Fm0.txt
agrep -0 -c 'AAGCTAGTACGAGCCTT' *.fastq > count/B8053_Fm0.txt
agrep -0 -c 'AGGGGATATAGTGAGGT' *.fastq > count/B8055_Fm0.txt
agrep -0 -c 'TGTTGTGCCGGCTCAGA' *.fastq > count/B8056_Fm0.txt
agrep -0 -c 'GTCGAGAAGAAACCAGG' *.fastq > count/B8057_Fm0.txt
agrep -0 -c 'CTAAGGTCATAAGGAAC' *.fastq > count/B8058_Fm0.txt
agrep -0 -c 'CATACAACGCAGGATGG' *.fastq > count/B8059_Fm0.txt
agrep -0 -c 'TTGAACCAACTGTGGAC' *.fastq > count/B8060_Fm0.txt
agrep -0 -c 'CGTCGGCAAGAGCTACA' *.fastq > count/B8061_Fm0.txt
agrep -0 -c 'CTGCTATGCCTAGACAA' *.fastq > count/B8062_Fm0.txt
agrep -0 -c 'TGTATGTGACACCTCGG' *.fastq > count/B8065_Fm0.txt
agrep -0 -c 'GACTAGTAGACATCTTC' *.fastq > count/B8066_Fm0.txt
agrep -0 -c 'CGCGTGTGAAAATCACT' *.fastq > count/B8067_Fm0.txt
agrep -0 -c 'GATACTCCTAGTGTCAG' *.fastq > count/B8068_Fm0.txt
agrep -0 -c 'GGTCACTACCTTGCAAA' *.fastq > count/B8069_Fm0.txt
agrep -0 -c 'GGTGGCGCTCTATCTAA' *.fastq > count/B8070_Fm0.txt
agrep -0 -c 'ATTAGGTCTAGCAGCCA' *.fastq > count/B8072_Fm0.txt
agrep -0 -c 'GGCGACTGTAATCCCAG' *.fastq > count/B8073_Fm0.txt
agrep -0 -c 'TGTCGTACTCGGTCTCC' *.fastq > count/B8074_Fm0.txt
agrep -0 -c 'CGGACCTAATCCCATGC' *.fastq > count/B8075_Fm0.txt
agrep -0 -c 'GTGTTGGCCTCATTTCC' *.fastq > count/B8076_Fm0.txt
agrep -0 -c 'GGCCTGCTCATCTTAAA' *.fastq > count/B8077_Fm0.txt
agrep -0 -c 'GGTTAGAGTCCATATGC' *.fastq > count/B8078_Fm0.txt
agrep -0 -c 'GTCAAACTAAGCGTACA' *.fastq > count/B8079_Fm0.txt
agrep -0 -c 'GCCGCTTTAGAAGCTAC' *.fastq > count/B8080_Fm0.txt
agrep -0 -c 'TCTAGGCGCAATAACGT' *.fastq > count/B8082_Fm0.txt
agrep -0 -c 'GCCCTAGTTCGTTACGG' *.fastq > count/B8083_Fm0.txt
agrep -0 -c 'TGCAGACGGCGTTATGA' *.fastq > count/B8084_Fm0.txt
agrep -0 -c 'CATAAGATGCAGGCCGT' *.fastq > count/B8085_Fm0.txt
agrep -0 -c 'GGCATATAAAAGCCTGC' *.fastq > count/B8087_Fm0.txt
agrep -0 -c 'AATGCTGCAGACCCTTA' *.fastq > count/B8088_Fm0.txt
agrep -0 -c 'ACTTCGCGAAGTCCTGT' *.fastq > count/B8089_Fm0.txt
agrep -0 -c 'TGCTCCATTTAGGGGAT' *.fastq > count/B8090_Fm0.txt
agrep -0 -c 'GTCATGACCGCAAACAG' *.fastq > count/B8091_Fm0.txt
agrep -0 -c 'CTCACGACGTTAGATTT' *.fastq > count/B8092_Fm0.txt
agrep -0 -c 'ACCTAGATCAAGTCAGT' *.fastq > count/B8093_Fm0.txt
agrep -0 -c 'GCGGTAGGTATGGTATC' *.fastq > count/B8094_Fm0.txt
agrep -0 -c 'CACCCTACTTGGCCACT' *.fastq > count/B8095_Fm0.txt
agrep -0 -c 'GCTATTCAGATCCTGGC' *.fastq > count/B8096_Fm0.txt
agrep -0 -c 'CCGACAGACCTCAACAC' *.fastq > count/B8098_Fm0.txt
agrep -0 -c 'TCGCGATCTAATCGACA' *.fastq > count/B8099_Fm0.txt
agrep -0 -c 'ATCTACTTAGTCTGCCC' *.fastq > count/B8100_Fm0.txt
agrep -0 -c 'ATCCCCCATTAGTCTGC' *.fastq > count/B8101_Fm0.txt
agrep -0 -c 'TCTTGTGCCGTATCCAA' *.fastq > count/B8103_Fm0.txt
agrep -0 -c 'CAAGGATAATCCAGGTT' *.fastq > count/B8104_Fm0.txt
agrep -0 -c 'GCCACGTACAATTTTAG' *.fastq > count/B8105_Fm0.txt
agrep -0 -c 'GCTGAGAACCGTAAGGG' *.fastq > count/B8107_Fm0.txt
agrep -0 -c 'GTTCGAGGAAGCTGTAG' *.fastq > count/B8108_Fm0.txt
agrep -0 -c 'TAGAGCTTGTGCTATCG' *.fastq > count/B8109_Fm0.txt
agrep -0 -c 'CTGCTTGCCTTATTCGT' *.fastq > count/B8110_Fm0.txt
agrep -0 -c 'GATAGCACGTAAATCAG' *.fastq > count/B8112_Fm0.txt
agrep -0 -c 'GTTGAGAGCTTGTAGTG' *.fastq > count/B8113_Fm0.txt
agrep -0 -c 'CGATTTATATCCTCCGG' *.fastq > count/B8114_Fm0.txt
agrep -0 -c 'GTTCGTCAAACGCTGTC' *.fastq > count/B8115_Fm0.txt
agrep -0 -c 'CCGTTCGCACCTGATGA' *.fastq > count/B8116_Fm0.txt
agrep -0 -c 'ACCCTACGTACTAACGA' *.fastq > count/B8117_Fm0.txt
agrep -0 -c 'TGCTGCGTACTAACCAC' *.fastq > count/B8118_Fm0.txt
agrep -0 -c 'ATCTCGCTAACGCACGT' *.fastq > count/B8120_Fm0.txt
agrep -0 -c 'AACTACTTCCGCACTTA' *.fastq > count/B8121_Fm0.txt
agrep -0 -c 'GTTGGGAGTTCCTTCGC' *.fastq > count/B8122_Fm0.txt
agrep -0 -c 'CAAAATGCCTGCGTCTA' *.fastq > count/B8123_Fm0.txt
agrep -0 -c 'GACTAGTAGTCTACGGA' *.fastq > count/B8124_Fm0.txt
agrep -0 -c 'CGTTTTCTCGATCATTG' *.fastq > count/B8126_Fm0.txt
agrep -0 -c 'GCGGTGTTTCGCGAAGT' *.fastq > count/B8127_Fm0.txt
agrep -0 -c 'ATATTAGGGGGTCAGAA' *.fastq > count/B8128_Fm0.txt
agrep -0 -c 'GGAGCTCGAATCTTATA' *.fastq > count/B8129_Fm0.txt
agrep -0 -c 'TGTGCGAACACTCGACG' *.fastq > count/B8130_Fm0.txt
agrep -0 -c 'CGCTATCGATGAGATCG' *.fastq > count/B8131_Fm0.txt
agrep -0 -c 'GTTGGCAGCCCCTTAGA' *.fastq > count/B8133_Fm0.txt
agrep -0 -c 'TTCGCACACGGAGGATG' *.fastq > count/B8134_Fm0.txt
agrep -0 -c 'GTGTACGCTTTCAGCAG' *.fastq > count/B8135_Fm0.txt
agrep -0 -c 'CTTCTTCATCGGGATCA' *.fastq > count/B8137_Fm0.txt
agrep -0 -c 'GATTATCACTAAAGCCG' *.fastq > count/B8138_Fm0.txt
agrep -0 -c 'ATTAGTTCACACTGGAC' *.fastq > count/B8139_Fm0.txt
agrep -0 -c 'CCTCAACCCTATCGGTA' *.fastq > count/B8140_Fm0.txt
agrep -0 -c 'AGACCACGCTCCTGAGA' *.fastq > count/B8141_Fm0.txt
agrep -0 -c 'TTACTCGTATACTCGGC' *.fastq > count/B8142_Fm0.txt
agrep -0 -c 'GTATACTTGACTCGTAC' *.fastq > count/B8144_Fm0.txt
agrep -0 -c 'CAAGGCAGCATTAAAGG' *.fastq > count/B8145_Fm0.txt
agrep -0 -c 'TTGACCGTCCTTCTGCA' *.fastq > count/B8146_Fm0.txt
agrep -0 -c 'TGCGGTCCGCATCTTCA' *.fastq > count/B8147_Fm0.txt
agrep -0 -c 'CCAGATCAAAAGCAATC' *.fastq > count/B8148_Fm0.txt
agrep -0 -c 'CAGAAACCCGACAACAA' *.fastq > count/B8149_Fm0.txt
agrep -0 -c 'CGTAGGAATTAACTCAG' *.fastq > count/B8151_Fm0.txt
agrep -0 -c 'CTATTATGCCAGGCGCG' *.fastq > count/B8152_Fm0.txt
agrep -0 -c 'CTGTGGATCAGCTAAGT' *.fastq > count/B8154_Fm0.txt
agrep -0 -c 'GCAATCGAAATTCTAGC' *.fastq > count/B8155_Fm0.txt
agrep -0 -c 'ACCATTATGGCTCGTGA' *.fastq > count/B8156_Fm0.txt
agrep -0 -c 'ACGACGCTGGAACGTTG' *.fastq > count/B8157_Fm0.txt
agrep -0 -c 'CGGAGCAGACTAATACC' *.fastq > count/B8159_Fm0.txt
agrep -0 -c 'ACGTTTAATGGCTGCTA' *.fastq > count/B8160_Fm0.txt
agrep -0 -c 'GGTGTGCGCACTTCTGA' *.fastq > count/B8161_Fm0.txt
agrep -0 -c 'AACTCCCCTCGAACACC' *.fastq > count/B8162_Fm0.txt
agrep -0 -c 'GTGTTTAACTCTTGGAC' *.fastq > count/B8163_Fm0.txt
agrep -0 -c 'AGACGAAACTGATTACC' *.fastq > count/B8164_Fm0.txt
agrep -0 -c 'GCTCATAGACAAAGCGC' *.fastq > count/B8165_Fm0.txt
agrep -0 -c 'ATTTCAGGTTGTGCTGG' *.fastq > count/B8167_Fm0.txt
agrep -0 -c 'TAATGCGCGAGCAACCC' *.fastq > count/B8168_Fm0.txt
agrep -0 -c 'TTCGAACCGTATTCTCA' *.fastq > count/B8169_Fm0.txt
agrep -0 -c 'AAGGTACTAGGGATGGT' *.fastq > count/B8170_Fm0.txt
agrep -0 -c 'ACCGCGTGCACTAATGG' *.fastq > count/B8171_Fm0.txt
agrep -0 -c 'AGACGCCCGCGTATTAA' *.fastq > count/B8172_Fm0.txt
agrep -0 -c 'TCACGCACAAAAGACTT' *.fastq > count/B8173_Fm0.txt
agrep -0 -c 'GTAAGATGGAACGGATG' *.fastq > count/B8177_Fm0.txt
agrep -0 -c 'TCGATAGACTCAACCCG' *.fastq > count/B8178_Fm0.txt
agrep -0 -c 'TAATCGGTTGACGTCCG' *.fastq > count/B8180_Fm0.txt
agrep -0 -c 'GATCTAGTTGGCGAACT' *.fastq > count/B8181_Fm0.txt
agrep -0 -c 'CCGTACACTATCACCGA' *.fastq > count/B8182_Fm0.txt
agrep -0 -c 'GATGTTTGAAACGAGAG' *.fastq > count/B8183_Fm0.txt
agrep -0 -c 'CGAACACGCATGTGCTA' *.fastq > count/B8184_Fm0.txt
agrep -0 -c 'CGACCTTCGTTTTCCAT' *.fastq > count/B8185_Fm0.txt
agrep -0 -c 'GGATAATGCTCAATCTC' *.fastq > count/B8186_Fm0.txt
agrep -0 -c 'TTAGGTTCCGCCCCAAA' *.fastq > count/B8187_Fm0.txt
agrep -0 -c 'TGCCAAGTCGATTTCCA' *.fastq > count/B8188_Fm0.txt
agrep -0 -c 'GGCTCCCAATCGTTTAA' *.fastq > count/B8189_Fm0.txt
agrep -0 -c 'TGTACTCGCCCCATATG' *.fastq > count/B8190_Fm0.txt
agrep -0 -c 'GAGCGTTCGCTTTCTTC' *.fastq > count/B8191_Fm0.txt
agrep -0 -c 'TTGCGCCCAATACAAGC' *.fastq > count/B8192_Fm0.txt
agrep -0 -c 'GCTAGATTCCAGAGCTA' *.fastq > count/B8193_Fm0.txt
agrep -0 -c 'GCTAGAATAGCGCGAAG' *.fastq > count/B8194_Fm0.txt
agrep -0 -c 'TTCAATCCAGCGTATTG' *.fastq > count/B8195_Fm0.txt
agrep -0 -c 'AAGGGTTTGACTTCGGC' *.fastq > count/B8196_Fm0.txt
agrep -0 -c 'GACAAGAGCGGCTATCT' *.fastq > count/B8197_Fm0.txt
agrep -0 -c 'CCGTCAGGCATCTAGGA' *.fastq > count/B8198_Fm0.txt
agrep -0 -c 'AAGATGTGATAGGGGTA' *.fastq > count/B8199_Fm0.txt
agrep -0 -c 'TCTTGCGTGTTGAGATT' *.fastq > count/B8200_Fm0.txt
agrep -0 -c 'AATGCCCTACGGACTTC' *.fastq > count/B8201_Fm0.txt
agrep -0 -c 'AACATGTAGCACCGTGT' *.fastq > count/B8202_Fm0.txt
agrep -0 -c 'GCGGTGTTGTGAAGGCA' *.fastq > count/B8203_Fm0.txt
agrep -0 -c 'GTAGTGAGCTGCGTTAA' *.fastq > count/B8205_Fm0.txt
agrep -0 -c 'GGGGAGTTGGAACTCGT' *.fastq > count/B8206_Fm0.txt
agrep -0 -c 'CTTATGAGGCGCCATAA' *.fastq > count/B8208_Fm0.txt
agrep -0 -c 'TGTTACTGTATCCAAGG' *.fastq > count/B8209_Fm0.txt
agrep -0 -c 'GCCGGCCAAATGCATAT' *.fastq > count/B8210_Fm0.txt
agrep -0 -c 'AATAACATGGATTGCCG' *.fastq > count/B8212_Fm0.txt
agrep -0 -c 'CGACGACCAATGATCGG' *.fastq > count/B8213_Fm0.txt
agrep -0 -c 'TGTCGAGCGTTGTTTCA' *.fastq > count/B8214_Fm0.txt
agrep -0 -c 'CTCTGTAGACTAAGTGA' *.fastq > count/B8216_Fm0.txt
agrep -0 -c 'AGCTGGTCATGTAAGGG' *.fastq > count/B8217_Fm0.txt
agrep -0 -c 'TCGCATGGCGAGTTCCA' *.fastq > count/B8218_Fm0.txt
agrep -0 -c 'TCGCGAAGTCATGGACC' *.fastq > count/B8219_Fm0.txt
agrep -0 -c 'CAATAACGGTAGCCTAG' *.fastq > count/B8220_Fm0.txt
agrep -0 -c 'ATGTCAGCGGACTAACT' *.fastq > count/B8221_Fm0.txt
agrep -0 -c 'CTGGGGTTTTAGTGCTT' *.fastq > count/B8222_Fm0.txt
agrep -0 -c 'CCTTGATACGTGTTCAT' *.fastq > count/B8223_Fm0.txt
agrep -0 -c 'ATACACTATCCGTGTCA' *.fastq > count/B8224_Fm0.txt
agrep -0 -c 'ACGCAATACTGGCATCG' *.fastq > count/B8226_Fm0.txt
agrep -0 -c 'CAACTCGTTGCATGTCA' *.fastq > count/B8227_Fm0.txt
agrep -0 -c 'TCGGGGTTTATCTGATA' *.fastq > count/B8228_Fm0.txt
agrep -0 -c 'GACTTCCACTAGTGTTA' *.fastq > count/B8229_Fm0.txt
agrep -0 -c 'TAGATCAAACACATCCC' *.fastq > count/B8231_Fm0.txt
agrep -0 -c 'ATCCTCTCCAAGAAACC' *.fastq > count/B8233_Fm0.txt
agrep -0 -c 'GTAGTTACGGTCGGGTT' *.fastq > count/B8234_Fm0.txt
agrep -0 -c 'GTTACACGGTAGTCTCG' *.fastq > count/B8235_Fm0.txt
agrep -0 -c 'GTATCCCAACAGCCTTA' *.fastq > count/B8236_Fm0.txt
agrep -0 -c 'CAAATTACTGCTGCGTC' *.fastq > count/B8238_Fm0.txt
agrep -0 -c 'AGAGGGTACTAGTAACT' *.fastq > count/B8239_Fm0.txt
agrep -0 -c 'GGAATAGTTAGCCCTGA' *.fastq > count/B8240_Fm0.txt
agrep -0 -c 'TCTATATCGTCTTCAGC' *.fastq > count/B8241_Fm0.txt
agrep -0 -c 'GGCGAGCAATATGATAA' *.fastq > count/B8242_Fm0.txt
agrep -0 -c 'TTCTCTGCTTAGTAGCA' *.fastq > count/B8243_Fm0.txt
agrep -0 -c 'AGTCAGTCCGCCAGAAG' *.fastq > count/B8244_Fm0.txt
agrep -0 -c 'ATCACGATGCGTGTTTA' *.fastq > count/B8246_Fm0.txt
agrep -0 -c 'TCAATTCTCCGCAGGGC' *.fastq > count/B8248_Fm0.txt
agrep -0 -c 'ACCGGTAGTTAGTATGT' *.fastq > count/B8250_Fm0.txt
agrep -0 -c 'CTGGCTGGTCACTATAC' *.fastq > count/B8251_Fm0.txt
agrep -0 -c 'TAATCGTCAGTGTCTTG' *.fastq > count/B8252_Fm0.txt
agrep -0 -c 'GACCATTTGCTTGAGTA' *.fastq > count/B8253_Fm0.txt
agrep -0 -c 'TCGTAAGGTTCAGCAGA' *.fastq > count/B8254_Fm0.txt
agrep -0 -c 'GGAGTGGAAGATTGACG' *.fastq > count/B8255_Fm0.txt
agrep -0 -c 'GGTCAATGTGATCAGCT' *.fastq > count/B8256_Fm0.txt
agrep -0 -c 'CGGTAATAAGAGGATTG' *.fastq > count/B8257_Fm0.txt
agrep -0 -c 'TCTAACGGGACGCCTAG' *.fastq > count/B8258_Fm0.txt
agrep -0 -c 'GTGGAAGCATGGTGGTA' *.fastq > count/B8259_Fm0.txt
agrep -0 -c 'GTGCCCAAACTCGAACC' *.fastq > count/B8260_Fm0.txt
agrep -0 -c 'CGCTTGCTCTATCGATG' *.fastq > count/B8261_Fm0.txt
agrep -0 -c 'TCACCACTGTCCAATCA' *.fastq > count/B8262_Fm0.txt
agrep -0 -c 'AAGAGTTAGGCGTAACT' *.fastq > count/B8263_Fm0.txt
agrep -0 -c 'CGTGTAAGAGCAATGAG' *.fastq > count/B8264_Fm0.txt
agrep -0 -c 'AGGGCTGTGCTAATACC' *.fastq > count/B8265_Fm0.txt
agrep -0 -c 'GCCAACATCAAAAACGT' *.fastq > count/B8266_Fm0.txt
agrep -0 -c 'CTCAAATCGAAGTCACG' *.fastq > count/B8267_Fm0.txt
agrep -0 -c 'TATTAGGCTGATGCGCG' *.fastq > count/B8269_Fm0.txt
agrep -0 -c 'GGTGCTTCTTGCTGAAA' *.fastq > count/B8270_Fm0.txt
agrep -0 -c 'TTATGCTCGCTTGTCGC' *.fastq > count/B8271_Fm0.txt
agrep -0 -c 'TACCCAATATGTTCTCC' *.fastq > count/B8272_Fm0.txt
agrep -0 -c 'TCAGATTGGACTGCTAT' *.fastq > count/B8273_Fm0.txt
agrep -0 -c 'GATAATACTGGCGGAGA' *.fastq > count/B8274_Fm0.txt
agrep -0 -c 'GAGATTCCAGTTCCAGC' *.fastq > count/B8275_Fm0.txt
agrep -0 -c 'CAACATCTGGAGCAGTC' *.fastq > count/B8276_Fm0.txt
agrep -0 -c 'GTTGGTACAGACATAGT' *.fastq > count/B8277_Fm0.txt
agrep -0 -c 'AACGACTGACCCTCTGG' *.fastq > count/B8278_Fm0.txt
agrep -0 -c 'ATGAAGCTCCTGCGGAC' *.fastq > count/B8279_Fm0.txt
agrep -0 -c 'ACTTACAAGCTCAGCGG' *.fastq > count/B8280_Fm0.txt
agrep -0 -c 'GGGCTGCTAACTTCGTG' *.fastq > count/B8282_Fm0.txt
agrep -0 -c 'TTGTGTACCTATTGGCT' *.fastq > count/B8283_Fm0.txt
agrep -0 -c 'ATGTAGCCGGAACCAGA' *.fastq > count/B8284_Fm0.txt
agrep -0 -c 'ATCTGCGATAACAGCAC' *.fastq > count/B8285_Fm0.txt
agrep -0 -c 'ACTACGACACGAGACTC' *.fastq > count/B8287_Fm0.txt
agrep -0 -c 'ATCGCAGGGATGATCTT' *.fastq > count/B8288_Fm0.txt
agrep -0 -c 'CTAGGTAACCGCAACAT' *.fastq > count/B8289_Fm0.txt
agrep -0 -c 'TCGGACGGGACCAATAA' *.fastq > count/B8290_Fm0.txt
agrep -0 -c 'GGATACACTCGCTTCAC' *.fastq > count/B8291_Fm0.txt
agrep -0 -c 'CGGTCATGCAGAGTTAT' *.fastq > count/B8292_Fm0.txt
agrep -0 -c 'GGGCCGTCTAGCAGATA' *.fastq > count/B8293_Fm0.txt
agrep -0 -c 'TGGACCTGGCTTAAAGC' *.fastq > count/B8294_Fm0.txt
agrep -0 -c 'TACTCCCGACGCTTAAT' *.fastq > count/B8295_Fm0.txt
agrep -0 -c 'ACAGAGTCGGGATTAAA' *.fastq > count/B8296_Fm0.txt
agrep -0 -c 'CGCTGAGTGTAACAGAC' *.fastq > count/B8297_Fm0.txt
agrep -0 -c 'AATCATTTCCACAGGGT' *.fastq > count/B8298_Fm0.txt
agrep -0 -c 'TTGTATGCCTTTCGAAC' *.fastq > count/B8300_Fm0.txt
agrep -0 -c 'CTAGTAGTTGTCCCTGC' *.fastq > count/B8301_Fm0.txt
agrep -0 -c 'GGACGGATTATTCTACC' *.fastq > count/B8302_Fm0.txt
agrep -0 -c 'TGACGTTGATCGTGCAT' *.fastq > count/B8303_Fm0.txt
agrep -0 -c 'AGAGTAGGGGCTCGGTT' *.fastq > count/B8304_Fm0.txt
agrep -0 -c 'CATACCGCTACAGCCTG' *.fastq > count/B8305_Fm0.txt
agrep -0 -c 'ACTTCAAAGTGACGGTT' *.fastq > count/B8307_Fm0.txt
agrep -0 -c 'ATCGACTTCCCACTCGC' *.fastq > count/B8308_Fm0.txt
agrep -0 -c 'CCGCTATAAGGACATTA' *.fastq > count/B8310_Fm0.txt
agrep -0 -c 'GTAGGCGCACGGCATAT' *.fastq > count/B8311_Fm0.txt
agrep -0 -c 'GAGTCCGTGGGAAACAT' *.fastq > count/B8314_Fm0.txt
agrep -0 -c 'CACGGTGTAGGTACAAA' *.fastq > count/B8315_Fm0.txt
agrep -0 -c 'GCGACCGAACAGAAGTC' *.fastq > count/B8316_Fm0.txt
agrep -0 -c 'CGGCACTTGGGATCGAT' *.fastq > count/B8317_Fm0.txt
agrep -0 -c 'CATTACGGTGAGGTGGT' *.fastq > count/B8318_Fm0.txt
agrep -0 -c 'TATTTACAGATCGGCCT' *.fastq > count/B8320_Fm0.txt
agrep -0 -c 'CGCTGATTACTCTGTTC' *.fastq > count/B8321_Fm0.txt
agrep -0 -c 'AGAACCGATGGCTATTT' *.fastq > count/B8322_Fm0.txt
agrep -0 -c 'GCATACATCGGTCATAC' *.fastq > count/B8323_Fm0.txt
agrep -0 -c 'TGTTTCCAGGGCCGATC' *.fastq > count/B8324_Fm0.txt
agrep -0 -c 'GCCGACATAACTTACGC' *.fastq > count/B8325_Fm0.txt
agrep -0 -c 'GTACCCATGCGAAACTC' *.fastq > count/B8327_Fm0.txt
agrep -0 -c 'ATTTGGTGAAGAGCGGT' *.fastq > count/B8328_Fm0.txt
agrep -0 -c 'TGCACCGACTTTATACT' *.fastq > count/B8329_Fm0.txt
agrep -0 -c 'CTATCGTATACGAACGC' *.fastq > count/B8330_Fm0.txt
agrep -0 -c 'GTGAATCCCTTGCCTCG' *.fastq > count/B8331_Fm0.txt
agrep -0 -c 'TGCTCCCCATACCTTCA' *.fastq > count/B8332_Fm0.txt
agrep -0 -c 'TGCCGTTAGGTTCTGAT' *.fastq > count/B8334_Fm0.txt
agrep -0 -c 'GCTACGTTATATTTCCC' *.fastq > count/B8335_Fm0.txt
agrep -0 -c 'CGTTACAACGAATATCG' *.fastq > count/B8336_Fm0.txt
agrep -0 -c 'TTCATATCCCGCAGTCA' *.fastq > count/B8337_Fm0.txt
agrep -0 -c 'GTCAGTCTATCGTTGGT' *.fastq > count/B8338_Fm0.txt
agrep -0 -c 'GCAGGATTTTAGGAACT' *.fastq > count/B8339_Fm0.txt
agrep -0 -c 'CGAAACTGAGATGAGCT' *.fastq > count/B8340_Fm0.txt
agrep -0 -c 'TTAGCGAGCTGGTTGGC' *.fastq > count/B8341_Fm0.txt
agrep -0 -c 'GCGCGGTTATTCATGAG' *.fastq > count/B8342_Fm0.txt
agrep -0 -c 'TCACGACGACAGTGTAA' *.fastq > count/B8343_Fm0.txt
agrep -0 -c 'TAGCACGATTGACAGAA' *.fastq > count/B8345_Fm0.txt
agrep -0 -c 'GGATCCGCTTTTATCAA' *.fastq > count/B8347_Fm0.txt
agrep -0 -c 'CTCGTATGCGTCAGACA' *.fastq > count/B8348_Fm0.txt
agrep -0 -c 'TGATGTAACGCGGCCAT' *.fastq > count/B8351_Fm0.txt
agrep -0 -c 'TAACACCGATATCTGTC' *.fastq > count/B8352_Fm0.txt
agrep -0 -c 'AGTACCAGTAGTCGGAA' *.fastq > count/B8353_Fm0.txt
agrep -0 -c 'ATAGTCAATGTCGGTCA' *.fastq > count/B8355_Fm0.txt
agrep -0 -c 'CTTGCATGGGCTACCAA' *.fastq > count/B8356_Fm0.txt
agrep -0 -c 'GGTAGCATATCTCTGAC' *.fastq > count/B8357_Fm0.txt
agrep -0 -c 'TTCCCAAACTCGAGGTC' *.fastq > count/B8358_Fm0.txt
agrep -0 -c 'CGTTCTTGTCCGCCGAT' *.fastq > count/B8359_Fm0.txt
agrep -0 -c 'ACGTAGCTAGAATGGTC' *.fastq > count/B8360_Fm0.txt
agrep -0 -c 'CTCTGAAGGGTTGGAAC' *.fastq > count/B8361_Fm0.txt
agrep -0 -c 'ATTTCTCCGACTGCTGA' *.fastq > count/B8362_Fm0.txt
agrep -0 -c 'CTCGGGACCGCATATTG' *.fastq > count/B8363_Fm0.txt
agrep -0 -c 'GGTAGGTACGTGCAGAG' *.fastq > count/B8364_Fm0.txt
agrep -0 -c 'TATTGCTGCAAATACGG' *.fastq > count/B8365_Fm0.txt
agrep -0 -c 'TGCGTGACTAGTGTCGT' *.fastq > count/B8366_Fm0.txt
agrep -0 -c 'AATCTAGGGACGAAGCC' *.fastq > count/B8367_Fm0.txt
agrep -0 -c 'ATCTTTCGCACGAGTTT' *.fastq > count/B8368_Fm0.txt
agrep -0 -c 'CACAGAAAATATTCGGG' *.fastq > count/B8369_Fm0.txt
agrep -0 -c 'ATCGGGCATGCTCAGTA' *.fastq > count/B8370_Fm0.txt
agrep -0 -c 'GAGAAGCTCTGTCACCC' *.fastq > count/B8371_Fm0.txt
agrep -0 -c 'TCTCTCAAAGAGCGACT' *.fastq > count/B8372_Fm0.txt
agrep -0 -c 'TAGAATTATCCAGGTGC' *.fastq > count/B8373_Fm0.txt
agrep -0 -c 'ACGCGATTTAGCCTCAA' *.fastq > count/B8374_Fm0.txt
agrep -0 -c 'GATCGAAGTGACCACGT' *.fastq > count/B8375_Fm0.txt
agrep -0 -c 'GCTCAAATTATTTCCCG' *.fastq > count/B8376_Fm0.txt
agrep -0 -c 'CATAATCCCGTAAGCTG' *.fastq > count/B8377_Fm0.txt
agrep -0 -c 'GGTCACTTTGCTCGTTG' *.fastq > count/B8378_Fm0.txt
agrep -0 -c 'CCATTGTGGAATCGATG' *.fastq > count/B8380_Fm0.txt
agrep -0 -c 'CAGTTCGGTCAGCGTAC' *.fastq > count/B8381_Fm0.txt
agrep -0 -c 'CGGCATGAACTATTAGT' *.fastq > count/B8382_Fm0.txt
agrep -0 -c 'CGAGTCTTTAAGTGTAG' *.fastq > count/B8383_Fm0.txt
agrep -0 -c 'ATGATATCGTGTTTGGG' *.fastq > count/B8384_Fm0.txt
agrep -0 -c 'CGTGCTGATAGAGTTTA' *.fastq > count/B8386_Fm0.txt
agrep -0 -c 'CTTATATGTCACCGTGC' *.fastq > count/B8387_Fm0.txt
agrep -0 -c 'GACTGTTATGTTTCCCG' *.fastq > count/B8388_Fm0.txt
agrep -0 -c 'CCGATTAAGCGTTTGTT' *.fastq > count/B8389_Fm0.txt
agrep -0 -c 'GGTTCGATCTATACGGA' *.fastq > count/B8390_Fm0.txt
agrep -0 -c 'AGTCGTCTGCGGTTACC' *.fastq > count/B8391_Fm0.txt
agrep -0 -c 'AGCGCATGGAACAGCCT' *.fastq > count/B8392_Fm0.txt
agrep -0 -c 'CCGACTTAATAACCACA' *.fastq > count/B8393_Fm0.txt
agrep -0 -c 'TGGCGGATTCAAGATCC' *.fastq > count/B8394_Fm0.txt
agrep -0 -c 'TGACAGGAGTTACAAAG' *.fastq > count/B8395_Fm0.txt
agrep -0 -c 'GTTGTACCGCAATACTC' *.fastq > count/B8396_Fm0.txt
agrep -0 -c 'TGAATAAATTCGCGTCG' *.fastq > count/B8397_Fm0.txt
agrep -0 -c 'AGCTAATTGATGGCACG' *.fastq > count/B8398_Fm0.txt
agrep -0 -c 'TAGCCCTCATGAGATGG' *.fastq > count/B8399_Fm0.txt
agrep -0 -c 'CTCAGGCTAAGAGCCAG' *.fastq > count/B8400_Fm0.txt
agrep -0 -c 'TGCAGGCGTTCGGTAAT' *.fastq > count/B8401_Fm0.txt
agrep -0 -c 'ATGTGTTGAGCACAAAG' *.fastq > count/B8402_Fm0.txt
agrep -0 -c 'GGGTTCCGAGTCCTGAT' *.fastq > count/B8403_Fm0.txt
agrep -0 -c 'CACTACACCCCATCGAA' *.fastq > count/B8404_Fm0.txt
agrep -0 -c 'AATCGCGCGAAAAAGAA' *.fastq > count/B8407_Fm0.txt
agrep -0 -c 'GACCTTGTAGGAGTACG' *.fastq > count/B8408_Fm0.txt
agrep -0 -c 'TTCAACACCACTCGTAT' *.fastq > count/B8409_Fm0.txt
agrep -0 -c 'AGAGGTGCCAAAAGATT' *.fastq > count/B8411_Fm0.txt
agrep -0 -c 'ACGTGTATCTACACGGT' *.fastq > count/B8412_Fm0.txt
agrep -0 -c 'ATCCGTGTATCGACCAA' *.fastq > count/B8413_Fm0.txt
agrep -0 -c 'GTTAATGTTCCGTGGTG' *.fastq > count/B8414_Fm0.txt
agrep -0 -c 'ATCATATGCCAAGTGCC' *.fastq > count/B8415_Fm0.txt
agrep -0 -c 'GAGGCATATAGTGTAGG' *.fastq > count/B8416_Fm0.txt
agrep -0 -c 'GTGGGATTACGCAGTAA' *.fastq > count/B8417_Fm0.txt
agrep -0 -c 'GTGCTTACGTGCGGAAT' *.fastq > count/B8418_Fm0.txt
agrep -0 -c 'GGCACCATTGAACAGTG' *.fastq > count/B8419_Fm0.txt
agrep -0 -c 'ACGTCAAGATCGGGGTG' *.fastq > count/B8420_Fm0.txt
agrep -0 -c 'AGCAGTAGCAAGACTTA' *.fastq > count/B8421_Fm0.txt
agrep -0 -c 'GCATACCTACTACTGAG' *.fastq > count/B8422_Fm0.txt
agrep -0 -c 'CGCATTGCATATGGCGG' *.fastq > count/B8423_Fm0.txt
agrep -0 -c 'TTCTGCCCTTATGCTAT' *.fastq > count/B8424_Fm0.txt
agrep -0 -c 'AGACGCCTTTACTTGGG' *.fastq > count/B8425_Fm0.txt
agrep -0 -c 'TCTGGAAATTCGCTATC' *.fastq > count/B8426_Fm0.txt
agrep -0 -c 'GACTAGTTGTGAACAGG' *.fastq > count/B8427_Fm0.txt
agrep -0 -c 'GGGAATACTGTGCATGA' *.fastq > count/B8428_Fm0.txt
agrep -0 -c 'AACCCGTAGCTGTACTC' *.fastq > count/B8430_Fm0.txt
agrep -0 -c 'GGGAGACTCTGTAAGTA' *.fastq > count/B8431_Fm0.txt
agrep -0 -c 'CACGGAATTATATGCGT' *.fastq > count/B8432_Fm0.txt
agrep -0 -c 'TATCACGTCCATGGTCG' *.fastq > count/B8433_Fm0.txt
agrep -0 -c 'GTGATTGGCGTGATGGC' *.fastq > count/B8434_Fm0.txt
agrep -0 -c 'ACCGTCCCAAATGAACG' *.fastq > count/B8435_Fm0.txt
agrep -0 -c 'ACCCCATTTGGTGCCAC' *.fastq > count/B8437_Fm0.txt
agrep -0 -c 'GTTGATCCGTAGTCTAG' *.fastq > count/B8438_Fm0.txt
agrep -0 -c 'CGGCTGTGCGTATTCTG' *.fastq > count/B8441_Fm0.txt
agrep -0 -c 'TTAGCGCCTTCTGTGTG' *.fastq > count/B8442_Fm0.txt
agrep -0 -c 'CAAAGCGATGCGCCATA' *.fastq > count/B8443_Fm0.txt
agrep -0 -c 'TAGGACAAGTCAAGTGC' *.fastq > count/B8444_Fm0.txt
agrep -0 -c 'GGGGTAAAATCCCTATT' *.fastq > count/B8445_Fm0.txt
agrep -0 -c 'GACTTCGGGTTTTGGGT' *.fastq > count/B8446_Fm0.txt
agrep -0 -c 'GCAATAGCCAAGTCTCG' *.fastq > count/B8447_Fm0.txt
agrep -0 -c 'ACATTGACCAGACAGAT' *.fastq > count/B8448_Fm0.txt
agrep -0 -c 'CGACGGAGATTAACAAA' *.fastq > count/B8449_Fm0.txt
agrep -0 -c 'TAGTACAGAGGTCTACC' *.fastq > count/B8450_Fm0.txt
agrep -0 -c 'ACGGTCTCTGGTGATGA' *.fastq > count/B8451_Fm0.txt
agrep -0 -c 'AGGTTCGAACGACCTGC' *.fastq > count/B8452_Fm0.txt
agrep -0 -c 'CAGGGTGACTATAATAG' *.fastq > count/B8453_Fm0.txt
agrep -0 -c 'CTAGCTGTCCTAGCTGG' *.fastq > count/B8454_Fm0.txt
agrep -0 -c 'TGATTCATCGCGCATAT' *.fastq > count/B8457_Fm0.txt
agrep -0 -c 'GTGATCCGGACCTACAA' *.fastq > count/B8458_Fm0.txt
agrep -0 -c 'TGCAGCTTGCGAATCGA' *.fastq > count/B8459_Fm0.txt
agrep -0 -c 'TATTAGCCCCGTATGTC' *.fastq > count/B8460_Fm0.txt
agrep -0 -c 'GTTGAAGACACGCCACG' *.fastq > count/B8461_Fm0.txt
agrep -0 -c 'ACGGTTTCTGCCACTGT' *.fastq > count/B8462_Fm0.txt
agrep -0 -c 'GCCAGCACATGTCTGGA' *.fastq > count/B8463_Fm0.txt
agrep -0 -c 'TATTCCGCCTGAAGTTC' *.fastq > count/B8465_Fm0.txt
agrep -0 -c 'ATAGTTGGTCTAGCGGC' *.fastq > count/B8466_Fm0.txt
agrep -0 -c 'GATATCATCAGGGAGGG' *.fastq > count/B8467_Fm0.txt
agrep -0 -c 'ACACATGATGCATCGAT' *.fastq > count/B8468_Fm0.txt
agrep -0 -c 'ATTGGATCCGCGCTCTC' *.fastq > count/B8471_Fm0.txt
agrep -0 -c 'TCTTTTTAACACGGTCG' *.fastq > count/B8472_Fm0.txt
agrep -0 -c 'TCGTTAAATGTCTCGCT' *.fastq > count/B8473_Fm0.txt
agrep -0 -c 'GTTTCCGTAGCCCGTAC' *.fastq > count/B8474_Fm0.txt
agrep -0 -c 'AACTCCGCTACAATGAA' *.fastq > count/B8475_Fm0.txt
agrep -0 -c 'CTTCGACGAGGGCTGTT' *.fastq > count/B8476_Fm0.txt
agrep -0 -c 'CACAGGACCTTACACGA' *.fastq > count/B8477_Fm0.txt
agrep -0 -c 'ATAAGACAATGTCGCTG' *.fastq > count/B8479_Fm0.txt
agrep -0 -c 'GTCCTCCTAAACCACGT' *.fastq > count/B8480_Fm0.txt
agrep -0 -c 'ATAGATCGTAAACGAGG' *.fastq > count/B8481_Fm0.txt
agrep -0 -c 'TGTGTTGGGGCGGTAGT' *.fastq > count/B8482_Fm0.txt
agrep -0 -c 'GTCAGCGACGTACCTTA' *.fastq > count/B8483_Fm0.txt
agrep -0 -c 'TGTAGGCTGGGGTTATC' *.fastq > count/B8484_Fm0.txt
agrep -0 -c 'AGCGTGTGCTGAAACAA' *.fastq > count/B8486_Fm0.txt
agrep -0 -c 'TAAGTCATCCATACGGG' *.fastq > count/B8487_Fm0.txt
agrep -0 -c 'TGTACTACGACAGCGGT' *.fastq > count/B8488_Fm0.txt
agrep -0 -c 'ACAGGCCAATCCTCTAG' *.fastq > count/B8490_Fm0.txt
agrep -0 -c 'CGATTAGTGCAGGATCG' *.fastq > count/B8492_Fm0.txt
agrep -0 -c 'TACTACAGTCGTGATGG' *.fastq > count/B8493_Fm0.txt
agrep -0 -c 'CGGGGATTAATGACAGT' *.fastq > count/B8494_Fm0.txt
agrep -0 -c 'GGTCAACTATCGTAGAC' *.fastq > count/B8495_Fm0.txt
agrep -0 -c 'GATCACTTGATAGTAGG' *.fastq > count/B8496_Fm0.txt
agrep -0 -c 'GTTATGGTATGTGCGCG' *.fastq > count/B8497_Fm0.txt
agrep -0 -c 'CGAACAATCCGTATGTT' *.fastq > count/B8498_Fm0.txt
agrep -0 -c 'CCAGGTCGAAATACTTA' *.fastq > count/B8499_Fm0.txt
agrep -0 -c 'ACTCACTTCGCTGGTGT' *.fastq > count/B8501_Fm0.txt
agrep -0 -c 'CGGGCTGTGTTTCACTA' *.fastq > count/B8502_Fm0.txt
agrep -0 -c 'CAAGGCCCTAGGATTAC' *.fastq > count/B8503_Fm0.txt
agrep -0 -c 'CACTCCTTTCTAGTGCC' *.fastq > count/B8505_Fm0.txt
agrep -0 -c 'TATCCACCCGTTTTAAG' *.fastq > count/B8506_Fm0.txt
agrep -0 -c 'AGGTTATTATTAGCCGG' *.fastq > count/B8507_Fm0.txt
agrep -0 -c 'ACGGATGGTCCCAACTC' *.fastq > count/B8508_Fm0.txt
agrep -0 -c 'CTGCGTAATAAGAGGAC' *.fastq > count/B8509_Fm0.txt
agrep -0 -c 'AGTCGAAGCATCCGACC' *.fastq > count/B8510_Fm0.txt
agrep -0 -c 'AGTGCGCAATCTGGTTC' *.fastq > count/B8511_Fm0.txt
agrep -0 -c 'AGCGGTTAATGTGTTCT' *.fastq > count/B8514_Fm0.txt
agrep -0 -c 'TTACGCTTCCTGAAACT' *.fastq > count/B8515_Fm0.txt
agrep -0 -c 'GTAGCGCTAAGACTACC' *.fastq > count/B8516_Fm0.txt
agrep -0 -c 'CAATCGCGGTGGTTTTA' *.fastq > count/B8518_Fm0.txt
agrep -0 -c 'GCACGCAACGATCTGTT' *.fastq > count/B8519_Fm0.txt
agrep -0 -c 'TCTTTACAAATGGGGGC' *.fastq > count/B8521_Fm0.txt
agrep -0 -c 'CAAGCAAACGTTACTTC' *.fastq > count/B8522_Fm0.txt
agrep -0 -c 'GTTGATAACCTCACTTC' *.fastq > count/B8523_Fm0.txt
agrep -0 -c 'GCCCTCAGTTTGAAGTT' *.fastq > count/B8524_Fm0.txt
agrep -0 -c 'CTTCAGCATTTTGTACG' *.fastq > count/B8525_Fm0.txt
agrep -0 -c 'GTCGAGCCAAAATAAAC' *.fastq > count/B8526_Fm0.txt
agrep -0 -c 'GCACGGTCATCCTTCCA' *.fastq > count/B8527_Fm0.txt
agrep -0 -c 'CTCTACCGTATCCTACC' *.fastq > count/B8528_Fm0.txt
agrep -0 -c 'ATGAGATCACTACCCTT' *.fastq > count/B8529_Fm0.txt
agrep -0 -c 'ACGATACATACCTCTGT' *.fastq > count/B8530_Fm0.txt
agrep -0 -c 'CGGGCGACTGAGATTTA' *.fastq > count/B8531_Fm0.txt
agrep -0 -c 'AAGGAGTGGGAAGAACC' *.fastq > count/B8533_Fm0.txt
agrep -0 -c 'CGGTTATTCATCCGATC' *.fastq > count/B8535_Fm0.txt
agrep -0 -c 'TGTCGGACAGAGACCTT' *.fastq > count/B8536_Fm0.txt
agrep -0 -c 'GTCGATCGTAGTGGTAC' *.fastq > count/B8537_Fm0.txt
agrep -0 -c 'TCTGGTACAGGAAGGAT' *.fastq > count/B8538_Fm0.txt
agrep -0 -c 'CATTACTTGTGCAAGGT' *.fastq > count/B8539_Fm0.txt
agrep -0 -c 'AGGGTTTGTGCGCCAAG' *.fastq > count/B8540_Fm0.txt
agrep -0 -c 'GCGTAGTGCGACGAATG' *.fastq > count/B8541_Fm0.txt
agrep -0 -c 'CGTCCTACTCGTGGCTA' *.fastq > count/B8542_Fm0.txt
agrep -0 -c 'AATTCGTCGGACCAGAG' *.fastq > count/B8543_Fm0.txt
agrep -0 -c 'CGAGATGATGAGCAATG' *.fastq > count/B8544_Fm0.txt
agrep -0 -c 'AGTGAGAACGGAAAGTA' *.fastq > count/B8546_Fm0.txt
agrep -0 -c 'ACTCGAAAGGGGACAAC' *.fastq > count/B8547_Fm0.txt
agrep -0 -c 'GAGCCGCATGTGAATAG' *.fastq > count/B8548_Fm0.txt
agrep -0 -c 'AATGTGGTGCCAATACT' *.fastq > count/B8550_Fm0.txt
agrep -0 -c 'GTCTTTTCTCCTTGCGC' *.fastq > count/B8552_Fm0.txt
agrep -0 -c 'GTCAAGACGTAAGATCG' *.fastq > count/B8553_Fm0.txt
agrep -0 -c 'ACTTAATGCCATGAACG' *.fastq > count/B8554_Fm0.txt
agrep -0 -c 'CAACTACGAAGCCACAC' *.fastq > count/B8555_Fm0.txt
agrep -0 -c 'TGGCTCCCTATACAAAG' *.fastq > count/B8556_Fm0.txt
agrep -0 -c 'GACCTAAGACTAGGCTA' *.fastq > count/B8557_Fm0.txt
agrep -0 -c 'GGTGTCGCAGTATTAAT' *.fastq > count/B8558_Fm0.txt
agrep -0 -c 'TTACCACAGCTTGGCCT' *.fastq > count/B8559_Fm0.txt
agrep -0 -c 'GCTTACACTCCTTTTGG' *.fastq > count/B8561_Fm0.txt
agrep -0 -c 'TGAGCCACACCAACGAT' *.fastq > count/B8562_Fm0.txt
agrep -0 -c 'CGGCCAGTGAGAATTCG' *.fastq > count/B8563_Fm0.txt
agrep -0 -c 'ACAACAAATGCACTCTC' *.fastq > count/B8564_Fm0.txt
agrep -0 -c 'AGTCGTCTGCCAGACAA' *.fastq > count/B8567_Fm0.txt
agrep -0 -c 'GTTTCCGCGTTCAGAAC' *.fastq > count/B8568_Fm0.txt
agrep -0 -c 'CGATTAAGCGGGTTCGA' *.fastq > count/B8569_Fm0.txt
agrep -0 -c 'ACATAAAGCCATCCTCC' *.fastq > count/B8572_Fm0.txt
agrep -0 -c 'GTTTATCCCTTCCGTGG' *.fastq > count/B8574_Fm0.txt
agrep -0 -c 'GGTATAGGTCAGGCTTC' *.fastq > count/B8576_Fm0.txt
agrep -0 -c 'TCAGTGCGGCTACTTTC' *.fastq > count/B8577_Fm0.txt
agrep -0 -c 'TTACACCTCGCCACCAC' *.fastq > count/B8578_Fm0.txt
agrep -0 -c 'GCTAGTACTGATCCGGA' *.fastq > count/B8579_Fm0.txt
agrep -0 -c 'GTCTGAATCGGATACCA' *.fastq > count/B8580_Fm0.txt
agrep -0 -c 'CAGTAACAGCAGGCCGA' *.fastq > count/B8581_Fm0.txt
agrep -0 -c 'AGTCACCCATGTGATCC' *.fastq > count/B8583_Fm0.txt
agrep -0 -c 'TACCTCGATAATGCCCG' *.fastq > count/B8584_Fm0.txt
agrep -0 -c 'CTCGCGTAAGATAAGTG' *.fastq > count/B8585_Fm0.txt
agrep -0 -c 'CGAATCGTTGCGTGTTT' *.fastq > count/B8586_Fm0.txt
agrep -0 -c 'CACCTAAGAGCGCGTTG' *.fastq > count/B8587_Fm0.txt
agrep -0 -c 'GTCACGCCAACGGGTTA' *.fastq > count/B8588_Fm0.txt
agrep -0 -c 'CACGATAGTGTACCCGT' *.fastq > count/B8589_Fm0.txt
agrep -0 -c 'GAGGTCGTCTATAGAAT' *.fastq > count/B8591_Fm0.txt
agrep -0 -c 'ATGGTAGGGTCATTGGG' *.fastq > count/B8592_Fm0.txt
agrep -0 -c 'TAGGTGTTCAAAGCTCC' *.fastq > count/B8593_Fm0.txt
agrep -0 -c 'CAGGCGTAACGATTTAC' *.fastq > count/B8594_Fm0.txt
agrep -0 -c 'AGGGTGCTCCATGCAAA' *.fastq > count/B8595_Fm0.txt
agrep -0 -c 'GACCTGTATCCAGGAAT' *.fastq > count/B8596_Fm0.txt
agrep -0 -c 'GCTTAAAACAGCGGGTC' *.fastq > count/B8597_Fm0.txt
agrep -0 -c 'GGTCGTGTCGTCATTCT' *.fastq > count/B8598_Fm0.txt
agrep -0 -c 'TAACGGGATACACATCA' *.fastq > count/B8599_Fm0.txt
agrep -0 -c 'TACACACTCGACTGTGT' *.fastq > count/B8600_Fm0.txt
agrep -0 -c 'TCGAACCTTGGTTGGTA' *.fastq > count/B8601_Fm0.txt
agrep -0 -c 'CACGGACTTTGTCGCAA' *.fastq > count/B8602_Fm0.txt
agrep -0 -c 'GATTTTGCGAGATATCG' *.fastq > count/B8603_Fm0.txt
agrep -0 -c 'TTCATAATCGAGTCCCG' *.fastq > count/B8604_Fm0.txt
agrep -0 -c 'GTTAACTGTTTACGTGG' *.fastq > count/B8605_Fm0.txt
agrep -0 -c 'CGTAGTAGGACCCGGAA' *.fastq > count/B8606_Fm0.txt
agrep -0 -c 'AGAGCTCCAACACGCTA' *.fastq > count/B8607_Fm0.txt
agrep -0 -c 'ACCTACTGTCCGCGCTT' *.fastq > count/B8608_Fm0.txt
agrep -0 -c 'ATGGGCACTACTAAGCT' *.fastq > count/B8609_Fm0.txt
agrep -0 -c 'CGAATACCCAAAGTTTC' *.fastq > count/B8610_Fm0.txt
agrep -0 -c 'CCTCATGTACCGGCCTT' *.fastq > count/B8611_Fm0.txt
agrep -0 -c 'ATCCGCCAAGGTATCTA' *.fastq > count/B8612_Fm0.txt
agrep -0 -c 'AAGAACTGAGGATCTCC' *.fastq > count/B8613_Fm0.txt
agrep -0 -c 'TCGCCTTCCGAGATTTG' *.fastq > count/B8614_Fm0.txt
agrep -0 -c 'TTCGAAGAAGCCACGAG' *.fastq > count/B8615_Fm0.txt
agrep -0 -c 'AGTGTAGCCTCACTCGA' *.fastq > count/B8616_Fm0.txt
agrep -0 -c 'TATCCCATATAGTTCCC' *.fastq > count/B8617_Fm0.txt
agrep -0 -c 'CAGGTTTACCAAGGGCT' *.fastq > count/B8618_Fm0.txt
agrep -0 -c 'TGGAGGTCGGTGCTAAA' *.fastq > count/B8620_Fm0.txt
agrep -0 -c 'GGGGAAGCATCTATTGG' *.fastq > count/B8621_Fm0.txt
agrep -0 -c 'CAACCCGTCTAGCGTGA' *.fastq > count/B8622_Fm0.txt
agrep -0 -c 'ACGTGCTATCACATAGG' *.fastq > count/B8623_Fm0.txt
agrep -0 -c 'ATTTGGTCGTTCCGGTC' *.fastq > count/B8624_Fm0.txt
agrep -0 -c 'GAGTGAAACTGTTCGAA' *.fastq > count/B8625_Fm0.txt
agrep -0 -c 'AGAATTAGCCGTGTCTT' *.fastq > count/B8627_Fm0.txt
agrep -0 -c 'CGTCCTATAGGCGATAG' *.fastq > count/B8628_Fm0.txt
agrep -0 -c 'CTAAGCTACTACCGATA' *.fastq > count/B8629_Fm0.txt
agrep -0 -c 'GTTGAAACCAGTCCGTG' *.fastq > count/B8630_Fm0.txt
agrep -0 -c 'CAAAACCAGTCGTTTCG' *.fastq > count/B8631_Fm0.txt
agrep -0 -c 'GTCATTCGGATAGCATT' *.fastq > count/B8632_Fm0.txt
agrep -0 -c 'ATTGTCATTCGTGAGGC' *.fastq > count/B8633_Fm0.txt
agrep -0 -c 'TCATTGTCAGCGAGTCC' *.fastq > count/B8634_Fm0.txt
agrep -0 -c 'GGATGACGAAGAGTTGA' *.fastq > count/B8635_Fm0.txt
agrep -0 -c 'TATCTCGTGGTAGGAGG' *.fastq > count/B8636_Fm0.txt
agrep -0 -c 'CCGTCTTGGCCTTGCAA' *.fastq > count/B8637_Fm0.txt
agrep -0 -c 'GTCTCGTCTAGCTATCC' *.fastq > count/B8638_Fm0.txt
agrep -0 -c 'TACCAGAATCAAGCGAA' *.fastq > count/B8641_Fm0.txt
agrep -0 -c 'TCGTATGCTCTGTCAAG' *.fastq > count/B8642_Fm0.txt
agrep -0 -c 'CCTCGTTGGTTGTAGAC' *.fastq > count/B8643_Fm0.txt
agrep -0 -c 'CATCCGCGTCACTCCAA' *.fastq > count/B8644_Fm0.txt
agrep -0 -c 'CTTCTCTAACTGCACGA' *.fastq > count/B8645_Fm0.txt
agrep -0 -c 'CAATTTACCCTGCGCCC' *.fastq > count/B8646_Fm0.txt
agrep -0 -c 'CAGTCTTAAGCGCATCA' *.fastq > count/B8647_Fm0.txt
agrep -0 -c 'TTCCGTGATACCTCTCG' *.fastq > count/B8648_Fm0.txt
agrep -0 -c 'AGCCGGACAATAATGTT' *.fastq > count/B8649_Fm0.txt
agrep -0 -c 'CAGTGGTGAAGACTCTA' *.fastq > count/B8650_Fm0.txt
agrep -0 -c 'ACCTAGATGGTCCAACA' *.fastq > count/B8651_Fm0.txt
agrep -0 -c 'ACAGTAGTAATTCCAGC' *.fastq > count/B8652_Fm0.txt
agrep -0 -c 'GGTAGAGCATGGCAACA' *.fastq > count/B8653_Fm0.txt
agrep -0 -c 'TATGCCTCCTATCATGG' *.fastq > count/B8654_Fm0.txt
agrep -0 -c 'CGCAATAGAGGTCGTTA' *.fastq > count/B8655_Fm0.txt
agrep -0 -c 'CATTCGTCTTACATGGA' *.fastq > count/B8656_Fm0.txt
agrep -0 -c 'GTGAATGGAAACCTTGC' *.fastq > count/B8658_Fm0.txt
agrep -0 -c 'GTGTCCTTGCGCCTTCA' *.fastq > count/B8659_Fm0.txt
agrep -0 -c 'CGAGCAGTACGGATTTC' *.fastq > count/B8660_Fm0.txt
agrep -0 -c 'AGCTCCAAATACGGCCC' *.fastq > count/B8661_Fm0.txt
agrep -0 -c 'TGATCCTTTAGCTCGCC' *.fastq > count/B8662_Fm0.txt
agrep -0 -c 'TTCTGCCGAACACCTGC' *.fastq > count/B8663_Fm0.txt
agrep -0 -c 'TAGCTTCCGTCTTGCTA' *.fastq > count/B8664_Fm0.txt
agrep -0 -c 'TATACACGTCGTATTCG' *.fastq > count/B8665_Fm0.txt
agrep -0 -c 'TTGTGGGCAGAGGCTAC' *.fastq > count/B8666_Fm0.txt
agrep -0 -c 'TCAGACAAGTATTCGCC' *.fastq > count/B8667_Fm0.txt
agrep -0 -c 'ACTCACCTGGGTTGTTG' *.fastq > count/B8668_Fm0.txt
agrep -0 -c 'AGCACTTTAGCGTGCAT' *.fastq > count/B8669_Fm0.txt
agrep -0 -c 'TCGTGAACCGGACATCG' *.fastq > count/B8670_Fm0.txt
agrep -0 -c 'TCAGCGTGGGTGAGTGA' *.fastq > count/B8674_Fm0.txt
agrep -0 -c 'GCGCCACACGAATTTCC' *.fastq > count/B8675_Fm0.txt
agrep -0 -c 'CGCAATGTACGGTAGAA' *.fastq > count/B8678_Fm0.txt
agrep -0 -c 'TAATGTAGACGGCTTCG' *.fastq > count/B8679_Fm0.txt
agrep -0 -c 'CAACGCGTTGATTAACC' *.fastq > count/B8681_Fm0.txt
agrep -0 -c 'CGTAGAATAAGGGCAAC' *.fastq > count/B8682_Fm0.txt
agrep -0 -c 'GATCTTTGGTCCAGGTC' *.fastq > count/B8683_Fm0.txt
agrep -0 -c 'TGCAAGTCCGTAGGTGA' *.fastq > count/B8684_Fm0.txt
agrep -0 -c 'CACCATCAACTAGGTAT' *.fastq > count/B8685_Fm0.txt
agrep -0 -c 'CTTGCTCATTAGTCGTG' *.fastq > count/B8686_Fm0.txt
agrep -0 -c 'CGCTAATCAGCTGTAAC' *.fastq > count/B8687_Fm0.txt
agrep -0 -c 'CGTGACCTGAACATATG' *.fastq > count/B8688_Fm0.txt
agrep -0 -c 'CGATAGACCTCCTCCAG' *.fastq > count/B8689_Fm0.txt
agrep -0 -c 'TAGCGCTCGCGTACTTC' *.fastq > count/B8690_Fm0.txt
agrep -0 -c 'GTTCGTCGTTATAGACG' *.fastq > count/B8691_Fm0.txt
agrep -0 -c 'CAGTCGGACGTAAATTT' *.fastq > count/B8692_Fm0.txt
agrep -0 -c 'TATAAGGCACTAGGAGA' *.fastq > count/B8693_Fm0.txt
agrep -0 -c 'CGTGATTCAGCGCTACG' *.fastq > count/B8694_Fm0.txt
agrep -0 -c 'TCGCCATATGATCGTCC' *.fastq > count/B8695_Fm0.txt
agrep -0 -c 'CGGAAGCATCGCGCAAA' *.fastq > count/B8696_Fm0.txt
agrep -0 -c 'GGACGTATTGGCGCTCA' *.fastq > count/B8697_Fm0.txt
agrep -0 -c 'CTCGAGTAATAACTGAC' *.fastq > count/B8698_Fm0.txt
agrep -0 -c 'CAAGGTCTTGCGTATAC' *.fastq > count/B8699_Fm0.txt
agrep -0 -c 'TTGTCCATAGGGCCAGT' *.fastq > count/B8700_Fm0.txt
agrep -0 -c 'ATACTGCGTGCTTTCCC' *.fastq > count/B8701_Fm0.txt
agrep -0 -c 'ATACCGCGTAAGCCGAC' *.fastq > count/B8702_Fm0.txt
agrep -0 -c 'GCGGAATGTAAACGTAT' *.fastq > count/B8704_Fm0.txt
agrep -0 -c 'GTAGATCGGCGGATTGT' *.fastq > count/B8705_Fm0.txt
agrep -0 -c 'ACACGGTAGACCGGTTA' *.fastq > count/B8706_Fm0.txt
agrep -0 -c 'ACGTTCGATTCTGACGG' *.fastq > count/B8707_Fm0.txt
agrep -0 -c 'CGCCTCAATTGCGTCCA' *.fastq > count/B8708_Fm0.txt
agrep -0 -c 'AGTTTAACGACCAGCGG' *.fastq > count/B8709_Fm0.txt
agrep -0 -c 'TTGGGTGCGAGCTACAC' *.fastq > count/B8710_Fm0.txt
agrep -0 -c 'AATTCTGCCGGCTAGGA' *.fastq > count/B8711_Fm0.txt
agrep -0 -c 'AGAAAGGACGCCACACG' *.fastq > count/B8712_Fm0.txt
agrep -0 -c 'CTAGGCATGCCTCAACA' *.fastq > count/B8714_Fm0.txt
agrep -0 -c 'AGCAATGTGTCCACAAT' *.fastq > count/B8715_Fm0.txt
agrep -0 -c 'TTGGCCGGTTAGTTGTA' *.fastq > count/B8717_Fm0.txt
agrep -0 -c 'CCGCGAACATGTCTTGT' *.fastq > count/B8720_Fm0.txt
agrep -0 -c 'ATACACCCACCAATCGA' *.fastq > count/B8722_Fm0.txt
agrep -0 -c 'TTCGGGAGTAACGATAG' *.fastq > count/B8723_Fm0.txt
agrep -0 -c 'AACAGCACGTTACTTGC' *.fastq > count/B8724_Fm0.txt
agrep -0 -c 'CGTAATGATCCCACGCT' *.fastq > count/B8725_Fm0.txt
agrep -0 -c 'ATCAATGACGGGGCTAT' *.fastq > count/B8726_Fm0.txt
agrep -0 -c 'TGTCCGCTGCTCAATAA' *.fastq > count/B8727_Fm0.txt
agrep -0 -c 'GCCGACTAAGGACGTCA' *.fastq > count/B8728_Fm0.txt
agrep -0 -c 'CGAGCGCAGTAAGACAT' *.fastq > count/B8729_Fm0.txt
agrep -0 -c 'TCGAGAGTTTGTCAAGA' *.fastq > count/B8730_Fm0.txt
agrep -0 -c 'TAGGGACTTCACCTACG' *.fastq > count/B8731_Fm0.txt
agrep -0 -c 'GTACCGTCACAGCATCC' *.fastq > count/B8732_Fm0.txt
agrep -0 -c 'CTTCTTTCGGCAGAGTG' *.fastq > count/B8733_Fm0.txt
agrep -0 -c 'TAACTCCTCCTTAGACA' *.fastq > count/B8734_Fm0.txt
agrep -0 -c 'CAGCGGCATTGTCAAAG' *.fastq > count/B8735_Fm0.txt
agrep -0 -c 'TGTCAGGATTGCGTGGA' *.fastq > count/B8736_Fm0.txt
agrep -0 -c 'AGAGCCCGTCAACAGGT' *.fastq > count/B8738_Fm0.txt
agrep -0 -c 'ATACGACGAATGAGCCC' *.fastq > count/B8739_Fm0.txt
agrep -0 -c 'GTTCGTAGAAGAAACCT' *.fastq > count/B8740_Fm0.txt
agrep -0 -c 'GCGCTATAAGAAGGCGA' *.fastq > count/B8741_Fm0.txt
agrep -0 -c 'GCGGTTTCGATACGCCT' *.fastq > count/B8742_Fm0.txt
agrep -0 -c 'AACTCCCGATAGGTAAG' *.fastq > count/B8743_Fm0.txt
agrep -0 -c 'TATTACCCGGCCTGTGC' *.fastq > count/B8744_Fm0.txt
agrep -0 -c 'GGTATGACACATGATGA' *.fastq > count/B8745_Fm0.txt
agrep -0 -c 'TCTTCCCAGTATACCGC' *.fastq > count/B8746_Fm0.txt
agrep -0 -c 'GTTACTCAGCGAGCATA' *.fastq > count/B8747_Fm0.txt
agrep -0 -c 'GCCGCTGAATCAGCTCA' *.fastq > count/B8749_Fm0.txt
agrep -0 -c 'TATTAGGACCGTGCAGG' *.fastq > count/B8750_Fm0.txt
agrep -0 -c 'CACGTTAATTGCAACAC' *.fastq > count/B8751_Fm0.txt
agrep -0 -c 'CAGGCACATCGGGTCTA' *.fastq > count/B8752_Fm0.txt
agrep -0 -c 'CATTTTACTAGGCGTGG' *.fastq > count/B8753_Fm0.txt
agrep -0 -c 'GGCGGCTGTTGGCTATT' *.fastq > count/B8754_Fm0.txt
agrep -0 -c 'GTCGATAGTAGGAACGA' *.fastq > count/B8755_Fm0.txt
agrep -0 -c 'AAGATTCAGGACGGTTA' *.fastq > count/B8756_Fm0.txt
agrep -0 -c 'GGTTTTTGCATACAGGA' *.fastq > count/B8757_Fm0.txt
agrep -0 -c 'ACAGTTCAGCCGTCTTT' *.fastq > count/B8758_Fm0.txt
agrep -0 -c 'ATTCCGTAACCATCACC' *.fastq > count/B8760_Fm0.txt
agrep -0 -c 'GCTAGAAGATGTTGTCG' *.fastq > count/B8761_Fm0.txt
agrep -0 -c 'GTGGCCAGGCAAATTTG' *.fastq > count/B8762_Fm0.txt
agrep -0 -c 'TGCATAATCGGAAAGGG' *.fastq > count/B8763_Fm0.txt
agrep -0 -c 'GTTATTTGCAAACGCGC' *.fastq > count/B8764_Fm0.txt
agrep -0 -c 'TGATCAAACCGCCCATC' *.fastq > count/B8765_Fm0.txt
agrep -0 -c 'CACTACCTGAGATCTAT' *.fastq > count/B8766_Fm0.txt
agrep -0 -c 'AAGAACGGGTATCGGTC' *.fastq > count/B8767_Fm0.txt
agrep -0 -c 'GTAACGAAGTCCGCTTT' *.fastq > count/B8768_Fm0.txt
agrep -0 -c 'CCTCGTGTGCAGATTCA' *.fastq > count/B8769_Fm0.txt
agrep -0 -c 'CGGTCTAATGAGCCTAC' *.fastq > count/B8770_Fm0.txt
agrep -0 -c 'ACGCGTTTCATCGCTAG' *.fastq > count/B8771_Fm0.txt
agrep -0 -c 'CACACTTGCACTGCACC' *.fastq > count/B8772_Fm0.txt
agrep -0 -c 'CTCTGGGCTTTGAAGTT' *.fastq > count/B8774_Fm0.txt
agrep -0 -c 'AGTACGCCCAGTGCTGT' *.fastq > count/B8777_Fm0.txt
agrep -0 -c 'CATAATGAGAACGCAGG' *.fastq > count/B8778_Fm0.txt
agrep -0 -c 'TTGTAGGCGAACCCTCG' *.fastq > count/B8779_Fm0.txt
agrep -0 -c 'ACGCATTAGGCTGTTGT' *.fastq > count/B8780_Fm0.txt
agrep -0 -c 'ATAAGTGCGACGGCGTA' *.fastq > count/B8782_Fm0.txt
agrep -0 -c 'AGCGGAACATTTGAGAA' *.fastq > count/B8784_Fm0.txt
agrep -0 -c 'ACAATTAGGTCAGATCG' *.fastq > count/B8785_Fm0.txt
agrep -0 -c 'CCGAGTCTAGAGGAAGG' *.fastq > count/B8786_Fm0.txt
agrep -0 -c 'GTGAGCAAGTTAATTCG' *.fastq > count/B8787_Fm0.txt
agrep -0 -c 'AGTAAGGTTACGCGCAA' *.fastq > count/B8788_Fm0.txt
agrep -0 -c 'GATACTAAAGCCGCGGG' *.fastq > count/B8790_Fm0.txt
agrep -0 -c 'AACGCTACGACGACACG' *.fastq > count/B8791_Fm0.txt
agrep -0 -c 'TCTGAACCACTACGTGG' *.fastq > count/B8792_Fm0.txt
agrep -0 -c 'ACTAAGCAACGTCACGA' *.fastq > count/B8793_Fm0.txt
agrep -0 -c 'TTCCGGAGGGTTTTCGT' *.fastq > count/B8794_Fm0.txt
agrep -0 -c 'AGGTTCAGGTCATTACT' *.fastq > count/B8795_Fm0.txt
agrep -0 -c 'CTCCAAGCTTTCTACCC' *.fastq > count/B8797_Fm0.txt
agrep -0 -c 'AGAGATTGGTGTTTCCC' *.fastq > count/B8798_Fm0.txt
agrep -0 -c 'GAGAGACCGCCAAGTAC' *.fastq > count/B8799_Fm0.txt
agrep -0 -c 'CACTCATGTGAACGAAT' *.fastq > count/B8800_Fm0.txt
agrep -0 -c 'AGTATACGCGATTGCCG' *.fastq > count/B8801_Fm0.txt
agrep -0 -c 'GCACAGTATTGACGAAG' *.fastq > count/B8802_Fm0.txt
agrep -0 -c 'GCTACCTGTACAAACAT' *.fastq > count/B8803_Fm0.txt
agrep -0 -c 'AGCCGAGATGATTCGCC' *.fastq > count/B8805_Fm0.txt
agrep -0 -c 'GCGTCAACATGCGTCAA' *.fastq > count/B8808_Fm0.txt
agrep -0 -c 'ACGAGAGGAATTTATGC' *.fastq > count/B8809_Fm0.txt
agrep -0 -c 'GTGCTCACGTTGTTTCG' *.fastq > count/B8810_Fm0.txt
agrep -0 -c 'TTGGGAACGATGGAGGT' *.fastq > count/B8811_Fm0.txt
agrep -0 -c 'AATGGCGAAGCGGAGAA' *.fastq > count/B8813_Fm0.txt
agrep -0 -c 'GCAATGAGGGTACAACT' *.fastq > count/B8814_Fm0.txt
agrep -0 -c 'CGTGTATCGCGGTGATA' *.fastq > count/B8815_Fm0.txt
agrep -0 -c 'CCGGATACCTATATTCT' *.fastq > count/B8816_Fm0.txt
agrep -0 -c 'CGTCTTACCAGCCTTGG' *.fastq > count/B8817_Fm0.txt
agrep -0 -c 'TCGACCAATCAACATGC' *.fastq > count/B8818_Fm0.txt
agrep -0 -c 'CACGGGATCGTCTTCAG' *.fastq > count/B8819_Fm0.txt
agrep -0 -c 'TCGCAGTCGAATAACTG' *.fastq > count/B8820_Fm0.txt
agrep -0 -c 'GATCGCTTAGGAGGGAA' *.fastq > count/B8821_Fm0.txt
agrep -0 -c 'CGAGCAAGATAGTCCAA' *.fastq > count/B8822_Fm0.txt
agrep -0 -c 'GCTCTCAAAACTCGTAG' *.fastq > count/B8824_Fm0.txt
agrep -0 -c 'TAATTGCCAACGCTGCG' *.fastq > count/B8825_Fm0.txt
agrep -0 -c 'CTGTTGAAGTAGCAATG' *.fastq > count/B8826_Fm0.txt
agrep -0 -c 'TCTCGAAAAAGACAGTG' *.fastq > count/B8829_Fm0.txt
agrep -0 -c 'AACAAGTGGGAGGCCCT' *.fastq > count/B8830_Fm0.txt
agrep -0 -c 'CTACTGATTGGAGTTGT' *.fastq > count/B8831_Fm0.txt
agrep -0 -c 'GGCTGGTAGTACCCTTA' *.fastq > count/B8832_Fm0.txt
agrep -0 -c 'TCATCAAACTGTACGGT' *.fastq > count/B8833_Fm0.txt
agrep -0 -c 'AGTCATTAGGTTGCCAG' *.fastq > count/B8834_Fm0.txt
agrep -0 -c 'CTTAAGACTAAGGCTCC' *.fastq > count/B8835_Fm0.txt
agrep -0 -c 'CCAGCGGACGTAGTTGA' *.fastq > count/B8839_Fm0.txt
agrep -0 -c 'ATGCACGCGGTGTTCCT' *.fastq > count/B8840_Fm0.txt
agrep -0 -c 'AGAGGAGCGTAAGCTCG' *.fastq > count/B8841_Fm0.txt
agrep -0 -c 'GATGACTCGGGCTACTG' *.fastq > count/B8842_Fm0.txt
agrep -0 -c 'TTGTGAAAGCGCGGCTA' *.fastq > count/B8843_Fm0.txt
agrep -0 -c 'CAGGGGGCGTGCATTAA' *.fastq > count/B8844_Fm0.txt
agrep -0 -c 'CTTACAAGAGCACGTTG' *.fastq > count/B8845_Fm0.txt
agrep -0 -c 'GTGACGTTATTCGCCTT' *.fastq > count/B8846_Fm0.txt
agrep -0 -c 'GACGACGAGCCGATACT' *.fastq > count/B8848_Fm0.txt
agrep -0 -c 'TGAATGCTCGGCTGATG' *.fastq > count/B8849_Fm0.txt
agrep -0 -c 'CCGATACTGCCCTAATA' *.fastq > count/B8850_Fm0.txt
agrep -0 -c 'AACCCAATACCCACGAT' *.fastq > count/B8851_Fm0.txt
agrep -0 -c 'ACCTGAAGCCCTATTGC' *.fastq > count/B8852_Fm0.txt
agrep -0 -c 'ACTGGCGTCTGGATTTC' *.fastq > count/B8853_Fm0.txt
agrep -0 -c 'GGCGAGATGCCCAACTA' *.fastq > count/B8854_Fm0.txt
agrep -0 -c 'CACGCTTCTGACCCATC' *.fastq > count/B8855_Fm0.txt
agrep -0 -c 'CAGGAACTGCTAGCTAA' *.fastq > count/B8856_Fm0.txt
agrep -0 -c 'ATATCGGATCGATTCCT' *.fastq > count/B8857_Fm0.txt
agrep -0 -c 'AGTATGTCGTCTATCCG' *.fastq > count/B8858_Fm0.txt
agrep -0 -c 'TCAGTTCTAGAGCTCAG' *.fastq > count/B8859_Fm0.txt
agrep -0 -c 'GACCACATTTGCGCGTA' *.fastq > count/B8860_Fm0.txt
agrep -0 -c 'TTAAGGGCTGGACCTCA' *.fastq > count/B8861_Fm0.txt
agrep -0 -c 'CAGCGGCTTCCCATTAT' *.fastq > count/B8862_Fm0.txt
agrep -0 -c 'CGCTCTAAAAAGCACAG' *.fastq > count/B8864_Fm0.txt
agrep -0 -c 'CTAGATGTTTGCCTCCA' *.fastq > count/B8869_Fm0.txt
agrep -0 -c 'TAAACCGGGTTCAAGCC' *.fastq > count/B8870_Fm0.txt
agrep -0 -c 'GTCGTTCGGCTACAATA' *.fastq > count/B8871_Fm0.txt
agrep -0 -c 'TGACGCGGGATCTTTGA' *.fastq > count/B8872_Fm0.txt
agrep -0 -c 'ACACCTGTTTGACACGT' *.fastq > count/B8873_Fm0.txt
agrep -0 -c 'AATTCTATCGACTTGCC' *.fastq > count/B8874_Fm0.txt
agrep -0 -c 'GCGCCGCTCAATTTATC' *.fastq > count/B8875_Fm0.txt
agrep -0 -c 'CAGTTAAATGGCTGAGG' *.fastq > count/B8876_Fm0.txt
agrep -0 -c 'ATCCTTGGGTGTGATAG' *.fastq > count/B8877_Fm0.txt
agrep -0 -c 'CGCAGGGGTAGCCAATA' *.fastq > count/B8878_Fm0.txt
agrep -0 -c 'ATGAAACGAGTCCCAGC' *.fastq > count/B8879_Fm0.txt
agrep -0 -c 'GGATGCCGAGTACTAAC' *.fastq > count/B8880_Fm0.txt
agrep -0 -c 'TACTAGCGCAATGGCTG' *.fastq > count/B8882_Fm0.txt
agrep -0 -c 'CCTTCGTAAGGGACTCT' *.fastq > count/B8883_Fm0.txt
agrep -0 -c 'GCGATTGAGTCAGAGAC' *.fastq > count/B8884_Fm0.txt
agrep -0 -c 'AAGCCCATTTCAAGGGT' *.fastq > count/B8885_Fm0.txt
agrep -0 -c 'GGGCAAGACTTCACAGG' *.fastq > count/B8886_Fm0.txt
agrep -0 -c 'AGCTCATCTTGCGACAA' *.fastq > count/B8887_Fm0.txt
agrep -0 -c 'AATCGAACCGGTATGCA' *.fastq > count/B8888_Fm0.txt
agrep -0 -c 'CCATTCTACAAACACGC' *.fastq > count/B8889_Fm0.txt
agrep -0 -c 'TACGTTCAGACCTTACT' *.fastq > count/B8890_Fm0.txt
agrep -0 -c 'GTGTGGCTGATCGAGTA' *.fastq > count/B8891_Fm0.txt
agrep -0 -c 'TCATATAGGTAACCCCG' *.fastq > count/B8893_Fm0.txt
agrep -0 -c 'CGAGTTTTGCTATACTG' *.fastq > count/B8894_Fm0.txt
agrep -0 -c 'GCCGTTTGTCTCACGCA' *.fastq > count/B8895_Fm0.txt
agrep -0 -c 'CTAAGTCCATATTTCGC' *.fastq > count/B8897_Fm0.txt
agrep -0 -c 'CCTGACCAGGGAATTCG' *.fastq > count/B8898_Fm0.txt
agrep -0 -c 'GGATTCGGAACTTGTAA' *.fastq > count/B8899_Fm0.txt
agrep -0 -c 'TGTACATTTCAAGGGTC' *.fastq > count/B8900_Fm0.txt
agrep -0 -c 'TCATGGTCTATCGTCGG' *.fastq > count/B8901_Fm0.txt
agrep -0 -c 'CAAATGGCGATACTCCT' *.fastq > count/B8902_Fm0.txt
agrep -0 -c 'CCATATTCCCGGGATTA' *.fastq > count/B8903_Fm0.txt
agrep -0 -c 'TAGGGGAGTGCACCCTT' *.fastq > count/B8904_Fm0.txt
agrep -0 -c 'CACACGGCTTTTGCCTG' *.fastq > count/B8905_Fm0.txt
agrep -0 -c 'CCGACACCATATCGCCA' *.fastq > count/B8906_Fm0.txt
agrep -0 -c 'CTCCCACCTACGATATT' *.fastq > count/B8907_Fm0.txt
agrep -0 -c 'ACGTACGCATACCGTGG' *.fastq > count/B8908_Fm0.txt
agrep -0 -c 'TTCCATGCCCTAAATCG' *.fastq > count/B8909_Fm0.txt
agrep -0 -c 'GATTTCACTCGCCACGG' *.fastq > count/B8910_Fm0.txt
agrep -0 -c 'CTCCGAAGTTGCAGTCA' *.fastq > count/B8911_Fm0.txt
agrep -0 -c 'TCTTGTTGGACATTGCC' *.fastq > count/B8912_Fm0.txt
agrep -0 -c 'CTTGTCCTTCCATCCCC' *.fastq > count/B8913_Fm0.txt
agrep -0 -c 'CGGGTTGTATCGAAAAC' *.fastq > count/B8914_Fm0.txt
agrep -0 -c 'TACCAGTGAGTGTACTC' *.fastq > count/B8915_Fm0.txt
agrep -0 -c 'CGCAATACTCCACACCG' *.fastq > count/B8916_Fm0.txt
agrep -0 -c 'TATGCAGTCACGGAGAT' *.fastq > count/B8917_Fm0.txt
agrep -0 -c 'TAAATCTGTGCCGTTTC' *.fastq > count/B8918_Fm0.txt
agrep -0 -c 'CAGTCGTATGCGCTTTC' *.fastq > count/B8919_Fm0.txt
agrep -0 -c 'CCTAACTCGTTATACAG' *.fastq > count/B8920_Fm0.txt
agrep -0 -c 'GCCTAATAACGTGGCTC' *.fastq > count/B8921_Fm0.txt
agrep -0 -c 'GGGTTTGATCGAATGGG' *.fastq > count/B8922_Fm0.txt
agrep -0 -c 'CATTTCTAAAGACGGCA' *.fastq > count/B8923_Fm0.txt
agrep -0 -c 'CAGTCACTTATGCCCGC' *.fastq > count/B8924_Fm0.txt
agrep -0 -c 'AACAACACGCGCTACCG' *.fastq > count/B8925_Fm0.txt
agrep -0 -c 'AATCGAGTGCCACGATA' *.fastq > count/B8926_Fm0.txt
agrep -0 -c 'AACAAGTTAATCACGGG' *.fastq > count/B8927_Fm0.txt
agrep -0 -c 'CTTAGCATTAATCGGCT' *.fastq > count/B8928_Fm0.txt
agrep -0 -c 'TTGTCAGGGGCGAAAAG' *.fastq > count/B8929_Fm0.txt
agrep -0 -c 'AAGGGCATGTTAACCAC' *.fastq > count/B8930_Fm0.txt
agrep -0 -c 'TCTCCGTCTTCCAGATA' *.fastq > count/B8932_Fm0.txt
agrep -0 -c 'CGCTCTGGGAAGTTGGT' *.fastq > count/B8933_Fm0.txt
agrep -0 -c 'TTGACAACCCATGCGTC' *.fastq > count/B8934_Fm0.txt
agrep -0 -c 'CGAAACCCGCTTATGAC' *.fastq > count/B8935_Fm0.txt
agrep -0 -c 'TTGTATCAACTCGGTCT' *.fastq > count/B8938_Fm0.txt
agrep -0 -c 'GTAGCTCAGATAAACCG' *.fastq > count/B8939_Fm0.txt
agrep -0 -c 'CTGAGTCAGTGACGGAA' *.fastq > count/B8940_Fm0.txt
agrep -0 -c 'TCGATTTTAGGTCGCTC' *.fastq > count/B8941_Fm0.txt
agrep -0 -c 'CGTAGGGTCTTTGAGCC' *.fastq > count/B8943_Fm0.txt
agrep -0 -c 'GTGAGCTGTGATCCATT' *.fastq > count/B8944_Fm0.txt
agrep -0 -c 'GGAACACGATCGGTTTG' *.fastq > count/B8945_Fm0.txt
agrep -0 -c 'AGACGGCATATTACGGC' *.fastq > count/B8946_Fm0.txt
agrep -0 -c 'GGCGAGTTCTGTCCTTT' *.fastq > count/B8947_Fm0.txt
agrep -0 -c 'CCGTTTCCTAGACCGTC' *.fastq > count/B8948_Fm0.txt
agrep -0 -c 'TATGCCGTCATACATGT' *.fastq > count/B8949_Fm0.txt
agrep -0 -c 'GCTGCCTTGTTCCTATA' *.fastq > count/B8950_Fm0.txt
agrep -0 -c 'GTGCCGGAACCATTAGG' *.fastq > count/B8951_Fm0.txt
agrep -0 -c 'ACCCCCCTCGCTCAATA' *.fastq > count/B8952_Fm0.txt
agrep -0 -c 'CATCTACTCTGCGCCCA' *.fastq > count/B8953_Fm0.txt
agrep -0 -c 'TATAGCTGAGCCTCAAC' *.fastq > count/B8954_Fm0.txt
agrep -0 -c 'GCAACTATCGTCTTCAC' *.fastq > count/B8956_Fm0.txt
agrep -0 -c 'TTATGTGGTACAGGGCA' *.fastq > count/B8957_Fm0.txt
agrep -0 -c 'CCAGAGAGCGTTTTTGC' *.fastq > count/B8958_Fm0.txt
agrep -0 -c 'TCTCCCTCGTTAAGGCT' *.fastq > count/B8959_Fm0.txt
agrep -0 -c 'AACGCTAGTCGGGACTG' *.fastq > count/B8960_Fm0.txt
agrep -0 -c 'GTAAGTCTAGTGTGATG' *.fastq > count/B8961_Fm0.txt
agrep -0 -c 'GGTAACCAAACGTAAGA' *.fastq > count/B8962_Fm0.txt
agrep -0 -c 'AGGGTGATTAACTCTGT' *.fastq > count/B8963_Fm0.txt
agrep -0 -c 'ATTTGGGTCCTCAGTGA' *.fastq > count/B8964_Fm0.txt
agrep -0 -c 'TGTCTGATTGCGCTATG' *.fastq > count/B8965_Fm0.txt
agrep -0 -c 'CTACTGGTGTGTATCCA' *.fastq > count/B8966_Fm0.txt
agrep -0 -c 'GGTCACCTTATCGGGTG' *.fastq > count/B8967_Fm0.txt
agrep -0 -c 'AGATGCCGCAGTCAAAT' *.fastq > count/B8968_Fm0.txt
agrep -0 -c 'CGTAACTCAGAGAGCTT' *.fastq > count/B8969_Fm0.txt
agrep -0 -c 'TATACGACCCCGTGTTC' *.fastq > count/B8970_Fm0.txt
agrep -0 -c 'CGAGCACACATTGATCA' *.fastq > count/B8971_Fm0.txt
agrep -0 -c 'ACATACGGTTTTCAGGG' *.fastq > count/B8972_Fm0.txt
agrep -0 -c 'CGACGTCTTTTGGCACG' *.fastq > count/B8973_Fm0.txt
agrep -0 -c 'CACACGTAAGCTTGGCG' *.fastq > count/B8974_Fm0.txt
agrep -0 -c 'GTACGGTAGCTCTGATA' *.fastq > count/B8975_Fm0.txt
agrep -0 -c 'GTTTTTGTCTGCGGCCG' *.fastq > count/B8976_Fm0.txt
agrep -0 -c 'AGTCGATCCCGTAGTAG' *.fastq > count/B8977_Fm0.txt
agrep -0 -c 'GGGCGTGTGTGATAAAC' *.fastq > count/B8978_Fm0.txt
agrep -0 -c 'TCTAGCTTAGGGAAGCG' *.fastq > count/B8979_Fm0.txt
agrep -0 -c 'ATCTAAGGGTCAACCCA' *.fastq > count/B8980_Fm0.txt
agrep -0 -c 'TGAATAGGGGCGATTGG' *.fastq > count/B8981_Fm0.txt
agrep -0 -c 'GCTTACTTCGATCTAGT' *.fastq > count/B8982_Fm0.txt
agrep -0 -c 'GACTGCTGACAGAGTTG' *.fastq > count/B8983_Fm0.txt
agrep -0 -c 'TGGCACGTTTAACAGAG' *.fastq > count/B8984_Fm0.txt
agrep -0 -c 'ACTCTTACCGATGCAGA' *.fastq > count/B8985_Fm0.txt
agrep -0 -c 'TAGATGTGTACCTGGAT' *.fastq > count/B8986_Fm0.txt
agrep -0 -c 'CGTGGTTATGTGGGCCA' *.fastq > count/B8987_Fm0.txt
agrep -0 -c 'GGGTCGGAACTCGCATT' *.fastq > count/B8988_Fm0.txt
agrep -0 -c 'GATGGTGATGCGTAGGA' *.fastq > count/B8989_Fm0.txt
agrep -0 -c 'TCACAATGTTTGGCCGT' *.fastq > count/B8992_Fm0.txt
agrep -0 -c 'ATGACACAAACCGGAAC' *.fastq > count/B8993_Fm0.txt
agrep -0 -c 'AGTCACTCAGTCAGGCG' *.fastq > count/B8994_Fm0.txt
agrep -0 -c 'CCTTAGCTGGTATTGGA' *.fastq > count/B8995_Fm0.txt
agrep -0 -c 'AGCGTACGTACTAAGTG' *.fastq > count/B8996_Fm0.txt
agrep -0 -c 'TCTTAGGTGGAGGCGAT' *.fastq > count/B8997_Fm0.txt
agrep -0 -c 'AGACCATGCTAGGCAGG' *.fastq > count/B8998_Fm0.txt
agrep -0 -c 'AAGTTCGTTTCGCGGTA' *.fastq > count/B9000_Fm0.txt
agrep -0 -c 'CAAACCGCACACAGTTC' *.fastq > count/B9001_Fm0.txt
agrep -0 -c 'TACTCAGTTAGTGAGGA' *.fastq > count/B9002_Fm0.txt
agrep -0 -c 'ACCCGACCCATAAAACC' *.fastq > count/B9003_Fm0.txt
agrep -0 -c 'CGTGGGGTATTCGGATT' *.fastq > count/B9004_Fm0.txt
agrep -0 -c 'GGACAGGAGGGTGATAT' *.fastq > count/B9005_Fm0.txt
agrep -0 -c 'GCATCTGTCCACACGTT' *.fastq > count/B9006_Fm0.txt
agrep -0 -c 'AAGCGTGATGTAACCTA' *.fastq > count/B9007_Fm0.txt
agrep -0 -c 'CCATACCACCAGTCTTG' *.fastq > count/B9009_Fm0.txt
agrep -0 -c 'TCATCGCATCCGGATAG' *.fastq > count/B9010_Fm0.txt
agrep -0 -c 'TATCGACCGCGTTGTAA' *.fastq > count/B9011_Fm0.txt
agrep -0 -c 'CGTGAACGCTGATCTCA' *.fastq > count/B9012_Fm0.txt
agrep -0 -c 'TATTCAAGGGCTTACGT' *.fastq > count/B9014_Fm0.txt
agrep -0 -c 'CGATCAATCTATCGCGC' *.fastq > count/B9015_Fm0.txt
agrep -0 -c 'CTTGGCGTACACCTTGA' *.fastq > count/B9016_Fm0.txt
agrep -0 -c 'CGCCACTGTCTAGAGAG' *.fastq > count/B9017_Fm0.txt
agrep -0 -c 'TCATTCACAAGACGCAA' *.fastq > count/B9019_Fm0.txt
agrep -0 -c 'GTAGTTGGCTAAGGCGT' *.fastq > count/B9020_Fm0.txt
agrep -0 -c 'ACCAATCCTATGTCTCT' *.fastq > count/B9022_Fm0.txt
agrep -0 -c 'GGTCACCTACTTTGTTA' *.fastq > count/B9023_Fm0.txt
agrep -0 -c 'CCTATCCGTTCAAAGCA' *.fastq > count/B9024_Fm0.txt
agrep -0 -c 'AGGTGGGAAGCGTTAGA' *.fastq > count/B9025_Fm0.txt
agrep -0 -c 'ACGTCTGACTATTGTAG' *.fastq > count/B9026_Fm0.txt
agrep -0 -c 'CTCCAGAGGTAACGCAC' *.fastq > count/B9028_Fm0.txt
agrep -0 -c 'TACTAGACTCGTTAAGC' *.fastq > count/B9029_Fm0.txt
agrep -0 -c 'GTGATCCGCTTAGAGCC' *.fastq > count/B9030_Fm0.txt
agrep -0 -c 'CATACGCGCCCAAAACG' *.fastq > count/B9031_Fm0.txt
agrep -0 -c 'CGTGGAATGGAATATCA' *.fastq > count/B9032_Fm0.txt
agrep -0 -c 'GAGGATGGTCAAACGTT' *.fastq > count/B9033_Fm0.txt
agrep -0 -c 'CTCTCTAGGGCAAGGAG' *.fastq > count/B9034_Fm0.txt
agrep -0 -c 'TGGCTGAGTCGGCTAAG' *.fastq > count/B9035_Fm0.txt
agrep -0 -c 'GACAACCGACAGCTCGA' *.fastq > count/B9036_Fm0.txt
agrep -0 -c 'CAAACGTGAAGTCCCCC' *.fastq > count/B9037_Fm0.txt
agrep -0 -c 'CACGTATCCTTGCGGGA' *.fastq > count/B9039_Fm0.txt
agrep -0 -c 'AAGAGGCGGAGATCATG' *.fastq > count/B9040_Fm0.txt
agrep -0 -c 'TAGCCCGCTTGTTTGTG' *.fastq > count/B9041_Fm0.txt
agrep -0 -c 'ACAGGTCGACGAATCGG' *.fastq > count/B9042_Fm0.txt
agrep -0 -c 'CATTGATGCTTCCTCGA' *.fastq > count/B9043_Fm0.txt
agrep -0 -c 'TCTGAGTAAGCGCGACC' *.fastq > count/B9044_Fm0.txt
agrep -0 -c 'TCGATTGGAGCACGACA' *.fastq > count/B9045_Fm0.txt
agrep -0 -c 'TAATTACATTCCCGGGG' *.fastq > count/B9047_Fm0.txt
agrep -0 -c 'GCACCCCTATTCATACT' *.fastq > count/B9048_Fm0.txt
agrep -0 -c 'AATCTTCAGTAGGCCAT' *.fastq > count/B9049_Fm0.txt
agrep -0 -c 'GTACGAATGGAGCCGTT' *.fastq > count/B9050_Fm0.txt
agrep -0 -c 'CGCGGACTTTAGTAGAT' *.fastq > count/B9051_Fm0.txt
agrep -0 -c 'GTACAGATTTCGGACAT' *.fastq > count/B9052_Fm0.txt
agrep -0 -c 'ATGCCCCACAACAAGGT' *.fastq > count/B9053_Fm0.txt
agrep -0 -c 'CATATCTTGTAGTGCAC' *.fastq > count/B9056_Fm0.txt
agrep -0 -c 'CTATCTGTGGGTCTACT' *.fastq > count/B9058_Fm0.txt
agrep -0 -c 'CACCAATTTGGCTCGCA' *.fastq > count/B9059_Fm0.txt
agrep -0 -c 'GCTCATTAGCGCGTGGT' *.fastq > count/B9060_Fm0.txt
agrep -0 -c 'TGTCTGTCGTTATTCCG' *.fastq > count/B9061_Fm0.txt
agrep -0 -c 'TGCTGATACGCCCTGAG' *.fastq > count/B9062_Fm0.txt
agrep -0 -c 'TGTCGCTCTATATGAGA' *.fastq > count/B9063_Fm0.txt
agrep -0 -c 'ATTTGCGGGACCACCAA' *.fastq > count/B9064_Fm0.txt
agrep -0 -c 'ACCGACACTACAGGTAG' *.fastq > count/B9065_Fm0.txt
agrep -0 -c 'CACGTAACCAGAGAAAG' *.fastq > count/B9066_Fm0.txt
agrep -0 -c 'GGAACGTAATCGTCATG' *.fastq > count/B9067_Fm0.txt
agrep -0 -c 'CGGGAACAGCTAATGAG' *.fastq > count/B9068_Fm0.txt
agrep -0 -c 'AAGGAAGTAGGTCGAAC' *.fastq > count/B9069_Fm0.txt
agrep -0 -c 'CGTGGATCGTCTGCTAG' *.fastq > count/B9070_Fm0.txt
agrep -0 -c 'GGCGTTCACTGGACGTT' *.fastq > count/B9072_Fm0.txt
agrep -0 -c 'CGTCTCCTAGCTTTTCG' *.fastq > count/B9073_Fm0.txt
agrep -0 -c 'ACTCTAAGCGTGTCTGA' *.fastq > count/B9074_Fm0.txt
agrep -0 -c 'ACCGCTATGACGTTGCT' *.fastq > count/B9077_Fm0.txt
agrep -0 -c 'AGTAATCCTAGCGCGGA' *.fastq > count/B9078_Fm0.txt
agrep -0 -c 'CGCCGGTCTTATGCATA' *.fastq > count/B9079_Fm0.txt
agrep -0 -c 'CTGCAACGCCGTTATGA' *.fastq > count/B9080_Fm0.txt
agrep -0 -c 'GCGGTCAACCGGTACTA' *.fastq > count/B9081_Fm0.txt
agrep -0 -c 'CAGGTTTACGTTGTGCG' *.fastq > count/B9082_Fm0.txt
agrep -0 -c 'TTAACAGCTTGCAAGGG' *.fastq > count/B9083_Fm0.txt
agrep -0 -c 'TATACGCGACATGTACG' *.fastq > count/B9084_Fm0.txt
agrep -0 -c 'ATACGAAACAGGGAATC' *.fastq > count/B9085_Fm0.txt
agrep -0 -c 'AACGGTAACCCTACTTA' *.fastq > count/B9086_Fm0.txt
agrep -0 -c 'ACGGGTGAAGGTGAAAG' *.fastq > count/B9088_Fm0.txt
agrep -0 -c 'GGGGGAACAGAACTAGT' *.fastq > count/B9089_Fm0.txt
agrep -0 -c 'GTAGGTGGTACGTCTGA' *.fastq > count/B9090_Fm0.txt
agrep -0 -c 'ATTGCATTTGCTCTTCG' *.fastq > count/B9091_Fm0.txt
agrep -0 -c 'TTCGGAGGGAACCGACA' *.fastq > count/B9092_Fm0.txt
agrep -0 -c 'GTATAGTCTGGGTTAGC' *.fastq > count/B9093_Fm0.txt
agrep -0 -c 'ATGATTCCTCTACGTCT' *.fastq > count/B9094_Fm0.txt
agrep -0 -c 'CTCGGCACCTTGATGGT' *.fastq > count/B9096_Fm0.txt
agrep -0 -c 'ATATTGCCGAACGGCGC' *.fastq > count/B9097_Fm0.txt
agrep -0 -c 'TATAGTTCTCGAGGCTG' *.fastq > count/B9099_Fm0.txt
agrep -0 -c 'GGTCAAACTTATGGCCG' *.fastq > count/B9102_Fm0.txt
agrep -0 -c 'ATAAACAGCGGGACACC' *.fastq > count/B9103_Fm0.txt
agrep -0 -c 'TCTTGACAACTTGGTCC' *.fastq > count/B9105_Fm0.txt
agrep -0 -c 'CCTCGCCAACAAATAAG' *.fastq > count/B9106_Fm0.txt
agrep -0 -c 'GTAGATTCCGCCGGTTG' *.fastq > count/B9107_Fm0.txt
agrep -0 -c 'AGCCTAGGTCGATATGA' *.fastq > count/B9108_Fm0.txt
agrep -0 -c 'GTTTCCTCGTTTGCGTG' *.fastq > count/B9109_Fm0.txt
agrep -0 -c 'CCAGGACTTGCTAACCC' *.fastq > count/B9110_Fm0.txt
agrep -0 -c 'TTGAGCTGCCTTAGGGA' *.fastq > count/B9111_Fm0.txt
agrep -0 -c 'AAGTTGTCGCCGACACC' *.fastq > count/B9112_Fm0.txt
agrep -0 -c 'GATTTCGTACTGTGCAA' *.fastq > count/B9113_Fm0.txt
agrep -0 -c 'TCTCGATACATGGCGTT' *.fastq > count/B9114_Fm0.txt
agrep -0 -c 'CTTGGTGGGATGTGGCT' *.fastq > count/B9116_Fm0.txt
agrep -0 -c 'TCGAACACGACCATGGA' *.fastq > count/B9117_Fm0.txt
agrep -0 -c 'ACGCACAGTATCAACTT' *.fastq > count/B9118_Fm0.txt
agrep -0 -c 'GCAAAACCAACCCCATG' *.fastq > count/B9119_Fm0.txt
agrep -0 -c 'CTGTTGTGCCATTAGAT' *.fastq > count/B9120_Fm0.txt
agrep -0 -c 'TTCGTATGGTGTGCGTT' *.fastq > count/B9121_Fm0.txt
agrep -0 -c 'CAGTCCACATTGCCCTA' *.fastq > count/B9122_Fm0.txt
agrep -0 -c 'GATGTCACCTTTTGCTC' *.fastq > count/B9123_Fm0.txt
agrep -0 -c 'ATGTACCTTCGGACACG' *.fastq > count/B9124_Fm0.txt
agrep -0 -c 'TATCGCGCCTAGGCCAT' *.fastq > count/B9125_Fm0.txt
agrep -0 -c 'AAGCGTAGGACCCTGTC' *.fastq > count/B9126_Fm0.txt
agrep -0 -c 'GCTATAGAGACATGGGC' *.fastq > count/B9127_Fm0.txt
agrep -0 -c 'GCAAAGCCGGGTTTCAA' *.fastq > count/B9128_Fm0.txt
agrep -0 -c 'AGCGTCAGTTACACCCT' *.fastq > count/B9129_Fm0.txt
agrep -0 -c 'AAGCATTCGGATCTGTC' *.fastq > count/B9131_Fm0.txt
agrep -0 -c 'CCTTCGTTCATTGCGGT' *.fastq > count/B9132_Fm0.txt
agrep -0 -c 'GGATACGACACAATTAG' *.fastq > count/B9134_Fm0.txt
agrep -0 -c 'TATGGACAGGACATCTT' *.fastq > count/B9135_Fm0.txt
agrep -0 -c 'ATTCTGTTCTGAGATGG' *.fastq > count/B9137_Fm0.txt
agrep -0 -c 'CTGCCAAACCGCAAGGA' *.fastq > count/B9138_Fm0.txt
agrep -0 -c 'TGCTGCAGAAAGTCACG' *.fastq > count/B9139_Fm0.txt
agrep -0 -c 'AGACAGTCCGTAGAACC' *.fastq > count/B9140_Fm0.txt
agrep -0 -c 'AGCCCGAGTTGTCTTGT' *.fastq > count/B9141_Fm0.txt
agrep -0 -c 'GTCAAGCGGTTTCGAAG' *.fastq > count/B9142_Fm0.txt
agrep -0 -c 'ACTGGTGGCTAACGGAT' *.fastq > count/B9144_Fm0.txt
agrep -0 -c 'ACTGTAACATGTCGACG' *.fastq > count/B9145_Fm0.txt
agrep -0 -c 'ACTTCATCCGGGAAGGA' *.fastq > count/B9146_Fm0.txt
agrep -0 -c 'AGTAAACTGCCGGCCAG' *.fastq > count/B9147_Fm0.txt
agrep -0 -c 'AAGCCCGTCAGAACATT' *.fastq > count/B9148_Fm0.txt
agrep -0 -c 'CATCAGACATCTGGGGA' *.fastq > count/B9149_Fm0.txt
agrep -0 -c 'ACCCCCACACGTTCTTA' *.fastq > count/B9150_Fm0.txt
agrep -0 -c 'TTGTGGATGTAGCTACC' *.fastq > count/B9151_Fm0.txt
agrep -0 -c 'CTCTTTACTAGTCGGGC' *.fastq > count/B9152_Fm0.txt
agrep -0 -c 'GCACGGTCAGATGCCTT' *.fastq > count/B9153_Fm0.txt
agrep -0 -c 'CGAAAGGAACGACTTAA' *.fastq > count/B9154_Fm0.txt
agrep -0 -c 'GGCTTGGTCAGTGTATC' *.fastq > count/B9156_Fm0.txt
agrep -0 -c 'GATTTGTTGGCGTAGTT' *.fastq > count/B9157_Fm0.txt
agrep -0 -c 'GTGTATTGTCTTCTGTC' *.fastq > count/B9159_Fm0.txt
agrep -0 -c 'ATGCAGGACTTAGTCGG' *.fastq > count/B9160_Fm0.txt
agrep -0 -c 'GGTTAGATGGATCTACC' *.fastq > count/B9161_Fm0.txt
agrep -0 -c 'GTTTATGCAACGAAGTC' *.fastq > count/B9162_Fm0.txt
agrep -0 -c 'TACGCCCTAATTGCTCT' *.fastq > count/B9163_Fm0.txt
agrep -0 -c 'GGGTTGTATCCGCCCTT' *.fastq > count/B9165_Fm0.txt
agrep -0 -c 'AGCTGTTAGTCGACCTT' *.fastq > count/B9166_Fm0.txt
agrep -0 -c 'AGGTTCTGTACTGGTGC' *.fastq > count/B9167_Fm0.txt
agrep -0 -c 'GGTCGAACACTACTATG' *.fastq > count/B9168_Fm0.txt
agrep -0 -c 'TAAGGCTATCAACCACC' *.fastq > count/B9169_Fm0.txt
agrep -0 -c 'TACCGGAGGCTTTATAG' *.fastq > count/B9170_Fm0.txt
agrep -0 -c 'TACGGTGAAACGTCCGA' *.fastq > count/B9171_Fm0.txt
agrep -0 -c 'ACTAACCCGACTGAAAC' *.fastq > count/B9172_Fm0.txt
agrep -0 -c 'AATCTACTGTGGGCGCT' *.fastq > count/B9173_Fm0.txt
agrep -0 -c 'CCTCATAGGACCTGCGT' *.fastq > count/B9174_Fm0.txt
agrep -0 -c 'ACGTATTGACCAAAGGG' *.fastq > count/B9176_Fm0.txt
agrep -0 -c 'TAGCGGTATGAGGAGTC' *.fastq > count/B9177_Fm0.txt
agrep -0 -c 'TTAGTACTACCCTAGGT' *.fastq > count/B9178_Fm0.txt
agrep -0 -c 'GATAATACGCCAGCTCT' *.fastq > count/B9179_Fm0.txt
agrep -0 -c 'CACTTTTGGGTTTGAGA' *.fastq > count/B9180_Fm0.txt
agrep -0 -c 'GCAACTAGAAAAAACGC' *.fastq > count/B9181_Fm0.txt
agrep -0 -c 'CGTCTTCCGATAGTGAA' *.fastq > count/B9183_Fm0.txt
agrep -0 -c 'ATCACAGCTTACGGCGT' *.fastq > count/B9184_Fm0.txt
agrep -0 -c 'AGTCTGTCAAACAACTG' *.fastq > count/B9186_Fm0.txt
agrep -0 -c 'TCACTCAAAAAGTGCCA' *.fastq > count/B9187_Fm0.txt
agrep -0 -c 'GTAACTGAAGGATACGC' *.fastq > count/B9188_Fm0.txt
agrep -0 -c 'TTAGCAGCGGTGTTCGG' *.fastq > count/B9190_Fm0.txt
agrep -0 -c 'ACGACCGGCTCAGAGAT' *.fastq > count/B9191_Fm0.txt
agrep -0 -c 'CGCGCCCAGGCTTTATT' *.fastq > count/B9194_Fm0.txt
agrep -0 -c 'ATGCGTCGATAGCGCGT' *.fastq > count/B9196_Fm0.txt
agrep -0 -c 'CGGATACAACTGCAATA' *.fastq > count/B9197_Fm0.txt
agrep -0 -c 'TACTGATGTAGCAGGAC' *.fastq > count/B9199_Fm0.txt
agrep -0 -c 'CAAGTCTCGAGAATGCG' *.fastq > count/B9200_Fm0.txt
agrep -0 -c 'CTCTTAGGACCCGGTCT' *.fastq > count/B9201_Fm0.txt
agrep -0 -c 'CATCGTAGGTCCGGAGT' *.fastq > count/B9202_Fm0.txt
agrep -0 -c 'AGGGCTATGACAGCAAT' *.fastq > count/B9203_Fm0.txt
agrep -0 -c 'TCAGCGTGCAGGTTCAA' *.fastq > count/B9204_Fm0.txt
agrep -0 -c 'CACCCGACGTTAATCTA' *.fastq > count/B9205_Fm0.txt
agrep -0 -c 'GTACCGGATTGTTATAC' *.fastq > count/B9206_Fm0.txt
agrep -0 -c 'AGAACTATGGGAGGCGG' *.fastq > count/B9207_Fm0.txt
agrep -0 -c 'GTGTCCGCGAAATCTGA' *.fastq > count/B9208_Fm0.txt
agrep -0 -c 'GGTTGATCCATATCCAG' *.fastq > count/B9209_Fm0.txt
agrep -0 -c 'CGCACACAGTCTGACCT' *.fastq > count/B9210_Fm0.txt
agrep -0 -c 'GCGCTCTAGGTAGCCTA' *.fastq > count/B9212_Fm0.txt
agrep -0 -c 'GGTTCTAAAGCCAGAAG' *.fastq > count/B9213_Fm0.txt
agrep -0 -c 'TTCTCGCTCGGTGGATG' *.fastq > count/B9214_Fm0.txt
agrep -0 -c 'TGCTGTGACGTAGACCC' *.fastq > count/B9216_Fm0.txt
agrep -0 -c 'GCCCTATTAAGGCAAAA' *.fastq > count/B9217_Fm0.txt
agrep -0 -c 'AGACCGGACGCTAAGAG' *.fastq > count/B9218_Fm0.txt
agrep -0 -c 'ACCATTATGATTGCAGG' *.fastq > count/B9219_Fm0.txt
agrep -0 -c 'TTCTGACGGCCAGGTGA' *.fastq > count/B9220_Fm0.txt
agrep -0 -c 'TTGTGTAAAGTCCGGCC' *.fastq > count/B9221_Fm0.txt
agrep -0 -c 'GTGCGTAATTTCTTCCG' *.fastq > count/B9223_Fm0.txt
agrep -0 -c 'AGGTCGAGAGCACTATC' *.fastq > count/B9225_Fm0.txt
agrep -0 -c 'ATTAGTGCGGAGACCGC' *.fastq > count/B9227_Fm0.txt
agrep -0 -c 'CGTAGAACACGGTGAAC' *.fastq > count/B9228_Fm0.txt
agrep -0 -c 'GACCAGGATACTGAACT' *.fastq > count/B9229_Fm0.txt
agrep -0 -c 'ATGTTAGCTGTGTTGCC' *.fastq > count/B9230_Fm0.txt
agrep -0 -c 'TGCAACAAACAGCCGAC' *.fastq > count/B9231_Fm0.txt
agrep -0 -c 'AGCAAGGCCTAAATGCC' *.fastq > count/B9233_Fm0.txt
agrep -0 -c 'CCTTCCTCTGTACTGAT' *.fastq > count/B9234_Fm0.txt
agrep -0 -c 'TGGCCACCGTGAAACTC' *.fastq > count/B9235_Fm0.txt
agrep -0 -c 'ACGGGTACTTCCGCAAG' *.fastq > count/B9236_Fm0.txt
agrep -0 -c 'TTGCAGGAGACACCCAC' *.fastq > count/B9237_Fm0.txt
agrep -0 -c 'TATTATGTGGGTAGTGC' *.fastq > count/B9238_Fm0.txt
agrep -0 -c 'ATTCTATGGGGCACGAT' *.fastq > count/B9239_Fm0.txt
agrep -0 -c 'CGGTGAACGTCTTAAAA' *.fastq > count/B9240_Fm0.txt
agrep -0 -c 'CAAAAGCACCCAGCGTC' *.fastq > count/B9241_Fm0.txt
agrep -0 -c 'CGCAGTACGTGGTCCAA' *.fastq > count/B9242_Fm0.txt
agrep -0 -c 'TATCGGTGGTACCCACT' *.fastq > count/B9244_Fm0.txt
agrep -0 -c 'GATCAGCCATCACAATT' *.fastq > count/B9246_Fm0.txt
agrep -0 -c 'CGAACGCCGATTAAGAC' *.fastq > count/B9247_Fm0.txt
agrep -0 -c 'AGGTATATAGACTGCAC' *.fastq > count/B9248_Fm0.txt
agrep -0 -c 'GGCCGTTGGAATGAGTG' *.fastq > count/B9249_Fm0.txt
agrep -0 -c 'ACGAAATGAACGAAAGC' *.fastq > count/B9250_Fm0.txt
agrep -0 -c 'AACTATCCGGTCTGGCT' *.fastq > count/B9251_Fm0.txt
agrep -0 -c 'CTAATCTACCACGGACC' *.fastq > count/B9252_Fm0.txt
agrep -0 -c 'CATATCTGAGGCATGGG' *.fastq > count/B9253_Fm0.txt
agrep -0 -c 'GTCATTGGCGGGACACT' *.fastq > count/B9254_Fm0.txt
agrep -0 -c 'GTGTCCGGCTAAACAAG' *.fastq > count/B9255_Fm0.txt
agrep -0 -c 'TCGACGACCGTTGCAAC' *.fastq > count/B9256_Fm0.txt
agrep -0 -c 'AATAAGGCAGGTCCCAG' *.fastq > count/B9257_Fm0.txt
agrep -0 -c 'CCAAGCCAGGGCACTTA' *.fastq > count/B9258_Fm0.txt
agrep -0 -c 'TATACGACAGGCAGGGG' *.fastq > count/B9260_Fm0.txt
agrep -0 -c 'GCCTCATGAGTCTGCTG' *.fastq > count/B9261_Fm0.txt
agrep -0 -c 'GTTTTTTCGCTCCAACA' *.fastq > count/B9262_Fm0.txt
agrep -0 -c 'CTTCCTTCTCCGCTGAT' *.fastq > count/B9263_Fm0.txt
agrep -0 -c 'TACAAACATGGAAGGTG' *.fastq > count/B9265_Fm0.txt
agrep -0 -c 'TATCGGCATAGACCTCT' *.fastq > count/B9266_Fm0.txt
agrep -0 -c 'ACGCTCCAAGGCACGAT' *.fastq > count/B9267_Fm0.txt
agrep -0 -c 'AATACCACTTCAGGCAC' *.fastq > count/B9268_Fm0.txt
agrep -0 -c 'GTGGCGGACGTTTTACA' *.fastq > count/B9269_Fm0.txt
agrep -0 -c 'AGCAATCTCGTTTTCGG' *.fastq > count/B9271_Fm0.txt
agrep -0 -c 'GAGTTTTGTTCCCGACT' *.fastq > count/B9272_Fm0.txt
agrep -0 -c 'ACCTCTGACGCTCAACC' *.fastq > count/B9273_Fm0.txt
agrep -0 -c 'CGGATTACTGCGGAGAA' *.fastq > count/B9274_Fm0.txt
agrep -0 -c 'CGTTATTTACGTGAGCG' *.fastq > count/B9275_Fm0.txt
agrep -0 -c 'TACTGCGCACATCAGGT' *.fastq > count/B9276_Fm0.txt
agrep -0 -c 'ACTATCGCACAATCCTT' *.fastq > count/B9277_Fm0.txt
agrep -0 -c 'GACTAGGTTTGGCGGGA' *.fastq > count/B9278_Fm0.txt
agrep -0 -c 'CAGATCGATCATCGCAC' *.fastq > count/B9281_Fm0.txt
agrep -0 -c 'TCACGCGCAGTCTACTT' *.fastq > count/B9282_Fm0.txt
agrep -0 -c 'GGATCCTCTTATAGGTC' *.fastq > count/B9283_Fm0.txt
agrep -0 -c 'GCCGACTACCTGAGTAA' *.fastq > count/B9284_Fm0.txt
agrep -0 -c 'GTCACGAAGTTTGCATA' *.fastq > count/B9285_Fm0.txt
agrep -0 -c 'CGTAACCACCTAAGTCG' *.fastq > count/B9286_Fm0.txt
agrep -0 -c 'AGACGCGGTAGATATGT' *.fastq > count/B9287_Fm0.txt
agrep -0 -c 'CGGACATGCGTGGCTTT' *.fastq > count/B9288_Fm0.txt
agrep -0 -c 'CGACTGACCTAAATTGC' *.fastq > count/B9289_Fm0.txt
agrep -0 -c 'AATGGACGCCTTTCCGA' *.fastq > count/B9290_Fm0.txt
agrep -0 -c 'CCGATTGTAACCGGATA' *.fastq > count/B9291_Fm0.txt
agrep -0 -c 'TCTACTTGGAGCGTACT' *.fastq > count/B9292_Fm0.txt
agrep -0 -c 'CAGCGTATCCAATAGGT' *.fastq > count/B9293_Fm0.txt
agrep -0 -c 'GAGCATAAATTGGCCGT' *.fastq > count/B9294_Fm0.txt
agrep -0 -c 'CATGGACCTGTGTCGTA' *.fastq > count/B9297_Fm0.txt
agrep -0 -c 'CTAGCGTCAACGATATT' *.fastq > count/B9298_Fm0.txt
agrep -0 -c 'GTCATGCGCTACGCGTT' *.fastq > count/B9300_Fm0.txt
agrep -0 -c 'GCGCTGATTACAGAGGG' *.fastq > count/B9301_Fm0.txt
agrep -0 -c 'CATCACATTCGCCTCTG' *.fastq > count/B9302_Fm0.txt
agrep -0 -c 'CTCTCTCCGCATTTTGT' *.fastq > count/B9303_Fm0.txt
agrep -0 -c 'GGGCATAGAACAGCGAG' *.fastq > count/B9304_Fm0.txt
agrep -0 -c 'AGAGCAGTTCGATGGAC' *.fastq > count/B9305_Fm0.txt
agrep -0 -c 'AGTTCAGCGGTATCATT' *.fastq > count/B9307_Fm0.txt
agrep -0 -c 'GATATAGACGCAGCGTG' *.fastq > count/B9308_Fm0.txt
agrep -0 -c 'CGCGACTAATAATGCAA' *.fastq > count/B9309_Fm0.txt
agrep -0 -c 'GTAAGTGTGCGGAACTC' *.fastq > count/B9310_Fm0.txt
agrep -0 -c 'GGTTCGGTTACCACACC' *.fastq > count/B9311_Fm0.txt
agrep -0 -c 'CACTAAGCGTTCGTCGC' *.fastq > count/B9312_Fm0.txt
agrep -0 -c 'AGAAAACCATGATGGTG' *.fastq > count/B9314_Fm0.txt
agrep -0 -c 'GCGATAGTGCCTCAGAT' *.fastq > count/B9315_Fm0.txt
agrep -0 -c 'AGTACACTTACCACGCT' *.fastq > count/B9316_Fm0.txt
agrep -0 -c 'CGTAGTCTCCCCTAAGA' *.fastq > count/B9318_Fm0.txt
agrep -0 -c 'ACGCCAGTATAGCCCGA' *.fastq > count/B9319_Fm0.txt
agrep -0 -c 'GGGCTAGAATACCCATA' *.fastq > count/B9320_Fm0.txt
agrep -0 -c 'ACCCGGAGAGATAAGAC' *.fastq > count/B9322_Fm0.txt
agrep -0 -c 'CTAATCGAAAAGGCCAA' *.fastq > count/B9323_Fm0.txt
agrep -0 -c 'AATCAATTGGCGTTCCG' *.fastq > count/B9324_Fm0.txt
agrep -0 -c 'GTCACATAGTGGAGTTA' *.fastq > count/B9326_Fm0.txt
agrep -0 -c 'GTAACGGAACAGAACGT' *.fastq > count/B9327_Fm0.txt
agrep -0 -c 'GAGCATTGTCCCAGACG' *.fastq > count/B9329_Fm0.txt
agrep -0 -c 'CCAGAAACTTCTGATGA' *.fastq > count/B9330_Fm0.txt
agrep -0 -c 'ATCTTGGTAGCCGCAGA' *.fastq > count/B9331_Fm0.txt
agrep -0 -c 'GACGATACGCAATACCC' *.fastq > count/B9332_Fm0.txt
agrep -0 -c 'AGGGTTGTACCGCGACA' *.fastq > count/B9333_Fm0.txt
agrep -0 -c 'TCGTTGCTTCGTGCAGA' *.fastq > count/B9334_Fm0.txt
agrep -0 -c 'GCCCAATATATAGCACT' *.fastq > count/B9335_Fm0.txt
agrep -0 -c 'TGAAGCATGCCTAGCGA' *.fastq > count/B9336_Fm0.txt
agrep -0 -c 'ATAGAAAGGGGTGCTGA' *.fastq > count/B9339_Fm0.txt
agrep -0 -c 'CAGAGCCGCACGTAAAC' *.fastq > count/B9340_Fm0.txt
agrep -0 -c 'CGTAACTGCACCCAGCT' *.fastq > count/B9342_Fm0.txt
agrep -0 -c 'TAGAGCTGGATATCCTC' *.fastq > count/B9344_Fm0.txt
agrep -0 -c 'AGACGCTGATAAGCACG' *.fastq > count/B9345_Fm0.txt
agrep -0 -c 'CAATGGTTTCACGGCAC' *.fastq > count/B9347_Fm0.txt
agrep -0 -c 'GTGCACCACAGATATAA' *.fastq > count/B9348_Fm0.txt
agrep -0 -c 'ATTGGTAAGCCGTTGGG' *.fastq > count/B9350_Fm0.txt
agrep -0 -c 'ACTTTCGTGACAAGATC' *.fastq > count/B9351_Fm0.txt
agrep -0 -c 'CGCATAGGAAGTGATTG' *.fastq > count/B9352_Fm0.txt
agrep -0 -c 'TAACCTTCCTGTCTCTT' *.fastq > count/B9353_Fm0.txt
agrep -0 -c 'ATAATCTCCACGCACGA' *.fastq > count/B9354_Fm0.txt
agrep -0 -c 'GTTAGAGCCGCCGAAGT' *.fastq > count/B9355_Fm0.txt
agrep -0 -c 'TAGGGTGTAAGGGTTGT' *.fastq > count/B9357_Fm0.txt
agrep -0 -c 'GTCCAAGTGAAGCTCCG' *.fastq > count/B9359_Fm0.txt
agrep -0 -c 'TAGGCGGTGGAATTTAG' *.fastq > count/B9361_Fm0.txt
agrep -0 -c 'GCATATAGACACGTCAT' *.fastq > count/B9362_Fm0.txt
agrep -0 -c 'AATCAAGGCTCCCCGAA' *.fastq > count/B9363_Fm0.txt
agrep -0 -c 'GGGACCAACGTACTATG' *.fastq > count/B9365_Fm0.txt
agrep -0 -c 'TGTAAGCAACTAGTGTC' *.fastq > count/B9367_Fm0.txt
agrep -0 -c 'TTAGGGCATACGACTAG' *.fastq > count/B9369_Fm0.txt
agrep -0 -c 'AGGCGACTGGTTTACAG' *.fastq > count/B9370_Fm0.txt
agrep -0 -c 'GCCGATAGTCTTAGCGT' *.fastq > count/B9371_Fm0.txt
agrep -0 -c 'CAATTTCGTGGGGGAAT' *.fastq > count/B9372_Fm0.txt
agrep -0 -c 'CCTTGATAAGTCGGTTA' *.fastq > count/B9373_Fm0.txt
agrep -0 -c 'CTATTGGCATGTGGGGA' *.fastq > count/B9375_Fm0.txt
agrep -0 -c 'ATCCAGCCTAGCACACT' *.fastq > count/B9376_Fm0.txt
agrep -0 -c 'GATTACCATAACACACG' *.fastq > count/B9377_Fm0.txt
agrep -0 -c 'CAGCCGTCAATACCTTC' *.fastq > count/B9379_Fm0.txt
agrep -0 -c 'AGCAGCACACGCACTCT' *.fastq > count/B9380_Fm0.txt
agrep -0 -c 'GTGGGAGGGTTTAGGAT' *.fastq > count/B9381_Fm0.txt
agrep -0 -c 'GTGTAACCAGTTGACAG' *.fastq > count/B9382_Fm0.txt
agrep -0 -c 'CAAGGCCAACTTGCAGA' *.fastq > count/B9383_Fm0.txt
agrep -0 -c 'TTCCTACAGTTGACGCT' *.fastq > count/B9384_Fm0.txt
agrep -0 -c 'GTTGTCAAGTGGAGAGT' *.fastq > count/B9385_Fm0.txt
agrep -0 -c 'ATTGTATCGCGGCAGTT' *.fastq > count/B9386_Fm0.txt
agrep -0 -c 'ATCGGGGGAACACCTAA' *.fastq > count/B9387_Fm0.txt
agrep -0 -c 'GCCGGACACACTATTAG' *.fastq > count/B9389_Fm0.txt
agrep -0 -c 'CCGTAGACTGTTAAGAA' *.fastq > count/B9390_Fm0.txt
agrep -0 -c 'CGACACCGAATGAGCAC' *.fastq > count/B9392_Fm0.txt
agrep -0 -c 'GTGCAACCCTCATACTA' *.fastq > count/B9393_Fm0.txt
agrep -0 -c 'ACCTTATCCTCTGATGA' *.fastq > count/B9394_Fm0.txt
agrep -0 -c 'CTACCTATCTTCCTCAA' *.fastq > count/B9395_Fm0.txt
agrep -0 -c 'GCCCAGTACTTTGGCAT' *.fastq > count/B9396_Fm0.txt
agrep -0 -c 'TATCGAAGAGACACTGT' *.fastq > count/B9397_Fm0.txt
agrep -0 -c 'TGCGTGTAACGACAAGT' *.fastq > count/B9400_Fm0.txt
agrep -0 -c 'GTATGGAGCCCAAATGT' *.fastq > count/B9401_Fm0.txt
agrep -0 -c 'GTGTCATCAATGTGCAG' *.fastq > count/B9402_Fm0.txt
agrep -0 -c 'TATTGCTAAGATAGCCG' *.fastq > count/B9405_Fm0.txt
agrep -0 -c 'CGGAGATTGATATCTAC' *.fastq > count/B9406_Fm0.txt
agrep -0 -c 'CTTACCCGCGTAGGAGT' *.fastq > count/B9408_Fm0.txt
agrep -0 -c 'TATTGGGAGAGGGGTTT' *.fastq > count/B9409_Fm0.txt
agrep -0 -c 'GATGGGAACAACCACAA' *.fastq > count/B9410_Fm0.txt
agrep -0 -c 'ACGTGACCATTCCGTGG' *.fastq > count/B9411_Fm0.txt
agrep -0 -c 'TTGACGCTCTGGACTGA' *.fastq > count/B9412_Fm0.txt
agrep -0 -c 'CAGCTAAATTGGACTTC' *.fastq > count/B9413_Fm0.txt
agrep -0 -c 'TAAAATCGGTGGCCCCA' *.fastq > count/B9414_Fm0.txt
agrep -0 -c 'GGCTTTTGACTGGTGAC' *.fastq > count/B9415_Fm0.txt
agrep -0 -c 'ACGATACCTTATCCGGC' *.fastq > count/B9418_Fm0.txt
agrep -0 -c 'TTGATTGGCGTAGGTGG' *.fastq > count/B9420_Fm0.txt
agrep -0 -c 'CGACTCATCCTTTGCTA' *.fastq > count/B9421_Fm0.txt
agrep -0 -c 'GACTGTCCGGGCTTTGA' *.fastq > count/B9422_Fm0.txt
agrep -0 -c 'AAGTGTGTTGTCGGTGC' *.fastq > count/B9424_Fm0.txt
agrep -0 -c 'AGGTTCAGCGGGAGTAA' *.fastq > count/B9426_Fm0.txt
agrep -0 -c 'CAGAGGTGTCTTTTCGG' *.fastq > count/B9428_Fm0.txt
agrep -0 -c 'ACCGCAAACGTCTGTAG' *.fastq > count/B9429_Fm0.txt
agrep -0 -c 'CGACTGGCAGTACACCT' *.fastq > count/B9430_Fm0.txt
agrep -0 -c 'GCTCGGACAATGCCTAC' *.fastq > count/B9431_Fm0.txt
agrep -0 -c 'GCTAGATTCGCGTGCGA' *.fastq > count/B9433_Fm0.txt
agrep -0 -c 'TAGCAGGAGAAACCCTC' *.fastq > count/B9434_Fm0.txt
agrep -0 -c 'CGTCAGTATCTCAAACC' *.fastq > count/B9435_Fm0.txt
agrep -0 -c 'CTTCGCCTTTAACTCAA' *.fastq > count/B9436_Fm0.txt
agrep -0 -c 'GCATTATCCGAGGGCAA' *.fastq > count/B9437_Fm0.txt
agrep -0 -c 'CCGCTGTACGCTATCCT' *.fastq > count/B9438_Fm0.txt
agrep -0 -c 'CGAATGGACGTGAAAAG' *.fastq > count/B9440_Fm0.txt
agrep -0 -c 'GCTACAGCTTATGCTTC' *.fastq > count/B9441_Fm0.txt
agrep -0 -c 'AACGGTTTGCGACGACC' *.fastq > count/B9442_Fm0.txt
agrep -0 -c 'GTCATGCTCCGATGATC' *.fastq > count/B9443_Fm0.txt
agrep -0 -c 'CTAGACCGTATCGGTTG' *.fastq > count/B9444_Fm0.txt
agrep -0 -c 'GTAGTGAGAATACGCTA' *.fastq > count/B9445_Fm0.txt
agrep -0 -c 'ACACTATAAGCGGCAGG' *.fastq > count/B9446_Fm0.txt
agrep -0 -c 'TGTAACGCACATGCGAA' *.fastq > count/B9447_Fm0.txt
agrep -0 -c 'GGCAATCCCGCCTTAAG' *.fastq > count/B9448_Fm0.txt
agrep -0 -c 'AGCCACATGCAAGGATC' *.fastq > count/B9449_Fm0.txt
agrep -0 -c 'CCGCACAAAGTTGGAAG' *.fastq > count/B9450_Fm0.txt
agrep -0 -c 'GAGAACCACGAAACGCG' *.fastq > count/B9453_Fm0.txt
agrep -0 -c 'CATGTAGGAGGCCGTTG' *.fastq > count/B9454_Fm0.txt
agrep -0 -c 'TATCTGTTCCGTTGTCT' *.fastq > count/B9455_Fm0.txt
agrep -0 -c 'CCGGGCGTACTTGCATT' *.fastq > count/B9459_Fm0.txt
agrep -0 -c 'TACATGAGGGGTGACCC' *.fastq > count/B9460_Fm0.txt
agrep -0 -c 'CTTACGGGCCTGTACTG' *.fastq > count/B9461_Fm0.txt
agrep -0 -c 'GCACGGAACAGACTGAT' *.fastq > count/B9462_Fm0.txt
agrep -0 -c 'CGAGACTTACTCTTGTT' *.fastq > count/B9463_Fm0.txt
agrep -0 -c 'GGCGACCATAGTCGTGA' *.fastq > count/B9464_Fm0.txt
agrep -0 -c 'TGCGACGAATAAGACGG' *.fastq > count/B9465_Fm0.txt
agrep -0 -c 'TATGCGGGCTTGGTACT' *.fastq > count/B9466_Fm0.txt
agrep -0 -c 'GGATCCGTAAATGTTGA' *.fastq > count/B9467_Fm0.txt
agrep -0 -c 'CAGCCCGTCAACTCATG' *.fastq > count/B9468_Fm0.txt
agrep -0 -c 'CGAATGAGGTATTGGTA' *.fastq > count/B9469_Fm0.txt
agrep -0 -c 'TAACCAGCCTCTTAGTG' *.fastq > count/B9472_Fm0.txt
agrep -0 -c 'TGATTCCATGGACCCGC' *.fastq > count/B9473_Fm0.txt
agrep -0 -c 'AGTGAGTGTGGGAGATA' *.fastq > count/B9474_Fm0.txt
agrep -0 -c 'CTACCACTCACAACGAT' *.fastq > count/B9475_Fm0.txt
agrep -0 -c 'AATGAGCCCTCCACATA' *.fastq > count/B9476_Fm0.txt
agrep -0 -c 'GTGATAGACAGCGATCT' *.fastq > count/B9477_Fm0.txt
agrep -0 -c 'CACATCAACGTATCAGC' *.fastq > count/B9478_Fm0.txt
agrep -0 -c 'TTCGGATCGAGTTGAGT' *.fastq > count/B9479_Fm0.txt
agrep -0 -c 'TGACCGAAATGTATGAG' *.fastq > count/B9480_Fm0.txt
agrep -0 -c 'GGTTAAGTGTACCTGAA' *.fastq > count/B9481_Fm0.txt
agrep -0 -c 'GTAGACCTAATGGGTAA' *.fastq > count/B9482_Fm0.txt
agrep -0 -c 'AGCAGTATTGGCTTATC' *.fastq > count/B9483_Fm0.txt
agrep -0 -c 'TTGAGCCGTGTTCATTC' *.fastq > count/B9484_Fm0.txt
agrep -0 -c 'AGCGGCTCCGTTCTTTT' *.fastq > count/B9485_Fm0.txt
agrep -0 -c 'TGGCGAAAAGTACATGA' *.fastq > count/B9486_Fm0.txt
agrep -0 -c 'AGACTGACTCTCGAAGA' *.fastq > count/B9487_Fm0.txt
agrep -0 -c 'ACGATAGATCAGTCACG' *.fastq > count/B9488_Fm0.txt
agrep -0 -c 'GGATTAGTATCTTGCAC' *.fastq > count/B9489_Fm0.txt
agrep -0 -c 'GTAGCTGCAGGAGTCGA' *.fastq > count/B9491_Fm0.txt
agrep -0 -c 'TTATTCTCCACACGCAC' *.fastq > count/B9492_Fm0.txt
agrep -0 -c 'TATAAACGCCGTAGCTC' *.fastq > count/B9494_Fm0.txt
agrep -0 -c 'GGAATTGATCCCGGATG' *.fastq > count/B9495_Fm0.txt
agrep -0 -c 'ACGTTACACCGATCGGC' *.fastq > count/B9496_Fm0.txt
agrep -0 -c 'GGGCACCGCTATAATCA' *.fastq > count/B9497_Fm0.txt
agrep -0 -c 'GCGGGATCGGATTTCCA' *.fastq > count/B9498_Fm0.txt
agrep -0 -c 'GCATCGTAAGGACTTAG' *.fastq > count/B9499_Fm0.txt
agrep -0 -c 'AGTTTGGCTATACCACC' *.fastq > count/B9500_Fm0.txt
agrep -0 -c 'CTAAGATCTTCCCGGCC' *.fastq > count/B9501_Fm0.txt
agrep -0 -c 'GTTGATAGATTGACCGC' *.fastq > count/B9502_Fm0.txt
agrep -0 -c 'AATTGGCCGCTAACGAC' *.fastq > count/B9503_Fm0.txt
agrep -0 -c 'GTATTTAACGTCCCGGG' *.fastq > count/B9504_Fm0.txt
agrep -0 -c 'CGTTTGAGATCCCTAAC' *.fastq > count/B9505_Fm0.txt
agrep -0 -c 'TTGATACCTCACCGGAC' *.fastq > count/B9506_Fm0.txt
agrep -0 -c 'AAGTCGGCAACGCTACA' *.fastq > count/B9507_Fm0.txt
agrep -0 -c 'GCCCACTTAATGGCGCA' *.fastq > count/B9508_Fm0.txt
agrep -0 -c 'CCATATGTAGTCAGTTC' *.fastq > count/B9509_Fm0.txt
agrep -0 -c 'GGCTACGTCCAACTACC' *.fastq > count/B9510_Fm0.txt
agrep -0 -c 'TACGAGACTCCTGCTAG' *.fastq > count/B9511_Fm0.txt
agrep -0 -c 'GCTATTGAAAATCTGCC' *.fastq > count/B9513_Fm0.txt
agrep -0 -c 'TGGCTCGGTACAGCAAG' *.fastq > count/B9514_Fm0.txt
agrep -0 -c 'GTTACTTCGCAAGGGAA' *.fastq > count/B9515_Fm0.txt
agrep -0 -c 'ACGCTACCATCAAAGGT' *.fastq > count/B9517_Fm0.txt
agrep -0 -c 'TGGCTAGGGTTTCGGCT' *.fastq > count/B9518_Fm0.txt
agrep -0 -c 'GCGCAACCGAATACTCC' *.fastq > count/B9519_Fm0.txt
agrep -0 -c 'CAGCAACGATTACCACG' *.fastq > count/B9520_Fm0.txt
agrep -0 -c 'CACCAGGTATAATGCTC' *.fastq > count/B9521_Fm0.txt
agrep -0 -c 'GTGCTCATTAAGCGTGG' *.fastq > count/B9522_Fm0.txt
agrep -0 -c 'AGTATGCTGATAGCCGC' *.fastq > count/B9523_Fm0.txt
agrep -0 -c 'TAAGTACCTGCTCGCTC' *.fastq > count/B9524_Fm0.txt
agrep -0 -c 'CTGCTGAGTGCGTAGTG' *.fastq > count/B9525_Fm0.txt
agrep -0 -c 'AGTAAACGAAACAGGCA' *.fastq > count/B9527_Fm0.txt
agrep -0 -c 'CCTTTGGCGCTTTGACG' *.fastq > count/B9528_Fm0.txt
agrep -0 -c 'ATACCCAATCGCGCTAA' *.fastq > count/B9530_Fm0.txt
agrep -0 -c 'ATCAGAGGCATACCGGC' *.fastq > count/B9531_Fm0.txt
agrep -0 -c 'CCGATGTAGTTAGGCTG' *.fastq > count/B9532_Fm0.txt
agrep -0 -c 'GGAGTACGGCAAGGATC' *.fastq > count/B9533_Fm0.txt
agrep -0 -c 'AGCTGATATGGCCTCGC' *.fastq > count/B9535_Fm0.txt
agrep -0 -c 'TGCGTCCCTGCTTATTC' *.fastq > count/B9536_Fm0.txt
agrep -0 -c 'AGAGGAATGCTGGGCTT' *.fastq > count/B9537_Fm0.txt
agrep -0 -c 'GTCGAGGCCAGCGTATA' *.fastq > count/B9538_Fm0.txt
agrep -0 -c 'GCAACTAGTGTGTCTCA' *.fastq > count/B9539_Fm0.txt
agrep -0 -c 'ATCGCATCTAATAGGAG' *.fastq > count/B9541_Fm0.txt
agrep -0 -c 'GGACCCCCTTTCTGTTA' *.fastq > count/B9542_Fm0.txt
agrep -0 -c 'ACGATGCATTGCCTGTA' *.fastq > count/B9543_Fm0.txt
agrep -0 -c 'AGTTCCTAACTGGTGGC' *.fastq > count/B9544_Fm0.txt
agrep -0 -c 'AACGCCGAGGTCTTGTC' *.fastq > count/B9545_Fm0.txt
agrep -0 -c 'ACGTGAGTAAGAGCCCT' *.fastq > count/B9546_Fm0.txt
agrep -0 -c 'GCACCACGTTTCATAAT' *.fastq > count/B9547_Fm0.txt
agrep -0 -c 'GACGCGAATGCGCTACA' *.fastq > count/B9548_Fm0.txt
agrep -0 -c 'TCATGTGTCGCTTGAAC' *.fastq > count/B9549_Fm0.txt
agrep -0 -c 'GAGTATTTAACGGATCG' *.fastq > count/B9550_Fm0.txt
agrep -0 -c 'TCGCCCGCATGAGACAA' *.fastq > count/B9551_Fm0.txt
agrep -0 -c 'GCCCTCTTAAACGCATT' *.fastq > count/B9552_Fm0.txt
agrep -0 -c 'CCGGCAGCATTAAAAAC' *.fastq > count/B9553_Fm0.txt
agrep -0 -c 'AGAAGGGGAATCTCCAA' *.fastq > count/B9554_Fm0.txt
agrep -0 -c 'AGAGTCATTACGAGATC' *.fastq > count/B9555_Fm0.txt
agrep -0 -c 'ATGGTTCCCGATTCAGA' *.fastq > count/B9556_Fm0.txt
agrep -0 -c 'ACAGCCGATCCATGCTA' *.fastq > count/B9558_Fm0.txt
agrep -0 -c 'GTCGTACGTTCCGTTCA' *.fastq > count/B9559_Fm0.txt
agrep -0 -c 'GGTTGTTGCTGATTATC' *.fastq > count/B9560_Fm0.txt
agrep -0 -c 'CGATGTTGTTCGAGTCT' *.fastq > count/B9561_Fm0.txt
agrep -0 -c 'AATCTATTGGCGGTCTC' *.fastq > count/B9562_Fm0.txt
agrep -0 -c 'AGCTAGTTTCATCCCGT' *.fastq > count/B9564_Fm0.txt
agrep -0 -c 'AGACAACGACCTTTGGC' *.fastq > count/B9565_Fm0.txt
agrep -0 -c 'CCGTTGCCAACGGGATA' *.fastq > count/B9566_Fm0.txt
agrep -0 -c 'AGCAATAGAGTTCGACT' *.fastq > count/B9567_Fm0.txt
agrep -0 -c 'CCGTGCACATCTAGCTT' *.fastq > count/B9568_Fm0.txt
agrep -0 -c 'GCTCAAACGACACACAT' *.fastq > count/B9569_Fm0.txt
agrep -0 -c 'AACGCCGGGAAGTGACT' *.fastq > count/B9570_Fm0.txt
agrep -0 -c 'CAGTAGTGCGAGGTGCA' *.fastq > count/B9571_Fm0.txt
agrep -0 -c 'GGTGGCCGCAGAAAATT' *.fastq > count/B9572_Fm0.txt
agrep -0 -c 'GATTTGAAGTCCCTGAA' *.fastq > count/B9573_Fm0.txt
agrep -0 -c 'GATAACCTTATTCAGCC' *.fastq > count/B9575_Fm0.txt
agrep -0 -c 'GACCCTTCCTACCGACA' *.fastq > count/B9576_Fm0.txt
agrep -0 -c 'TTAAGCAGCTACGCACT' *.fastq > count/B9577_Fm0.txt
agrep -0 -c 'CACCCGATACGGTCAGT' *.fastq > count/B9579_Fm0.txt
agrep -0 -c 'TATCTGAGGACTGTAGC' *.fastq > count/B9580_Fm0.txt
agrep -0 -c 'ACATAGCGTTACGACAC' *.fastq > count/B9581_Fm0.txt
agrep -0 -c 'CAGTATCTACTCGCAAC' *.fastq > count/B9582_Fm0.txt
agrep -0 -c 'CGTAAAATGCTCCCATC' *.fastq > count/B9583_Fm0.txt
agrep -0 -c 'GATTGGAAAAGGCGTAG' *.fastq > count/B9584_Fm0.txt
agrep -0 -c 'GGGAGAACCGATTCCGA' *.fastq > count/B9585_Fm0.txt
agrep -0 -c 'TCGTGGAAAGTAGCCGC' *.fastq > count/B9587_Fm0.txt
agrep -0 -c 'AGTTCGGGTCACATTCG' *.fastq > count/B9588_Fm0.txt
agrep -0 -c 'TTGCCAGACGCGCGTAT' *.fastq > count/B9589_Fm0.txt
agrep -0 -c 'TTCGCCAAGTCCTTCGC' *.fastq > count/B9590_Fm0.txt
agrep -0 -c 'CGACTGAAAAAATGCTG' *.fastq > count/B9591_Fm0.txt
agrep -0 -c 'TACTCTACGGATGAGCG' *.fastq > count/B9592_Fm0.txt
agrep -0 -c 'CTGTCGCAGCTTACCTT' *.fastq > count/B9593_Fm0.txt
agrep -0 -c 'GATTAGCCACTTCCCGC' *.fastq > count/B9594_Fm0.txt
agrep -0 -c 'CAATATCGCGAAACATC' *.fastq > count/B9595_Fm0.txt
agrep -0 -c 'CGGCACTGCGCCTTTAA' *.fastq > count/B9597_Fm0.txt
agrep -0 -c 'TTCTCGTTCGGCCGATA' *.fastq > count/B9598_Fm0.txt
agrep -0 -c 'GTAGCACCTGAAAGGCG' *.fastq > count/B9600_Fm0.txt
agrep -0 -c 'TCTGTGGGAACCTCACT' *.fastq > count/B9601_Fm0.txt
agrep -0 -c 'ATTCGGATCTAATCCAG' *.fastq > count/B9602_Fm0.txt
agrep -0 -c 'ACGATAGCTCGTTCATG' *.fastq > count/B9603_Fm0.txt
agrep -0 -c 'TCGCTTATACGACGAAG' *.fastq > count/B9606_Fm0.txt
agrep -0 -c 'GGTGATCATGTAACAAG' *.fastq > count/B9607_Fm0.txt
agrep -0 -c 'TTCATGTGCTCGCTTGA' *.fastq > count/B9609_Fm0.txt
agrep -0 -c 'ATCGGGATAGACCGCTA' *.fastq > count/B9611_Fm0.txt
agrep -0 -c 'CCAAAGCTAAGACGAAG' *.fastq > count/B9613_Fm0.txt
agrep -0 -c 'TATCTCAGCGGTGATTT' *.fastq > count/B9615_Fm0.txt
agrep -0 -c 'AGGTGACAATGCGGTGC' *.fastq > count/B9616_Fm0.txt
agrep -0 -c 'GCAACGTCCTTTATAGC' *.fastq > count/B9617_Fm0.txt
agrep -0 -c 'TCGCAACTAATTGTGGC' *.fastq > count/B9618_Fm0.txt
agrep -0 -c 'TATCTCAAGTGCCCTAC' *.fastq > count/B9619_Fm0.txt
agrep -0 -c 'TGCTTCGGACGATGTTT' *.fastq > count/B9620_Fm0.txt
agrep -0 -c 'AATCGCCAATCTCGGGT' *.fastq > count/B9622_Fm0.txt
agrep -0 -c 'GTAGCGGACCTCAAAAG' *.fastq > count/B9623_Fm0.txt
agrep -0 -c 'CTCAGAAGAATCAGCTA' *.fastq > count/B9624_Fm0.txt
agrep -0 -c 'ATATTATGGTGTTCGGC' *.fastq > count/B9626_Fm0.txt
agrep -0 -c 'ACTGCGTCGAGTGACAA' *.fastq > count/B9628_Fm0.txt
agrep -0 -c 'GGATATGAAGACAGACG' *.fastq > count/B9629_Fm0.txt
agrep -0 -c 'AAGAGTAGAGCACTACG' *.fastq > count/B9633_Fm0.txt
agrep -0 -c 'AACATTGGCATCAGTGA' *.fastq > count/B9635_Fm0.txt
agrep -0 -c 'CCTTATGCAATCAGTCA' *.fastq > count/B9636_Fm0.txt
agrep -0 -c 'TAGGACCTCGTCTGTTA' *.fastq > count/B9637_Fm0.txt
agrep -0 -c 'TTCGCAACAGCAGTTGC' *.fastq > count/B9638_Fm0.txt
agrep -0 -c 'GACAAGTTAAGAATGCC' *.fastq > count/B9639_Fm0.txt
agrep -0 -c 'AGCGCGGCGTAGAACTA' *.fastq > count/B9642_Fm0.txt
agrep -0 -c 'TTGAGGGCTCACTATCG' *.fastq > count/B9643_Fm0.txt
agrep -0 -c 'TCTAGTCGATCTGTAAC' *.fastq > count/B9644_Fm0.txt
agrep -0 -c 'GTCTTTGATATCGCGCA' *.fastq > count/B9645_Fm0.txt
agrep -0 -c 'AACTGGCGAGATACACT' *.fastq > count/B9646_Fm0.txt
agrep -0 -c 'ACATTGCGTTTAGGTCA' *.fastq > count/B9647_Fm0.txt
agrep -0 -c 'GCCGAATATCTTCGGGA' *.fastq > count/B9648_Fm0.txt
agrep -0 -c 'AGTTGGAATGAACTGGG' *.fastq > count/B9649_Fm0.txt
agrep -0 -c 'CCGTAACCACTAGAGAT' *.fastq > count/B9650_Fm0.txt
agrep -0 -c 'TGTAATCAGGTCCCGTG' *.fastq > count/B9652_Fm0.txt
agrep -0 -c 'TGCTGAGTTCGAATTGG' *.fastq > count/B9653_Fm0.txt
agrep -0 -c 'TGGACATGATGCCGGTT' *.fastq > count/B9654_Fm0.txt
agrep -0 -c 'CTGGGAGAGTCTACTCG' *.fastq > count/B9655_Fm0.txt
agrep -0 -c 'GTTCCCCGGATGAATGA' *.fastq > count/B9656_Fm0.txt
agrep -0 -c 'CCTTGCTTGTGTCACTT' *.fastq > count/B9657_Fm0.txt
agrep -0 -c 'GGGACATTAGCCCTATC' *.fastq > count/B9658_Fm0.txt
agrep -0 -c 'GCTATCTTGCCGTTAGA' *.fastq > count/B9659_Fm0.txt
agrep -0 -c 'ATCGGAGGGGAATCGTG' *.fastq > count/B9660_Fm0.txt
agrep -0 -c 'TAGAGGGTGGCGTAGCT' *.fastq > count/B9661_Fm0.txt
agrep -0 -c 'CTCGAGTTCACCACCAA' *.fastq > count/B9662_Fm0.txt
agrep -0 -c 'TCGCGGACACCAATTCT' *.fastq > count/B9664_Fm0.txt
agrep -0 -c 'TCGACTATAGTACTACC' *.fastq > count/B9665_Fm0.txt
agrep -0 -c 'CGTGTCTTCGGACATGA' *.fastq > count/B9667_Fm0.txt
agrep -0 -c 'TGATAGCAAGCTTCGGC' *.fastq > count/B9668_Fm0.txt
agrep -0 -c 'CCACCTATGGAAGACTA' *.fastq > count/B9669_Fm0.txt
agrep -0 -c 'TTCGTCACCGAGTACAT' *.fastq > count/B9670_Fm0.txt
agrep -0 -c 'CTCCGCGGTTTGAGTGA' *.fastq > count/B9671_Fm0.txt
agrep -0 -c 'GTCAAGGTTCTTTCGAT' *.fastq > count/B9673_Fm0.txt
agrep -0 -c 'CAAAGAGTCAAGGGCTC' *.fastq > count/B9674_Fm0.txt
agrep -0 -c 'AGTGTTAAGCGCCCCCT' *.fastq > count/B9675_Fm0.txt
agrep -0 -c 'TCTAGAGACCAATTGAG' *.fastq > count/B9676_Fm0.txt
agrep -0 -c 'GCGTTCCGAATAACTGG' *.fastq > count/B9677_Fm0.txt
agrep -0 -c 'TGTCGACGCGTCATAGG' *.fastq > count/B9678_Fm0.txt
agrep -0 -c 'ATGATATAATGGCGCCC' *.fastq > count/B9679_Fm0.txt
agrep -0 -c 'GTGCCACTTACGTTGTT' *.fastq > count/B9680_Fm0.txt
agrep -0 -c 'CCTTGGGTATACAACTC' *.fastq > count/B9681_Fm0.txt
agrep -0 -c 'CTCCGTTTATCCCAAGA' *.fastq > count/B9682_Fm0.txt
agrep -0 -c 'GTGTTCACCAATGATCG' *.fastq > count/B9684_Fm0.txt
agrep -0 -c 'CACTGAACGAGTGTAGG' *.fastq > count/B9685_Fm0.txt
agrep -0 -c 'GCGTCTCGCGTTAAGTC' *.fastq > count/B9686_Fm0.txt
agrep -0 -c 'CGGTTACGGCCCACTTT' *.fastq > count/B9687_Fm0.txt
agrep -0 -c 'GCCCGCAATTTTCTACG' *.fastq > count/B9688_Fm0.txt
agrep -0 -c 'TGTACGTTTCCCGTCAG' *.fastq > count/B9689_Fm0.txt
agrep -0 -c 'CGTCTCATTGTGGCAGA' *.fastq > count/B9690_Fm0.txt
agrep -0 -c 'CTGCAATTCCGAAGGTT' *.fastq > count/B9691_Fm0.txt
agrep -0 -c 'GTGTCTAGCCAAGGCGT' *.fastq > count/B9692_Fm0.txt
agrep -0 -c 'AACTTGCGGTCAAACCC' *.fastq > count/B9693_Fm0.txt
agrep -0 -c 'CGTCGTGGCTCTTCGTT' *.fastq > count/B9694_Fm0.txt
agrep -0 -c 'GGTTATCCGTGCCCAGT' *.fastq > count/B9695_Fm0.txt
agrep -0 -c 'TTCATCTGGCCCATATG' *.fastq > count/B9696_Fm0.txt
agrep -0 -c 'GATCCATCTTACGGCCT' *.fastq > count/B9698_Fm0.txt
agrep -0 -c 'TGCTTTGCGCTGGGCAA' *.fastq > count/B9699_Fm0.txt
agrep -0 -c 'AGTTCACCAGGCCTATT' *.fastq > count/B9700_Fm0.txt
agrep -0 -c 'CGTGTGAAGGTGTCGAA' *.fastq > count/B9701_Fm0.txt
agrep -0 -c 'GCTAGGAAGCTAATACA' *.fastq > count/B9702_Fm0.txt
agrep -0 -c 'CTAGCTGAGGACTTAAC' *.fastq > count/B9703_Fm0.txt
agrep -0 -c 'AACGGACAACGCCTTCG' *.fastq > count/B9704_Fm0.txt
agrep -0 -c 'AGGGAACTAACCCTGGA' *.fastq > count/B9705_Fm0.txt
agrep -0 -c 'CGGATCATAGGTCAATC' *.fastq > count/B9706_Fm0.txt
agrep -0 -c 'CTCCTGATTGTAAAGCC' *.fastq > count/B9707_Fm0.txt
agrep -0 -c 'GACGAACACGAAGTCAT' *.fastq > count/B9708_Fm0.txt
agrep -0 -c 'CATCGTGATATGCAGGA' *.fastq > count/B9709_Fm0.txt
agrep -0 -c 'GCATGCGAATAGTACTC' *.fastq > count/B9710_Fm0.txt
agrep -0 -c 'TGGAGGGGCGGACATAT' *.fastq > count/B9713_Fm0.txt
agrep -0 -c 'GCGCAAGTAAAAGTGCC' *.fastq > count/B9714_Fm0.txt
agrep -0 -c 'TGTCGGTCAACACGGGA' *.fastq > count/B9716_Fm0.txt
agrep -0 -c 'ATTAGGTGATCCGATAC' *.fastq > count/B9717_Fm0.txt
agrep -0 -c 'ATTCCCCCCCGTCTTGA' *.fastq > count/B9718_Fm0.txt
agrep -0 -c 'TAGCATAACTAGCGAGA' *.fastq > count/B9721_Fm0.txt
agrep -0 -c 'GTAGAGAATCCTCTCCA' *.fastq > count/B9722_Fm0.txt
agrep -0 -c 'ACGTTCTTTCACACGGG' *.fastq > count/B9723_Fm0.txt
agrep -0 -c 'CCTAGACATCGACGTTC' *.fastq > count/B9724_Fm0.txt
agrep -0 -c 'AGGCGGAATCTAATGCC' *.fastq > count/B9725_Fm0.txt
agrep -0 -c 'AGATAGCCACTGGTACC' *.fastq > count/B9727_Fm0.txt
agrep -0 -c 'AATTGGATGGGTAAGCG' *.fastq > count/B9728_Fm0.txt
agrep -0 -c 'GTATTCACCTCCGGGGA' *.fastq > count/B9729_Fm0.txt
agrep -0 -c 'TGACCGGGCAGACTTTA' *.fastq > count/B9730_Fm0.txt
agrep -0 -c 'TGTCGCCGTACTATCAA' *.fastq > count/B9731_Fm0.txt
agrep -0 -c 'ATCTATTTGTCGAGGGT' *.fastq > count/B9732_Fm0.txt
agrep -0 -c 'ATGAGCAGCGATAGTTT' *.fastq > count/B9735_Fm0.txt
agrep -0 -c 'CGCCAGCGTTTCAAGCT' *.fastq > count/B9736_Fm0.txt
agrep -0 -c 'CGCGCCATACACAAACG' *.fastq > count/B9737_Fm0.txt
agrep -0 -c 'CTGGCCCTAAAAAGCTA' *.fastq > count/B9738_Fm0.txt
agrep -0 -c 'GGGGCTACATTACGTCA' *.fastq > count/B9739_Fm0.txt
agrep -0 -c 'AGGAATAGTAACAGTCG' *.fastq > count/B9740_Fm0.txt
agrep -0 -c 'ATCCCATGTCCTTCTGG' *.fastq > count/B9741_Fm0.txt
agrep -0 -c 'AAGTCGGCTTTCAGCGG' *.fastq > count/B9744_Fm0.txt
agrep -0 -c 'CTTAACCCCGTATGAGC' *.fastq > count/B9745_Fm0.txt
agrep -0 -c 'TCGGAGAGTCATTAACT' *.fastq > count/B9746_Fm0.txt
agrep -0 -c 'CGTCGACCTCAGGATCT' *.fastq > count/B9747_Fm0.txt
agrep -0 -c 'TTGAGATCGACACGGCT' *.fastq > count/B9748_Fm0.txt
agrep -0 -c 'TGTTGCCCATTTTCTGG' *.fastq > count/B9750_Fm0.txt
agrep -0 -c 'CGTTACACACGTAACGC' *.fastq > count/B9751_Fm0.txt
agrep -0 -c 'AAGAGGGCCGATGCTCA' *.fastq > count/B9752_Fm0.txt
agrep -0 -c 'CATATAGGTAGAGTCCA' *.fastq > count/B9753_Fm0.txt
agrep -0 -c 'ATACAATCAGGCACGGA' *.fastq > count/B9754_Fm0.txt
agrep -0 -c 'ACCTGAGGTAAGCCGTA' *.fastq > count/B9755_Fm0.txt
agrep -0 -c 'TTCCAACAGGGTCTATA' *.fastq > count/B9756_Fm0.txt
agrep -0 -c 'CACTGCATATGTTGCAT' *.fastq > count/B9757_Fm0.txt
agrep -0 -c 'ACTCCCGTCTCTTTACC' *.fastq > count/B9758_Fm0.txt
agrep -0 -c 'CGATAACCACATTGCAG' *.fastq > count/B9759_Fm0.txt
agrep -0 -c 'TTGCGGCTATGAGTGAA' *.fastq > count/B9760_Fm0.txt
agrep -0 -c 'TTAGGAGCGCTGAATGG' *.fastq > count/B9761_Fm0.txt
agrep -0 -c 'CAGTTGGAACCTCGACA' *.fastq > count/B9762_Fm0.txt
agrep -0 -c 'TCGACGTATAGGCGACT' *.fastq > count/B9763_Fm0.txt
agrep -0 -c 'ACGCTGGGATTGTCGTT' *.fastq > count/B9764_Fm0.txt
agrep -0 -c 'AGCGGGGTTGCTCCAAT' *.fastq > count/B9767_Fm0.txt
agrep -0 -c 'TCGGCAACACACGCAAG' *.fastq > count/B9768_Fm0.txt
agrep -0 -c 'AATAAATGGACAGCCCC' *.fastq > count/B9769_Fm0.txt
agrep -0 -c 'GGTGCGGGCGTAATCAT' *.fastq > count/B9770_Fm0.txt
agrep -0 -c 'TTCAGCGCCTCACCAAC' *.fastq > count/B9771_Fm0.txt
agrep -0 -c 'ACGCAGTTTTCGGCTCC' *.fastq > count/B9772_Fm0.txt
agrep -0 -c 'AACCCATCACGTCAGGG' *.fastq > count/B9773_Fm0.txt
agrep -0 -c 'GACCACGCGGACAAAAG' *.fastq > count/B9774_Fm0.txt
agrep -0 -c 'TACCAGGTGGTCACGTC' *.fastq > count/B9775_Fm0.txt
agrep -0 -c 'TCTAGTCATCGCGCAAC' *.fastq > count/B9776_Fm0.txt
agrep -0 -c 'GGGCGATCAGATTGAAG' *.fastq > count/B9778_Fm0.txt
agrep -0 -c 'TTCGGACTCGAAGCGGT' *.fastq > count/B9779_Fm0.txt
agrep -0 -c 'GCGTTTCGGAGCTGGTA' *.fastq > count/B9782_Fm0.txt
agrep -0 -c 'GACAAGCGATACTGGGA' *.fastq > count/B9784_Fm0.txt
agrep -0 -c 'TTGGAATGCACGGCAAA' *.fastq > count/B9785_Fm0.txt
agrep -0 -c 'ATGCGCGAAGCGGCTTA' *.fastq > count/B9786_Fm0.txt
agrep -0 -c 'CAAGTCATGGGGATAGA' *.fastq > count/B9790_Fm0.txt
agrep -0 -c 'GAGACCTCTTCCAAGTA' *.fastq > count/B9791_Fm0.txt
agrep -0 -c 'CAGGAGGAGGTGTTCTG' *.fastq > count/B9792_Fm0.txt
agrep -0 -c 'ATGATGCTTGGGTTCGT' *.fastq > count/B9793_Fm0.txt
agrep -0 -c 'ACTCTGCTCTGATGAAC' *.fastq > count/B9794_Fm0.txt
agrep -0 -c 'GGACTTGGGCGATAAAC' *.fastq > count/B9795_Fm0.txt
agrep -0 -c 'AGGTATCTTTGTGGGGG' *.fastq > count/B9796_Fm0.txt
agrep -0 -c 'CGATAGCGGTGTCATTA' *.fastq > count/B9800_Fm0.txt
agrep -0 -c 'AAGCTACCAGAATGTAG' *.fastq > count/B9801_Fm0.txt
agrep -0 -c 'CTGAAGTTTACTGGGTT' *.fastq > count/B9802_Fm0.txt
agrep -0 -c 'GGTTTGAGAGTGGCGAT' *.fastq > count/B9803_Fm0.txt
agrep -0 -c 'ATACGAGACAGAGCTTT' *.fastq > count/B9804_Fm0.txt
agrep -0 -c 'AGCAGTACCAGACATTG' *.fastq > count/B9805_Fm0.txt
agrep -0 -c 'TGCCGGTATGCACTAAA' *.fastq > count/B9806_Fm0.txt
agrep -0 -c 'ACAGCGAAACTAATCTC' *.fastq > count/B9807_Fm0.txt
agrep -0 -c 'GGCGACAATAGTATTGT' *.fastq > count/B9808_Fm0.txt
agrep -0 -c 'CTAGATCATGACTACGG' *.fastq > count/B9809_Fm0.txt
agrep -0 -c 'GGAGCGTCCCATACTCA' *.fastq > count/B9810_Fm0.txt
agrep -0 -c 'CCGGGCTCCAATATAAA' *.fastq > count/B9811_Fm0.txt
agrep -0 -c 'TTGAAGAGCACCGTGTG' *.fastq > count/B9812_Fm0.txt
agrep -0 -c 'AACTATCCGGGAATCTA' *.fastq > count/B9813_Fm0.txt
agrep -0 -c 'CACGATAACTGTATAGG' *.fastq > count/B9814_Fm0.txt
agrep -0 -c 'TGTAGCGACCCACATTA' *.fastq > count/B9815_Fm0.txt
agrep -0 -c 'GGGTCGATAGTAACTAG' *.fastq > count/B9816_Fm0.txt
agrep -0 -c 'CAGTCGAACACAACGGA' *.fastq > count/B9818_Fm0.txt
agrep -0 -c 'ATAGGTCCGCCCCATTA' *.fastq > count/B9820_Fm0.txt
agrep -0 -c 'TTCCTGGTCCGTAACGC' *.fastq > count/B9822_Fm0.txt
agrep -0 -c 'TTGGGTTTGTACAGGCC' *.fastq > count/B9823_Fm0.txt
agrep -0 -c 'CTGTAGGATAGGCTGGG' *.fastq > count/B9824_Fm0.txt
agrep -0 -c 'CTTGCGGAGATTAGTCT' *.fastq > count/B9826_Fm0.txt
agrep -0 -c 'CGGGGGAAGCACAGTTA' *.fastq > count/B9827_Fm0.txt
agrep -0 -c 'TCATACGAGTTCGGGTG' *.fastq > count/B9828_Fm0.txt
agrep -0 -c 'GTAGTCTCCTCTTACTT' *.fastq > count/B9829_Fm0.txt
agrep -0 -c 'TGTAGCCCGGTTCCAGT' *.fastq > count/B9830_Fm0.txt
agrep -0 -c 'CTGGTTGCTCATTTTGC' *.fastq > count/B9831_Fm0.txt
agrep -0 -c 'CGAGTAATAGCTATTCG' *.fastq > count/B9832_Fm0.txt
agrep -0 -c 'CGCCCAAATCGTTGAAT' *.fastq > count/B9834_Fm0.txt
agrep -0 -c 'CACTGTCCAATCGGGTT' *.fastq > count/B9835_Fm0.txt
agrep -0 -c 'TTAGTCAAGCGGTGTTT' *.fastq > count/B9836_Fm0.txt
agrep -0 -c 'AGGTTCATGATTAGTCC' *.fastq > count/B9837_Fm0.txt
agrep -0 -c 'GTTAAGGGTCAGACGGT' *.fastq > count/B9838_Fm0.txt
agrep -0 -c 'TCTCCCCGATAAATCTA' *.fastq > count/B9839_Fm0.txt
agrep -0 -c 'CGCATGGACCTCACGAA' *.fastq > count/B9840_Fm0.txt
agrep -0 -c 'ATGCGTAGGAAGAGGTG' *.fastq > count/B9842_Fm0.txt
agrep -0 -c 'ACAGGGCTGTTCAATAG' *.fastq > count/B9843_Fm0.txt
agrep -0 -c 'CGTTTAATAGGAGCTGA' *.fastq > count/B9844_Fm0.txt
agrep -0 -c 'CAATGGCATTTCGGATT' *.fastq > count/B9845_Fm0.txt
agrep -0 -c 'CACATACTTTCCCCGAC' *.fastq > count/B9846_Fm0.txt
agrep -0 -c 'TGTCACACAGTTGGCTC' *.fastq > count/B9847_Fm0.txt
agrep -0 -c 'GCGGGTATCTATATGAT' *.fastq > count/B9848_Fm0.txt
agrep -0 -c 'GGTCTCCACTCTGTGAA' *.fastq > count/B9849_Fm0.txt
agrep -0 -c 'CGCTCATTTGACGCGAA' *.fastq > count/B9850_Fm0.txt
agrep -0 -c 'CGGAATATAACAAGGAC' *.fastq > count/B9851_Fm0.txt
agrep -0 -c 'CGCGTCGAAGACTGTTC' *.fastq > count/B9852_Fm0.txt
agrep -0 -c 'GTCTCAAAAGGTAGTCC' *.fastq > count/B9854_Fm0.txt
agrep -0 -c 'GAGCGAATGGCAAACTA' *.fastq > count/B9856_Fm0.txt
agrep -0 -c 'CGTAGGTAACGACAACG' *.fastq > count/B9858_Fm0.txt
agrep -0 -c 'AATTTACTTGCTGACCG' *.fastq > count/B9859_Fm0.txt
agrep -0 -c 'GTGACTCGGTCCAGGAT' *.fastq > count/B9860_Fm0.txt
agrep -0 -c 'TTCCCCAGGTTCGGCTT' *.fastq > count/B9861_Fm0.txt
agrep -0 -c 'GTTGTCACGCACTTTCT' *.fastq > count/B9862_Fm0.txt
agrep -0 -c 'CTTAGGAATCTTCACGC' *.fastq > count/B9863_Fm0.txt
agrep -0 -c 'CAGTGGACTGCAAAGAC' *.fastq > count/B9864_Fm0.txt
agrep -0 -c 'GGCTCGGTTTAGTCCGA' *.fastq > count/B9865_Fm0.txt
agrep -0 -c 'GTATGGGTGCAAAAACC' *.fastq > count/B9866_Fm0.txt
agrep -0 -c 'AGTTATTCGCACTTGAG' *.fastq > count/B9867_Fm0.txt
agrep -0 -c 'CATAACGTCAATTAGCG' *.fastq > count/B9868_Fm0.txt
agrep -0 -c 'GCGATAATTTTTTGGGG' *.fastq > count/B9869_Fm0.txt
agrep -0 -c 'ACACTGGTAGGAGCTCG' *.fastq > count/B9871_Fm0.txt
agrep -0 -c 'AGACGGAGTGAGTTTTT' *.fastq > count/B9872_Fm0.txt
agrep -0 -c 'CTATCCGCCTTGTCTCT' *.fastq > count/B9873_Fm0.txt
agrep -0 -c 'GCACAAATGTAGGGACT' *.fastq > count/B9874_Fm0.txt
agrep -0 -c 'CGTTAGTATAGGAGGCC' *.fastq > count/B9876_Fm0.txt
agrep -0 -c 'TAGCGATACGGCTATAT' *.fastq > count/B9877_Fm0.txt
agrep -0 -c 'TGTATGGCGGGATCCAG' *.fastq > count/B9879_Fm0.txt
agrep -0 -c 'GTCCGAAGCTGTTAGCG' *.fastq > count/B9882_Fm0.txt
agrep -0 -c 'CGGTCTTATTGCCAAAT' *.fastq > count/B9883_Fm0.txt
agrep -0 -c 'TATTACGCGCGGAAGAA' *.fastq > count/B9884_Fm0.txt
agrep -0 -c 'ATTCGAATCGGGAAGAG' *.fastq > count/B9885_Fm0.txt
agrep -0 -c 'CCACTCACCGATTCGGT' *.fastq > count/B9886_Fm0.txt
agrep -0 -c 'GCCGGTTGCTGAATATC' *.fastq > count/B9887_Fm0.txt
agrep -0 -c 'GTATCATAGGGTCTAGA' *.fastq > count/B9888_Fm0.txt
agrep -0 -c 'GCCGTGGAGAGTAAAAC' *.fastq > count/B9892_Fm0.txt
agrep -0 -c 'AGCCGCTATAGAGGAGC' *.fastq > count/B9894_Fm0.txt
agrep -0 -c 'CTCCGACCTCTACTCTC' *.fastq > count/B9896_Fm0.txt
agrep -0 -c 'AGTCGCTTTACACATTG' *.fastq > count/B9897_Fm0.txt
agrep -0 -c 'TTCCAAGTGTTCGGGCT' *.fastq > count/B9898_Fm0.txt
agrep -0 -c 'TGCGCGGAATAGCGTAC' *.fastq > count/B9899_Fm0.txt
agrep -0 -c 'CAAGCAGACGCTGATCG' *.fastq > count/B9900_Fm0.txt
agrep -0 -c 'CCGGTCGGATCTGCTTA' *.fastq > count/B9901_Fm0.txt
agrep -0 -c 'GGTTGGTGATCCACTGA' *.fastq > count/B9902_Fm0.txt
agrep -0 -c 'GGACAATAAAGAAGGGT' *.fastq > count/B9903_Fm0.txt
agrep -0 -c 'ACGTTGGCCGGTCAATA' *.fastq > count/B9905_Fm0.txt
agrep -0 -c 'GAGTAACGGGTCAGAGA' *.fastq > count/B9906_Fm0.txt
agrep -0 -c 'CGGATAGGAATGGTCCT' *.fastq > count/B9907_Fm0.txt
agrep -0 -c 'TGCCCTCGTATTCACCC' *.fastq > count/B9908_Fm0.txt
agrep -0 -c 'AGGCCTATTCAACAACC' *.fastq > count/B9909_Fm0.txt
agrep -0 -c 'TCGTAGGGACGTTCCAG' *.fastq > count/B9910_Fm0.txt
agrep -0 -c 'CTTCGTTGACGCCCTAT' *.fastq > count/B9911_Fm0.txt
agrep -0 -c 'AACAGTCTGCGTCAACC' *.fastq > count/B9912_Fm0.txt
agrep -0 -c 'CGCTTGCTACATCTAGA' *.fastq > count/B9914_Fm0.txt
agrep -0 -c 'GGCGTAGAAGATCGGAG' *.fastq > count/B9915_Fm0.txt
agrep -0 -c 'ATCAGCGCAAGACGCAA' *.fastq > count/B9916_Fm0.txt
agrep -0 -c 'CACGCTGAGGCGTCATA' *.fastq > count/B9917_Fm0.txt
agrep -0 -c 'GACTGGTTTGGAACTGG' *.fastq > count/B9918_Fm0.txt
agrep -0 -c 'TCGCGAACGACCTTAGT' *.fastq > count/B9919_Fm0.txt
agrep -0 -c 'GCACCTCATCCGTGTAT' *.fastq > count/B9922_Fm0.txt
agrep -0 -c 'ACCCCTGCTTGAGAACA' *.fastq > count/B9923_Fm0.txt
agrep -0 -c 'ACAACCTCACCCGGATA' *.fastq > count/B9924_Fm0.txt
agrep -0 -c 'TAGACGAAGCTGAGCCT' *.fastq > count/B9925_Fm0.txt
agrep -0 -c 'TGAGTCATATCTTCCCT' *.fastq > count/B9926_Fm0.txt
agrep -0 -c 'GTCCGTATCTTACTTCA' *.fastq > count/B9927_Fm0.txt
agrep -0 -c 'GCCAGTTGTCGAGATCG' *.fastq > count/B9928_Fm0.txt
agrep -0 -c 'TGCATAGGACCTACGGA' *.fastq > count/B9929_Fm0.txt
agrep -0 -c 'GGGATGATATAGTTACC' *.fastq > count/B9930_Fm0.txt
agrep -0 -c 'TAGTGCAGTAGGCCGTG' *.fastq > count/B9931_Fm0.txt
agrep -0 -c 'CTCGACGACTGGTAAAT' *.fastq > count/B9932_Fm0.txt
agrep -0 -c 'CCTAACATACGCTACCG' *.fastq > count/B9933_Fm0.txt
agrep -0 -c 'TAGAGCTCAGGCTTGCG' *.fastq > count/B9934_Fm0.txt
agrep -0 -c 'CTCGGACGCAAGATACA' *.fastq > count/B9935_Fm0.txt
agrep -0 -c 'TATTGGTCAAGTTGGCA' *.fastq > count/B9936_Fm0.txt
agrep -0 -c 'ATTTGTAGCTGGTTCCG' *.fastq > count/B9937_Fm0.txt
agrep -0 -c 'ACGATCTCGACTCAGCG' *.fastq > count/B9939_Fm0.txt
agrep -0 -c 'ACTGTTCTAAACAGCAC' *.fastq > count/B9940_Fm0.txt
agrep -0 -c 'GCCACGACGTCATATTG' *.fastq > count/B9941_Fm0.txt
agrep -0 -c 'TAACCTAAGCGGAAATC' *.fastq > count/B9942_Fm0.txt
agrep -0 -c 'GGGTAGTGACGTGGTAT' *.fastq > count/B9943_Fm0.txt
agrep -0 -c 'ATAACATACTGAGGGGG' *.fastq > count/B9944_Fm0.txt
agrep -0 -c 'CAGTTTGATGAGCCGAC' *.fastq > count/B9945_Fm0.txt
agrep -0 -c 'GTCGCTATTGCTGTGGG' *.fastq > count/B9946_Fm0.txt
agrep -0 -c 'CCAGTGGTGAACACTGA' *.fastq > count/B9947_Fm0.txt
agrep -0 -c 'TGGAGGAGCCTCTTGTC' *.fastq > count/B9948_Fm0.txt
agrep -0 -c 'GGAGTTCCTATGCGACG' *.fastq > count/B9949_Fm0.txt
agrep -0 -c 'AAGGCCGATTTTCGGAG' *.fastq > count/B9950_Fm0.txt
agrep -0 -c 'TCAGGTAGCGGTGGGTT' *.fastq > count/B9951_Fm0.txt
agrep -0 -c 'CGTATTGACCGCACGTT' *.fastq > count/B9952_Fm0.txt
agrep -0 -c 'ACAAATATGCGGCTAAG' *.fastq > count/B9953_Fm0.txt
agrep -0 -c 'TGAGATCCCGAACTCTA' *.fastq > count/B9954_Fm0.txt
agrep -0 -c 'TCATCTGTGAGGCATTC' *.fastq > count/B9955_Fm0.txt
agrep -0 -c 'TTGATATGTCGCCTCAA' *.fastq > count/B9956_Fm0.txt
agrep -0 -c 'CGTCTGTGTTCGGAAAA' *.fastq > count/B9957_Fm0.txt
agrep -0 -c 'AGGGCCGACTAGAACAT' *.fastq > count/B9958_Fm0.txt
agrep -0 -c 'CCATAGCAAGGTCCGGT' *.fastq > count/B9959_Fm0.txt
agrep -0 -c 'GGAGCATCCGATTTGTA' *.fastq > count/B9960_Fm0.txt
agrep -0 -c 'GTAGAAGGGCATACGTG' *.fastq > count/B9961_Fm0.txt
agrep -0 -c 'CGCGTCACAAGAAGAGT' *.fastq > count/B9963_Fm0.txt
agrep -0 -c 'CCACCACTATCGTATTT' *.fastq > count/B9965_Fm0.txt
agrep -0 -c 'AATGACCAGAAGGATGA' *.fastq > count/B9966_Fm0.txt
agrep -0 -c 'TGTCATTGGGAGCGTCA' *.fastq > count/B9967_Fm0.txt
agrep -0 -c 'CATGCCAGGAATATCGA' *.fastq > count/B9970_Fm0.txt
agrep -0 -c 'GGACGTTACAGGTATAA' *.fastq > count/B9972_Fm0.txt
agrep -0 -c 'TCTAACCAGGTCTAATC' *.fastq > count/B9973_Fm0.txt
agrep -0 -c 'CAACGCTAACGCAGTGC' *.fastq > count/B9974_Fm0.txt
agrep -0 -c 'AGTGCGCCAATTGTTTG' *.fastq > count/B9975_Fm0.txt
agrep -0 -c 'GCACGAGATCATTTCCG' *.fastq > count/B9976_Fm0.txt
agrep -0 -c 'CTCAAGGAAGAGACCGA' *.fastq > count/B9977_Fm0.txt
agrep -0 -c 'CAGTCCTGCGTATGACC' *.fastq > count/B9980_Fm0.txt
agrep -0 -c 'CACGCCATTGTTAACAA' *.fastq > count/B9982_Fm0.txt
agrep -0 -c 'GATTGGCACCCCTGATA' *.fastq > count/B9984_Fm0.txt
agrep -0 -c 'GAGCTGAGCCACTAACT' *.fastq > count/B9985_Fm0.txt
agrep -0 -c 'ACATAAAGTGTTAGGCG' *.fastq > count/B9986_Fm0.txt
agrep -0 -c 'CCAATTTCAACTGACGT' *.fastq > count/B9987_Fm0.txt
agrep -0 -c 'AGCCTCACGCGGAATCT' *.fastq > count/B9988_Fm0.txt
agrep -0 -c 'CGGGTCTCGTGAACAAT' *.fastq > count/B9990_Fm0.txt
agrep -0 -c 'ACGAAAAAAATCGCCCA' *.fastq > count/B9991_Fm0.txt
agrep -0 -c 'CCGAAGTCCGATCTACA' *.fastq > count/B9993_Fm0.txt
agrep -0 -c 'AGGAAGGTATCCACTGG' *.fastq > count/B9994_Fm0.txt
agrep -0 -c 'CAGTCTATCCGTAGAGG' *.fastq > count/B9996_Fm0.txt
agrep -0 -c 'CTCCTCTGAATACCACG' *.fastq > count/B9997_Fm0.txt
agrep -0 -c 'CAAGACGATGCAGTCCA' *.fastq > count/B9998_Fm0.txt
agrep -0 -c 'CGGCATCCAAGGAAGCT' *.fastq > count/B10001_Fm0.txt
agrep -0 -c 'TCTAACGAAGCCCCAGC' *.fastq > count/B10002_Fm0.txt
agrep -0 -c 'ACGATAGTCAGCCGTCA' *.fastq > count/B10003_Fm0.txt
agrep -0 -c 'CGCTTAACCTGAGTAGT' *.fastq > count/B10004_Fm0.txt
agrep -0 -c 'GTTACTCGGAACCACAC' *.fastq > count/B10005_Fm0.txt
agrep -0 -c 'GGGAAGCAATGTTTGGC' *.fastq > count/B10006_Fm0.txt
agrep -0 -c 'TTGTGCTTGATAGAGCA' *.fastq > count/B10007_Fm0.txt
agrep -0 -c 'ATCTGTGCGACTATGCG' *.fastq > count/B10008_Fm0.txt
agrep -0 -c 'GCGCAGATCGTATACTT' *.fastq > count/B10009_Fm0.txt
agrep -0 -c 'GCGATGAAGCAGTTGTT' *.fastq > count/B10010_Fm0.txt
agrep -0 -c 'GATCTACCCCTCGGTCT' *.fastq > count/B10011_Fm0.txt
agrep -0 -c 'GTGTCTACGGTTGGGAT' *.fastq > count/B10012_Fm0.txt
agrep -0 -c 'CTTAAGGAGCTGTAGTG' *.fastq > count/B10013_Fm0.txt
agrep -0 -c 'CACGTGTTAAGCGAAGA' *.fastq > count/B10015_Fm0.txt
agrep -0 -c 'TGTGCACTCATGGACGG' *.fastq > count/B10016_Fm0.txt
agrep -0 -c 'CATCACTGTCTTGGTCG' *.fastq > count/B10017_Fm0.txt
agrep -0 -c 'CTTGTCCAACTAGGGCT' *.fastq > count/B10018_Fm0.txt
agrep -0 -c 'GATCAATTGGCCCGCAT' *.fastq > count/B10020_Fm0.txt
agrep -0 -c 'GATAGGACTTCAATGCC' *.fastq > count/B10021_Fm0.txt
agrep -0 -c 'AACTGAGTGCATCAGCA' *.fastq > count/B10022_Fm0.txt
agrep -0 -c 'GGAGTGGTTCAATCTTC' *.fastq > count/B10023_Fm0.txt
agrep -0 -c 'TGGCTTAGCGACAGAAA' *.fastq > count/B10024_Fm0.txt
agrep -0 -c 'TCTCACACGTCTGGCTA' *.fastq > count/B10025_Fm0.txt
agrep -0 -c 'AGCGTTGTTTACGATCG' *.fastq > count/B10028_Fm0.txt
agrep -0 -c 'GTGGCACTGAATATTGT' *.fastq > count/B10029_Fm0.txt
agrep -0 -c 'CATCGAGTGCACAAGGA' *.fastq > count/B10031_Fm0.txt
agrep -0 -c 'GGCTTCCGTCGGTATCA' *.fastq > count/B10032_Fm0.txt
agrep -0 -c 'TCTAATTGGCGGACCGA' *.fastq > count/B10033_Fm0.txt
agrep -0 -c 'TTGGTCAACCGTTGCGG' *.fastq > count/B10034_Fm0.txt
agrep -0 -c 'GACGGTACACGTGTACC' *.fastq > count/B10035_Fm0.txt
agrep -0 -c 'CGTGGGTGCGTCTTTTG' *.fastq > count/B10036_Fm0.txt
agrep -0 -c 'CGTAGATGTCTACGAAA' *.fastq > count/B10037_Fm0.txt
agrep -0 -c 'TAAACGAGACGGTGTGC' *.fastq > count/B10039_Fm0.txt
agrep -0 -c 'AGTATGACTGTCGACAA' *.fastq > count/B10040_Fm0.txt
agrep -0 -c 'TGGCAGACCCTTCTAAC' *.fastq > count/B10041_Fm0.txt
agrep -0 -c 'CTGAAGCACGCCTCTTT' *.fastq > count/B10044_Fm0.txt
agrep -0 -c 'AGTGCTATAAAAACGGC' *.fastq > count/B10045_Fm0.txt
agrep -0 -c 'AGTGGGTATACCCCCGT' *.fastq > count/B10046_Fm0.txt
agrep -0 -c 'ACGTAGACTACAATCCC' *.fastq > count/B10047_Fm0.txt
agrep -0 -c 'GGCGATAAGCTTGACAT' *.fastq > count/B10048_Fm0.txt
agrep -0 -c 'CCTTTGCGACAGCAGGT' *.fastq > count/B10049_Fm0.txt
agrep -0 -c 'TCACTGTGGAAATGCCC' *.fastq > count/B10050_Fm0.txt
agrep -0 -c 'GTTCCAGAAAACCGGTA' *.fastq > count/B10051_Fm0.txt
agrep -0 -c 'AGTGAGTCGACTTGTTC' *.fastq > count/B10052_Fm0.txt
agrep -0 -c 'GGGACAAATCACTTCGA' *.fastq > count/B10053_Fm0.txt
agrep -0 -c 'ATATGGCTCGATCTCGG' *.fastq > count/B10054_Fm0.txt
agrep -0 -c 'GTTGGATTACGGGTCTC' *.fastq > count/B10057_Fm0.txt
agrep -0 -c 'CTATGAAGCCACCACGT' *.fastq > count/B10058_Fm0.txt
agrep -0 -c 'CATGTGTCATTGTCAAC' *.fastq > count/B10059_Fm0.txt
agrep -0 -c 'GTGTCCGTTCTTTCCGT' *.fastq > count/B10060_Fm0.txt
agrep -0 -c 'CCAACGAGCATTATGCG' *.fastq > count/B10061_Fm0.txt
agrep -0 -c 'TCTTAGCCCTGCGAGGT' *.fastq > count/B10062_Fm0.txt
agrep -0 -c 'GTGATATAAATTGGCCC' *.fastq > count/B10063_Fm0.txt
agrep -0 -c 'ACACCATCTCACTTATC' *.fastq > count/B10065_Fm0.txt
agrep -0 -c 'AGAGAGATGCCCGTGAG' *.fastq > count/B10067_Fm0.txt
agrep -0 -c 'CCAAGAGCGCCGATATT' *.fastq > count/B10068_Fm0.txt
agrep -0 -c 'CAACGGGTGCATTAATT' *.fastq > count/B10069_Fm0.txt
agrep -0 -c 'AATGCAGGATACTCCGG' *.fastq > count/B10070_Fm0.txt
agrep -0 -c 'CCGTTCGCAGATAATGT' *.fastq > count/B10071_Fm0.txt
agrep -0 -c 'AACTTGGGGCGTCATTA' *.fastq > count/B10072_Fm0.txt
agrep -0 -c 'CCGGCTATCACAAAATT' *.fastq > count/B10073_Fm0.txt
agrep -0 -c 'ACTAGCTAACCATGGCT' *.fastq > count/B10074_Fm0.txt
agrep -0 -c 'TGGAGATCACGTGTCGG' *.fastq > count/B10075_Fm0.txt
agrep -0 -c 'GGTGCTCGCAGCGTTAA' *.fastq > count/B10076_Fm0.txt
agrep -0 -c 'AGACAGTCAGCCGAAAT' *.fastq > count/B10078_Fm0.txt
agrep -0 -c 'CGTCTACTGAAGCTGGG' *.fastq > count/B10080_Fm0.txt
agrep -0 -c 'TGTAAGTGATCGTGAGC' *.fastq > count/B10081_Fm0.txt
agrep -0 -c 'ATTTCCGTGTGACCATA' *.fastq > count/B10082_Fm0.txt
agrep -0 -c 'CTCGATCGCAAGATACC' *.fastq > count/B10084_Fm0.txt
agrep -0 -c 'CGGCGCAAGGTCTGTTA' *.fastq > count/B10085_Fm0.txt
agrep -0 -c 'TTGACAGCAACGGCGGA' *.fastq > count/B10086_Fm0.txt
agrep -0 -c 'TAAACCGAGAGATTCAG' *.fastq > count/B10087_Fm0.txt
agrep -0 -c 'TAATGTACGAGGACTGA' *.fastq > count/B10088_Fm0.txt
agrep -0 -c 'CTATGAGGCCTAATCGG' *.fastq > count/B10089_Fm0.txt
agrep -0 -c 'CACAACCAGACTAAATG' *.fastq > count/B10090_Fm0.txt
agrep -0 -c 'CGATCCTGGTGACTATG' *.fastq > count/B10091_Fm0.txt
agrep -0 -c 'CCACTGTACTAGCTAAC' *.fastq > count/B10092_Fm0.txt
agrep -0 -c 'GGTGGTGTAACGAGTGT' *.fastq > count/B10093_Fm0.txt
agrep -0 -c 'CCTAAGGGAGGCGTTTA' *.fastq > count/B10094_Fm0.txt
agrep -0 -c 'GGAATGTGCCCTCTTCC' *.fastq > count/B10095_Fm0.txt
agrep -0 -c 'GTCGAGCAGGACCTTGA' *.fastq > count/B10096_Fm0.txt
agrep -0 -c 'CAGTTAGACTACGGGCA' *.fastq > count/B10097_Fm0.txt
agrep -0 -c 'TATGGTAGCATACTCGG' *.fastq > count/B10098_Fm0.txt
agrep -0 -c 'CATTGCCATTTAGCTAG' *.fastq > count/B10100_Fm0.txt
agrep -0 -c 'AACGAACCATCGGTGAT' *.fastq > count/B10101_Fm0.txt
agrep -0 -c 'ATCTACTCCCAGATTGT' *.fastq > count/B10103_Fm0.txt
agrep -0 -c 'CTCTAACACCGCATGCT' *.fastq > count/B10104_Fm0.txt
agrep -0 -c 'GGGTAATGTGTTGTACT' *.fastq > count/B10105_Fm0.txt
agrep -0 -c 'CCAGCGTTATCTCACTA' *.fastq > count/B10106_Fm0.txt
agrep -0 -c 'TTAGGTGCGCCCGTGTT' *.fastq > count/B10107_Fm0.txt
agrep -0 -c 'TCGCTAGGTTTTGTAGC' *.fastq > count/B10108_Fm0.txt
agrep -0 -c 'ATGTTCAGCCGTCTGAA' *.fastq > count/B10109_Fm0.txt
agrep -0 -c 'ATAGTCCCACGGTATAT' *.fastq > count/B10110_Fm0.txt
agrep -0 -c 'AACCGTTCCATTAACAC' *.fastq > count/B10111_Fm0.txt
agrep -0 -c 'AACGTGGTCCTTTTCAT' *.fastq > count/B10112_Fm0.txt
agrep -0 -c 'TTCCCCTTGGTGTTCTA' *.fastq > count/B10113_Fm0.txt
agrep -0 -c 'GCTGACACGAACTCTCA' *.fastq > count/B10115_Fm0.txt
agrep -0 -c 'CGGCGTATACGGAATAA' *.fastq > count/B10117_Fm0.txt
agrep -0 -c 'TCATGCCTAGGTGTGCT' *.fastq > count/B10119_Fm0.txt
agrep -0 -c 'CACATGATCGACCCTCT' *.fastq > count/B10120_Fm0.txt
agrep -0 -c 'CACACTGTCCACTCGTC' *.fastq > count/B10121_Fm0.txt
agrep -0 -c 'CTGTCGACGATTCAGGT' *.fastq > count/B10122_Fm0.txt
agrep -0 -c 'ATGACTGGAGAGTGTTG' *.fastq > count/B10123_Fm0.txt
agrep -0 -c 'CTAGTAACCCTACACGA' *.fastq > count/B10125_Fm0.txt
agrep -0 -c 'GTGGGGGACGTAACTTA' *.fastq > count/B10126_Fm0.txt
agrep -0 -c 'AGCCGTAAATTTTCCAG' *.fastq > count/B10127_Fm0.txt
agrep -0 -c 'GGCCTACGTAAGTCATC' *.fastq > count/B10128_Fm0.txt
agrep -0 -c 'CACTGTCGACACCCATC' *.fastq > count/B10129_Fm0.txt
agrep -0 -c 'GCGGTTTTTGTGTGCGT' *.fastq > count/B10130_Fm0.txt
agrep -0 -c 'AGTGTGGTGCTAGTCCG' *.fastq > count/B10131_Fm0.txt
agrep -0 -c 'GTACCGTTCCACACTGC' *.fastq > count/B10132_Fm0.txt
agrep -0 -c 'TCAGAACTCCCCGATTT' *.fastq > count/B10133_Fm0.txt
agrep -0 -c 'ACACAGTTACGTGTGTA' *.fastq > count/B10135_Fm0.txt
agrep -0 -c 'GTAAAACACATCCCGAT' *.fastq > count/B10136_Fm0.txt
agrep -0 -c 'GTTCGTGTTTCTTTCGC' *.fastq > count/B10137_Fm0.txt
agrep -0 -c 'TTGTAAGTCAACCCGGT' *.fastq > count/B10140_Fm0.txt
agrep -0 -c 'ATCACTTGCTACACGGA' *.fastq > count/B10141_Fm0.txt
agrep -0 -c 'GACAGGTGGTTACATAA' *.fastq > count/B10142_Fm0.txt
agrep -0 -c 'AGTTACTAAACGGGAGG' *.fastq > count/B10143_Fm0.txt
agrep -0 -c 'CGAGCACCCTCCTGATA' *.fastq > count/B10144_Fm0.txt
agrep -0 -c 'CGATGCCTTCCCTAGTG' *.fastq > count/B10145_Fm0.txt
agrep -0 -c 'CAGGATAAGGGAACCGG' *.fastq > count/B10146_Fm0.txt
agrep -0 -c 'GCGCTTATATTCATGCG' *.fastq > count/B10147_Fm0.txt
agrep -0 -c 'CTGCTGTAACGAAAGTT' *.fastq > count/B10148_Fm0.txt
agrep -0 -c 'AGAGATGGACCAGTACG' *.fastq > count/B10149_Fm0.txt
agrep -0 -c 'TCGACATCAGAACTTGT' *.fastq > count/B10150_Fm0.txt
agrep -0 -c 'AACCGTATCGTGCAGGT' *.fastq > count/B10151_Fm0.txt
agrep -0 -c 'TGGATGGTTCCACGACG' *.fastq > count/B10154_Fm0.txt
agrep -0 -c 'ACTGCTATTAATCCGGA' *.fastq > count/B10155_Fm0.txt
agrep -0 -c 'CAGTGCGTAAACATCAA' *.fastq > count/B10156_Fm0.txt
agrep -0 -c 'TCACGCTGAGATACTTC' *.fastq > count/B10157_Fm0.txt
agrep -0 -c 'TGCCATTGGCAATAACA' *.fastq > count/B10158_Fm0.txt
agrep -0 -c 'GGATAGACGTTGGTCCC' *.fastq > count/B10159_Fm0.txt
agrep -0 -c 'CGTATACTCTCCCGTAA' *.fastq > count/B10160_Fm0.txt
agrep -0 -c 'CCTCAGGCCAAACATTC' *.fastq > count/B10162_Fm0.txt
agrep -0 -c 'TACCAACTATACTGGTC' *.fastq > count/B10164_Fm0.txt
agrep -0 -c 'CCAATGCGGAGCGGTAT' *.fastq > count/B10165_Fm0.txt
agrep -0 -c 'CGGACTGTTTTGACCGA' *.fastq > count/B10166_Fm0.txt
agrep -0 -c 'TATGCTGTGGCCTACGT' *.fastq > count/B10168_Fm0.txt
agrep -0 -c 'GATGGAAAAGGCCGACG' *.fastq > count/B10169_Fm0.txt
agrep -0 -c 'AACACTTTTTACGCTCG' *.fastq > count/B10170_Fm0.txt
agrep -0 -c 'TGAGCGCGAGCCTAAGA' *.fastq > count/B10171_Fm0.txt
agrep -0 -c 'GAGTTCCCTTTCCAAAC' *.fastq > count/B10172_Fm0.txt
agrep -0 -c 'GTGTGCGTGGTCAACTC' *.fastq > count/B10173_Fm0.txt
agrep -0 -c 'GGTCTGTCTAACAGATC' *.fastq > count/B10174_Fm0.txt
agrep -0 -c 'GGACGGATGGTCACAAA' *.fastq > count/B10175_Fm0.txt
agrep -0 -c 'ATTCGGTGCCTCGGATC' *.fastq > count/B10176_Fm0.txt
agrep -0 -c 'TCAACGGTCACATTACC' *.fastq > count/B10177_Fm0.txt
agrep -0 -c 'CAACTGAGACATCCCAA' *.fastq > count/B10178_Fm0.txt
agrep -0 -c 'CCTGCAGGAGTGAACAT' *.fastq > count/B10180_Fm0.txt
agrep -0 -c 'ACGCCGGTAGTGCTTAC' *.fastq > count/B10182_Fm0.txt
agrep -0 -c 'TTATAAGTGGTCAGCCA' *.fastq > count/B10183_Fm0.txt
agrep -0 -c 'ATCTTATGACCACGACG' *.fastq > count/B10184_Fm0.txt
agrep -0 -c 'TGCGACAGGCATCTCGT' *.fastq > count/B10185_Fm0.txt
agrep -0 -c 'GATTAATGCGGGACATG' *.fastq > count/B10186_Fm0.txt
agrep -0 -c 'CGATCCATATGAGAGTA' *.fastq > count/B10187_Fm0.txt
agrep -0 -c 'TACCCCTTGAAGGAAAC' *.fastq > count/B10188_Fm0.txt
agrep -0 -c 'CAACTATAAGCGCTTAG' *.fastq > count/B10189_Fm0.txt
agrep -0 -c 'ACGCCAAGTGTGAACGT' *.fastq > count/B10191_Fm0.txt
agrep -0 -c 'CCTGGAGTAATAACACC' *.fastq > count/B10192_Fm0.txt
agrep -0 -c 'GTACTCTTGCAATAGGC' *.fastq > count/B10193_Fm0.txt
agrep -0 -c 'TGTTCATGGCAAGACTC' *.fastq > count/B10194_Fm0.txt
agrep -0 -c 'CTACGCATTGGATCTCT' *.fastq > count/B10195_Fm0.txt
agrep -0 -c 'TAGTCAGTGCTGCGCTT' *.fastq > count/B10196_Fm0.txt
agrep -0 -c 'GAGCGCACCTTTGTTCT' *.fastq > count/B10198_Fm0.txt
agrep -0 -c 'CGAAGGTTCTTGACGAG' *.fastq > count/B10199_Fm0.txt
agrep -0 -c 'GTATCCTCAATATCGCA' *.fastq > count/B10200_Fm0.txt
agrep -0 -c 'ATCCAGCTACTCGTTAG' *.fastq > count/B10201_Fm0.txt
agrep -0 -c 'CCAGGTTCGTCCCTATC' *.fastq > count/B10202_Fm0.txt
agrep -0 -c 'AGCAGATTTCGTCGTAA' *.fastq > count/B10203_Fm0.txt
agrep -0 -c 'TAGGATAACCAGCGGCA' *.fastq > count/B10204_Fm0.txt
agrep -0 -c 'TCATTAGCAGCGGTGCC' *.fastq > count/B10205_Fm0.txt
agrep -0 -c 'ATATACGTAGTCTGCTG' *.fastq > count/B10206_Fm0.txt
agrep -0 -c 'CTATCGTAATTTCACCG' *.fastq > count/B10207_Fm0.txt
agrep -0 -c 'GAGCGCACTGAAGATGG' *.fastq > count/B10208_Fm0.txt
agrep -0 -c 'TGCGAGTTTGTGTGTCA' *.fastq > count/B10209_Fm0.txt
agrep -0 -c 'AGGCATGCCCTTTGCGT' *.fastq > count/B10210_Fm0.txt
agrep -0 -c 'AGGACAACAGGGGACTA' *.fastq > count/B10213_Fm0.txt
agrep -0 -c 'CGATAAGCTTCCATGAT' *.fastq > count/B10214_Fm0.txt
agrep -0 -c 'GTGACTAGATTGGTTCA' *.fastq > count/B10215_Fm0.txt
agrep -0 -c 'AATTCAAGTTTGGGGGC' *.fastq > count/B10216_Fm0.txt
agrep -0 -c 'TATGCCAAGCGATTCCC' *.fastq > count/B10217_Fm0.txt
agrep -0 -c 'ATAGCCGTGTCCTGAGA' *.fastq > count/B10218_Fm0.txt
agrep -0 -c 'GCAATTAGGTACGACGA' *.fastq > count/B10220_Fm0.txt
agrep -0 -c 'AGCTGGGGACACTACTC' *.fastq > count/B10221_Fm0.txt
agrep -0 -c 'TGCAACTTAGTCGGACA' *.fastq > count/B10223_Fm0.txt
agrep -0 -c 'TATCTCCGGGTTATGTG' *.fastq > count/B10224_Fm0.txt
agrep -0 -c 'GCATTTATAGGGCGACT' *.fastq > count/B10225_Fm0.txt
agrep -0 -c 'GGACTAACTCGCAGTAT' *.fastq > count/B10226_Fm0.txt
agrep -0 -c 'CCACACTCTATCATCGA' *.fastq > count/B10228_Fm0.txt
agrep -0 -c 'CAAATTCCCAAAGGGAT' *.fastq > count/B10229_Fm0.txt
agrep -0 -c 'GCAACGATGCTTTGAAA' *.fastq > count/B10230_Fm0.txt
agrep -0 -c 'GTGGAGCATTACAGTCG' *.fastq > count/B10232_Fm0.txt
agrep -0 -c 'TTCAGTAGCAGGCGAGG' *.fastq > count/B10233_Fm0.txt
agrep -0 -c 'TAGGGTCGCACTATGTC' *.fastq > count/B10235_Fm0.txt
agrep -0 -c 'CGCGCCTTATTGTTTAA' *.fastq > count/B10236_Fm0.txt
agrep -0 -c 'AGGGTGGAACACGTATT' *.fastq > count/B10237_Fm0.txt
agrep -0 -c 'GCCGCGAAAGTGCTGTA' *.fastq > count/B10238_Fm0.txt
agrep -0 -c 'AATACCGTATGGTGCGT' *.fastq > count/B10239_Fm0.txt
agrep -0 -c 'ACGACTCAAGTTAACCA' *.fastq > count/B10240_Fm0.txt
agrep -0 -c 'TTCTAGAGCCGGGGGTT' *.fastq > count/B10242_Fm0.txt
agrep -0 -c 'GCGAACGTCCTGTGATA' *.fastq > count/B10243_Fm0.txt
agrep -0 -c 'CAAAAATGAGTCACCTC' *.fastq > count/B10244_Fm0.txt
agrep -0 -c 'GCATTGTGGCGGCTTAT' *.fastq > count/B10245_Fm0.txt
agrep -0 -c 'TTCTCGGTAGAGTTCGT' *.fastq > count/B10246_Fm0.txt
agrep -0 -c 'ATCGGGTGTACTATCCC' *.fastq > count/B10247_Fm0.txt
agrep -0 -c 'CCACGCCTAAAGCCTTA' *.fastq > count/B10248_Fm0.txt
agrep -0 -c 'AATAGTCGCACTCGGTG' *.fastq > count/B10250_Fm0.txt
agrep -0 -c 'GATAGACATGGCTAACG' *.fastq > count/B10251_Fm0.txt
agrep -0 -c 'CGTTGTCCTAGCATCGT' *.fastq > count/B10253_Fm0.txt
agrep -0 -c 'AGTTGGCTATCTCGTGC' *.fastq > count/B10254_Fm0.txt
agrep -0 -c 'GGGTGCTGGCTGATCAA' *.fastq > count/B10255_Fm0.txt
agrep -0 -c 'TTAAGCACGACAGTGGC' *.fastq > count/B10256_Fm0.txt
agrep -0 -c 'CGCAATCTCGTCGCTTT' *.fastq > count/B10257_Fm0.txt
agrep -0 -c 'GTTCTCGGCGTAGGTTC' *.fastq > count/B10258_Fm0.txt
agrep -0 -c 'GGCCATAAGTACGCTCC' *.fastq > count/B10259_Fm0.txt
agrep -0 -c 'CTCGCGACAAACTGTCT' *.fastq > count/B10260_Fm0.txt
agrep -0 -c 'CTTGATGGTGCCCGATA' *.fastq > count/B10261_Fm0.txt
agrep -0 -c 'TACCAGTGACTTGGCTT' *.fastq > count/B10263_Fm0.txt
agrep -0 -c 'GTGCGATCTAAGGCCTA' *.fastq > count/B10264_Fm0.txt
agrep -0 -c 'TTCCTCTTTGCGTATGG' *.fastq > count/B10265_Fm0.txt
agrep -0 -c 'TAGGAGTTGGCAGAAAC' *.fastq > count/B10266_Fm0.txt
agrep -0 -c 'AGAACAAGTCCTCCCGA' *.fastq > count/B10267_Fm0.txt
agrep -0 -c 'ATCCGACTACATAGGGA' *.fastq > count/B10268_Fm0.txt
agrep -0 -c 'TTGTCTCAGGCACGAGT' *.fastq > count/B10270_Fm0.txt
agrep -0 -c 'CGTCGGCAGTCATTTAG' *.fastq > count/B10271_Fm0.txt
agrep -0 -c 'TGACGCGAACAGCTAAG' *.fastq > count/B10272_Fm0.txt
agrep -0 -c 'AGTTTTCGAGAGGAGGT' *.fastq > count/B10273_Fm0.txt
agrep -0 -c 'GTATTGTCAACCGTTGC' *.fastq > count/B10274_Fm0.txt
agrep -0 -c 'GCCCAAACCCTGAGTTG' *.fastq > count/B10275_Fm0.txt
agrep -0 -c 'TCTTCGCGAGAAAGTTG' *.fastq > count/B10276_Fm0.txt
agrep -0 -c 'CGTGGCTATTTCTCGAA' *.fastq > count/B10277_Fm0.txt
agrep -0 -c 'GCGTATGATGACATCTC' *.fastq > count/B10278_Fm0.txt
agrep -0 -c 'GAGAACGTAAGAACCCG' *.fastq > count/B10280_Fm0.txt
agrep -0 -c 'AGTGTTGTGGTGTCCAT' *.fastq > count/B10281_Fm0.txt
agrep -0 -c 'TTCGTGTGGAGGAAGAT' *.fastq > count/B10282_Fm0.txt
agrep -0 -c 'CGACAGTGGTCGTTAGT' *.fastq > count/B10283_Fm0.txt
agrep -0 -c 'AAGTGTCTTGGTCGAGA' *.fastq > count/B10284_Fm0.txt
agrep -0 -c 'GAGGTGCCAGTCGATCT' *.fastq > count/B10285_Fm0.txt
agrep -0 -c 'CGACGACCTAAATGTTA' *.fastq > count/B10286_Fm0.txt
agrep -0 -c 'GGCTGATCAAAGCAAGC' *.fastq > count/B10287_Fm0.txt
agrep -0 -c 'CCGATTTTTATAGGCGA' *.fastq > count/B10288_Fm0.txt
agrep -0 -c 'AGACGGCTAAAGTTAAG' *.fastq > count/B10289_Fm0.txt
agrep -0 -c 'CTTCTTCAGCTCGCGTT' *.fastq > count/B10290_Fm0.txt
agrep -0 -c 'GTACTGGCGATTCGATG' *.fastq > count/B10291_Fm0.txt
agrep -0 -c 'CTAGTGGCAGATATCAC' *.fastq > count/B10292_Fm0.txt
agrep -0 -c 'CGTAATCGTAGTAGGCA' *.fastq > count/B10294_Fm0.txt
agrep -0 -c 'GTTGATTGCGCTGCTTC' *.fastq > count/B10295_Fm0.txt
agrep -0 -c 'ACGATAGTAAGCTAGAG' *.fastq > count/B10296_Fm0.txt
agrep -0 -c 'ATACTACTAAGGACGTG' *.fastq > count/B10297_Fm0.txt
agrep -0 -c 'GTATGTTTGACGGCCTC' *.fastq > count/B10298_Fm0.txt
agrep -0 -c 'ACCTGAGGAGAGTTCGT' *.fastq > count/B10299_Fm0.txt
agrep -0 -c 'TCGAGCGGACTAAACAA' *.fastq > count/B10300_Fm0.txt
agrep -0 -c 'CAGTCTCAGATTATGCG' *.fastq > count/B10301_Fm0.txt
agrep -0 -c 'GGGGCGCATTTGTCGAA' *.fastq > count/B10302_Fm0.txt
agrep -0 -c 'TGGAGTGACAACTATGA' *.fastq > count/B10303_Fm0.txt
agrep -0 -c 'CTGTAGGCTTACTAGAC' *.fastq > count/B10304_Fm0.txt
agrep -0 -c 'CTGCCCGAGAGAACCTA' *.fastq > count/B10305_Fm0.txt
agrep -0 -c 'CATTCGTCCGGCAGTCT' *.fastq > count/B10307_Fm0.txt
agrep -0 -c 'ATGGATTTGGTCGTCTA' *.fastq > count/B10308_Fm0.txt
agrep -0 -c 'TTAGTCCGCGCTTGTCC' *.fastq > count/B10309_Fm0.txt
agrep -0 -c 'CTGTACAGGTAAAGGGA' *.fastq > count/B10310_Fm0.txt
agrep -0 -c 'TACAGCAATTCGGGTAG' *.fastq > count/B10312_Fm0.txt
agrep -0 -c 'TAAAGTCTGACGCGATC' *.fastq > count/B10314_Fm0.txt
agrep -0 -c 'TCGCTTCGGATCGACTA' *.fastq > count/B10315_Fm0.txt
agrep -0 -c 'CGGAAGTATACAAAAGG' *.fastq > count/B10317_Fm0.txt
agrep -0 -c 'CTCTGAACAGACGTTTC' *.fastq > count/B10318_Fm0.txt
agrep -0 -c 'GTGCGTTCAACCTCCTA' *.fastq > count/B10319_Fm0.txt
agrep -0 -c 'GCGCGACGTAGATGTTT' *.fastq > count/B10320_Fm0.txt
agrep -0 -c 'TTATCGCTAGGATCGAG' *.fastq > count/B10321_Fm0.txt
agrep -0 -c 'CGTCTCACCGCTTTTCA' *.fastq > count/B10322_Fm0.txt
agrep -0 -c 'CGCGTAGTATGTATCAG' *.fastq > count/B10323_Fm0.txt
agrep -0 -c 'CTACTTTCCATCGGAGA' *.fastq > count/B10324_Fm0.txt
agrep -0 -c 'AAGTTGGCGGTTACGAC' *.fastq > count/B10325_Fm0.txt
agrep -0 -c 'CGAAGATGTCACACCTG' *.fastq > count/B10326_Fm0.txt
agrep -0 -c 'CAACTGACACGGAATTG' *.fastq > count/B10327_Fm0.txt
agrep -0 -c 'GTCTCACAGTCCAGAGT' *.fastq > count/B10328_Fm0.txt
agrep -0 -c 'CGGTAAATTCGCTACAC' *.fastq > count/B10329_Fm0.txt
agrep -0 -c 'TTACGCCTTACTTCGGT' *.fastq > count/B10332_Fm0.txt
agrep -0 -c 'TACTATCTGTACTGTCG' *.fastq > count/B10333_Fm0.txt
agrep -0 -c 'CTGCCAACCGAGAATAC' *.fastq > count/B10334_Fm0.txt
agrep -0 -c 'GCGCCGTAATACCGTCA' *.fastq > count/B10335_Fm0.txt
agrep -0 -c 'GCTCTACGGTGAACAAG' *.fastq > count/B10336_Fm0.txt
agrep -0 -c 'GATGACATACCCACTAA' *.fastq > count/B10337_Fm0.txt
agrep -0 -c 'TCAAGTCAAATGCCCGC' *.fastq > count/B10339_Fm0.txt
agrep -0 -c 'TAGCGATCGCTTACCGT' *.fastq > count/B10342_Fm0.txt
agrep -0 -c 'ATTTCGGCTAGCAAGAC' *.fastq > count/B10343_Fm0.txt
agrep -0 -c 'CCTGGGTATTACACCTT' *.fastq > count/B10344_Fm0.txt
agrep -0 -c 'TGAGACGCAGTCATAGA' *.fastq > count/B10345_Fm0.txt
agrep -0 -c 'TTACGCCCCGAATTCGC' *.fastq > count/B10346_Fm0.txt
agrep -0 -c 'GAGGATAATTCCTAGGT' *.fastq > count/B10347_Fm0.txt
agrep -0 -c 'GGTGCAAATTGCAGAAA' *.fastq > count/B10348_Fm0.txt
agrep -0 -c 'GAGGACTCGTAAGCAGG' *.fastq > count/B10350_Fm0.txt
agrep -0 -c 'ATTGAGTCCCGTCCGAA' *.fastq > count/B10351_Fm0.txt
agrep -0 -c 'ATAACGTTGACCGGCCA' *.fastq > count/B10352_Fm0.txt
agrep -0 -c 'TCTCTGAGTATGTCAGC' *.fastq > count/B10353_Fm0.txt
agrep -0 -c 'TGCATCCTGCCGATTCA' *.fastq > count/B10354_Fm0.txt
agrep -0 -c 'AAGTAGCTAGCCGGTAT' *.fastq > count/B10356_Fm0.txt
agrep -0 -c 'TCTACGGAGGGTTTCAT' *.fastq > count/B10358_Fm0.txt
agrep -0 -c 'CCGATATCGGTTATTGA' *.fastq > count/B10360_Fm0.txt
agrep -0 -c 'GTCGACCAGAACCAGTA' *.fastq > count/B10361_Fm0.txt
agrep -0 -c 'CCTCGTAGTTTCACTAT' *.fastq > count/B10362_Fm0.txt
agrep -0 -c 'ATAGGGCCCAATAAATG' *.fastq > count/B10363_Fm0.txt
agrep -0 -c 'CCTGAGTCTAGGAGCTG' *.fastq > count/B10367_Fm0.txt
agrep -0 -c 'GCGAACCCATGGCAACT' *.fastq > count/B10370_Fm0.txt
agrep -0 -c 'GATAACTCAATCGGATC' *.fastq > count/B10371_Fm0.txt
agrep -0 -c 'GCCGGAAGTTGCAACAC' *.fastq > count/B10372_Fm0.txt
agrep -0 -c 'GGTTGAACAGACAGGAG' *.fastq > count/B10376_Fm0.txt
agrep -0 -c 'GATGTCGTCTTCAAGAT' *.fastq > count/B10377_Fm0.txt
agrep -0 -c 'TTCCGGACATCACTAGA' *.fastq > count/B10378_Fm0.txt
agrep -0 -c 'ACTCCGAGTATCCTAGC' *.fastq > count/B10379_Fm0.txt
agrep -0 -c 'CTTCCGTCAGGCAATGG' *.fastq > count/B10380_Fm0.txt
agrep -0 -c 'CACGCGAAAACCGTGAA' *.fastq > count/B10381_Fm0.txt
agrep -0 -c 'TGCACGCTAGGAATAAC' *.fastq > count/B10382_Fm0.txt
agrep -0 -c 'CAACCGATTACGTGCTT' *.fastq > count/B10383_Fm0.txt
agrep -0 -c 'TATCTTCCTCGGGACAC' *.fastq > count/B10384_Fm0.txt
agrep -0 -c 'ATGACACTCCCAGTTAG' *.fastq > count/B10385_Fm0.txt
agrep -0 -c 'AGTAACCCGTATACCGG' *.fastq > count/B10388_Fm0.txt
agrep -0 -c 'AATAGTTTGCTGTGGCC' *.fastq > count/B10392_Fm0.txt
agrep -0 -c 'TTGGCACCTGGCTTCAC' *.fastq > count/B10393_Fm0.txt
agrep -0 -c 'CGGTCCCACAATAGTTC' *.fastq > count/B10394_Fm0.txt
agrep -0 -c 'TGGCAATGGCCGTTACA' *.fastq > count/B10396_Fm0.txt
agrep -0 -c 'GCCTTCCAGCCTCTGAT' *.fastq > count/B10397_Fm0.txt
agrep -0 -c 'CATGAACCCGGGCCTAA' *.fastq > count/B10399_Fm0.txt
agrep -0 -c 'TTCCAGCTGCGCTTGAA' *.fastq > count/B10400_Fm0.txt
agrep -0 -c 'ACACAACTTACTTCCCC' *.fastq > count/B10401_Fm0.txt
agrep -0 -c 'GTACCATACTCTCGTCT' *.fastq > count/B10402_Fm0.txt
agrep -0 -c 'GTGCTAGAGTCATACGA' *.fastq > count/B10403_Fm0.txt
agrep -0 -c 'CGACAAGCTAGGCATTC' *.fastq > count/B10404_Fm0.txt
agrep -0 -c 'GTTCGGCGACTAAGACT' *.fastq > count/B10405_Fm0.txt
agrep -0 -c 'CAGCGGGTTTAAGTTTG' *.fastq > count/B10406_Fm0.txt
agrep -0 -c 'TCTGACAGATAACCAGG' *.fastq > count/B10407_Fm0.txt
agrep -0 -c 'ACCCACCCGCAACCTTT' *.fastq > count/B10408_Fm0.txt
agrep -0 -c 'AGACCATGCGGCATGCT' *.fastq > count/B10409_Fm0.txt
agrep -0 -c 'ACCAACTCCGAAGTACT' *.fastq > count/B10410_Fm0.txt
agrep -0 -c 'CATAGCGCATCTCTAGG' *.fastq > count/B10411_Fm0.txt
agrep -0 -c 'TCTTTGTCGGATTCGCT' *.fastq > count/B10412_Fm0.txt
agrep -0 -c 'GATTCGCAGTTATGCTG' *.fastq > count/B10413_Fm0.txt
agrep -0 -c 'CCGCTATCGGTTTCCTT' *.fastq > count/B10414_Fm0.txt
agrep -0 -c 'AATCGCGATTCTACCGC' *.fastq > count/B10415_Fm0.txt
agrep -0 -c 'CTAATGCCCTTAACTTC' *.fastq > count/B10416_Fm0.txt
agrep -0 -c 'TGCGGCCAATTGGCATA' *.fastq > count/B10417_Fm0.txt
agrep -0 -c 'CTCGTTAAACGGTTTAG' *.fastq > count/B10418_Fm0.txt
agrep -0 -c 'GACACGGCCCAAGATTG' *.fastq > count/B10421_Fm0.txt
agrep -0 -c 'ACCAGCTCGATACGTCT' *.fastq > count/B10422_Fm0.txt
agrep -0 -c 'CTTGACCTGTCCTCACT' *.fastq > count/B10424_Fm0.txt
agrep -0 -c 'TTAGACTGCTCATGCCA' *.fastq > count/B10425_Fm0.txt
agrep -0 -c 'TACGACGGCATAAGTAG' *.fastq > count/B10426_Fm0.txt
agrep -0 -c 'GTGGCTGATGTCCGTAT' *.fastq > count/B10427_Fm0.txt
agrep -0 -c 'TTATAAGTCCGCGCGCC' *.fastq > count/B10428_Fm0.txt
agrep -0 -c 'TCTCCGAAAAATGGACC' *.fastq > count/B10429_Fm0.txt
agrep -0 -c 'CCTTGTTGGGCATCACG' *.fastq > count/B10430_Fm0.txt
agrep -0 -c 'CAAGACGTAGCGAGCAC' *.fastq > count/B10431_Fm0.txt
agrep -0 -c 'CATCTCGTCCCATTATC' *.fastq > count/B10432_Fm0.txt
agrep -0 -c 'CCTACTTAAGGGGCCAT' *.fastq > count/B10433_Fm0.txt
agrep -0 -c 'TCTGCTGTACGTATTCC' *.fastq > count/B10434_Fm0.txt
agrep -0 -c 'CGCTACACAGATTAGCA' *.fastq > count/B10435_Fm0.txt
agrep -0 -c 'CCTGGTACTTCTGCGAT' *.fastq > count/B10436_Fm0.txt
agrep -0 -c 'AAGGCCTCAGTTGGCAG' *.fastq > count/B10437_Fm0.txt
agrep -0 -c 'TCGGACTGACATATCTG' *.fastq > count/B10438_Fm0.txt
agrep -0 -c 'GCACCAACTCCATACTC' *.fastq > count/B10440_Fm0.txt
agrep -0 -c 'CAGGATGTTAGCGGCTA' *.fastq > count/B10441_Fm0.txt
agrep -0 -c 'AGCGGTTATCATGAGTC' *.fastq > count/B10443_Fm0.txt
agrep -0 -c 'GTGCCTGGATTGCTAGT' *.fastq > count/B10444_Fm0.txt
agrep -0 -c 'AGAGTCGATCAGAGGTG' *.fastq > count/B10445_Fm0.txt
agrep -0 -c 'AAGGGACATCCGAATTG' *.fastq > count/B10446_Fm0.txt
agrep -0 -c 'CCTAGGCTGTGTGTTCA' *.fastq > count/B10447_Fm0.txt
agrep -0 -c 'GACTGACTATGGGATCA' *.fastq > count/B10448_Fm0.txt
agrep -0 -c 'TCTTTATGGCGGATGCA' *.fastq > count/B10449_Fm0.txt
agrep -0 -c 'CTAGCCGTTATAGACCT' *.fastq > count/B10453_Fm0.txt
agrep -0 -c 'TTACACAGCCCGCCTCT' *.fastq > count/B10455_Fm0.txt
agrep -0 -c 'GCTCTCGGGCAATGTAA' *.fastq > count/B10456_Fm0.txt
agrep -0 -c 'CAATGTCGGCATCATGG' *.fastq > count/B10457_Fm0.txt
agrep -0 -c 'TGATCGACTTTAACGCG' *.fastq > count/B10459_Fm0.txt
agrep -0 -c 'CGCTATACGGGGATCTA' *.fastq > count/B10461_Fm0.txt
agrep -0 -c 'GTCAGATGGCGGACTCA' *.fastq > count/B10462_Fm0.txt
agrep -0 -c 'CCGTATCTAAGGGAGAA' *.fastq > count/B10463_Fm0.txt
agrep -0 -c 'GCATTACCTGAAGGTCG' *.fastq > count/B10464_Fm0.txt
agrep -0 -c 'CATTGGTCTTATCTGAG' *.fastq > count/B10465_Fm0.txt
agrep -0 -c 'ACGGCCTTTAGAAGCCT' *.fastq > count/B10466_Fm0.txt
agrep -0 -c 'GTCTGTTACACTATGCT' *.fastq > count/B10467_Fm0.txt
agrep -0 -c 'GCCAGGAATGTACCTCT' *.fastq > count/B10468_Fm0.txt
agrep -0 -c 'CACTAGTCGCATGACAG' *.fastq > count/B10469_Fm0.txt
agrep -0 -c 'CTCGTCTCGGTCAGAAT' *.fastq > count/B10471_Fm0.txt
agrep -0 -c 'TCACGCCCTAATAGCTC' *.fastq > count/B10472_Fm0.txt
agrep -0 -c 'GTGACTCTCATAGTGAA' *.fastq > count/B10473_Fm0.txt
agrep -0 -c 'CCGTCAGATTCCGCTTA' *.fastq > count/B10474_Fm0.txt
agrep -0 -c 'CTCGTTATGACCAACTG' *.fastq > count/B10475_Fm0.txt
agrep -0 -c 'CTGTCCCACTTATCGCA' *.fastq > count/B10476_Fm0.txt
agrep -0 -c 'TGGCATTCGAAAACTTC' *.fastq > count/B10477_Fm0.txt
agrep -0 -c 'GGTGACCGATTACGAAC' *.fastq > count/B10478_Fm0.txt
agrep -0 -c 'GTTCCGACCAAGGACCT' *.fastq > count/B10480_Fm0.txt
agrep -0 -c 'TCTGTTGGGCGGTTTTC' *.fastq > count/B10481_Fm0.txt
agrep -0 -c 'GGGACGTCTAAATAGGA' *.fastq > count/B10482_Fm0.txt
agrep -0 -c 'TACCTATTCCTTCTGGG' *.fastq > count/B10483_Fm0.txt
agrep -0 -c 'CAAACTGTCGTCTCAGC' *.fastq > count/B10484_Fm0.txt
agrep -0 -c 'GTGCTCCTGTCAAGGAA' *.fastq > count/B10485_Fm0.txt
agrep -0 -c 'GACCAAAGGATCGCGCT' *.fastq > count/B10486_Fm0.txt
agrep -0 -c 'CGCCATATCAATCACTC' *.fastq > count/B10487_Fm0.txt
agrep -0 -c 'GTCGCGTCAAAAGAAGA' *.fastq > count/B10488_Fm0.txt
agrep -0 -c 'TGCTCGGCCTTATGCTT' *.fastq > count/B10489_Fm0.txt
agrep -0 -c 'CGTCTACCTAAGCCATT' *.fastq > count/B10490_Fm0.txt
agrep -0 -c 'TTAGATTCATAAGCCCG' *.fastq > count/B10491_Fm0.txt
agrep -0 -c 'ATGATACCCCAGTAGAC' *.fastq > count/B10492_Fm0.txt
agrep -0 -c 'TCAACCCCACGTCTCAA' *.fastq > count/B10493_Fm0.txt
agrep -0 -c 'ACGTATACAAGTGCTTC' *.fastq > count/B10494_Fm0.txt
agrep -0 -c 'ATTCCATAATCCAGCGG' *.fastq > count/B10495_Fm0.txt
agrep -0 -c 'CAATTTTCGATGGCATG' *.fastq > count/B10496_Fm0.txt
agrep -0 -c 'TAGTCGGTTCTTACTTC' *.fastq > count/B10497_Fm0.txt
agrep -0 -c 'TAGTTTGAGGGTACTAC' *.fastq > count/B10499_Fm0.txt
agrep -0 -c 'GAGTTTTCATACCCTGT' *.fastq > count/B10500_Fm0.txt
agrep -0 -c 'TCTGTTAGTGATGCACC' *.fastq > count/B10501_Fm0.txt
agrep -0 -c 'CAACCCTTGCCGTGCAT' *.fastq > count/B10502_Fm0.txt
agrep -0 -c 'GAGAGCTTAACTCTGTC' *.fastq > count/B10503_Fm0.txt
agrep -0 -c 'ACCGAATCCGTGTGCAA' *.fastq > count/B10504_Fm0.txt
agrep -0 -c 'GTCATCGGGTGAAACGA' *.fastq > count/B10506_Fm0.txt
agrep -0 -c 'TTGCCACAGGCTCCATC' *.fastq > count/B10507_Fm0.txt
agrep -0 -c 'CCAACGAGCAGCACTCT' *.fastq > count/B10508_Fm0.txt
agrep -0 -c 'GTTTGTGACTCTCGCTC' *.fastq > count/B10509_Fm0.txt
agrep -0 -c 'GATCATCGTTCGTATGG' *.fastq > count/B10510_Fm0.txt
agrep -0 -c 'CGTCTAGGAGTAGCGAT' *.fastq > count/B10511_Fm0.txt
agrep -0 -c 'TAGTGTGAACGGCAGTC' *.fastq > count/B10512_Fm0.txt
agrep -0 -c 'CGATGGATAGGGTTTAG' *.fastq > count/B10513_Fm0.txt
agrep -0 -c 'CGGTCATTACGTACTTG' *.fastq > count/B10514_Fm0.txt
agrep -0 -c 'GCAAGATAAGCTGGTCT' *.fastq > count/B10515_Fm0.txt
agrep -0 -c 'GTGAATTCCCGTCAACT' *.fastq > count/B10516_Fm0.txt
agrep -0 -c 'CACCTGTTGCGAGTCCT' *.fastq > count/B10517_Fm0.txt
agrep -0 -c 'CGTTATGATGTGCTTCG' *.fastq > count/B10518_Fm0.txt
agrep -0 -c 'ATGATTTAACGGCGTGA' *.fastq > count/B10519_Fm0.txt
agrep -0 -c 'GCGCGATGTTTTGCGTT' *.fastq > count/B10520_Fm0.txt
agrep -0 -c 'TACGGTCTAAAACAGCT' *.fastq > count/B10521_Fm0.txt
agrep -0 -c 'AATACCATCGTAAGGGT' *.fastq > count/B10522_Fm0.txt
agrep -0 -c 'GTTGGAGACGGTGTTAA' *.fastq > count/B10523_Fm0.txt
agrep -0 -c 'ATGTAACCGCCCGAGTG' *.fastq > count/B10524_Fm0.txt
agrep -0 -c 'GACCCTAGGTGGAATTA' *.fastq > count/B10525_Fm0.txt
agrep -0 -c 'CAGTAACACGTCGACAC' *.fastq > count/B10528_Fm0.txt
agrep -0 -c 'GGCCTGAGTAGAGGAAC' *.fastq > count/B10529_Fm0.txt
agrep -0 -c 'GTAACCACCAGGTCACC' *.fastq > count/B10531_Fm0.txt
agrep -0 -c 'CGTGGTGTGTATAGCCA' *.fastq > count/B10533_Fm0.txt
agrep -0 -c 'GCGAATCAAACCCAAAA' *.fastq > count/B10535_Fm0.txt
agrep -0 -c 'GCTATTGATCCGTTCGA' *.fastq > count/B10537_Fm0.txt
agrep -0 -c 'ATTTGCTGCTCCCGCAC' *.fastq > count/B10538_Fm0.txt
agrep -0 -c 'TGTCGAGTATCGCGGCT' *.fastq > count/B10539_Fm0.txt
agrep -0 -c 'GCGAGGACATAGAATAC' *.fastq > count/B10540_Fm0.txt
agrep -0 -c 'TCTGAATGCACCATGGC' *.fastq > count/B10541_Fm0.txt
agrep -0 -c 'CCGAGGATGATCTATGG' *.fastq > count/B10542_Fm0.txt
agrep -0 -c 'CCAGACGGTGTTTCCTC' *.fastq > count/B10543_Fm0.txt
agrep -0 -c 'CATTGTATGGCCTCTGA' *.fastq > count/B10544_Fm0.txt
agrep -0 -c 'CTTGTTCTGTCAGCTCG' *.fastq > count/B10545_Fm0.txt
agrep -0 -c 'CTCTATTGTGGTGCCTC' *.fastq > count/B10546_Fm0.txt
agrep -0 -c 'ATAGCAACGATGGACTC' *.fastq > count/B10547_Fm0.txt
agrep -0 -c 'ACGGGGTCATACACATA' *.fastq > count/B10548_Fm0.txt
agrep -0 -c 'AACGCGTCATGGAACTA' *.fastq > count/B10549_Fm0.txt
agrep -0 -c 'CACGGTGTTTCACACAA' *.fastq > count/B10550_Fm0.txt
agrep -0 -c 'TGCTTAGCGGACCTGAA' *.fastq > count/B10551_Fm0.txt
agrep -0 -c 'TTCATCCTCGCACGTCC' *.fastq > count/B10552_Fm0.txt
agrep -0 -c 'TGGCCGTCATCGTACTG' *.fastq > count/B10553_Fm0.txt
agrep -0 -c 'GCAATGTTCGAAGAGGA' *.fastq > count/B10554_Fm0.txt
agrep -0 -c 'AATTGAGGGCTACGATT' *.fastq > count/B10555_Fm0.txt
agrep -0 -c 'CGGGTCCGATACTATGC' *.fastq > count/B10557_Fm0.txt
agrep -0 -c 'CAACGCGTACCCTTAGC' *.fastq > count/B10560_Fm0.txt
agrep -0 -c 'AGTATAGCTACCCTCAC' *.fastq > count/B10561_Fm0.txt
agrep -0 -c 'TCGACGACAGTAAACTA' *.fastq > count/B10562_Fm0.txt
agrep -0 -c 'TCTGTAGTACCTTCGAT' *.fastq > count/B10567_Fm0.txt
agrep -0 -c 'TGTAAAAAGCGTGCCGC' *.fastq > count/B10568_Fm0.txt
agrep -0 -c 'GTCGGATATGTCAGACT' *.fastq > count/B10569_Fm0.txt
agrep -0 -c 'GATTATGCAACGAAAGG' *.fastq > count/B10570_Fm0.txt
agrep -0 -c 'CCAAAAACGTGCTCGAG' *.fastq > count/B10572_Fm0.txt
agrep -0 -c 'TAACCCACGATCTCTCG' *.fastq > count/B10573_Fm0.txt
agrep -0 -c 'AAGTGACAGGCCCCAGT' *.fastq > count/B10574_Fm0.txt
agrep -0 -c 'ACGACGGCAAACACAAC' *.fastq > count/B10575_Fm0.txt
agrep -0 -c 'AGCGGCAGCCTTATACA' *.fastq > count/B10576_Fm0.txt
agrep -0 -c 'TGATAAGCGCGCGTCGT' *.fastq > count/B10577_Fm0.txt
agrep -0 -c 'GGGAGTTTGGCTTTACT' *.fastq > count/B10578_Fm0.txt
agrep -0 -c 'GTCTGTATGTCGCAGTT' *.fastq > count/B10579_Fm0.txt
agrep -0 -c 'ATCGCTCTCCATCCGTG' *.fastq > count/B10580_Fm0.txt
agrep -0 -c 'AATCAAGTCGAGCCAGG' *.fastq > count/B10581_Fm0.txt
agrep -0 -c 'GATGTCGTAGAGCAGTT' *.fastq > count/B10582_Fm0.txt
agrep -0 -c 'CATTCCTATGTATGGCA' *.fastq > count/B10583_Fm0.txt
agrep -0 -c 'ATGTTGATCCATTCGCA' *.fastq > count/B10584_Fm0.txt
agrep -0 -c 'AGATACCGAACACGGGG' *.fastq > count/B10585_Fm0.txt
agrep -0 -c 'ACGTGTAGGAGATGCTG' *.fastq > count/B10586_Fm0.txt
agrep -0 -c 'TAAGCCTAGAGTGACTA' *.fastq > count/B10587_Fm0.txt
agrep -0 -c 'CATACTGGCTACACGTG' *.fastq > count/B10588_Fm0.txt
agrep -0 -c 'CCTAACCACTAGATCAC' *.fastq > count/B10589_Fm0.txt
agrep -0 -c 'TGCGGATCGTCTAACAA' *.fastq > count/B10591_Fm0.txt
agrep -0 -c 'CCTACTACGTAATGACT' *.fastq > count/B10592_Fm0.txt
agrep -0 -c 'GGTAGGGTAGGTTGGCT' *.fastq > count/B10593_Fm0.txt
agrep -0 -c 'TGCGGCAATTTAGGTTC' *.fastq > count/B10594_Fm0.txt
agrep -0 -c 'TACAAACCATTAAGCCC' *.fastq > count/B10595_Fm0.txt
agrep -0 -c 'GTCTTCGTAGGCCCAAG' *.fastq > count/B10596_Fm0.txt
agrep -0 -c 'CTCGACACTTTCCTGAT' *.fastq > count/B10598_Fm0.txt
agrep -0 -c 'TGCTATCCCGCTCATCG' *.fastq > count/B10600_Fm0.txt
agrep -0 -c 'GGTCCGATCAAAAAGTA' *.fastq > count/B10602_Fm0.txt
agrep -0 -c 'TCTTGCTCAGTCTACTA' *.fastq > count/B10603_Fm0.txt
agrep -0 -c 'AGGGATTAGCGTTCCTA' *.fastq > count/B10604_Fm0.txt
agrep -0 -c 'GACCATATCCGTCGTGA' *.fastq > count/B10606_Fm0.txt
agrep -0 -c 'TCACCTCTGTCTGTTCG' *.fastq > count/B10607_Fm0.txt
agrep -0 -c 'AACTCAAAGGTCGCATT' *.fastq > count/B10609_Fm0.txt
agrep -0 -c 'CAACGCATCTTCGCATT' *.fastq > count/B10610_Fm0.txt
agrep -0 -c 'GTAGTGTCCTCGCAGCA' *.fastq > count/B10612_Fm0.txt
agrep -0 -c 'GGCCACTTTCCAAGCTG' *.fastq > count/B10613_Fm0.txt
agrep -0 -c 'GCTTGATGACGGCAAAC' *.fastq > count/B10614_Fm0.txt
agrep -0 -c 'CAGCGGGGCTATAATCC' *.fastq > count/B10615_Fm0.txt
agrep -0 -c 'ACAAGCCCCGATCCAAA' *.fastq > count/B10617_Fm0.txt
agrep -0 -c 'ATAGAATGCGACCCTAA' *.fastq > count/B10619_Fm0.txt
agrep -0 -c 'CTAACCTCCTCGGTGGT' *.fastq > count/B10620_Fm0.txt
agrep -0 -c 'CTTGCCACGATTGAGAG' *.fastq > count/B10622_Fm0.txt
agrep -0 -c 'CCAAGCCTATTTCTGTC' *.fastq > count/B10623_Fm0.txt
agrep -0 -c 'GACCTCCTTTGATTCCG' *.fastq > count/B10624_Fm0.txt
agrep -0 -c 'TCTCACTCGCAAAAACA' *.fastq > count/B10625_Fm0.txt
agrep -0 -c 'GTTAGGTCTGATGGGAA' *.fastq > count/B10626_Fm0.txt
agrep -0 -c 'ACACTATCACACGCTCT' *.fastq > count/B10627_Fm0.txt
agrep -0 -c 'GAGATTACGTCTTGCAC' *.fastq > count/B10629_Fm0.txt
agrep -0 -c 'GTGTGTCTACTTCACCT' *.fastq > count/B10630_Fm0.txt
agrep -0 -c 'TAAGGCTTTCGACACTC' *.fastq > count/B10631_Fm0.txt
agrep -0 -c 'CGGGAATCATGCGCTCT' *.fastq > count/B10632_Fm0.txt
agrep -0 -c 'CACACATGACATTCCTC' *.fastq > count/B10633_Fm0.txt
agrep -0 -c 'CCAGCCACACGTTAAAG' *.fastq > count/B10635_Fm0.txt
agrep -0 -c 'GTGCTGACGGTTCCAAA' *.fastq > count/B10637_Fm0.txt
agrep -0 -c 'CTGCTCTAACGTTACCA' *.fastq > count/B10638_Fm0.txt
agrep -0 -c 'CTTGCCAGTTAGCATGG' *.fastq > count/B10641_Fm0.txt
agrep -0 -c 'GATGATGGACCTTTTGG' *.fastq > count/B10642_Fm0.txt
agrep -0 -c 'GGGGTGAATGCCGGATT' *.fastq > count/B10643_Fm0.txt
agrep -0 -c 'TATTGTGAAGTGCGGGA' *.fastq > count/B10644_Fm0.txt
agrep -0 -c 'TACCTCTCGCAAGACGA' *.fastq > count/B10645_Fm0.txt
agrep -0 -c 'GAGGAACATTGAGTGGG' *.fastq > count/B10647_Fm0.txt
agrep -0 -c 'CAGGATGATGCCCTATG' *.fastq > count/B10648_Fm0.txt
agrep -0 -c 'TAAGGCTATTTGCCACG' *.fastq > count/B10649_Fm0.txt
agrep -0 -c 'GTGGCTATCGGTAGTGA' *.fastq > count/B10650_Fm0.txt
agrep -0 -c 'CATTGAGCCCCTAAACG' *.fastq > count/B10651_Fm0.txt
agrep -0 -c 'CAGTCAGCTAAGGGGTC' *.fastq > count/B10652_Fm0.txt
agrep -0 -c 'CTCAAGTGGTCGATGCT' *.fastq > count/B10653_Fm0.txt
agrep -0 -c 'AGCTACAGTATCCTGCG' *.fastq > count/B10654_Fm0.txt
agrep -0 -c 'CAACAATAGACTTGACG' *.fastq > count/B10656_Fm0.txt
agrep -0 -c 'GTTCGGAAGATTGGCCA' *.fastq > count/B10657_Fm0.txt
agrep -0 -c 'ACTCGGAGTATGACCCA' *.fastq > count/B10658_Fm0.txt
agrep -0 -c 'GGACCATGTGCTTCTTT' *.fastq > count/B10659_Fm0.txt
agrep -0 -c 'CATCATTCTATGCTCGC' *.fastq > count/B10660_Fm0.txt
agrep -0 -c 'TGCAAAAAAGGTACACC' *.fastq > count/B10661_Fm0.txt
agrep -0 -c 'GATTCAGTGCCACCAGT' *.fastq > count/B10662_Fm0.txt
agrep -0 -c 'GGGTTGCGTCTACTTGG' *.fastq > count/B10663_Fm0.txt
agrep -0 -c 'CGGCATTCACCGTGATC' *.fastq > count/B10664_Fm0.txt
agrep -0 -c 'GTATGTAATAGAGGGCA' *.fastq > count/B10666_Fm0.txt
agrep -0 -c 'GCTGGTGAAGTCGCCAA' *.fastq > count/B10667_Fm0.txt
agrep -0 -c 'ATCGCTCGAGTCTGCTG' *.fastq > count/B10668_Fm0.txt
agrep -0 -c 'ATAGCAGATCGGGGTGG' *.fastq > count/B10669_Fm0.txt
agrep -0 -c 'TGCATATACCCCCCCGA' *.fastq > count/B10670_Fm0.txt
agrep -0 -c 'AACGAGACACGCGAGGT' *.fastq > count/B10671_Fm0.txt
agrep -0 -c 'CTTACCCTAAGCGGATG' *.fastq > count/B10672_Fm0.txt
agrep -0 -c 'GCCGCGTACTATAACCC' *.fastq > count/B10673_Fm0.txt
agrep -0 -c 'AACTTCCCTAAGTTCCA' *.fastq > count/B10674_Fm0.txt
agrep -0 -c 'CTTGAATTGCCTTCGAA' *.fastq > count/B10675_Fm0.txt
agrep -0 -c 'CGAGGAGGAATTTCAAG' *.fastq > count/B10677_Fm0.txt
agrep -0 -c 'CGTAATCACGTTGCGAT' *.fastq > count/B10678_Fm0.txt
agrep -0 -c 'TCTAAATGCCCCGCGTG' *.fastq > count/B10679_Fm0.txt
agrep -0 -c 'CGTCGGCACCTGTACAA' *.fastq > count/B10680_Fm0.txt
agrep -0 -c 'GACTAGGAGTTGCACTT' *.fastq > count/B10681_Fm0.txt
agrep -0 -c 'CCACTCCAAGTGTAAGA' *.fastq > count/B10682_Fm0.txt
agrep -0 -c 'CCGGAAATCCGTCTAGG' *.fastq > count/B10683_Fm0.txt
agrep -0 -c 'ATCCCTATCTCGACTCG' *.fastq > count/B10684_Fm0.txt
agrep -0 -c 'CATTTCACCCCAGAAGA' *.fastq > count/B10686_Fm0.txt
agrep -0 -c 'CCGGTACACGCTAAATT' *.fastq > count/B10687_Fm0.txt
agrep -0 -c 'CAAGCATGTCATGTACA' *.fastq > count/B10688_Fm0.txt
agrep -0 -c 'TGAGTACGACCGTAAGC' *.fastq > count/B10689_Fm0.txt
agrep -0 -c 'ATCACACCACCAATCTG' *.fastq > count/B10690_Fm0.txt
agrep -0 -c 'TATATTCACTCCCATCG' *.fastq > count/B10691_Fm0.txt
agrep -0 -c 'CGCCAGTTCGATTGCTT' *.fastq > count/B10692_Fm0.txt
agrep -0 -c 'AGGGTATCACGGGAGCT' *.fastq > count/B10694_Fm0.txt
agrep -0 -c 'TAGAACAGCCTGCGACG' *.fastq > count/B10695_Fm0.txt
agrep -0 -c 'AACTAGGGCATGGATTC' *.fastq > count/B10696_Fm0.txt
agrep -0 -c 'CAACCCGTTCGATTGCA' *.fastq > count/B10697_Fm0.txt
agrep -0 -c 'ATCGAGTCTGTCGAATT' *.fastq > count/B10698_Fm0.txt
agrep -0 -c 'GGCGATGGCGTTTATCC' *.fastq > count/B10699_Fm0.txt
agrep -0 -c 'CCTACCCTTCATAGAGA' *.fastq > count/B10700_Fm0.txt
agrep -0 -c 'TAACTCAGTTGGGTATC' *.fastq > count/B10701_Fm0.txt
agrep -0 -c 'TAAAGACGAGGCCCTGA' *.fastq > count/B10702_Fm0.txt
agrep -0 -c 'CGACATTCCACCACATC' *.fastq > count/B10703_Fm0.txt
agrep -0 -c 'AATAAATGCCCTCCTGA' *.fastq > count/B10704_Fm0.txt
agrep -0 -c 'AGAGTCATCCACTAGAC' *.fastq > count/B10705_Fm0.txt
agrep -0 -c 'CCGCAGGATCGTTACTC' *.fastq > count/B10707_Fm0.txt
agrep -0 -c 'CGTGCAGCACCTGATAC' *.fastq > count/B10708_Fm0.txt
agrep -0 -c 'GCTCACTTGTAGTGTCA' *.fastq > count/B10709_Fm0.txt
agrep -0 -c 'CAACGCATCTGCAACGT' *.fastq > count/B10711_Fm0.txt
agrep -0 -c 'CTATCACTCGGCGAGCA' *.fastq > count/B10712_Fm0.txt
agrep -0 -c 'TGAGAATGCTGTTACCC' *.fastq > count/B10714_Fm0.txt
agrep -0 -c 'CATCAGAGTGCAGTTGA' *.fastq > count/B10716_Fm0.txt
agrep -0 -c 'TCGTCAGCGTGCTGGTT' *.fastq > count/B10717_Fm0.txt
agrep -0 -c 'CGAGGTCGGCGATCTTA' *.fastq > count/B10718_Fm0.txt
agrep -0 -c 'ACTATACGATGTCGGTC' *.fastq > count/B10719_Fm0.txt
agrep -0 -c 'CTCTGGGACTGCCACAA' *.fastq > count/B10720_Fm0.txt
agrep -0 -c 'CGCTTCTGGCGAGATGT' *.fastq > count/B10721_Fm0.txt
agrep -0 -c 'ACACCGGTGGACCAATT' *.fastq > count/B10722_Fm0.txt
agrep -0 -c 'CTACTTGACCTTGCAAT' *.fastq > count/B10723_Fm0.txt
agrep -0 -c 'CATGGGGTGTTATAGCA' *.fastq > count/B10724_Fm0.txt
agrep -0 -c 'TATGAGACCGCCATTGA' *.fastq > count/B10725_Fm0.txt
agrep -0 -c 'ATGCTGTGTGCGTGAAT' *.fastq > count/B10726_Fm0.txt
agrep -0 -c 'AACCGTTGAGTGGGCAG' *.fastq > count/B10727_Fm0.txt
agrep -0 -c 'ACATTCGAAAGACTAGG' *.fastq > count/B10728_Fm0.txt
agrep -0 -c 'AACCTCGGATAGAAGGC' *.fastq > count/B10729_Fm0.txt
agrep -0 -c 'CCGTATGTACCTGACGC' *.fastq > count/B10730_Fm0.txt
agrep -0 -c 'ACTATCGTAGGGGGGAT' *.fastq > count/B10731_Fm0.txt
agrep -0 -c 'TCGTGAGTGGGTCGATA' *.fastq > count/B10732_Fm0.txt
agrep -0 -c 'GCATGGTATAGATGGGC' *.fastq > count/B10733_Fm0.txt
agrep -0 -c 'TGAGGTAGCCTAGTCGG' *.fastq > count/B10734_Fm0.txt
agrep -0 -c 'CTAGTGAGCATACTGGT' *.fastq > count/B10735_Fm0.txt
agrep -0 -c 'CAGAAATAGACGGCGTT' *.fastq > count/B10736_Fm0.txt
agrep -0 -c 'TAAGGATGGCGCAAGAC' *.fastq > count/B10737_Fm0.txt
agrep -0 -c 'CGTGCTCATGATTTGGG' *.fastq > count/B10738_Fm0.txt
agrep -0 -c 'TGGATCTGTGCCCTCTA' *.fastq > count/B10739_Fm0.txt
agrep -0 -c 'CGAATAACTACCCTTCT' *.fastq > count/B10740_Fm0.txt
agrep -0 -c 'TATCTGGGTATCAGGGA' *.fastq > count/B10741_Fm0.txt
agrep -0 -c 'ACCACTATTTGTTGCGG' *.fastq > count/B10742_Fm0.txt
agrep -0 -c 'TACGGCAGTCGAGATCC' *.fastq > count/B10743_Fm0.txt
agrep -0 -c 'ATGTGGCGTTGGGTTAC' *.fastq > count/B10744_Fm0.txt
agrep -0 -c 'TCTTCAGAGGGCTCGTA' *.fastq > count/B10745_Fm0.txt
agrep -0 -c 'AGGCTATATTCGGCGAT' *.fastq > count/B10747_Fm0.txt
agrep -0 -c 'CTCCAGAGGTGCAAAAT' *.fastq > count/B10748_Fm0.txt
agrep -0 -c 'AGTGTCCAATCCTGTTA' *.fastq > count/B10749_Fm0.txt
agrep -0 -c 'GGTCTATTAAGCGCATC' *.fastq > count/B10750_Fm0.txt
agrep -0 -c 'ACCCACCCCACTATAGA' *.fastq > count/B10753_Fm0.txt
agrep -0 -c 'AGTTCGCTGTGGGTCAA' *.fastq > count/B10754_Fm0.txt
agrep -0 -c 'TTAGACACGCGTAGCCT' *.fastq > count/B10755_Fm0.txt
agrep -0 -c 'AATAAACCGGTCGTAGA' *.fastq > count/B10756_Fm0.txt
agrep -0 -c 'GTATACACTTTCGCCAA' *.fastq > count/B10757_Fm0.txt
agrep -0 -c 'CCTCGACTATACGTCTA' *.fastq > count/B10758_Fm0.txt
agrep -0 -c 'TGTTCGTTTCTCGCGGA' *.fastq > count/B10760_Fm0.txt
agrep -0 -c 'CCTAACTAATCCGAAAG' *.fastq > count/B10761_Fm0.txt
agrep -0 -c 'GGCAGAGATAATTCTCT' *.fastq > count/B10762_Fm0.txt
agrep -0 -c 'GCGTCAGAATACCCTAT' *.fastq > count/B10763_Fm0.txt
agrep -0 -c 'TACACAATGTGGCACCA' *.fastq > count/B10764_Fm0.txt
agrep -0 -c 'GGCGTGTTGAAATTCGG' *.fastq > count/B10765_Fm0.txt
agrep -0 -c 'CCGGGCACAACAAGCTA' *.fastq > count/B10767_Fm0.txt
agrep -0 -c 'ATCAGGTTTATAGCGCG' *.fastq > count/B10768_Fm0.txt
agrep -0 -c 'GGATCAGAGCCTCCATA' *.fastq > count/B10770_Fm0.txt
agrep -0 -c 'GTCAGCGCTTCAGTATA' *.fastq > count/B10771_Fm0.txt
agrep -0 -c 'ATTGATAGGACGCCCCG' *.fastq > count/B10772_Fm0.txt
agrep -0 -c 'ACTTTCAGTATGGAAGC' *.fastq > count/B10773_Fm0.txt
agrep -0 -c 'GATCCTTAAGTCCCGTT' *.fastq > count/B10774_Fm0.txt
agrep -0 -c 'GATACTCGCTGAACATA' *.fastq > count/B10775_Fm0.txt
agrep -0 -c 'GATAGGCCTTCTTAACG' *.fastq > count/B10776_Fm0.txt
agrep -0 -c 'CGGGCACACGTATCTCT' *.fastq > count/B10777_Fm0.txt
agrep -0 -c 'AAGAACGCGAGCTGTTC' *.fastq > count/B10778_Fm0.txt
agrep -0 -c 'GTCCTCCACTCAACTGT' *.fastq > count/B10779_Fm0.txt
agrep -0 -c 'ATGGACCGTCGACCTCT' *.fastq > count/B10781_Fm0.txt
agrep -0 -c 'TTAGTGGGCGTCGTCTT' *.fastq > count/B10784_Fm0.txt
agrep -0 -c 'GGAATCGACCCACTTGG' *.fastq > count/B10785_Fm0.txt
agrep -0 -c 'CGGTGTAATGTAACCTG' *.fastq > count/B10787_Fm0.txt
agrep -0 -c 'CCGATGCAGTTAGTATT' *.fastq > count/B10788_Fm0.txt
agrep -0 -c 'TAAACCGGATCGTCACT' *.fastq > count/B10789_Fm0.txt
agrep -0 -c 'AGGCGTTGGCCAACGTT' *.fastq > count/B10790_Fm0.txt
agrep -0 -c 'CCTCAACACTCGGTACA' *.fastq > count/B10791_Fm0.txt
agrep -0 -c 'TTCAGAGGCTCATGAGA' *.fastq > count/B10792_Fm0.txt
agrep -0 -c 'TAGTAGCGTTAGCGCCA' *.fastq > count/B10793_Fm0.txt
agrep -0 -c 'TTAGGAAAGATCGCCCG' *.fastq > count/B10794_Fm0.txt
agrep -0 -c 'GACGCTAGTGGGTTCAA' *.fastq > count/B10795_Fm0.txt
agrep -0 -c 'GTCAACCATTGCTCGGT' *.fastq > count/B10796_Fm0.txt
agrep -0 -c 'GTCCACGTGATTACTTC' *.fastq > count/B10797_Fm0.txt
agrep -0 -c 'GTCACATGGTTCCCCTT' *.fastq > count/B10798_Fm0.txt
agrep -0 -c 'GTTCTTCCTGGATCTTC' *.fastq > count/B10799_Fm0.txt
agrep -0 -c 'GGTGCAACCATCTGCAC' *.fastq > count/B10800_Fm0.txt
agrep -0 -c 'CCACGTACGCTCAGTCA' *.fastq > count/B10801_Fm0.txt
agrep -0 -c 'TGTATCACGATCGGAGG' *.fastq > count/B10802_Fm0.txt
agrep -0 -c 'ATGACCTAAGCTGGCAA' *.fastq > count/B10803_Fm0.txt
agrep -0 -c 'GTTGGCGATACGAACAA' *.fastq > count/B10804_Fm0.txt
agrep -0 -c 'ATTTAAAGACGAGAGCG' *.fastq > count/B10805_Fm0.txt
agrep -0 -c 'CAGCGTCGGGAAAGTAT' *.fastq > count/B10807_Fm0.txt
agrep -0 -c 'AGGGTGATTATCTAGTG' *.fastq > count/B10808_Fm0.txt
agrep -0 -c 'ACGGTCCAGGTAGAGGA' *.fastq > count/B10810_Fm0.txt
agrep -0 -c 'GGACATACACAGGACGA' *.fastq > count/B10812_Fm0.txt
agrep -0 -c 'AGTGAATGGCGATTAAC' *.fastq > count/B10813_Fm0.txt
agrep -0 -c 'CACACCATGGTCACCTA' *.fastq > count/B10815_Fm0.txt
agrep -0 -c 'GTAGAACATGCGTTGCC' *.fastq > count/B10816_Fm0.txt
agrep -0 -c 'AGTTCTCCGCTGCACAA' *.fastq > count/B10817_Fm0.txt
agrep -0 -c 'TAACGAACAACTGGCAT' *.fastq > count/B10818_Fm0.txt
agrep -0 -c 'CGGATTATGAGAAACGA' *.fastq > count/B10820_Fm0.txt
agrep -0 -c 'TACGTACCAGTAGACGG' *.fastq > count/B10821_Fm0.txt
agrep -0 -c 'ACAGAGTCACGCTAGCC' *.fastq > count/B10822_Fm0.txt
agrep -0 -c 'TAGAGCTTTCTCGCACT' *.fastq > count/B10823_Fm0.txt
agrep -0 -c 'CTACACTGCCAAGCTAT' *.fastq > count/B10824_Fm0.txt
agrep -0 -c 'GTTACTTGTTACCGACT' *.fastq > count/B10825_Fm0.txt
agrep -0 -c 'TAATCTAGCAAATGCCG' *.fastq > count/B10826_Fm0.txt
agrep -0 -c 'CAGTCCAGACTTCCCGT' *.fastq > count/B10828_Fm0.txt
agrep -0 -c 'TACTGGTGGGCGACAGA' *.fastq > count/B10829_Fm0.txt
agrep -0 -c 'CGTATTGACGGCGATGT' *.fastq > count/B10830_Fm0.txt
agrep -0 -c 'GGCACGACTGCTAGGTT' *.fastq > count/B10831_Fm0.txt
agrep -0 -c 'CGGTATGCTTTCATTTG' *.fastq > count/B10834_Fm0.txt
agrep -0 -c 'CTTCGAATCGCACTTGG' *.fastq > count/B10836_Fm0.txt
agrep -0 -c 'TATCGACTGGCTATACG' *.fastq > count/B10837_Fm0.txt
agrep -0 -c 'TGAAACGTCGCCCAGTA' *.fastq > count/B10839_Fm0.txt
agrep -0 -c 'AGTCGAGGCAAGATCAC' *.fastq > count/B10840_Fm0.txt
agrep -0 -c 'CTCGAGCTCTATTTCGC' *.fastq > count/B10842_Fm0.txt
agrep -0 -c 'CGGGCCAAATAATCTGG' *.fastq > count/B10843_Fm0.txt
agrep -0 -c 'TTCACATGAATGACGCA' *.fastq > count/B10844_Fm0.txt
agrep -0 -c 'ACTGGTACTTTATACCG' *.fastq > count/B10845_Fm0.txt
agrep -0 -c 'GTGTTAAGTCTACGATG' *.fastq > count/B10847_Fm0.txt
agrep -0 -c 'AACCAGTTGACGGACAT' *.fastq > count/B10848_Fm0.txt
agrep -0 -c 'GTGACTCAGAACACAAC' *.fastq > count/B10849_Fm0.txt
agrep -0 -c 'ATAAGCGGTGGGGGTAT' *.fastq > count/B10851_Fm0.txt
agrep -0 -c 'AGTATTCGTATCTGCCA' *.fastq > count/B10853_Fm0.txt
agrep -0 -c 'GCGTTGTATACCAAAGG' *.fastq > count/B10854_Fm0.txt
agrep -0 -c 'CTGTTAATAGGCGTCTC' *.fastq > count/B10856_Fm0.txt
agrep -0 -c 'GACGATGAGGTTAAGAC' *.fastq > count/B10857_Fm0.txt
agrep -0 -c 'ACGCACTGCTCTCTGAG' *.fastq > count/B10858_Fm0.txt
agrep -0 -c 'ACGTTCGCGAGACCTGT' *.fastq > count/B10859_Fm0.txt
agrep -0 -c 'CCTCAGACTCTTTCGTC' *.fastq > count/B10860_Fm0.txt
agrep -0 -c 'CGGAGTCCCAAAAACGC' *.fastq > count/B10861_Fm0.txt
agrep -0 -c 'AGTGTCAACTAGGGATT' *.fastq > count/B10862_Fm0.txt
agrep -0 -c 'TTGCAAGTCTACGTTCT' *.fastq > count/B10866_Fm0.txt
agrep -0 -c 'AGTAAGTCATAATGGGC' *.fastq > count/B10867_Fm0.txt
agrep -0 -c 'GTGGTAGATGGTCAATT' *.fastq > count/B10868_Fm0.txt
agrep -0 -c 'GGTAGCTAGACCGCTCA' *.fastq > count/B10870_Fm0.txt
agrep -0 -c 'AACGCATTGGTTGGCTT' *.fastq > count/B10872_Fm0.txt
agrep -0 -c 'CCGGTATCTCTGTATGA' *.fastq > count/B10874_Fm0.txt
agrep -0 -c 'ATAAAGCGGAGTCTTCA' *.fastq > count/B10875_Fm0.txt
agrep -0 -c 'CATCACGAGAGCTTTGT' *.fastq > count/B10876_Fm0.txt
agrep -0 -c 'AGTACCTTGACATTCGG' *.fastq > count/B10878_Fm0.txt
agrep -0 -c 'TATATGGAGGTGGCACT' *.fastq > count/B10879_Fm0.txt
agrep -0 -c 'GGTTCTCAAGCTCTCAC' *.fastq > count/B10880_Fm0.txt
agrep -0 -c 'TAATGGATCAATTCCGC' *.fastq > count/B10881_Fm0.txt
agrep -0 -c 'GAGCCCGACTTGGTTTA' *.fastq > count/B10882_Fm0.txt
agrep -0 -c 'CAGGCGGTTTAGGCAGA' *.fastq > count/B10885_Fm0.txt
agrep -0 -c 'GCGATTGATAATTAGGC' *.fastq > count/B10887_Fm0.txt
agrep -0 -c 'CATATTACCCCTCCCAG' *.fastq > count/B10888_Fm0.txt
agrep -0 -c 'TGCCTTGACAAGTTAAC' *.fastq > count/B10889_Fm0.txt
agrep -0 -c 'TCGAGCCGACATCAGAG' *.fastq > count/B10890_Fm0.txt
agrep -0 -c 'ATTTGCCCTCTCCAAAT' *.fastq > count/B10891_Fm0.txt
agrep -0 -c 'AGCGTCAGCCGTATTCA' *.fastq > count/B10894_Fm0.txt
agrep -0 -c 'ACCGCGTGAAGAAGTCC' *.fastq > count/B10895_Fm0.txt
agrep -0 -c 'AACGGACCAAAGAGTTG' *.fastq > count/B10896_Fm0.txt
agrep -0 -c 'TTCGGTCTAGAACGACC' *.fastq > count/B10897_Fm0.txt
agrep -0 -c 'TGAGCCGAGTAGGAGCT' *.fastq > count/B10898_Fm0.txt
agrep -0 -c 'GTACCAGTCCTTCAGGC' *.fastq > count/B10899_Fm0.txt
agrep -0 -c 'GATGGTTGTATGCCCGG' *.fastq > count/B10900_Fm0.txt
agrep -0 -c 'CTATATAGTGGCTCTAG' *.fastq > count/B10901_Fm0.txt
agrep -0 -c 'CAGACAACGCTGTCGAT' *.fastq > count/B10903_Fm0.txt
agrep -0 -c 'GGCTTTTCGAACAGCAC' *.fastq > count/B10904_Fm0.txt
agrep -0 -c 'AGCGCAGTAATCCGATA' *.fastq > count/B10905_Fm0.txt
agrep -0 -c 'TATCAGGCGCTTTCATG' *.fastq > count/B10906_Fm0.txt
agrep -0 -c 'TATACGACGGACAGCTC' *.fastq > count/B10907_Fm0.txt
agrep -0 -c 'AGTTCGTGTTGTAACCG' *.fastq > count/B10908_Fm0.txt
agrep -0 -c 'ACTATGGTCGCATCTAA' *.fastq > count/B10910_Fm0.txt
agrep -0 -c 'GTCTACTGAGACATTAC' *.fastq > count/B10911_Fm0.txt
agrep -0 -c 'TTCCTGCGAGCAATATG' *.fastq > count/B10912_Fm0.txt
agrep -0 -c 'GGGCAGGTACCTGGATT' *.fastq > count/B10913_Fm0.txt
agrep -0 -c 'GAGGAAGTCGGCCTGAT' *.fastq > count/B10914_Fm0.txt
agrep -0 -c 'CAGGCATTCCGGATTGA' *.fastq > count/B10915_Fm0.txt
agrep -0 -c 'TCAATCCCGCGTTACAG' *.fastq > count/B10917_Fm0.txt
agrep -0 -c 'GGGACGTCCCAGAATCA' *.fastq > count/B10918_Fm0.txt
agrep -0 -c 'AGGTCGTAAGGATCGGT' *.fastq > count/B10919_Fm0.txt
agrep -0 -c 'GCCGTGTTGCATGGTTA' *.fastq > count/B10920_Fm0.txt
agrep -0 -c 'TGCGATAAAGGATGCCT' *.fastq > count/B10922_Fm0.txt
agrep -0 -c 'CGTCTTTCCCATCCGGT' *.fastq > count/B10923_Fm0.txt
agrep -0 -c 'CCTGGTTGTACCACGGT' *.fastq > count/B10924_Fm0.txt
agrep -0 -c 'GGGTGACATAACTTGTA' *.fastq > count/B10925_Fm0.txt
agrep -0 -c 'GCGTTCGGGACCTCTAT' *.fastq > count/B10926_Fm0.txt
agrep -0 -c 'GGGTCCTCTCTACATAG' *.fastq > count/B10927_Fm0.txt
agrep -0 -c 'TCACCACGAGACTCATG' *.fastq > count/B10928_Fm0.txt
agrep -0 -c 'AACAGGGTATGGGCGTG' *.fastq > count/B10929_Fm0.txt
agrep -0 -c 'GATCCCCTAAGGTCGAC' *.fastq > count/B10931_Fm0.txt
agrep -0 -c 'AACATACACTCAACGCC' *.fastq > count/B10932_Fm0.txt
agrep -0 -c 'AAGTCACGTAAGTTCCC' *.fastq > count/B10934_Fm0.txt
agrep -0 -c 'CGAGTACTGTGCTAAAT' *.fastq > count/B10935_Fm0.txt
agrep -0 -c 'GTCGTTAATACACCCCA' *.fastq > count/B10936_Fm0.txt
agrep -0 -c 'ATCCCCCTGGGATCGAT' *.fastq > count/B10937_Fm0.txt
agrep -0 -c 'TATCAAGCGGGAGCGGA' *.fastq > count/B10938_Fm0.txt
agrep -0 -c 'CCTAAGCGTCTAGGCGA' *.fastq > count/B10939_Fm0.txt
agrep -0 -c 'TTCTTTTGGAATGCCGA' *.fastq > count/B10940_Fm0.txt
agrep -0 -c 'TGCAGTGAACTGACTAA' *.fastq > count/B10941_Fm0.txt
agrep -0 -c 'GCAGCGGTGATCCAAGT' *.fastq > count/B10942_Fm0.txt
agrep -0 -c 'CAGAGGGCTCTCGTAAG' *.fastq > count/B10943_Fm0.txt
agrep -0 -c 'CACTGTTTGTTCGACTA' *.fastq > count/B10944_Fm0.txt
agrep -0 -c 'GGTGTCACAAAGCACTG' *.fastq > count/B10945_Fm0.txt
agrep -0 -c 'GGTTCACACATTACGGT' *.fastq > count/B10946_Fm0.txt
agrep -0 -c 'GCCGCTACTGAGTCATT' *.fastq > count/B10947_Fm0.txt
agrep -0 -c 'ACCAGCGTGTCTTGAGT' *.fastq > count/B10948_Fm0.txt
agrep -0 -c 'TGCCACGACTGGTATCA' *.fastq > count/B10949_Fm0.txt
agrep -0 -c 'AATAGGCGAAGCCGCAC' *.fastq > count/B10950_Fm0.txt
agrep -0 -c 'GTGGCTACCGTGAATCA' *.fastq > count/B10951_Fm0.txt
agrep -0 -c 'CGACAATATAGGTCCAA' *.fastq > count/B10952_Fm0.txt
agrep -0 -c 'TAGTCGACCGGTCCAGT' *.fastq > count/B10953_Fm0.txt
agrep -0 -c 'GCTGGACACCTATAACC' *.fastq > count/B10956_Fm0.txt
agrep -0 -c 'GGTAGCCAACCCTAGTA' *.fastq > count/B10957_Fm0.txt
agrep -0 -c 'TATCAGTCTTCGCCTGT' *.fastq > count/B10958_Fm0.txt
agrep -0 -c 'TGCATTTTTCGGCGAAG' *.fastq > count/B10960_Fm0.txt
agrep -0 -c 'CTACCTTATCCACAGGT' *.fastq > count/B10963_Fm0.txt
agrep -0 -c 'AATTTGCTATCGCGGCC' *.fastq > count/B10964_Fm0.txt
agrep -0 -c 'TACGCTCGACATTCGGG' *.fastq > count/B10965_Fm0.txt
agrep -0 -c 'ATCTCTCCTCGTCAAAG' *.fastq > count/B10966_Fm0.txt
agrep -0 -c 'TACTTAATCCGCAACGG' *.fastq > count/B10967_Fm0.txt
agrep -0 -c 'GGGGACTCGTGTTCTAA' *.fastq > count/B10968_Fm0.txt
agrep -0 -c 'CATCGGTTGTACGTTTC' *.fastq > count/B10970_Fm0.txt
agrep -0 -c 'CCGTTCAACGTAGGTTC' *.fastq > count/B10971_Fm0.txt
agrep -0 -c 'GCATTCAATCTACCCCG' *.fastq > count/B10972_Fm0.txt
agrep -0 -c 'TACCAGGTACACCATCC' *.fastq > count/B10973_Fm0.txt
agrep -0 -c 'ACTGGAACTGCCGTCAG' *.fastq > count/B10975_Fm0.txt
agrep -0 -c 'GCCACACTTCGAACTCG' *.fastq > count/B10976_Fm0.txt
agrep -0 -c 'TGTTGGAGCTCATCGGA' *.fastq > count/B10978_Fm0.txt
agrep -0 -c 'AGATCATGTAGTCGCTC' *.fastq > count/B10980_Fm0.txt
agrep -0 -c 'GGTGCCCTTTTGATCCT' *.fastq > count/B10981_Fm0.txt
agrep -0 -c 'GATGCGTCGGTTTCTAG' *.fastq > count/B10983_Fm0.txt
agrep -0 -c 'GTAGGTTGAGCCGCCAA' *.fastq > count/B10984_Fm0.txt
agrep -0 -c 'ACCTAGGAAAGCTCATG' *.fastq > count/B10985_Fm0.txt
agrep -0 -c 'TCACATTACCTGCGCCT' *.fastq > count/B10986_Fm0.txt
agrep -0 -c 'CCTGGTATCCTAATGGG' *.fastq > count/B10987_Fm0.txt
agrep -0 -c 'AGCAATCTAGGGTTGGG' *.fastq > count/B10988_Fm0.txt
agrep -0 -c 'TAGCTGGCCCCGCTTTT' *.fastq > count/B10989_Fm0.txt
agrep -0 -c 'ATTTCGTTAACATGGGG' *.fastq > count/B10990_Fm0.txt
agrep -0 -c 'CACTGCTTTTGGGACAG' *.fastq > count/B10991_Fm0.txt
agrep -0 -c 'TCGATATCGATGCGGTA' *.fastq > count/B10992_Fm0.txt
agrep -0 -c 'TTCCAGGACTAACTCCA' *.fastq > count/B10993_Fm0.txt
agrep -0 -c 'ATACCAAGTTCAGCACG' *.fastq > count/B10994_Fm0.txt
agrep -0 -c 'ACACAGTGCGCTAAGTC' *.fastq > count/B10995_Fm0.txt
agrep -0 -c 'GGCACTAATCCTAAGTT' *.fastq > count/B10997_Fm0.txt
agrep -0 -c 'AGTGCCAAACTATGGGA' *.fastq > count/B10999_Fm0.txt
agrep -0 -c 'GCTAGATCCCGTGTCCT' *.fastq > count/B11001_Fm0.txt
agrep -0 -c 'GCCTGACTCCCCCATTT' *.fastq > count/B11002_Fm0.txt
agrep -0 -c 'CCATAAGCCGATGGTGG' *.fastq > count/B11003_Fm0.txt
agrep -0 -c 'CAATCTTGTCAACGGTA' *.fastq > count/B11004_Fm0.txt
agrep -0 -c 'GCGCACAAGTGGTTTGA' *.fastq > count/B11005_Fm0.txt
agrep -0 -c 'AAGTCGAGACTCCGTCT' *.fastq > count/B11006_Fm0.txt
agrep -0 -c 'GACTTGCCAAATCGTCC' *.fastq > count/B11007_Fm0.txt
agrep -0 -c 'GATGTAACGTGGACTCC' *.fastq > count/B11008_Fm0.txt
agrep -0 -c 'TTGCCATCGTGGTCTTA' *.fastq > count/B11010_Fm0.txt
agrep -0 -c 'TGCACCCTAAGTTGCCA' *.fastq > count/B11011_Fm0.txt
agrep -0 -c 'CGTTTATATCGTGCGGG' *.fastq > count/B11012_Fm0.txt
agrep -0 -c 'TCACGAACTCACAATCT' *.fastq > count/B11013_Fm0.txt
agrep -0 -c 'CTACAGGCATGATTGAG' *.fastq > count/B11014_Fm0.txt
agrep -0 -c 'TCAGTTCCTATTGTGCC' *.fastq > count/B11015_Fm0.txt
agrep -0 -c 'TGCCTGGAAACGGTTAA' *.fastq > count/B11016_Fm0.txt
agrep -0 -c 'CCGGATAGATGCTCCAA' *.fastq > count/B11017_Fm0.txt
agrep -0 -c 'TCACCCGTTAAATGCAA' *.fastq > count/B11018_Fm0.txt
agrep -0 -c 'ATACCAGTTTGAGCATG' *.fastq > count/B11019_Fm0.txt
agrep -0 -c 'AATCCTGAGACCGTCTA' *.fastq > count/B11021_Fm0.txt
agrep -0 -c 'TATTGAGCATTCCGGGC' *.fastq > count/B11022_Fm0.txt
agrep -0 -c 'TTGGGGTATAAGTCTTG' *.fastq > count/B11023_Fm0.txt
agrep -0 -c 'GTACGAGGGTTACCTCA' *.fastq > count/B11024_Fm0.txt
agrep -0 -c 'GCTGAGTCGTGGATTAC' *.fastq > count/B11025_Fm0.txt
agrep -0 -c 'TGAGGAGATGCAGCGAG' *.fastq > count/B11026_Fm0.txt
agrep -0 -c 'TGTAATCCCGTGCCAAC' *.fastq > count/B11029_Fm0.txt
agrep -0 -c 'CTTCTCGGTTCACGCAA' *.fastq > count/B11030_Fm0.txt
agrep -0 -c 'CCGTGGTAACATGTACT' *.fastq > count/B11031_Fm0.txt
agrep -0 -c 'ACGTGCTTTGTCGTTGG' *.fastq > count/B11032_Fm0.txt
agrep -0 -c 'TATCAAACCCTAAGCCC' *.fastq > count/B11033_Fm0.txt
agrep -0 -c 'TTGTTGCAGTACAGGCT' *.fastq > count/B11034_Fm0.txt
agrep -0 -c 'CCTCGTGGAATTTCAGG' *.fastq > count/B11035_Fm0.txt
agrep -0 -c 'GGGACTATACTAATGGA' *.fastq > count/B11038_Fm0.txt
agrep -0 -c 'GGCACATGAGCGTTGAT' *.fastq > count/B11039_Fm0.txt
agrep -0 -c 'CAACCAATTTACCGGAC' *.fastq > count/B11040_Fm0.txt
agrep -0 -c 'GGCCAGTGTAAAATGAG' *.fastq > count/B11042_Fm0.txt
agrep -0 -c 'AACTAACGTAGGCCTTT' *.fastq > count/B11043_Fm0.txt
agrep -0 -c 'GTCTTAAGGTTTGACGC' *.fastq > count/B11044_Fm0.txt
agrep -0 -c 'GATCCGTAGAAACAAGG' *.fastq > count/B11046_Fm0.txt
agrep -0 -c 'CAGCGATTTGTTAGTTG' *.fastq > count/B11047_Fm0.txt
agrep -0 -c 'ACCCGATCAGGTAAATG' *.fastq > count/B11048_Fm0.txt
agrep -0 -c 'CGTCGCCCAAGAGACAT' *.fastq > count/B11049_Fm0.txt
agrep -0 -c 'GGGCATGCTCGCTCTAA' *.fastq > count/B11050_Fm0.txt
agrep -0 -c 'AGTCGTGGATAGTCCGA' *.fastq > count/B11051_Fm0.txt
agrep -0 -c 'GGCCGGTCTAATCGCTA' *.fastq > count/B11052_Fm0.txt
agrep -0 -c 'ACTAGACCCGTACCTGG' *.fastq > count/B11053_Fm0.txt
agrep -0 -c 'GGTTCTAGTCATGGTAG' *.fastq > count/B11054_Fm0.txt
agrep -0 -c 'ATTAGGGATCACCCAGC' *.fastq > count/B11055_Fm0.txt
agrep -0 -c 'ACGAGGGTACTGGCTTG' *.fastq > count/B11056_Fm0.txt
agrep -0 -c 'TTGCGTATCCGTTCTAG' *.fastq > count/B11057_Fm0.txt
agrep -0 -c 'ACTAGCCAGCTGCAGAT' *.fastq > count/B11059_Fm0.txt
agrep -0 -c 'CTTCGAAGTCAGAATAC' *.fastq > count/B11061_Fm0.txt
agrep -0 -c 'CTAAGATATTGGGAGCT' *.fastq > count/B11062_Fm0.txt
agrep -0 -c 'AGACCCAGATCAGGAAT' *.fastq > count/B11064_Fm0.txt
agrep -0 -c 'TCTAGTAGTCTCGTTCT' *.fastq > count/B11065_Fm0.txt
agrep -0 -c 'TTGCGACCCTCAAGTCG' *.fastq > count/B11066_Fm0.txt
agrep -0 -c 'GTCTCAAGGTTTACCGA' *.fastq > count/B11067_Fm0.txt
agrep -0 -c 'AACATGACTCCAGAACT' *.fastq > count/B11068_Fm0.txt
agrep -0 -c 'GTCATCGCCCAAACTGA' *.fastq > count/B11069_Fm0.txt
agrep -0 -c 'AGCCCTAAATGCCCTCC' *.fastq > count/B11070_Fm0.txt
agrep -0 -c 'GTCTCATCAGACCTAAA' *.fastq > count/B11071_Fm0.txt
agrep -0 -c 'GAGTCTGGGACTTCTGC' *.fastq > count/B11072_Fm0.txt
agrep -0 -c 'ACTCTTATAGCGCTATC' *.fastq > count/B11073_Fm0.txt
agrep -0 -c 'GAGTTGCGTTTGGGAGG' *.fastq > count/B11074_Fm0.txt
agrep -0 -c 'AAGCGACAGTTCGCGGT' *.fastq > count/B11075_Fm0.txt
agrep -0 -c 'GTTACCCGCCCGTTATT' *.fastq > count/B11077_Fm0.txt
agrep -0 -c 'TAGTTTCACACGCACCA' *.fastq > count/B11079_Fm0.txt
agrep -0 -c 'ACACCCCTATGCGTACG' *.fastq > count/B11080_Fm0.txt
agrep -0 -c 'TTGAGTCCTACATCGTG' *.fastq > count/B11081_Fm0.txt
agrep -0 -c 'ACTAGTGCCATTACAGC' *.fastq > count/B11082_Fm0.txt
agrep -0 -c 'TAGAGGTGCACTAGGCA' *.fastq > count/B11083_Fm0.txt
agrep -0 -c 'ATTAAACCCTGGGGGCT' *.fastq > count/B11084_Fm0.txt
agrep -0 -c 'ATGATGCCTACCCTGAT' *.fastq > count/B11085_Fm0.txt
agrep -0 -c 'AGGTTAGCTGCGGATGG' *.fastq > count/B11088_Fm0.txt
agrep -0 -c 'GGCAGTACGGAACATGC' *.fastq > count/B11089_Fm0.txt
agrep -0 -c 'CTTAAGATCTCTTCGCC' *.fastq > count/B11090_Fm0.txt
agrep -0 -c 'GAGGGGATGCCAGAATG' *.fastq > count/B11091_Fm0.txt
agrep -0 -c 'CCACATGGGTAGTAGAC' *.fastq > count/B11092_Fm0.txt
agrep -0 -c 'GCGTCGTTTTGTTCTGA' *.fastq > count/B11093_Fm0.txt
agrep -0 -c 'GCCACAACGATATCAGT' *.fastq > count/B11094_Fm0.txt
agrep -0 -c 'CACTCTAACGTTAACCC' *.fastq > count/B11095_Fm0.txt
agrep -0 -c 'TACTCGTGGCCTTGCAA' *.fastq > count/B11096_Fm0.txt
agrep -0 -c 'TTCTTAAGCTAATGCGC' *.fastq > count/B11097_Fm0.txt
agrep -0 -c 'TAGCACTCGTCTTACGT' *.fastq > count/B11098_Fm0.txt
agrep -0 -c 'TGTCTCAAGAAGCGTTG' *.fastq > count/B11099_Fm0.txt
agrep -0 -c 'GATTGGCGTGTGATTAG' *.fastq > count/B11100_Fm0.txt
agrep -0 -c 'CTTAGACAACGACTGTA' *.fastq > count/B11102_Fm0.txt
agrep -0 -c 'GACGAGGAGCCACTTCA' *.fastq > count/B11103_Fm0.txt
agrep -0 -c 'AGAATCCGACGGCGTTG' *.fastq > count/B11104_Fm0.txt
agrep -0 -c 'GCTAGGGACGGTCAATT' *.fastq > count/B11106_Fm0.txt
agrep -0 -c 'CAGCAGACGTCCCATGT' *.fastq > count/B11107_Fm0.txt
agrep -0 -c 'CTATTCCTCACTTCCGG' *.fastq > count/B11108_Fm0.txt
agrep -0 -c 'GTGGACCACCTCGTACT' *.fastq > count/B11109_Fm0.txt
agrep -0 -c 'AACTCATCCGGTCTACT' *.fastq > count/B11110_Fm0.txt
agrep -0 -c 'CTCCGCCATAACAGTCG' *.fastq > count/B11111_Fm0.txt
agrep -0 -c 'AGTGGAAATCGACCCTG' *.fastq > count/B11112_Fm0.txt
agrep -0 -c 'CCGATTTCCAACTGCCC' *.fastq > count/B11113_Fm0.txt
agrep -0 -c 'TGTATCGGAGACGACAC' *.fastq > count/B11115_Fm0.txt
agrep -0 -c 'ATTAGTTCGCAGAGTGA' *.fastq > count/B11116_Fm0.txt
agrep -0 -c 'GTGTCAGAGGGCGATTT' *.fastq > count/B11118_Fm0.txt
agrep -0 -c 'TCGCATGGATAGACATT' *.fastq > count/B11119_Fm0.txt
agrep -0 -c 'GGGCAATCGTAACTAAT' *.fastq > count/B11120_Fm0.txt
agrep -0 -c 'AACAGTGGTCCACAACG' *.fastq > count/B11122_Fm0.txt
agrep -0 -c 'AACGGAGACACTTTTAC' *.fastq > count/B11123_Fm0.txt
agrep -0 -c 'CGTACAAGGTTAGTGGC' *.fastq > count/B11124_Fm0.txt
agrep -0 -c 'CTGAGTCGGATGCTGTT' *.fastq > count/B11125_Fm0.txt
agrep -0 -c 'AGCGTTTCTACTTCGGG' *.fastq > count/B11126_Fm0.txt
agrep -0 -c 'ATGGAATACGAGCAGCA' *.fastq > count/B11127_Fm0.txt
agrep -0 -c 'CGTTCACAGATAAGTTC' *.fastq > count/B11128_Fm0.txt
agrep -0 -c 'CCAGAGGATGGTTTGCT' *.fastq > count/B11130_Fm0.txt
agrep -0 -c 'TGCATGACGAGAATCGA' *.fastq > count/B11132_Fm0.txt
agrep -0 -c 'GTCGACTATATAAGGGG' *.fastq > count/B11133_Fm0.txt
agrep -0 -c 'GGATAGGCCAGTAGTAA' *.fastq > count/B11134_Fm0.txt
agrep -0 -c 'AGCTAAGACTTATGGCC' *.fastq > count/B11135_Fm0.txt
agrep -0 -c 'GGTAATCGCGATCAAGC' *.fastq > count/B11136_Fm0.txt
agrep -0 -c 'GCTGTCAAACTAGTGGT' *.fastq > count/B11137_Fm0.txt
agrep -0 -c 'TAGAGATTGCCCCTTAT' *.fastq > count/B11139_Fm0.txt
agrep -0 -c 'ATTATGTGGCCTTCGAT' *.fastq > count/B11140_Fm0.txt
agrep -0 -c 'ACGTATATAGAAGCCGG' *.fastq > count/B11142_Fm0.txt
agrep -0 -c 'CTTGAACGGAGAATGCT' *.fastq > count/B11143_Fm0.txt
agrep -0 -c 'CACCAAATATTTGCCGT' *.fastq > count/B11144_Fm0.txt
agrep -0 -c 'TATGCTGTCGAACCTAC' *.fastq > count/B11145_Fm0.txt
agrep -0 -c 'GCGCTGGGTTGTTAAAT' *.fastq > count/B11147_Fm0.txt
agrep -0 -c 'TGCACAGCCCGTTTTAC' *.fastq > count/B11148_Fm0.txt
agrep -0 -c 'AATGGGGCGACTGGAAT' *.fastq > count/B11149_Fm0.txt
agrep -0 -c 'GACCTAATAGCTATACC' *.fastq > count/B11150_Fm0.txt
agrep -0 -c 'ACGGTTTTCTTTGTGAG' *.fastq > count/B11151_Fm0.txt
agrep -0 -c 'GTTGCTGATCTTAGACG' *.fastq > count/B11152_Fm0.txt
agrep -0 -c 'GACCTAAATCGAATTGC' *.fastq > count/B11153_Fm0.txt
agrep -0 -c 'GGGATAGGTTCGTTAAG' *.fastq > count/B11154_Fm0.txt
agrep -0 -c 'CCACGCACGAAGTACTG' *.fastq > count/B11155_Fm0.txt
agrep -0 -c 'GGGGTTAAATAAGTGGA' *.fastq > count/B11156_Fm0.txt
agrep -0 -c 'TTCCATATAGGGGGGAA' *.fastq > count/B11157_Fm0.txt
agrep -0 -c 'GATGCGTTGTTAAAGGC' *.fastq > count/B11158_Fm0.txt
agrep -0 -c 'ATTCGCCAACGTATTTG' *.fastq > count/B11161_Fm0.txt
agrep -0 -c 'CCGTTATCAAGGTATTG' *.fastq > count/B11162_Fm0.txt
agrep -0 -c 'TTCCTAGCGGTCACGTT' *.fastq > count/B11164_Fm0.txt
agrep -0 -c 'GCGAACTTTTGGCTTTG' *.fastq > count/B11165_Fm0.txt
agrep -0 -c 'TATCTACGAGAGAACCA' *.fastq > count/B11166_Fm0.txt
agrep -0 -c 'ATCCGGTTCTATCTGGG' *.fastq > count/B11167_Fm0.txt
agrep -0 -c 'GCGCACTTACGTCCTTC' *.fastq > count/B11168_Fm0.txt
agrep -0 -c 'ACAGTCGGTTGCTTGAT' *.fastq > count/B11169_Fm0.txt
agrep -0 -c 'AATGTTTCGTATAGGCG' *.fastq > count/B11170_Fm0.txt
agrep -0 -c 'TGTGCTGGAGCGAATCG' *.fastq > count/B11171_Fm0.txt
agrep -0 -c 'AACCGATTACCGGCAAC' *.fastq > count/B11172_Fm0.txt
agrep -0 -c 'GTCAGTATGGAAACGCC' *.fastq > count/B11173_Fm0.txt
agrep -0 -c 'TTCACTGACATCCCGTG' *.fastq > count/B11174_Fm0.txt
agrep -0 -c 'GTCACTGCTTCTCAAGG' *.fastq > count/B11175_Fm0.txt
agrep -0 -c 'ATCGAATTTCCTTCAGC' *.fastq > count/B11176_Fm0.txt
agrep -0 -c 'AGCGATCCTGTTAGCTT' *.fastq > count/B11177_Fm0.txt
agrep -0 -c 'TGCCTACATCGGCATCA' *.fastq > count/B11178_Fm0.txt
agrep -0 -c 'CACCACATCAGGTTGTT' *.fastq > count/B11179_Fm0.txt
agrep -0 -c 'TAACAGGGACGAAAGGC' *.fastq > count/B11181_Fm0.txt
agrep -0 -c 'ATCAGTTCAGCGATTGA' *.fastq > count/B11182_Fm0.txt
agrep -0 -c 'GGTGATTACTTCGCGTC' *.fastq > count/B11183_Fm0.txt
agrep -0 -c 'GACGTCCGTGTTAGGAA' *.fastq > count/B11184_Fm0.txt
agrep -0 -c 'GTTGGCACTCATTGTTT' *.fastq > count/B11185_Fm0.txt
agrep -0 -c 'GGACTCCAATCTCAAAT' *.fastq > count/B11186_Fm0.txt
agrep -0 -c 'AACGGGCTCTGAGGATC' *.fastq > count/B11187_Fm0.txt
agrep -0 -c 'CATATTGGCTCAATCGT' *.fastq > count/B11188_Fm0.txt
agrep -0 -c 'CACCTGGATTGTTGTAG' *.fastq > count/B11189_Fm0.txt
agrep -0 -c 'AGCACTCACAAAGGGGT' *.fastq > count/B11190_Fm0.txt
agrep -0 -c 'CTCTGGCGTTTGACCTT' *.fastq > count/B11192_Fm0.txt
agrep -0 -c 'ATCGTGTCACAAAACAC' *.fastq > count/B11193_Fm0.txt
agrep -0 -c 'GGTACTAATCCGTCCTT' *.fastq > count/B11194_Fm0.txt
agrep -0 -c 'AAGGGATAGTGTCCGAT' *.fastq > count/B11196_Fm0.txt
agrep -0 -c 'TCGCTTTACTCCTCTGG' *.fastq > count/B11197_Fm0.txt
agrep -0 -c 'GCGTCGTCTTTCGGTAG' *.fastq > count/B11198_Fm0.txt
agrep -0 -c 'CGAACGACCCGGTCATA' *.fastq > count/B11199_Fm0.txt
agrep -0 -c 'GGCATCTGGCTACACTG' *.fastq > count/B11200_Fm0.txt
agrep -0 -c 'CTGAAACTACTTGTCAG' *.fastq > count/B11201_Fm0.txt
agrep -0 -c 'CATGCACAATTCCCGGA' *.fastq > count/B11203_Fm0.txt
agrep -0 -c 'TTAGTTATTGCCGCGAT' *.fastq > count/B11204_Fm0.txt
agrep -0 -c 'CGCGCTCAGACTTAACG' *.fastq > count/B11205_Fm0.txt
agrep -0 -c 'CTTGCGGTTCTAGCAGA' *.fastq > count/B11207_Fm0.txt
agrep -0 -c 'CTAGAAAGATGGCGAGA' *.fastq > count/B11208_Fm0.txt
agrep -0 -c 'TCATCTACTGCATAGTC' *.fastq > count/B11210_Fm0.txt
agrep -0 -c 'CGGTTTACGGCAAACGT' *.fastq > count/B11211_Fm0.txt
agrep -0 -c 'CAAGTAACCACCATGCA' *.fastq > count/B11212_Fm0.txt
agrep -0 -c 'GAGCCGATTGAGACCTT' *.fastq > count/B11213_Fm0.txt
agrep -0 -c 'TTATCGGGTACAGGAGC' *.fastq > count/B11214_Fm0.txt
agrep -0 -c 'CAACGACCGATATTGGT' *.fastq > count/B11216_Fm0.txt
agrep -0 -c 'AAGAACTGTGCCCGGCA' *.fastq > count/B11218_Fm0.txt
agrep -0 -c 'GACTTGATTGTGACGTA' *.fastq > count/B11219_Fm0.txt
agrep -0 -c 'GGCATTCAAGCTCAAAC' *.fastq > count/B11222_Fm0.txt
agrep -0 -c 'AGGATCGTTGCAACAAG' *.fastq > count/B11223_Fm0.txt
agrep -0 -c 'TTCTGGGTTAACCCTGA' *.fastq > count/B11224_Fm0.txt
agrep -0 -c 'GCATCGACACCATATAA' *.fastq > count/B11225_Fm0.txt
agrep -0 -c 'CTCGGATGTACGAAGTC' *.fastq > count/B11226_Fm0.txt
agrep -0 -c 'GTGCCCACATATAGCAG' *.fastq > count/B11227_Fm0.txt
agrep -0 -c 'GAGGTTCCTGAATCTAA' *.fastq > count/B11228_Fm0.txt
agrep -0 -c 'CGCATACTATCAAAAGG' *.fastq > count/B11229_Fm0.txt
agrep -0 -c 'AGAGATGTCCCATATAG' *.fastq > count/B11231_Fm0.txt
agrep -0 -c 'AAGGGCGAAAAACCACC' *.fastq > count/B11232_Fm0.txt
agrep -0 -c 'AGGCTGATGTGTGCGGA' *.fastq > count/B11233_Fm0.txt
agrep -0 -c 'CCGACTCACTGCAAAAA' *.fastq > count/B11234_Fm0.txt
agrep -0 -c 'GCCGATTTGGGCTTTCG' *.fastq > count/B11235_Fm0.txt
agrep -0 -c 'GTCATTTCTCTCATCGC' *.fastq > count/B11236_Fm0.txt
agrep -0 -c 'GTCCGCGACTGACTAAT' *.fastq > count/B11237_Fm0.txt
agrep -0 -c 'GTTGCTAGGTCTACGTG' *.fastq > count/B11238_Fm0.txt
agrep -0 -c 'GTCAACGTCTAAAGAAC' *.fastq > count/B11239_Fm0.txt
agrep -0 -c 'AGGTCTCCTCGGGACAT' *.fastq > count/B11240_Fm0.txt
agrep -0 -c 'GTTCGCTATTGACTCTC' *.fastq > count/B11242_Fm0.txt
agrep -0 -c 'TCATTACCTTGCCTTCG' *.fastq > count/B11243_Fm0.txt
agrep -0 -c 'CTCTAGCCGAAGCCCAA' *.fastq > count/B11244_Fm0.txt
agrep -0 -c 'GAGCCTTAAGGAACTGG' *.fastq > count/B11246_Fm0.txt
agrep -0 -c 'GGTTCTCATAGCCACCG' *.fastq > count/B11247_Fm0.txt
agrep -0 -c 'AATAGTGACCCTCTCGG' *.fastq > count/B11248_Fm0.txt
agrep -0 -c 'CTTCCAAGACTACTTCA' *.fastq > count/B11249_Fm0.txt
agrep -0 -c 'AACGATCTGGAACGAGA' *.fastq > count/B11250_Fm0.txt
agrep -0 -c 'GATCTAGCATTTCGGAA' *.fastq > count/B11251_Fm0.txt
agrep -0 -c 'TATCAGTACGCGGTGGC' *.fastq > count/B11252_Fm0.txt
agrep -0 -c 'GGTTGAGAGTAGTGGGT' *.fastq > count/B11253_Fm0.txt
agrep -0 -c 'GCTAGTAATCGGAGCAC' *.fastq > count/B11254_Fm0.txt
agrep -0 -c 'AAGTATCTTAGAGCGAG' *.fastq > count/B11255_Fm0.txt
agrep -0 -c 'GACTAACAAGGGTGTGA' *.fastq > count/B11256_Fm0.txt
agrep -0 -c 'AATTACGCCCTCCTATC' *.fastq > count/B11257_Fm0.txt
agrep -0 -c 'TCGCACGGTCTAGTAAT' *.fastq > count/B11258_Fm0.txt
agrep -0 -c 'GGCAGGCAAGAAGTAAT' *.fastq > count/B11259_Fm0.txt
agrep -0 -c 'TAGCCACAAGATTCAGA' *.fastq > count/B11260_Fm0.txt
agrep -0 -c 'TCTTACAGGGTGAGATG' *.fastq > count/B11261_Fm0.txt
agrep -0 -c 'AGCGACCTTGGTTTTAG' *.fastq > count/B11262_Fm0.txt
agrep -0 -c 'ATGCATAGGCGGGCTGT' *.fastq > count/B11264_Fm0.txt
agrep -0 -c 'AAGTCGGCAGACCTCAT' *.fastq > count/B11266_Fm0.txt
agrep -0 -c 'GCATAAAGGCCTCCGTG' *.fastq > count/B11267_Fm0.txt
agrep -0 -c 'AGCGTCTATGAGGCCGA' *.fastq > count/B11268_Fm0.txt
agrep -0 -c 'CTCAGGAAAAGGGACGA' *.fastq > count/B11269_Fm0.txt
agrep -0 -c 'AGGTTTACGAGACAGAA' *.fastq > count/B11270_Fm0.txt
agrep -0 -c 'ACCTCTTACCAGGTCGC' *.fastq > count/B11271_Fm0.txt
agrep -0 -c 'ATGGCGGACAAAACAAA' *.fastq > count/B11272_Fm0.txt
agrep -0 -c 'ACTCACGTCATGATTGG' *.fastq > count/B11276_Fm0.txt
agrep -0 -c 'CATGACAAGGGGCTAAT' *.fastq > count/B11278_Fm0.txt
agrep -0 -c 'AGGTACCTGCTTATCCG' *.fastq > count/B11280_Fm0.txt
agrep -0 -c 'GGCTCATCATCGGCTAG' *.fastq > count/B11282_Fm0.txt
agrep -0 -c 'TGACTTACGTGAGAAGC' *.fastq > count/B11283_Fm0.txt
agrep -0 -c 'TAGATAGTGTGTCCCGA' *.fastq > count/B11284_Fm0.txt
agrep -0 -c 'ACTCGTTATCTCATCGT' *.fastq > count/B11285_Fm0.txt
agrep -0 -c 'TACTTCCCTGATCCATA' *.fastq > count/B11287_Fm0.txt
agrep -0 -c 'TGCGCAGCGCGTACTAA' *.fastq > count/B11288_Fm0.txt
agrep -0 -c 'ACATGCCCTCGTAGACT' *.fastq > count/B11289_Fm0.txt
agrep -0 -c 'CGCTGTTAAAGCACCAT' *.fastq > count/B11290_Fm0.txt
agrep -0 -c 'AACATGCTGAAGTGCTA' *.fastq > count/B11291_Fm0.txt
agrep -0 -c 'AAGAATGACTAGCAGGC' *.fastq > count/B11292_Fm0.txt
agrep -0 -c 'ACGTGTCGAACCATAAC' *.fastq > count/B11293_Fm0.txt
agrep -0 -c 'CGGAGCTGAGGGATCTA' *.fastq > count/B11294_Fm0.txt
agrep -0 -c 'TATCCGGCGATATTTAG' *.fastq > count/B11295_Fm0.txt
agrep -0 -c 'CACACAATGAGAAGTCA' *.fastq > count/B11296_Fm0.txt
agrep -0 -c 'AGGTAATCGAACCTGCG' *.fastq > count/B11298_Fm0.txt
agrep -0 -c 'CTATGTCCCAAGAGTGG' *.fastq > count/B11299_Fm0.txt
agrep -0 -c 'GGATTGGAACGAGCGTT' *.fastq > count/B11300_Fm0.txt
agrep -0 -c 'AACCGTGTTTGAAGCTT' *.fastq > count/B11301_Fm0.txt
agrep -0 -c 'ACCTCAGGAGATCGCAG' *.fastq > count/B11302_Fm0.txt
agrep -0 -c 'TCTCCATAGTTCAGACC' *.fastq > count/B11303_Fm0.txt
agrep -0 -c 'CGATGATGATCGGTAAT' *.fastq > count/B11304_Fm0.txt
agrep -0 -c 'CTAAGTCTTACTCGTTG' *.fastq > count/B11305_Fm0.txt
agrep -0 -c 'TGCACGTTACACGGAGA' *.fastq > count/B11306_Fm0.txt
agrep -0 -c 'CGTCACTTTGCTGACCC' *.fastq > count/B11308_Fm0.txt
agrep -0 -c 'ATACATTTGGCCGTGGA' *.fastq > count/B11309_Fm0.txt
agrep -0 -c 'CTTAGACAGAGAGTAGT' *.fastq > count/B11310_Fm0.txt
agrep -0 -c 'AGATACAAAGCATGACC' *.fastq > count/B11311_Fm0.txt
agrep -0 -c 'CGATTAACGTCTAGGGG' *.fastq > count/B11312_Fm0.txt
agrep -0 -c 'TTACAAGGGAGGGATCG' *.fastq > count/B11313_Fm0.txt
agrep -0 -c 'CTGCCCGTGACAGAAAA' *.fastq > count/B11314_Fm0.txt
agrep -0 -c 'ATACTCTTCGCCTATGC' *.fastq > count/B11315_Fm0.txt
agrep -0 -c 'GGGGTTGGCTATTGCTC' *.fastq > count/B11316_Fm0.txt
agrep -0 -c 'TCTAAATTAGCCGGCCA' *.fastq > count/B11317_Fm0.txt
agrep -0 -c 'CAGTCCGACCACAAGGA' *.fastq > count/B11318_Fm0.txt
agrep -0 -c 'GTTGAGTGCGCCAAGCA' *.fastq > count/B11320_Fm0.txt
agrep -0 -c 'TTCAGTACGGCCCTAAT' *.fastq > count/B11321_Fm0.txt
agrep -0 -c 'CGAGTTCATCAATCTTC' *.fastq > count/B11322_Fm0.txt
agrep -0 -c 'ATCCGCTATTGTAGGGG' *.fastq > count/B11323_Fm0.txt
agrep -0 -c 'AGCTCCATTTGGCGATA' *.fastq > count/B11324_Fm0.txt
agrep -0 -c 'AACTGCCTCCGATCGCT' *.fastq > count/B11326_Fm0.txt
agrep -0 -c 'TACCGAGTAGGCAAGCA' *.fastq > count/B11327_Fm0.txt
agrep -0 -c 'TCACCATGTAAGGAATG' *.fastq > count/B11328_Fm0.txt
agrep -0 -c 'TTCGGAGCATCCATAAG' *.fastq > count/B11329_Fm0.txt
agrep -0 -c 'TGTCGAACCTCCAATAC' *.fastq > count/B11330_Fm0.txt
agrep -0 -c 'ACTCCACGCGGTCGTAT' *.fastq > count/B11331_Fm0.txt
agrep -0 -c 'CCGGGAGCGGTACAAAT' *.fastq > count/B11332_Fm0.txt
agrep -0 -c 'CCGGCATTGATGGCATC' *.fastq > count/B11334_Fm0.txt
agrep -0 -c 'ACTAAGACAAACGCGGC' *.fastq > count/B11335_Fm0.txt
agrep -0 -c 'CGCCAGACACTATACAG' *.fastq > count/B11336_Fm0.txt
agrep -0 -c 'TCGATAGAGGATATCGT' *.fastq > count/B11339_Fm0.txt
agrep -0 -c 'GGACATGCACTTTAGAT' *.fastq > count/B11340_Fm0.txt
agrep -0 -c 'CCGGTCACGGTTTTGTC' *.fastq > count/B11341_Fm0.txt
agrep -0 -c 'ACCCTCGCGAATAGTAG' *.fastq > count/B11342_Fm0.txt
agrep -0 -c 'GTATGGGCATGCCTATT' *.fastq > count/B11344_Fm0.txt
agrep -0 -c 'CATACCTTGAATGGTGC' *.fastq > count/B11345_Fm0.txt
agrep -0 -c 'CGAGGATTAGCAGACGG' *.fastq > count/B11347_Fm0.txt
agrep -0 -c 'CGCGTACTTAGACCTTA' *.fastq > count/B11348_Fm0.txt
agrep -0 -c 'GAGAAATCAGTTAGCGA' *.fastq > count/B11349_Fm0.txt
agrep -0 -c 'ACTGGCAACCCGAGAAG' *.fastq > count/B11350_Fm0.txt
agrep -0 -c 'ACTGTTTACTGAGAGGC' *.fastq > count/B11352_Fm0.txt
agrep -0 -c 'CACTCGTTGTTGAACCT' *.fastq > count/B11353_Fm0.txt
agrep -0 -c 'TATTATAGCGCGCAATC' *.fastq > count/B11354_Fm0.txt
agrep -0 -c 'ACGTAGTTAAGGGACCT' *.fastq > count/B11355_Fm0.txt
agrep -0 -c 'TTCAACAGGACCAGAGA' *.fastq > count/B11356_Fm0.txt
agrep -0 -c 'TCTGCGTTCAATATTGG' *.fastq > count/B11357_Fm0.txt
agrep -0 -c 'CTAGGACTGCGTGTGGA' *.fastq > count/B11358_Fm0.txt
agrep -0 -c 'TTGAGAGGGGCGTAGTC' *.fastq > count/B11359_Fm0.txt
agrep -0 -c 'ACACCGATGGCATACAA' *.fastq > count/B11360_Fm0.txt
agrep -0 -c 'TGCGCCTGTAGCCAGTT' *.fastq > count/B11361_Fm0.txt
agrep -0 -c 'CAGAGTACTTAGCGTGA' *.fastq > count/B11363_Fm0.txt
agrep -0 -c 'ATACTAGTAGCGACTCA' *.fastq > count/B11364_Fm0.txt
agrep -0 -c 'CACGGTTGGAACTGCCT' *.fastq > count/B11365_Fm0.txt
agrep -0 -c 'AACTGGTACCCTGGAGG' *.fastq > count/B11366_Fm0.txt
agrep -0 -c 'AACTAACTGTTGATGGC' *.fastq > count/B11367_Fm0.txt
agrep -0 -c 'ATCTCATTTTTCGCCTG' *.fastq > count/B11368_Fm0.txt
agrep -0 -c 'CTGCTTAGCGCAATCGA' *.fastq > count/B11369_Fm0.txt
agrep -0 -c 'AGTCTTCGGTGAAGTAG' *.fastq > count/B11370_Fm0.txt
agrep -0 -c 'CAGTGCTCATCAAGCGG' *.fastq > count/B11371_Fm0.txt
agrep -0 -c 'AGACAATGCACGACACA' *.fastq > count/B11372_Fm0.txt
agrep -0 -c 'GCATATTATACCCGGTT' *.fastq > count/B11373_Fm0.txt
agrep -0 -c 'ATGTGGCGTCATGAACG' *.fastq > count/B11374_Fm0.txt
agrep -0 -c 'CGGAGTCCGAAAAAGCA' *.fastq > count/B11375_Fm0.txt
agrep -0 -c 'CTTCCTCTGAAAGATCG' *.fastq > count/B11376_Fm0.txt
agrep -0 -c 'GACCACGAATCTATTCT' *.fastq > count/B11378_Fm0.txt
agrep -0 -c 'TTGGGGTGTCGGTAAAA' *.fastq > count/B11379_Fm0.txt
agrep -0 -c 'GGGGGATGCTTGAAGAC' *.fastq > count/B11380_Fm0.txt
agrep -0 -c 'AGGGATTAGAGCACGGT' *.fastq > count/B11382_Fm0.txt
agrep -0 -c 'TATGGAGTTAGAACGAC' *.fastq > count/B11383_Fm0.txt
agrep -0 -c 'AGTGTATAGCTCCGCTT' *.fastq > count/B11384_Fm0.txt
agrep -0 -c 'TCGAGTTCGAGGTAAGT' *.fastq > count/B11385_Fm0.txt
agrep -0 -c 'CCGAATTGTCGCTGGCT' *.fastq > count/B11386_Fm0.txt
agrep -0 -c 'TGCCGACCTGCGTTCTT' *.fastq > count/B11388_Fm0.txt
agrep -0 -c 'GTAAACCGCCTCGCGTA' *.fastq > count/B11390_Fm0.txt
agrep -0 -c 'ACCATCGACTGAGACCT' *.fastq > count/B11391_Fm0.txt
agrep -0 -c 'TAGACTTGTTGCTGCAG' *.fastq > count/B11392_Fm0.txt
agrep -0 -c 'CGGCTAACAGTACAAGA' *.fastq > count/B11393_Fm0.txt
agrep -0 -c 'GCAAGTTACTTCGATAC' *.fastq > count/B11394_Fm0.txt
agrep -0 -c 'GTTCTAAACCACTCTAC' *.fastq > count/B11395_Fm0.txt
agrep -0 -c 'TCTTGACGTCATACTAC' *.fastq > count/B11396_Fm0.txt
agrep -0 -c 'AATGAAACCCAATCACG' *.fastq > count/B11397_Fm0.txt
agrep -0 -c 'AGGATACATCCGCCAAC' *.fastq > count/B11399_Fm0.txt
agrep -0 -c 'TTGGATTCAGAAGCACG' *.fastq > count/B11400_Fm0.txt
agrep -0 -c 'GCGTTTACGACACTATG' *.fastq > count/B11401_Fm0.txt
agrep -0 -c 'TATTTTCGCTTCCTCTG' *.fastq > count/B11402_Fm0.txt
agrep -0 -c 'TGCAACAGCTAATGACA' *.fastq > count/B11405_Fm0.txt
agrep -0 -c 'CACTACCGTCTAAGTCA' *.fastq > count/B11406_Fm0.txt
agrep -0 -c 'GACTCAGTCACATTCGC' *.fastq > count/B11409_Fm0.txt
agrep -0 -c 'AACGGAGGCCCATGCAA' *.fastq > count/B11410_Fm0.txt
agrep -0 -c 'TCGTCATTAACGCCCGC' *.fastq > count/B11411_Fm0.txt
agrep -0 -c 'GGGCTTCGTTGCAGGTT' *.fastq > count/B11412_Fm0.txt
agrep -0 -c 'TGATAGCCCTTCAACGT' *.fastq > count/B11414_Fm0.txt
agrep -0 -c 'TGGAACTAGAGACACCC' *.fastq > count/B11415_Fm0.txt
agrep -0 -c 'ATTGCCCTGACCAATTA' *.fastq > count/B11416_Fm0.txt
agrep -0 -c 'CCGAGTTTGTGCCCTCT' *.fastq > count/B11417_Fm0.txt
agrep -0 -c 'TGCGCAAGATTTTAAGG' *.fastq > count/B11418_Fm0.txt
agrep -0 -c 'GGTTCGTTGTAACCCTT' *.fastq > count/B11419_Fm0.txt
agrep -0 -c 'CGTGGTATCGCTTACTT' *.fastq > count/B11422_Fm0.txt
agrep -0 -c 'CTAACTGACGGTAGCGC' *.fastq > count/B11423_Fm0.txt
agrep -0 -c 'GACTCGAATCCGATTCC' *.fastq > count/B11424_Fm0.txt
agrep -0 -c 'ACCGGAAGCCAGCATAC' *.fastq > count/B11425_Fm0.txt
agrep -0 -c 'ATAGACTACCCCTCAGT' *.fastq > count/B11426_Fm0.txt
agrep -0 -c 'TCGCCTGTTACGCCTTA' *.fastq > count/B11427_Fm0.txt
agrep -0 -c 'GTGCATCCGCTCTGTTC' *.fastq > count/B11428_Fm0.txt
agrep -0 -c 'CAACACGTACCTCGATC' *.fastq > count/B11429_Fm0.txt
agrep -0 -c 'ATCCCGGTTTGGTCTTA' *.fastq > count/B11430_Fm0.txt
agrep -0 -c 'GTACTCAAGCCAGCTGC' *.fastq > count/B11431_Fm0.txt
agrep -0 -c 'GTGTTACAACCCATGCA' *.fastq > count/B11432_Fm0.txt
agrep -0 -c 'ACCCTCAAAGATATCGA' *.fastq > count/B11433_Fm0.txt
agrep -0 -c 'AACGAGTTCGCATCTAT' *.fastq > count/B11434_Fm0.txt
agrep -0 -c 'GATCGAAGTGGACGTTA' *.fastq > count/B11435_Fm0.txt
agrep -0 -c 'TAAGGTAGGCTTCCTAC' *.fastq > count/B11436_Fm0.txt
agrep -0 -c 'TAAACGGTATGCCCGCT' *.fastq > count/B11437_Fm0.txt
agrep -0 -c 'AGCTTACTGCTTACGTT' *.fastq > count/B11440_Fm0.txt
agrep -0 -c 'CGCGTTGCCAAATACAA' *.fastq > count/B11442_Fm0.txt
agrep -0 -c 'GTGTATCGTTCTGCTTA' *.fastq > count/B11443_Fm0.txt
agrep -0 -c 'GCAGACCATTGATTGGG' *.fastq > count/B11445_Fm0.txt
agrep -0 -c 'ACAGGGTCGTGACTACT' *.fastq > count/B11448_Fm0.txt
agrep -0 -c 'CGCACTGTAGTAACGTC' *.fastq > count/B11449_Fm0.txt
agrep -0 -c 'TCTAAGCAGAGCACGCC' *.fastq > count/B11451_Fm0.txt
agrep -0 -c 'AACGACTGCAAATAGCT' *.fastq > count/B11452_Fm0.txt
agrep -0 -c 'AGGGGTGCCCTTTCACT' *.fastq > count/B11453_Fm0.txt
agrep -0 -c 'ACGTCTGATGTCGTAAC' *.fastq > count/B11454_Fm0.txt
agrep -0 -c 'CGTTAGACGGGTCAGTG' *.fastq > count/B11455_Fm0.txt
agrep -0 -c 'CGTTGTGTACGTTACTT' *.fastq > count/B11456_Fm0.txt
agrep -0 -c 'ACGCGTGATTAAAGTTC' *.fastq > count/B11457_Fm0.txt
agrep -0 -c 'CGACGTGTGTGTAGGAG' *.fastq > count/B11458_Fm0.txt
agrep -0 -c 'GTTGTATCTGGCCATCG' *.fastq > count/B11459_Fm0.txt
agrep -0 -c 'TATGCTGTCCATCCTCG' *.fastq > count/B11460_Fm0.txt
agrep -0 -c 'TATCGGATGTCGGCAAT' *.fastq > count/B11461_Fm0.txt
agrep -0 -c 'CACACCATCCAGTCGAG' *.fastq > count/B11462_Fm0.txt
agrep -0 -c 'ACTGAAGGCGGAACGAC' *.fastq > count/B11463_Fm0.txt
agrep -0 -c 'ACCCCGGGTAACGGTTA' *.fastq > count/B11465_Fm0.txt
agrep -0 -c 'TGCCTTTGCGTTCCCTC' *.fastq > count/B11466_Fm0.txt
agrep -0 -c 'TATCCAAGCAGGGCAGC' *.fastq > count/B11467_Fm0.txt
agrep -0 -c 'ATACTGAGCGGAATAGA' *.fastq > count/B11468_Fm0.txt
agrep -0 -c 'GGTACCATCTGTTTGCC' *.fastq > count/B11470_Fm0.txt
agrep -0 -c 'GACTTGGAAGCAAACCG' *.fastq > count/B11471_Fm0.txt
agrep -0 -c 'ATACTACCGCGGTTCAG' *.fastq > count/B11472_Fm0.txt
agrep -0 -c 'GCGAGCGGACAATTGTA' *.fastq > count/B11474_Fm0.txt
agrep -0 -c 'CCGTATGGAATGTATTG' *.fastq > count/B11475_Fm0.txt
agrep -0 -c 'ATACGAAGGGTCAGCGA' *.fastq > count/B11476_Fm0.txt
agrep -0 -c 'TCTCTTACACGCCAAAT' *.fastq > count/B11478_Fm0.txt
agrep -0 -c 'CTTACGTTAACGGTTCG' *.fastq > count/B11479_Fm0.txt
agrep -0 -c 'TCTACAGAGGCTTATGC' *.fastq > count/B11480_Fm0.txt
agrep -0 -c 'TTAGATACATCGACCCA' *.fastq > count/B11481_Fm0.txt
agrep -0 -c 'GCATGGATGAACGATCA' *.fastq > count/B11482_Fm0.txt
agrep -0 -c 'GCGTGAACTAGCATGGG' *.fastq > count/B11483_Fm0.txt
agrep -0 -c 'ACTGATTCGGCAACCAA' *.fastq > count/B11484_Fm0.txt
agrep -0 -c 'GTCTGGGTCAAGGCTTT' *.fastq > count/B11485_Fm0.txt
agrep -0 -c 'TGTGAAACCGACACACC' *.fastq > count/B11486_Fm0.txt
agrep -0 -c 'ACAGCTTAGACGATCTG' *.fastq > count/B11487_Fm0.txt
agrep -0 -c 'GGTTACTGTTCGACTTA' *.fastq > count/B11489_Fm0.txt
agrep -0 -c 'GTGAGTCAAGAAGGCTA' *.fastq > count/B11493_Fm0.txt
agrep -0 -c 'ATATAACGCTCTCACCA' *.fastq > count/B11494_Fm0.txt
agrep -0 -c 'CTCCGCGCATACTCAAG' *.fastq > count/B11496_Fm0.txt
agrep -0 -c 'TGCTGCGACCTAATCAG' *.fastq > count/B11497_Fm0.txt
agrep -0 -c 'TCTTCGTGGTCAATGGG' *.fastq > count/B11498_Fm0.txt
agrep -0 -c 'CGGCAAAATCTCGGTGT' *.fastq > count/B11499_Fm0.txt
agrep -0 -c 'AGAGACCCGACATCGTG' *.fastq > count/B11500_Fm0.txt
agrep -0 -c 'CCAGTGTTCACGTAGAC' *.fastq > count/B11501_Fm0.txt
agrep -0 -c 'GCTGCGGGTATCCTAAC' *.fastq > count/B11502_Fm0.txt
agrep -0 -c 'GCTCAAAAACCCTTTAC' *.fastq > count/B11503_Fm0.txt
agrep -0 -c 'GCTTAGTGCAGTAAATC' *.fastq > count/B11504_Fm0.txt
agrep -0 -c 'TGACGTAGATCGCTAAA' *.fastq > count/B11505_Fm0.txt
agrep -0 -c 'GAGACTCAAGAGCCGTT' *.fastq > count/B11506_Fm0.txt
agrep -0 -c 'CCTCATGATCGTAGGGT' *.fastq > count/B11507_Fm0.txt
agrep -0 -c 'GCATAGCGAGTTGTTTA' *.fastq > count/B11508_Fm0.txt
agrep -0 -c 'GTAAACCAACGGGGTTG' *.fastq > count/B11511_Fm0.txt
agrep -0 -c 'CAATCATGTCTGCGGGC' *.fastq > count/B11512_Fm0.txt
agrep -0 -c 'CCAATGTGCCCTATGCT' *.fastq > count/B11513_Fm0.txt
agrep -0 -c 'ACCGAGTTAGACATTCC' *.fastq > count/B11514_Fm0.txt
agrep -0 -c 'GGCCTAAACGAACTTCG' *.fastq > count/B11515_Fm0.txt
agrep -0 -c 'GCTGGTTGTTTGTCTGT' *.fastq > count/B11517_Fm0.txt
agrep -0 -c 'TTCAGGAGACCTCGACA' *.fastq > count/B11520_Fm0.txt
agrep -0 -c 'CACAGGGCAGTCAAATT' *.fastq > count/B11521_Fm0.txt
agrep -0 -c 'ATGCTGGGGATGACTAA' *.fastq > count/B11522_Fm0.txt
agrep -0 -c 'TTAGCAGTGGACTCTTT' *.fastq > count/B11524_Fm0.txt
agrep -0 -c 'ATCAACCCATGTTCCAC' *.fastq > count/B11525_Fm0.txt
agrep -0 -c 'AGCACTAGATATGGTCT' *.fastq > count/B11526_Fm0.txt
agrep -0 -c 'GAGGTCCTTTTGCAGCG' *.fastq > count/B11527_Fm0.txt
agrep -0 -c 'ATGCCTGACTAATCCTC' *.fastq > count/B11528_Fm0.txt
agrep -0 -c 'CAGGAAGACTAGCGACT' *.fastq > count/B11529_Fm0.txt
agrep -0 -c 'CTAGACGTATGGTCAAC' *.fastq > count/B11530_Fm0.txt
agrep -0 -c 'ACGTACCAAAGCAGGTG' *.fastq > count/B11531_Fm0.txt
agrep -0 -c 'AAGGGCTCGCTATTAGA' *.fastq > count/B11532_Fm0.txt
agrep -0 -c 'CCACGTGCGATTCTGCT' *.fastq > count/B11533_Fm0.txt
agrep -0 -c 'TTCATACCAGGTTGAAC' *.fastq > count/B11534_Fm0.txt
agrep -0 -c 'CGATTCTGATGTGTTTC' *.fastq > count/B11535_Fm0.txt
agrep -0 -c 'CAAGACGCTTAACTCAT' *.fastq > count/B11536_Fm0.txt
agrep -0 -c 'ACCAAGCCGTGCTTCCA' *.fastq > count/B11537_Fm0.txt
agrep -0 -c 'AGTAACCGAGGCAGACA' *.fastq > count/B11539_Fm0.txt
agrep -0 -c 'TTAGTTGCATCAGGTAC' *.fastq > count/B11541_Fm0.txt
agrep -0 -c 'GTCTGTATTACATCGCG' *.fastq > count/B11542_Fm0.txt
agrep -0 -c 'AACTTCTTAGCCCCACA' *.fastq > count/B11543_Fm0.txt
agrep -0 -c 'CAACGCGTGGGTCTTTG' *.fastq > count/B11544_Fm0.txt
agrep -0 -c 'ACCTATCAATGGTTCTC' *.fastq > count/B11545_Fm0.txt
agrep -0 -c 'TGATAGAACGCGTTGAC' *.fastq > count/B11546_Fm0.txt
agrep -0 -c 'CTGCGTGCTAAGTGAAA' *.fastq > count/B11548_Fm0.txt
agrep -0 -c 'TAGCGCAGTTTAGACCT' *.fastq > count/B11549_Fm0.txt
agrep -0 -c 'CCGCGGTAACATATTGA' *.fastq > count/B11550_Fm0.txt
agrep -0 -c 'AGGATTCGCACTCGATT' *.fastq > count/B11551_Fm0.txt
agrep -0 -c 'CTGGCAGGGGTTCGTAA' *.fastq > count/B11552_Fm0.txt
agrep -0 -c 'ACGGAGCTTTAGCCTGA' *.fastq > count/B11553_Fm0.txt
agrep -0 -c 'TAAAGGGCCTCTGCCTA' *.fastq > count/B11554_Fm0.txt
agrep -0 -c 'AATGGTCAGTCTAGTAG' *.fastq > count/B11555_Fm0.txt
agrep -0 -c 'ATATGTGATGGCGCCCC' *.fastq > count/B11556_Fm0.txt
agrep -0 -c 'CTTACCGTAGTTTGGAC' *.fastq > count/B11557_Fm0.txt
agrep -0 -c 'GCGCGTTTAGTTTCCCC' *.fastq > count/B11558_Fm0.txt
agrep -0 -c 'CTGACAAAGGAATGGCA' *.fastq > count/B11559_Fm0.txt
agrep -0 -c 'GCCTGCAGCTTCATTCG' *.fastq > count/B11560_Fm0.txt
agrep -0 -c 'ATATTTGCGCGTGAAGA' *.fastq > count/B11561_Fm0.txt
agrep -0 -c 'GATGGTGCGGACTAAAT' *.fastq > count/B11562_Fm0.txt
agrep -0 -c 'AGGTCGTGTTGATTGGA' *.fastq > count/B11563_Fm0.txt
agrep -0 -c 'AGCATTGGTCGTTGTTG' *.fastq > count/B11564_Fm0.txt
agrep -0 -c 'GCCGTTATATGCTGGAG' *.fastq > count/B11565_Fm0.txt
agrep -0 -c 'TTGTCTACACGCCTTGC' *.fastq > count/B11566_Fm0.txt
agrep -0 -c 'GATTTGTTCATCCGAGG' *.fastq > count/B11567_Fm0.txt
agrep -0 -c 'GGTCTTGTAGTTGGCGC' *.fastq > count/B11568_Fm0.txt
agrep -0 -c 'ATTCTTTAGCAGGCGCG' *.fastq > count/B11571_Fm0.txt
agrep -0 -c 'GACTGAGATACGAGGGT' *.fastq > count/B11572_Fm0.txt
agrep -0 -c 'GATTTACTCTCGCGTAA' *.fastq > count/B11575_Fm0.txt
agrep -0 -c 'TGTTCTAGTATCGTCCC' *.fastq > count/B11576_Fm0.txt
agrep -0 -c 'GAGAGGCTAGTTGTTCA' *.fastq > count/B11578_Fm0.txt
agrep -0 -c 'ATTTTAGTGCAGCCCCG' *.fastq > count/B11579_Fm0.txt
agrep -0 -c 'AAGCACTTGATCGCAAT' *.fastq > count/B11580_Fm0.txt
agrep -0 -c 'AGAGCGGACTCATCAAC' *.fastq > count/B11581_Fm0.txt
agrep -0 -c 'GGACGAGCAGTTCGAGA' *.fastq > count/B11582_Fm0.txt
agrep -0 -c 'CCGTTTATGTCGGCATC' *.fastq > count/B11583_Fm0.txt
agrep -0 -c 'ATTCCAAGATGACGACG' *.fastq > count/B11585_Fm0.txt
agrep -0 -c 'CTTCTCACCAATTCGTA' *.fastq > count/B11586_Fm0.txt
agrep -0 -c 'TACGATAATTAGTCGCG' *.fastq > count/B11587_Fm0.txt
agrep -0 -c 'CGTGTTAACCGTTACTG' *.fastq > count/B11588_Fm0.txt
agrep -0 -c 'CGACACGATGGTGCTCT' *.fastq > count/B11589_Fm0.txt
agrep -0 -c 'CGACCAACTACGGTGAG' *.fastq > count/B11590_Fm0.txt
agrep -0 -c 'GAGGCCCCAAACTCGAA' *.fastq > count/B11591_Fm0.txt
agrep -0 -c 'ACGTCAGAGTATTAAGC' *.fastq > count/B11592_Fm0.txt
agrep -0 -c 'GACCGCAAAGTTTACAT' *.fastq > count/B11593_Fm0.txt
agrep -0 -c 'CGTTGGGCTATACAAAC' *.fastq > count/B11594_Fm0.txt
agrep -0 -c 'TCACTAGACGACAACGA' *.fastq > count/B11595_Fm0.txt
agrep -0 -c 'CATGGTAGAATACGGCT' *.fastq > count/B11596_Fm0.txt
agrep -0 -c 'TTCTCAGCTAGGTCCCA' *.fastq > count/B11598_Fm0.txt
agrep -0 -c 'GGGAGGATCGCTTTAGC' *.fastq > count/B11599_Fm0.txt
agrep -0 -c 'GAGTGGGTGCAAACTAA' *.fastq > count/B11601_Fm0.txt
agrep -0 -c 'CTGACTACTCAACGCAT' *.fastq > count/B11602_Fm0.txt
agrep -0 -c 'CACGGAAGATGTATTAG' *.fastq > count/B11603_Fm0.txt
agrep -0 -c 'AGTCGTTCTGGCGAAGC' *.fastq > count/B11604_Fm0.txt
agrep -0 -c 'GTACGGGTTCCGTAATA' *.fastq > count/B11605_Fm0.txt
agrep -0 -c 'GCACCCTAATACCTTCC' *.fastq > count/B11606_Fm0.txt
agrep -0 -c 'GAGTGGGCTACATTCGC' *.fastq > count/B11608_Fm0.txt
agrep -0 -c 'CTACTACACCGCAACTC' *.fastq > count/B11611_Fm0.txt
agrep -0 -c 'CACTCTCAAGCCGTGGA' *.fastq > count/B11613_Fm0.txt
agrep -0 -c 'TAGGGCTAGGACGTGTG' *.fastq > count/B11614_Fm0.txt
agrep -0 -c 'AGGCCGCACTCTGGTAA' *.fastq > count/B11615_Fm0.txt
agrep -0 -c 'TAAGCTCGCGTTACGTA' *.fastq > count/B11616_Fm0.txt
agrep -0 -c 'TTCCCAGTAGTTCAGTT' *.fastq > count/B11618_Fm0.txt
agrep -0 -c 'AGAATGCGAAGTGCGGC' *.fastq > count/B11619_Fm0.txt
agrep -0 -c 'CAACGTGGTCACAGAAT' *.fastq > count/B11620_Fm0.txt
agrep -0 -c 'CATTGCGGACTCGTACG' *.fastq > count/B11621_Fm0.txt
agrep -0 -c 'CGCATCCACGACATTAC' *.fastq > count/B11622_Fm0.txt
agrep -0 -c 'TTCCTAGCCATTATAGC' *.fastq > count/B11623_Fm0.txt
agrep -0 -c 'GACAGTCCGGCCTTAAC' *.fastq > count/B11624_Fm0.txt
agrep -0 -c 'TTGGACAAGCCAATCGT' *.fastq > count/B11625_Fm0.txt
agrep -0 -c 'CACGTCACGCACACTTA' *.fastq > count/B11626_Fm0.txt
agrep -0 -c 'CGAGTAGCTATGTTTGC' *.fastq > count/B11627_Fm0.txt
agrep -0 -c 'CCGTGCCACTCTACTAG' *.fastq > count/B11628_Fm0.txt
agrep -0 -c 'CAAATCCCAGTCGGTAT' *.fastq > count/B11630_Fm0.txt
agrep -0 -c 'GCAATGGCCCGAGTTTT' *.fastq > count/B11631_Fm0.txt
agrep -0 -c 'GATCCCATTAGTTAGTG' *.fastq > count/B11632_Fm0.txt
agrep -0 -c 'CCGGATCGCTTAGAATC' *.fastq > count/B11633_Fm0.txt
agrep -0 -c 'GGAATTGATACTCAGGA' *.fastq > count/B11634_Fm0.txt
agrep -0 -c 'GGTAGGTCTTGGACGTA' *.fastq > count/B11635_Fm0.txt
agrep -0 -c 'TTCTATCCACTTCTCAG' *.fastq > count/B11636_Fm0.txt
agrep -0 -c 'CTTGGTCATTGGGCTGC' *.fastq > count/B11637_Fm0.txt
agrep -0 -c 'ATGGTCCGCACGTAGCA' *.fastq > count/B11639_Fm0.txt
agrep -0 -c 'ATCAAAAGTCGGGAGGC' *.fastq > count/B11640_Fm0.txt
agrep -0 -c 'CCTTAACGTGACTCAGC' *.fastq > count/B11642_Fm0.txt
agrep -0 -c 'TACACGACTGCCATAGC' *.fastq > count/B11643_Fm0.txt
agrep -0 -c 'TGCACACCGATATTTTG' *.fastq > count/B11645_Fm0.txt
agrep -0 -c 'TCTCGTACACTCTCAGC' *.fastq > count/B11648_Fm0.txt
agrep -0 -c 'TCTCAACTGCAGTCAAC' *.fastq > count/B11649_Fm0.txt
agrep -0 -c 'TGAAGGCATTCGACCCT' *.fastq > count/B11650_Fm0.txt
agrep -0 -c 'GAGGCATTCAAACGTTA' *.fastq > count/B11651_Fm0.txt
agrep -0 -c 'GCCTCGCTTTACCAATA' *.fastq > count/B11652_Fm0.txt
agrep -0 -c 'CGGAGCTATGTCAGAAC' *.fastq > count/B11653_Fm0.txt
agrep -0 -c 'ACACCTAATCTCTCCGT' *.fastq > count/B11654_Fm0.txt
agrep -0 -c 'TGATAGGTCATACGGAC' *.fastq > count/B11655_Fm0.txt
agrep -0 -c 'CAGGAATACGAGACATG' *.fastq > count/B11656_Fm0.txt
agrep -0 -c 'TTGCCTAATTGAGCTAC' *.fastq > count/B11657_Fm0.txt
agrep -0 -c 'CCACTTCTTATTGGCAA' *.fastq > count/B11659_Fm0.txt
agrep -0 -c 'AGCCTTGGTAGAGTTCT' *.fastq > count/B11660_Fm0.txt
agrep -0 -c 'ACGCGCTCCTTGATGAG' *.fastq > count/B11661_Fm0.txt
agrep -0 -c 'GCCCCCTAACTCGTAGA' *.fastq > count/B11662_Fm0.txt
agrep -0 -c 'TTAGTAACAGTTCGTCC' *.fastq > count/B11663_Fm0.txt
agrep -0 -c 'TCACCGAACCAATAGAG' *.fastq > count/B11664_Fm0.txt
agrep -0 -c 'AATCACCCCCATCTTTA' *.fastq > count/B11665_Fm0.txt
agrep -0 -c 'TGAGACCTGACGATGTC' *.fastq > count/B11667_Fm0.txt
agrep -0 -c 'AAGAGCATTCGCCCCAT' *.fastq > count/B11668_Fm0.txt
agrep -0 -c 'TGCCCAATTCGTTGGGG' *.fastq > count/B11669_Fm0.txt
agrep -0 -c 'AGAGCGGCCGTTCCTTA' *.fastq > count/B11671_Fm0.txt
agrep -0 -c 'AGACATACGGTCTAATG' *.fastq > count/B11672_Fm0.txt
agrep -0 -c 'GGCAGGCGGAACAATGA' *.fastq > count/B11673_Fm0.txt
agrep -0 -c 'AGATTCGTAGCCGAATG' *.fastq > count/B11674_Fm0.txt
agrep -0 -c 'CGACCGATTACCTATCG' *.fastq > count/B11675_Fm0.txt
agrep -0 -c 'AGGGGAAAGCTGTCGAT' *.fastq > count/B11676_Fm0.txt
agrep -0 -c 'CATCGACATCCATGCTA' *.fastq > count/B11677_Fm0.txt
agrep -0 -c 'TTACTTGAGCTCTCCGC' *.fastq > count/B11678_Fm0.txt
agrep -0 -c 'CTGTGGGTAGTGAATTT' *.fastq > count/B11681_Fm0.txt
agrep -0 -c 'AATTGCTCACGATAGAC' *.fastq > count/B11682_Fm0.txt
agrep -0 -c 'AATCGAGCGAATCAGTC' *.fastq > count/B11683_Fm0.txt
agrep -0 -c 'GCGTAGTGTAGATAGGG' *.fastq > count/B11684_Fm0.txt
agrep -0 -c 'GGCCTACATTTGTGCAC' *.fastq > count/B11686_Fm0.txt
agrep -0 -c 'AGGTTTCCTATGGGAGT' *.fastq > count/B11687_Fm0.txt
agrep -0 -c 'ACATCTAGGGGCCTTTT' *.fastq > count/B11689_Fm0.txt
agrep -0 -c 'AGCTTAGTTTCGAACGC' *.fastq > count/B11690_Fm0.txt
agrep -0 -c 'TTCTTCACCATAAGCGG' *.fastq > count/B11692_Fm0.txt
agrep -0 -c 'CTCGACACAACGCAGAC' *.fastq > count/B11693_Fm0.txt
agrep -0 -c 'GTTAGTCTAACAGGAGG' *.fastq > count/B11694_Fm0.txt
agrep -0 -c 'CGACTTTCGGTGGTAAC' *.fastq > count/B11695_Fm0.txt
agrep -0 -c 'GCCCGCTTAATTGCTCA' *.fastq > count/B11697_Fm0.txt
agrep -0 -c 'CGTACATACCGCAGGGA' *.fastq > count/B11700_Fm0.txt
agrep -0 -c 'ATTCCTGGCTCCTGGTA' *.fastq > count/B11701_Fm0.txt
agrep -0 -c 'ATCGGTCGGCATTTCGG' *.fastq > count/B11702_Fm0.txt
agrep -0 -c 'TCTTCTAGGCCCGGTTT' *.fastq > count/B11703_Fm0.txt
agrep -0 -c 'GTATTAGCCGGAGAAGA' *.fastq > count/B11704_Fm0.txt
agrep -0 -c 'CCGGGAGCTAGTATGTC' *.fastq > count/B11705_Fm0.txt
agrep -0 -c 'ACGAGTGTCTACGATAA' *.fastq > count/B11706_Fm0.txt
agrep -0 -c 'TCGAGGATCGAGTTGCC' *.fastq > count/B11707_Fm0.txt
agrep -0 -c 'ACGTTACCAGGAACCGG' *.fastq > count/B11710_Fm0.txt
agrep -0 -c 'CAACTATCGCTGGATTG' *.fastq > count/B11711_Fm0.txt
agrep -0 -c 'TGTAGGGCTGGCACGTA' *.fastq > count/B11712_Fm0.txt
agrep -0 -c 'TCATGAGATCGGCGACT' *.fastq > count/B11714_Fm0.txt
agrep -0 -c 'CTAATCCCAAGGCCGTT' *.fastq > count/B11715_Fm0.txt
agrep -0 -c 'GGCTCAAAGTGTTGTAA' *.fastq > count/B11717_Fm0.txt
agrep -0 -c 'TTAAGTGACACCCTGAG' *.fastq > count/B11719_Fm0.txt
agrep -0 -c 'CCATGAGGGTAAGGTCT' *.fastq > count/B11720_Fm0.txt
agrep -0 -c 'GCGACTATTACGGTACC' *.fastq > count/B11721_Fm0.txt
agrep -0 -c 'AGCAAAGAGCAACTTCG' *.fastq > count/B11722_Fm0.txt
agrep -0 -c 'AGGCGAGGGAACCCTTT' *.fastq > count/B11723_Fm0.txt
agrep -0 -c 'CGTGGTCTTGCAGGATG' *.fastq > count/B11724_Fm0.txt
agrep -0 -c 'TCGACGTTGAAAGGTTA' *.fastq > count/B11725_Fm0.txt
agrep -0 -c 'GCGTCAAGGAGAGATTA' *.fastq > count/B11726_Fm0.txt
agrep -0 -c 'GTATCTAACCAGTCTAC' *.fastq > count/B11727_Fm0.txt
agrep -0 -c 'TATGCCCCTGACTAGAT' *.fastq > count/B11728_Fm0.txt
agrep -0 -c 'ACCTCTCCTACGCGGTT' *.fastq > count/B11729_Fm0.txt
agrep -0 -c 'AGCAGTGGGAACACTTC' *.fastq > count/B11730_Fm0.txt
agrep -0 -c 'AAGACCAAGCCCGCAAA' *.fastq > count/B11731_Fm0.txt
agrep -0 -c 'AGGAGATTGAAGAACGA' *.fastq > count/B11732_Fm0.txt
agrep -0 -c 'AAGTCTTACGTGGGCAG' *.fastq > count/B11733_Fm0.txt
agrep -0 -c 'TGTTACAGCGATGTTAG' *.fastq > count/B11735_Fm0.txt
agrep -0 -c 'CTCAGCTAATACACGGA' *.fastq > count/B11736_Fm0.txt
agrep -0 -c 'ATTACTCGTCGCATAAG' *.fastq > count/B11738_Fm0.txt
agrep -0 -c 'GCGGTTAGTAAAGGTCG' *.fastq > count/B11739_Fm0.txt
agrep -0 -c 'ATCGTTCAAGATTGTCG' *.fastq > count/B11740_Fm0.txt
agrep -0 -c 'ATCGGGAAATCCATGGG' *.fastq > count/B11741_Fm0.txt
agrep -0 -c 'TGCCTCTCACCCGATAA' *.fastq > count/B11742_Fm0.txt
agrep -0 -c 'GTTCGATCCCTCAAGGC' *.fastq > count/B11743_Fm0.txt
agrep -0 -c 'GGAAGTACCAGGCAATA' *.fastq > count/B11744_Fm0.txt
agrep -0 -c 'CCTGGCCGCAATCATCA' *.fastq > count/B11745_Fm0.txt
agrep -0 -c 'CGAGCTAGAAGCATATT' *.fastq > count/B11746_Fm0.txt
agrep -0 -c 'ACTTTGAGCTTGGTCGT' *.fastq > count/B11747_Fm0.txt
agrep -0 -c 'TAGTATTATGGGAGGTC' *.fastq > count/B11749_Fm0.txt
agrep -0 -c 'TGACCCGCTGGCGTTAA' *.fastq > count/B11750_Fm0.txt
agrep -0 -c 'GCTAAGGCACTGCAATG' *.fastq > count/B11751_Fm0.txt
agrep -0 -c 'GCTGGTTACGTGTAAAT' *.fastq > count/B11752_Fm0.txt
agrep -0 -c 'AGGTACCCAGGCATAGC' *.fastq > count/B11753_Fm0.txt
agrep -0 -c 'CTACGTAGCATAAGTTC' *.fastq > count/B11754_Fm0.txt
agrep -0 -c 'TCGCCCTCCTATCTATT' *.fastq > count/B11755_Fm0.txt
agrep -0 -c 'AGAGCCAACTGGGTATT' *.fastq > count/B11756_Fm0.txt
agrep -0 -c 'GTTTAGGGCCACAAGGA' *.fastq > count/B11759_Fm0.txt
agrep -0 -c 'AATGAACGGCCTACGTC' *.fastq > count/B11760_Fm0.txt
agrep -0 -c 'GCCGCCTTATCTTTCGT' *.fastq > count/B11761_Fm0.txt
agrep -0 -c 'ACCCCTATTAGATTGCC' *.fastq > count/B11762_Fm0.txt
agrep -0 -c 'TGATCGTCGAACTGGGT' *.fastq > count/B11764_Fm0.txt
agrep -0 -c 'CACAGGTACAGTTCAGC' *.fastq > count/B11765_Fm0.txt
agrep -0 -c 'TATCCGTTCCAACACAC' *.fastq > count/B11766_Fm0.txt
agrep -0 -c 'CGTTCCGCGACGTACTT' *.fastq > count/B11767_Fm0.txt
agrep -0 -c 'TCACTGGGCGGTCTAAT' *.fastq > count/B11768_Fm0.txt
agrep -0 -c 'GCCCAATACTTCCGGCA' *.fastq > count/B11771_Fm0.txt
agrep -0 -c 'TGAAGACACCCCTCTAA' *.fastq > count/B11773_Fm0.txt
agrep -0 -c 'CCTCGTACTAAGTGGCT' *.fastq > count/B11774_Fm0.txt
agrep -0 -c 'GCTCACAATCAGGTTCC' *.fastq > count/B11775_Fm0.txt
agrep -0 -c 'CTCACCTTACTAGGCAA' *.fastq > count/B11776_Fm0.txt
agrep -0 -c 'ACCATAACACATAGGAC' *.fastq > count/B11777_Fm0.txt
agrep -0 -c 'AAGATGATGTGCGCGAA' *.fastq > count/B11779_Fm0.txt
agrep -0 -c 'TACCTCGGATCCCCTCT' *.fastq > count/B11780_Fm0.txt
agrep -0 -c 'TGGCACTGAAGCCCGTT' *.fastq > count/B11781_Fm0.txt
agrep -0 -c 'GTCAACATCTGGAGGTT' *.fastq > count/B11782_Fm0.txt
agrep -0 -c 'GAGACTGGGATCTTTCG' *.fastq > count/B11783_Fm0.txt
agrep -0 -c 'ACCCTCAAGAGCCGTTT' *.fastq > count/B11786_Fm0.txt
agrep -0 -c 'ACACAACCATGGCGAAG' *.fastq > count/B11787_Fm0.txt
agrep -0 -c 'GGTTCAAAATCCGGGTG' *.fastq > count/B11789_Fm0.txt
agrep -0 -c 'GTGCGATACACAGTTTT' *.fastq > count/B11790_Fm0.txt
agrep -0 -c 'CTATTCATGCTCTAGAC' *.fastq > count/B11791_Fm0.txt
agrep -0 -c 'CTCGAAAAAGGTAGTCT' *.fastq > count/B11792_Fm0.txt
agrep -0 -c 'CGCCATCGTTATCTAAT' *.fastq > count/B11793_Fm0.txt
agrep -0 -c 'TCGCTTATACAACCTCA' *.fastq > count/B11794_Fm0.txt
agrep -0 -c 'CTAGGCCCGGATGATGA' *.fastq > count/B11795_Fm0.txt
agrep -0 -c 'AGGTAGACGCGACAATC' *.fastq > count/B11797_Fm0.txt
agrep -0 -c 'AATGCAAATGGACGCCT' *.fastq > count/B11798_Fm0.txt
agrep -0 -c 'CAGTAGGTAGCATCAAC' *.fastq > count/B11799_Fm0.txt
agrep -0 -c 'GAGAGCAACGGTCATAT' *.fastq > count/B11800_Fm0.txt
agrep -0 -c 'ATCAACCGGATAAGCTA' *.fastq > count/B11802_Fm0.txt
agrep -0 -c 'CGTGGATAATTCGAACA' *.fastq > count/B11803_Fm0.txt
agrep -0 -c 'CGAGTGTGCTAAGATGG' *.fastq > count/B11804_Fm0.txt
agrep -0 -c 'ACGGAACGTTATGAACG' *.fastq > count/B11806_Fm0.txt
agrep -0 -c 'AGCGGTGTTATTTATCG' *.fastq > count/B11807_Fm0.txt
agrep -0 -c 'GGACTGTGGGTATTATC' *.fastq > count/B11808_Fm0.txt
agrep -0 -c 'AAGTCTGCACTCTTAAG' *.fastq > count/B11809_Fm0.txt
agrep -0 -c 'CTGATAAGTCGGTGGAT' *.fastq > count/B11810_Fm0.txt
agrep -0 -c 'CCGGAATGGGACATCGA' *.fastq > count/B11812_Fm0.txt
agrep -0 -c 'AAGCTTTGGGTGTGCGT' *.fastq > count/B11813_Fm0.txt
agrep -0 -c 'CGGAGGTACTCCTGATA' *.fastq > count/B11814_Fm0.txt
agrep -0 -c 'ACCAGCCGAACGTCTTT' *.fastq > count/B11815_Fm0.txt
agrep -0 -c 'GCGCACATGTTGCATCG' *.fastq > count/B11816_Fm0.txt
agrep -0 -c 'GAGCTAGGATGAAGGGC' *.fastq > count/B11818_Fm0.txt
agrep -0 -c 'ACGACTGGTGTGAACAT' *.fastq > count/B11819_Fm0.txt
agrep -0 -c 'GATGTGAGCATTTCGGG' *.fastq > count/B11821_Fm0.txt
agrep -0 -c 'AGTCTTCGCTTTGAGAC' *.fastq > count/B11822_Fm0.txt
agrep -0 -c 'GTATAAGTCCCGACTTT' *.fastq > count/B11823_Fm0.txt
agrep -0 -c 'ATAACGCGGGAGAGCGA' *.fastq > count/B11824_Fm0.txt
agrep -0 -c 'TCAAGGTCTCCTCCAAT' *.fastq > count/B11825_Fm0.txt
agrep -0 -c 'CGAACGTCGCTCAACAG' *.fastq > count/B11826_Fm0.txt
agrep -0 -c 'ACCACGGGGATGGTACT' *.fastq > count/B11827_Fm0.txt
agrep -0 -c 'AGGTCGCTATGGAGTTA' *.fastq > count/B11828_Fm0.txt
agrep -0 -c 'GGTCTTGATTCGGTCTC' *.fastq > count/B11829_Fm0.txt
agrep -0 -c 'CATTGAACCTCGGGGCT' *.fastq > count/B11830_Fm0.txt
agrep -0 -c 'CATCCGAACTCGTTCTC' *.fastq > count/B11831_Fm0.txt
agrep -0 -c 'GCCTATCGACCATTACT' *.fastq > count/B11833_Fm0.txt
agrep -0 -c 'TCGGGTGGCACATTGAC' *.fastq > count/B11836_Fm0.txt
agrep -0 -c 'AATCCAAGCGCCGTGTA' *.fastq > count/B11837_Fm0.txt
agrep -0 -c 'GGCTTTATACATGGGAA' *.fastq > count/B11838_Fm0.txt
agrep -0 -c 'GTTGAATCCAGCATCTA' *.fastq > count/B11839_Fm0.txt
agrep -0 -c 'GTAACAGAAGGAACATC' *.fastq > count/B11840_Fm0.txt
agrep -0 -c 'AGGTTCGAGCGGTATTC' *.fastq > count/B11841_Fm0.txt
agrep -0 -c 'TCAAGTTGCTAGACCGA' *.fastq > count/B11842_Fm0.txt
agrep -0 -c 'ACCCTGACGTGGGTTTT' *.fastq > count/B11843_Fm0.txt
agrep -0 -c 'GTTCTCGATCGGCCTAG' *.fastq > count/B11844_Fm0.txt
agrep -0 -c 'GTTTGTACGCGGGGGTA' *.fastq > count/B11845_Fm0.txt
agrep -0 -c 'CGGCTGATCATGCATTA' *.fastq > count/B11846_Fm0.txt
agrep -0 -c 'GCAGCGCAGAGATTAAT' *.fastq > count/B11847_Fm0.txt
agrep -0 -c 'AGGGTCTTGCGAGAACC' *.fastq > count/B11848_Fm0.txt
agrep -0 -c 'GTTCCAGATCCAGTGTT' *.fastq > count/B11849_Fm0.txt
agrep -0 -c 'ATTCTCCCCGCATCACT' *.fastq > count/B11851_Fm0.txt
agrep -0 -c 'TTAGCATGCATCGGGTA' *.fastq > count/B11853_Fm0.txt
agrep -0 -c 'GGCGATCTCACACTTGC' *.fastq > count/B11855_Fm0.txt
agrep -0 -c 'CATAGCCTATGTACGCG' *.fastq > count/B11856_Fm0.txt
agrep -0 -c 'TTCTACTCCCACCGATG' *.fastq > count/B11858_Fm0.txt
agrep -0 -c 'GGACGCTCAAAGTGCCT' *.fastq > count/B11859_Fm0.txt
agrep -0 -c 'TAGAGGCGAAGTTTATC' *.fastq > count/B11860_Fm0.txt
agrep -0 -c 'CTCCGTTTCTTTGGAGG' *.fastq > count/B11862_Fm0.txt
agrep -0 -c 'AATCCTAGTGTCATGCG' *.fastq > count/B11863_Fm0.txt
agrep -0 -c 'AGCGAGGGATTACCGGA' *.fastq > count/B11864_Fm0.txt
agrep -0 -c 'GTAAAGGAGTTGGCCAC' *.fastq > count/B11865_Fm0.txt
agrep -0 -c 'CGTTCATGTCCCGATCC' *.fastq > count/B11866_Fm0.txt
agrep -0 -c 'AGGATAACTCCGTTGTC' *.fastq > count/B11867_Fm0.txt
agrep -0 -c 'AGAATGTTTATGCCGCT' *.fastq > count/B11868_Fm0.txt
agrep -0 -c 'ATCATTCGGGTATGCCT' *.fastq > count/B11869_Fm0.txt
agrep -0 -c 'AAGCGCACGTTTCTACA' *.fastq > count/B11870_Fm0.txt
agrep -0 -c 'ACAGATCCAAACAATCC' *.fastq > count/B11871_Fm0.txt
agrep -0 -c 'GGGATCGAGACAATATA' *.fastq > count/B11872_Fm0.txt
agrep -0 -c 'TGTCGTCCTGAACGTAT' *.fastq > count/B11873_Fm0.txt
agrep -0 -c 'GACGTTTACGCAGTATC' *.fastq > count/B11875_Fm0.txt
agrep -0 -c 'CCGTACCATGGATTCTA' *.fastq > count/B11876_Fm0.txt
agrep -0 -c 'GCTAGAACGACCACAAG' *.fastq > count/B11877_Fm0.txt
agrep -0 -c 'AAGTGTGGCCCCTTTAT' *.fastq > count/B11878_Fm0.txt
agrep -0 -c 'CGTCATCCGATTCAACC' *.fastq > count/B11879_Fm0.txt
agrep -0 -c 'TACGGTACGCTTGAGGC' *.fastq > count/B11881_Fm0.txt
agrep -0 -c 'AGCTGAAATTGTGCCCG' *.fastq > count/B11882_Fm0.txt
agrep -0 -c 'CTCGGACATCGAACGTG' *.fastq > count/B11883_Fm0.txt
agrep -0 -c 'CCAGAGAATATCGTCAA' *.fastq > count/B11884_Fm0.txt
agrep -0 -c 'CTGACTGACTCGCGATA' *.fastq > count/B11885_Fm0.txt
agrep -0 -c 'TACGGAACATTCGTGAC' *.fastq > count/B11887_Fm0.txt
agrep -0 -c 'TAGCTTGTCTGCTATAC' *.fastq > count/B11889_Fm0.txt
agrep -0 -c 'CGTTGTGCCTAACAGGG' *.fastq > count/B11890_Fm0.txt
agrep -0 -c 'GGGTTGCAAATTCAGAT' *.fastq > count/B11892_Fm0.txt
agrep -0 -c 'TACTAGCAATCGTCGCT' *.fastq > count/B11893_Fm0.txt
agrep -0 -c 'ACGTTTCTCATCCAACA' *.fastq > count/B11895_Fm0.txt
agrep -0 -c 'CTAGGTTATGTGTCGAG' *.fastq > count/B11896_Fm0.txt
agrep -0 -c 'AACTCCCTCGAGCATGA' *.fastq > count/B11897_Fm0.txt
agrep -0 -c 'GCAACAGTTCGCGTCAA' *.fastq > count/B11899_Fm0.txt
agrep -0 -c 'AACGCCTTTCGAACCCC' *.fastq > count/B11900_Fm0.txt
agrep -0 -c 'TCACCGTTCGGAACGTT' *.fastq > count/B11901_Fm0.txt
agrep -0 -c 'CGACAATAATGGTCGGC' *.fastq > count/B11902_Fm0.txt
agrep -0 -c 'TTGGCACGGCACAACCT' *.fastq > count/B11903_Fm0.txt
agrep -0 -c 'ACTCTTGCCCCACGACA' *.fastq > count/B11904_Fm0.txt
agrep -0 -c 'CTCATCGGTATCGGACC' *.fastq > count/B11905_Fm0.txt
agrep -0 -c 'GCACTAAACAGGACCTT' *.fastq > count/B11906_Fm0.txt
agrep -0 -c 'GCAGGTCGTCTAAGAGT' *.fastq > count/B11907_Fm0.txt
agrep -0 -c 'TAACCTCTCCGACTAAG' *.fastq > count/B11908_Fm0.txt
agrep -0 -c 'ATATCAATCGGCGTCCC' *.fastq > count/B11909_Fm0.txt
agrep -0 -c 'AGTCGCGTAAATAAGCT' *.fastq > count/B11910_Fm0.txt
agrep -0 -c 'TTCTGAATGTGATTGGC' *.fastq > count/B11911_Fm0.txt
agrep -0 -c 'CCGTCGGCACGATTTAG' *.fastq > count/B11912_Fm0.txt
agrep -0 -c 'AACCCCCACCAGCCTTA' *.fastq > count/B11914_Fm0.txt
agrep -0 -c 'TACGGCTAAGCGTGTCG' *.fastq > count/B11915_Fm0.txt
agrep -0 -c 'ACGGCCCAATGGACTAC' *.fastq > count/B11916_Fm0.txt
agrep -0 -c 'GTAATGCAGCGTGGAAA' *.fastq > count/B11918_Fm0.txt
agrep -0 -c 'ACGCGAAAAACACCAAC' *.fastq > count/B11919_Fm0.txt
agrep -0 -c 'CGCGCATTATTCAGAAG' *.fastq > count/B11920_Fm0.txt
agrep -0 -c 'TGCTTTTTCGTCCCTAC' *.fastq > count/B11921_Fm0.txt
agrep -0 -c 'TATGTGGACGTCCATAA' *.fastq > count/B11923_Fm0.txt
agrep -0 -c 'ACAGATTGCATGGGAAA' *.fastq > count/B11924_Fm0.txt
agrep -0 -c 'TAGAAGGGTTCCACACG' *.fastq > count/B11925_Fm0.txt
agrep -0 -c 'ATCAGACGGGATGTATA' *.fastq > count/B11926_Fm0.txt
agrep -0 -c 'ACTCAATCTACGTGAAC' *.fastq > count/B11927_Fm0.txt
agrep -0 -c 'AAGCGCGCTTCGGCATA' *.fastq > count/B11928_Fm0.txt
agrep -0 -c 'CGTACGGGCTTAGGAGT' *.fastq > count/B11929_Fm0.txt
agrep -0 -c 'GTAAACCAAGCAGACGG' *.fastq > count/B11930_Fm0.txt
agrep -0 -c 'CACCGATCTCAGAACGT' *.fastq > count/B11931_Fm0.txt
agrep -0 -c 'CGAATAGCATACACACT' *.fastq > count/B11932_Fm0.txt
agrep -0 -c 'TGTTACTCCTCCATAGC' *.fastq > count/B11933_Fm0.txt
agrep -0 -c 'TCATATGGCAGTTCACG' *.fastq > count/B11934_Fm0.txt
agrep -0 -c 'GCTCAAGAAAAACAGAG' *.fastq > count/B11935_Fm0.txt
agrep -0 -c 'GTATACGACGAGGGTCA' *.fastq > count/B11936_Fm0.txt
agrep -0 -c 'GTTTCTCGATAGCGGAA' *.fastq > count/B11937_Fm0.txt
agrep -0 -c 'ATCGTGCGTCTCTTCTA' *.fastq > count/B11938_Fm0.txt
agrep -0 -c 'AGACTGGGATGAGGGTA' *.fastq > count/B11939_Fm0.txt
agrep -0 -c 'GTAAACCTGACATTGCA' *.fastq > count/B11940_Fm0.txt
agrep -0 -c 'CATCACTGTCAGAGGAG' *.fastq > count/B11941_Fm0.txt
agrep -0 -c 'ATTGGTCGCCTTAAGAG' *.fastq > count/B11942_Fm0.txt
agrep -0 -c 'ATGTAGGAGCTTCCGTG' *.fastq > count/B11946_Fm0.txt
agrep -0 -c 'GAGCCAGCTGAGATTTA' *.fastq > count/B11947_Fm0.txt
agrep -0 -c 'ACTCTGAACCATCTGTA' *.fastq > count/B11948_Fm0.txt
agrep -0 -c 'GGGTCTAACATAGTAGA' *.fastq > count/B11949_Fm0.txt
agrep -0 -c 'AGTAAATTCGTCGCTTG' *.fastq > count/B11950_Fm0.txt
agrep -0 -c 'ATACGTATGACGACAAC' *.fastq > count/B11953_Fm0.txt
agrep -0 -c 'TGAACTAGTGGTCCTTT' *.fastq > count/B11954_Fm0.txt
agrep -0 -c 'GTCACAAGTCAGTCGAC' *.fastq > count/B11955_Fm0.txt
agrep -0 -c 'CTGAAAGCTTGCGGGGT' *.fastq > count/B11956_Fm0.txt
agrep -0 -c 'GGGAACTTGACCAGCTA' *.fastq > count/B11957_Fm0.txt
agrep -0 -c 'AATCGTGGAATGCGAAT' *.fastq > count/B11958_Fm0.txt
agrep -0 -c 'GGCGTTATGGCTCTGAT' *.fastq > count/B11959_Fm0.txt
agrep -0 -c 'AACGATGGACATCCCTG' *.fastq > count/B11960_Fm0.txt
agrep -0 -c 'TAGGTACTCAGGGAGCC' *.fastq > count/B11961_Fm0.txt
agrep -0 -c 'AGACTATTTACGCGTTG' *.fastq > count/B11962_Fm0.txt
agrep -0 -c 'GGGAATGCGTTGGTAAT' *.fastq > count/B11963_Fm0.txt
agrep -0 -c 'ACCGCCGAAAATTACCG' *.fastq > count/B11965_Fm0.txt
agrep -0 -c 'TAACGTATTGTCCTCCG' *.fastq > count/B11966_Fm0.txt
agrep -0 -c 'CATAAAGTCTGGTCAGT' *.fastq > count/B11967_Fm0.txt
agrep -0 -c 'AGGATCAGCTATCTAGC' *.fastq > count/B11969_Fm0.txt
agrep -0 -c 'TATGGTCGTCTATCTCT' *.fastq > count/B11971_Fm0.txt
agrep -0 -c 'CTGGTTGGTTAAGGTTC' *.fastq > count/B11972_Fm0.txt
agrep -0 -c 'CACGATTCCAACACAGT' *.fastq > count/B11973_Fm0.txt
agrep -0 -c 'GCGAGGCGCCACAATTA' *.fastq > count/B11974_Fm0.txt
agrep -0 -c 'TTATAGGAGTACTGCGG' *.fastq > count/B11975_Fm0.txt
agrep -0 -c 'TCGATATAAGGTCCGCA' *.fastq > count/B11976_Fm0.txt
agrep -0 -c 'GTTCAAGCTCTGGGAAT' *.fastq > count/B11977_Fm0.txt
agrep -0 -c 'CTGAACAAGGATGATTG' *.fastq > count/B11980_Fm0.txt
agrep -0 -c 'ATGAATGATGGTCTTCG' *.fastq > count/B11981_Fm0.txt
agrep -0 -c 'GCATTTGCACCTATAGT' *.fastq > count/B11983_Fm0.txt
agrep -0 -c 'ATCCCGTATTAACCTGT' *.fastq > count/B11984_Fm0.txt
agrep -0 -c 'CGAGTGATCTGCCAGTT' *.fastq > count/B11985_Fm0.txt
agrep -0 -c 'CGACGAATGCTCCGCTT' *.fastq > count/B11986_Fm0.txt
agrep -0 -c 'TATGCCAGTAAACTCGA' *.fastq > count/B11987_Fm0.txt
agrep -0 -c 'AAGTTGCAGGACTATTG' *.fastq > count/B11988_Fm0.txt
agrep -0 -c 'TTAGGACGTTCCTCATG' *.fastq > count/B11989_Fm0.txt
agrep -0 -c 'CGTCCCGCTCAATAAGC' *.fastq > count/B11990_Fm0.txt
agrep -0 -c 'GACAATGCGTAAGTTCG' *.fastq > count/B11991_Fm0.txt
agrep -0 -c 'CGAACTTCCTCGACGAG' *.fastq > count/B11992_Fm0.txt
agrep -0 -c 'ATGTAAACCGTCCGTAT' *.fastq > count/B11993_Fm0.txt
agrep -0 -c 'CTCGTACGCAAGAATAA' *.fastq > count/B11994_Fm0.txt
agrep -0 -c 'AATTGCCCATCTATGGC' *.fastq > count/B11996_Fm0.txt
agrep -0 -c 'GTCCTTAATGCTCGGGT' *.fastq > count/B11997_Fm0.txt
agrep -0 -c 'GACACTGCACGAAAACC' *.fastq > count/B12000_Fm0.txt
agrep -0 -c 'CCTACGCAAAGACTACA' *.fastq > count/B12001_Fm0.txt
agrep -0 -c 'TACCTAATCGAAGGATC' *.fastq > count/B12002_Fm0.txt
agrep -0 -c 'TACCCATCTGCTGCTCG' *.fastq > count/B12003_Fm0.txt
agrep -0 -c 'GTCAGAACCTTAACCTC' *.fastq > count/B12004_Fm0.txt
agrep -0 -c 'GATAGTAGTTGCACTGC' *.fastq > count/B12005_Fm0.txt
agrep -0 -c 'AGATTACGCTGGTGGTC' *.fastq > count/B12006_Fm0.txt
agrep -0 -c 'CTCGGGATGTTAAGACC' *.fastq > count/B12007_Fm0.txt
agrep -0 -c 'TCTAGGCGTCCTAGGTC' *.fastq > count/B12008_Fm0.txt
agrep -0 -c 'ATGTCGAAAGGTTGGGG' *.fastq > count/B12009_Fm0.txt
agrep -0 -c 'ATACCTCTACAGGCGAT' *.fastq > count/B12010_Fm0.txt
agrep -0 -c 'GGATAACGGCTATTTGC' *.fastq > count/B12011_Fm0.txt
agrep -0 -c 'GGCTATGCAAGTGGTGT' *.fastq > count/B12012_Fm0.txt
agrep -0 -c 'ACGACTGGATTGCTATA' *.fastq > count/B12013_Fm0.txt
agrep -0 -c 'TTATCCTGAACCTAACG' *.fastq > count/B12014_Fm0.txt
agrep -0 -c 'TGAAGACCGATGCGGTG' *.fastq > count/B12015_Fm0.txt
agrep -0 -c 'TCGATAGTAGAACTTGC' *.fastq > count/B12016_Fm0.txt
agrep -0 -c 'CTGCAATCCGTTGATTC' *.fastq > count/B12017_Fm0.txt
agrep -0 -c 'AGAGAACTGCGCCTTAG' *.fastq > count/B12018_Fm0.txt
agrep -0 -c 'AACCTTTTGACCAGTCC' *.fastq > count/B12020_Fm0.txt
agrep -0 -c 'TACCGCATTGGGATCCT' *.fastq > count/B12021_Fm0.txt
agrep -0 -c 'CTGGTCGTAGTCTGACC' *.fastq > count/B12022_Fm0.txt
agrep -0 -c 'TACGGAGAAGTGCGGCA' *.fastq > count/B12023_Fm0.txt
agrep -0 -c 'TGTGTAGCCCGGTATCA' *.fastq > count/B12024_Fm0.txt
agrep -0 -c 'ACGCAGGAAGCACCATC' *.fastq > count/B12025_Fm0.txt
agrep -0 -c 'CAAGTTCACTACGGGGT' *.fastq > count/B12026_Fm0.txt
agrep -0 -c 'TAAGAAGCGCGCTTTCT' *.fastq > count/B12027_Fm0.txt
agrep -0 -c 'GCTGCTGTTTCTAGCCG' *.fastq > count/B12029_Fm0.txt
agrep -0 -c 'CGTATCCGTCCCAATCG' *.fastq > count/B12030_Fm0.txt
agrep -0 -c 'AGAATTCTCTCCGTAGA' *.fastq > count/B12031_Fm0.txt
agrep -0 -c 'TAGGAGAGATCACCGCC' *.fastq > count/B12032_Fm0.txt
agrep -0 -c 'ATGCCTGGATTGAATTC' *.fastq > count/B12033_Fm0.txt
agrep -0 -c 'AGTGATCATGCTCAGCC' *.fastq > count/B12034_Fm0.txt
agrep -0 -c 'GTGCATTACGCGACTCT' *.fastq > count/B12036_Fm0.txt
agrep -0 -c 'ATACTTCTGTGATCCCC' *.fastq > count/B12037_Fm0.txt
agrep -0 -c 'ATCGACTCTGCCATAAG' *.fastq > count/B12038_Fm0.txt
agrep -0 -c 'ATCTTGTGCCTGACCGA' *.fastq > count/B12039_Fm0.txt
agrep -0 -c 'TCACGAGAACCTCTTGC' *.fastq > count/B12040_Fm0.txt
agrep -0 -c 'CTAGGCTGATGGGCACA' *.fastq > count/B12041_Fm0.txt
agrep -0 -c 'AGCCGCAAGTTTCCGTG' *.fastq > count/B12042_Fm0.txt
agrep -0 -c 'TCTTGCGCGGTCATTCT' *.fastq > count/B12043_Fm0.txt
agrep -0 -c 'ATATCAGGGAGCAGCCG' *.fastq > count/B12044_Fm0.txt
agrep -0 -c 'CATCACTGTTTTCCGGA' *.fastq > count/B12045_Fm0.txt
agrep -0 -c 'GACTGCAGAGAGTTTTG' *.fastq > count/B12046_Fm0.txt
agrep -0 -c 'ACTCGGAGTCTCCAAAG' *.fastq > count/B12047_Fm0.txt
agrep -0 -c 'AGTCGCCTACACGAACA' *.fastq > count/B12048_Fm0.txt
agrep -0 -c 'CAACAGAACTCCCACTT' *.fastq > count/B12049_Fm0.txt
agrep -0 -c 'TGGAGTGGTTATTCTCT' *.fastq > count/B12050_Fm0.txt
agrep -0 -c 'ATCGTTTCTATCGTCAG' *.fastq > count/B12052_Fm0.txt
agrep -0 -c 'CTTCTAGCGACAAACAC' *.fastq > count/B12053_Fm0.txt
agrep -0 -c 'TAGTAACGTCGTGGGAG' *.fastq > count/B12055_Fm0.txt
agrep -0 -c 'GATGGTGATGCTAGATG' *.fastq > count/B12056_Fm0.txt
agrep -0 -c 'GCCGCATCGATAGCTCA' *.fastq > count/B12057_Fm0.txt
agrep -0 -c 'CGGAACATAGCGTTTGC' *.fastq > count/B12058_Fm0.txt
agrep -0 -c 'GTGGGCCAGAGCTAAAG' *.fastq > count/B12059_Fm0.txt
agrep -0 -c 'AGTACCTATACGCCGCT' *.fastq > count/B12060_Fm0.txt
agrep -0 -c 'TTCCGGAATCTATTCGA' *.fastq > count/B12061_Fm0.txt
agrep -0 -c 'CTCAGTCGTCATAGGCA' *.fastq > count/B12062_Fm0.txt
agrep -0 -c 'CGTGCGACCTCAATCTC' *.fastq > count/B12063_Fm0.txt
agrep -0 -c 'CATTCCGTAAATGGCAT' *.fastq > count/B12065_Fm0.txt
agrep -0 -c 'AGCACGGGACAGAGGAA' *.fastq > count/B12066_Fm0.txt
agrep -0 -c 'GGACACAGTAACTCCGA' *.fastq > count/B12068_Fm0.txt
agrep -0 -c 'CAGTCGCAGTTATTCCA' *.fastq > count/B12069_Fm0.txt
agrep -0 -c 'GTCACACATCATATCTG' *.fastq > count/B12070_Fm0.txt
agrep -0 -c 'AATAACCTATCAGGCAG' *.fastq > count/B12071_Fm0.txt
agrep -0 -c 'CCGCCTATTTCATCAGA' *.fastq > count/B12072_Fm0.txt
agrep -0 -c 'GTGACGGATTGATGTTA' *.fastq > count/B12074_Fm0.txt
agrep -0 -c 'ACGTCCGGCCTAGGTAA' *.fastq > count/B12075_Fm0.txt
agrep -0 -c 'TCTTCGACAGGCTGCTA' *.fastq > count/B12076_Fm0.txt
agrep -0 -c 'GCCATCCTTAAATAGTG' *.fastq > count/B12077_Fm0.txt
agrep -0 -c 'TGTCGCACTGAGTTGAT' *.fastq > count/B12078_Fm0.txt
agrep -0 -c 'CATAGGCCTTACCCCGA' *.fastq > count/B12079_Fm0.txt
agrep -0 -c 'TGCCGGAAATTCTGGGC' *.fastq > count/B12080_Fm0.txt
agrep -0 -c 'TTCAGAATCTCGCATGT' *.fastq > count/B12081_Fm0.txt
agrep -0 -c 'CAAATTCTCTAGCGGAA' *.fastq > count/B12084_Fm0.txt
agrep -0 -c 'CAGCCGCGAGTTTTTAC' *.fastq > count/B12086_Fm0.txt
agrep -0 -c 'GTTCTCCTCAGTGCCCT' *.fastq > count/B12087_Fm0.txt
agrep -0 -c 'TAGACGGTTGACTAGTA' *.fastq > count/B12088_Fm0.txt
agrep -0 -c 'TAAGCATGCTATGACTG' *.fastq > count/B12089_Fm0.txt
agrep -0 -c 'CGGCAACGTGACTTATG' *.fastq > count/B12090_Fm0.txt
agrep -0 -c 'TGCAAATGTTAGGTCGA' *.fastq > count/B12091_Fm0.txt
agrep -0 -c 'CCGCAATATGTCCATAA' *.fastq > count/B12092_Fm0.txt
agrep -0 -c 'GTTTACCCTGGGACAGC' *.fastq > count/B12096_Fm0.txt
agrep -0 -c 'CACAGAAAGAAACCGCG' *.fastq > count/B12098_Fm0.txt
agrep -0 -c 'GGGGTTTCCGGGTATAA' *.fastq > count/B12099_Fm0.txt
agrep -0 -c 'AACCCAACCTAAGAGTT' *.fastq > count/B12100_Fm0.txt
agrep -0 -c 'TAGACGATCCGCACGGT' *.fastq > count/B12101_Fm0.txt
agrep -0 -c 'AGCCACATCTCACCGAG' *.fastq > count/B12103_Fm0.txt
agrep -0 -c 'AAGCAGCCACCCATTAT' *.fastq > count/B12104_Fm0.txt
agrep -0 -c 'ATAGGCCTCCGATCTAT' *.fastq > count/B12105_Fm0.txt
agrep -0 -c 'ACTAACAGTGCGAAACC' *.fastq > count/B12106_Fm0.txt
agrep -0 -c 'CACTCTACTTCGCGGAC' *.fastq > count/B12107_Fm0.txt
agrep -0 -c 'GGATAGGTTATTTCGGG' *.fastq > count/B12108_Fm0.txt
agrep -0 -c 'GTTTCAAAGGCGTTCAA' *.fastq > count/B12109_Fm0.txt
agrep -0 -c 'CCGAATGTTACAGCTAT' *.fastq > count/B12111_Fm0.txt
agrep -0 -c 'CGTTAAGAATTTGGGTG' *.fastq > count/B12112_Fm0.txt
agrep -0 -c 'AATTCTCGTCACCCTAC' *.fastq > count/B12113_Fm0.txt
agrep -0 -c 'TTCTGGGGCGAATTAGC' *.fastq > count/B12115_Fm0.txt
agrep -0 -c 'ACGGTTATGTGAACGCT' *.fastq > count/B12117_Fm0.txt
agrep -0 -c 'ACGGTGGTCATACTTTA' *.fastq > count/B12118_Fm0.txt
agrep -0 -c 'TCGAGGATGTAAAGTGA' *.fastq > count/B12119_Fm0.txt
agrep -0 -c 'GGACAATTGATGTCGCA' *.fastq > count/B12120_Fm0.txt
agrep -0 -c 'AGGCCGCGAATATACAA' *.fastq > count/B12121_Fm0.txt
agrep -0 -c 'TAGTGGCGGAGGAATAG' *.fastq > count/B12122_Fm0.txt
agrep -0 -c 'GTGAAAACGCCCCGACA' *.fastq > count/B12123_Fm0.txt
agrep -0 -c 'GGTTCGACTGAAGGAGA' *.fastq > count/B12124_Fm0.txt
agrep -0 -c 'AGGCTCAATGCTAACCG' *.fastq > count/B12125_Fm0.txt
agrep -0 -c 'AACTTTCTACTGACGGA' *.fastq > count/B12126_Fm0.txt
agrep -0 -c 'TAACCGGCGTAACCGTA' *.fastq > count/B12127_Fm0.txt
agrep -0 -c 'GCACTGAGATCAGGTAG' *.fastq > count/B12128_Fm0.txt
agrep -0 -c 'GGACTAAGGGGACAAGC' *.fastq > count/B12129_Fm0.txt
agrep -0 -c 'GAGAGCTGATTCCATGG' *.fastq > count/B12131_Fm0.txt
agrep -0 -c 'GCCTCAGTGCTTACTGT' *.fastq > count/B12132_Fm0.txt
agrep -0 -c 'CATTGCCGGTTTTCGTG' *.fastq > count/B12134_Fm0.txt
agrep -0 -c 'CTCTCGGCGATTCATAG' *.fastq > count/B12135_Fm0.txt
agrep -0 -c 'ATAGCTTCACGGACCGG' *.fastq > count/B12136_Fm0.txt
agrep -0 -c 'GGTCAAGTAAGCCGAAA' *.fastq > count/B12137_Fm0.txt
agrep -0 -c 'GCCATCCGAGTAGTAGA' *.fastq > count/B12139_Fm0.txt
agrep -0 -c 'GGATACACTAGGACGAT' *.fastq > count/B12140_Fm0.txt
agrep -0 -c 'CGGAATACCTCGAGCTG' *.fastq > count/B12141_Fm0.txt
agrep -0 -c 'GTCTCTCGGAATGTAAT' *.fastq > count/B12142_Fm0.txt
agrep -0 -c 'ACATGCTGTTTCACCCG' *.fastq > count/B12143_Fm0.txt
agrep -0 -c 'ATTGACTTGTTAGCCAG' *.fastq > count/B12144_Fm0.txt
agrep -0 -c 'AGGACTTCACATGTTTG' *.fastq > count/B12145_Fm0.txt
agrep -0 -c 'CGAATGTTGTGGGTCCA' *.fastq > count/B12146_Fm0.txt
agrep -0 -c 'GGCTGCGAGCTGCTTTA' *.fastq > count/B12147_Fm0.txt
agrep -0 -c 'CTTCCACACTATTCGAA' *.fastq > count/B12148_Fm0.txt
agrep -0 -c 'AGCGGGGAAAAGACCAG' *.fastq > count/B12149_Fm0.txt
agrep -0 -c 'TTGCGCGTAAGTCATTG' *.fastq > count/B12150_Fm0.txt
agrep -0 -c 'ACGACTAACCTCCAAAA' *.fastq > count/B12151_Fm0.txt
agrep -0 -c 'ACTAGATTTGACGGAGT' *.fastq > count/B12152_Fm0.txt
agrep -0 -c 'ATACGGTACGAAACACC' *.fastq > count/B12153_Fm0.txt
agrep -0 -c 'TGTTAGTAGCGGAAGTG' *.fastq > count/B12154_Fm0.txt
agrep -0 -c 'CCTTCTGGACCTTGCAA' *.fastq > count/B12155_Fm0.txt
agrep -0 -c 'TGTAGCGAAGCTAGCTC' *.fastq > count/B12156_Fm0.txt
agrep -0 -c 'TCGATGCAGACGATTCT' *.fastq > count/B12157_Fm0.txt
agrep -0 -c 'GGAGCGAGTTCTTGATT' *.fastq > count/B12158_Fm0.txt
agrep -0 -c 'TAGAGCTCTACTGATGC' *.fastq > count/B12159_Fm0.txt
agrep -0 -c 'ATCGGCCATGAGAAACG' *.fastq > count/B12161_Fm0.txt
agrep -0 -c 'TATTCGAAGTGCACGGA' *.fastq > count/B12162_Fm0.txt
agrep -0 -c 'ATGTGATCCAGACTTCT' *.fastq > count/B12163_Fm0.txt
agrep -0 -c 'GTACGCTTACGAAAGCG' *.fastq > count/B12164_Fm0.txt
agrep -0 -c 'CCTAAAACTGGCGCAAC' *.fastq > count/B12165_Fm0.txt
agrep -0 -c 'GGCATAACCGACACACG' *.fastq > count/B12167_Fm0.txt
agrep -0 -c 'CAGCGCGCATTTATAAC' *.fastq > count/B12168_Fm0.txt
agrep -0 -c 'TGTCGGTCAATGGTCAA' *.fastq > count/B12169_Fm0.txt
agrep -0 -c 'TTGCATCCCCAGCTAAA' *.fastq > count/B12170_Fm0.txt
agrep -0 -c 'TGGATTCTTAGTTCAGC' *.fastq > count/B12171_Fm0.txt
agrep -0 -c 'TAGGTCCGATGCAATCA' *.fastq > count/B12172_Fm0.txt
agrep -0 -c 'TATATGCGAGGATATCG' *.fastq > count/B12173_Fm0.txt
agrep -0 -c 'CGCTAAAATTGAGTGTC' *.fastq > count/B12174_Fm0.txt
agrep -0 -c 'ACAAGTGATCCCTTGTG' *.fastq > count/B12175_Fm0.txt
agrep -0 -c 'CCTCAAGTTCGACAGGC' *.fastq > count/B12176_Fm0.txt
agrep -0 -c 'CTAACACCACCTGACCA' *.fastq > count/B12181_Fm0.txt
agrep -0 -c 'GCGTTATTGTACTTGTG' *.fastq > count/B12182_Fm0.txt
agrep -0 -c 'AACGCAAGACCAACTGT' *.fastq > count/B12183_Fm0.txt
agrep -0 -c 'CTCCTGTTACCCTTGGC' *.fastq > count/B12184_Fm0.txt
agrep -0 -c 'TTGCCCTCGACCCTGTA' *.fastq > count/B12185_Fm0.txt
agrep -0 -c 'GCGAGGCATTTTACTGC' *.fastq > count/B12186_Fm0.txt
agrep -0 -c 'ACTTGCGATGAACGACA' *.fastq > count/B12187_Fm0.txt
agrep -0 -c 'ACGTAATGGAGACCGCC' *.fastq > count/B12188_Fm0.txt
agrep -0 -c 'ACGGACGTGTGTTCTGG' *.fastq > count/B12189_Fm0.txt
agrep -0 -c 'TCAGAGCACGTGGCAGT' *.fastq > count/B12190_Fm0.txt
agrep -0 -c 'GTTCATCTAAGATCTGC' *.fastq > count/B12191_Fm0.txt
agrep -0 -c 'CTGCGGAAAAGCTTTCA' *.fastq > count/B12192_Fm0.txt
agrep -0 -c 'CGTGTTGACAGTCAGAC' *.fastq > count/B12194_Fm0.txt
agrep -0 -c 'AGAGTGTTAAGCGTCGA' *.fastq > count/B12195_Fm0.txt
agrep -0 -c 'TGGCAGTTTGACCCACA' *.fastq > count/B12196_Fm0.txt
agrep -0 -c 'CGGATCGAGTTTTAACC' *.fastq > count/B12198_Fm0.txt
agrep -0 -c 'AGTAGAGTCGTCATGAC' *.fastq > count/B12199_Fm0.txt
agrep -0 -c 'CTCCGACGCTCATGAGA' *.fastq > count/B12200_Fm0.txt
agrep -0 -c 'GCTACTCGGCGTTAAAT' *.fastq > count/B12201_Fm0.txt
agrep -0 -c 'GTAACTGGTTTCTCGCT' *.fastq > count/B12202_Fm0.txt
agrep -0 -c 'AGTTGCCTCGACGAGGA' *.fastq > count/B12203_Fm0.txt
agrep -0 -c 'GTTCGATGGTATTGCTC' *.fastq > count/B12204_Fm0.txt
agrep -0 -c 'TAGGCCCACGAAAACCC' *.fastq > count/B12205_Fm0.txt
agrep -0 -c 'GCACTTCCTTAGCATAG' *.fastq > count/B12206_Fm0.txt
agrep -0 -c 'TTCTCACGCTATCCCCA' *.fastq > count/B12207_Fm0.txt
agrep -0 -c 'GCAACTACATTAGACCT' *.fastq > count/B12208_Fm0.txt
agrep -0 -c 'GCGTGACAATGACCTCA' *.fastq > count/B12210_Fm0.txt
agrep -0 -c 'CGTACATGATCCAGTTT' *.fastq > count/B12212_Fm0.txt
agrep -0 -c 'CACAAGCTGATTGGCCT' *.fastq > count/B12213_Fm0.txt
agrep -0 -c 'GCCTGTTGCGCTTCCAA' *.fastq > count/B12214_Fm0.txt
agrep -0 -c 'GGGTATCATCCACCTTT' *.fastq > count/B12216_Fm0.txt
agrep -0 -c 'TACAGGGGCGTTAGACC' *.fastq > count/B12217_Fm0.txt
agrep -0 -c 'TCAGGACGACCATGTAT' *.fastq > count/B12218_Fm0.txt
agrep -0 -c 'CTTGTAATGCGCTCCGT' *.fastq > count/B12219_Fm0.txt
agrep -0 -c 'AACTCCCCAGCCAGTGA' *.fastq > count/B12221_Fm0.txt
agrep -0 -c 'GGGCTACCACGGGTTTA' *.fastq > count/B12222_Fm0.txt
agrep -0 -c 'AACTACCCGTACCCAGT' *.fastq > count/B12223_Fm0.txt
agrep -0 -c 'CTTCCCCATAGAGGGTA' *.fastq > count/B12224_Fm0.txt
agrep -0 -c 'TTGCGTGAATCCCAAAA' *.fastq > count/B12225_Fm0.txt
agrep -0 -c 'GCCCTTAGTATGAGGCT' *.fastq > count/B12227_Fm0.txt
agrep -0 -c 'GTATTACACATCCCGAA' *.fastq > count/B12228_Fm0.txt
agrep -0 -c 'ACCAGAATTGGCTTTGT' *.fastq > count/B12229_Fm0.txt
agrep -0 -c 'TTAGTCCCGGTTCCGTT' *.fastq > count/B12230_Fm0.txt
agrep -0 -c 'CCAGGATACTTAGGCTA' *.fastq > count/B12231_Fm0.txt
agrep -0 -c 'ACTGTCGGTGAGACGTG' *.fastq > count/B12233_Fm0.txt
agrep -0 -c 'CCGAAGTTGTGTAATAG' *.fastq > count/B12234_Fm0.txt
agrep -0 -c 'TTACCCCGTCCTATATA' *.fastq > count/B12235_Fm0.txt
agrep -0 -c 'GCCCAGCGCTTAGATTG' *.fastq > count/B12237_Fm0.txt
agrep -0 -c 'TACCCAAGCAGCGCCAA' *.fastq > count/B12238_Fm0.txt
agrep -0 -c 'GCCATGGGGAGTCGTAT' *.fastq > count/B12239_Fm0.txt
agrep -0 -c 'AGTCAGGCGCAAATCTG' *.fastq > count/B12241_Fm0.txt
agrep -0 -c 'CATGGAATGCAGACGGC' *.fastq > count/B12242_Fm0.txt
agrep -0 -c 'ATACTTGATCGGCACCA' *.fastq > count/B12243_Fm0.txt
agrep -0 -c 'GCTTATCATGACGTAGT' *.fastq > count/B12245_Fm0.txt
agrep -0 -c 'ATGCAAGATCTGACACA' *.fastq > count/B12246_Fm0.txt
agrep -0 -c 'CATTTACACGATACCAC' *.fastq > count/B12247_Fm0.txt
agrep -0 -c 'TTAACCCTGTCTAGTGT' *.fastq > count/B12249_Fm0.txt
agrep -0 -c 'ACGTGACATCGTCGCAC' *.fastq > count/B12250_Fm0.txt
agrep -0 -c 'AGCTTCAACCTCATTGC' *.fastq > count/B12251_Fm0.txt
agrep -0 -c 'ATAGACCAGGACTTTTG' *.fastq > count/B12252_Fm0.txt
agrep -0 -c 'GGCGGGATCTGAACTAT' *.fastq > count/B12253_Fm0.txt
agrep -0 -c 'TAGGGATCATGGTAGCC' *.fastq > count/B12254_Fm0.txt
agrep -0 -c 'TCGCGACGGTTCTCAAA' *.fastq > count/B12255_Fm0.txt
agrep -0 -c 'TATAGATGAGCTGGCGC' *.fastq > count/B12256_Fm0.txt
agrep -0 -c 'ACGAGACCCTTATACAC' *.fastq > count/B12257_Fm0.txt
agrep -0 -c 'TCATGAACTGTCTCGCC' *.fastq > count/B12259_Fm0.txt
agrep -0 -c 'AGTGCGTGTTCTGCAGG' *.fastq > count/B12260_Fm0.txt
agrep -0 -c 'GTGCTGTAATGTCCGGC' *.fastq > count/B12261_Fm0.txt
agrep -0 -c 'CTTACGGCCTTTTAAGA' *.fastq > count/B12263_Fm0.txt
agrep -0 -c 'CAGGCGATGTATGTGAC' *.fastq > count/B12264_Fm0.txt
agrep -0 -c 'TGTCGCCTGCCTTATGA' *.fastq > count/B12265_Fm0.txt
agrep -0 -c 'GGATACTTGGTATGAAG' *.fastq > count/B12267_Fm0.txt
agrep -0 -c 'ACTATCGAGGCAGTTAC' *.fastq > count/B12268_Fm0.txt
agrep -0 -c 'ACAACCCGTGAGACGTA' *.fastq > count/B12269_Fm0.txt
agrep -0 -c 'TAGATGGGCGATTGATC' *.fastq > count/B12270_Fm0.txt
agrep -0 -c 'GCCCCGTTATCAAACCA' *.fastq > count/B12272_Fm0.txt
agrep -0 -c 'ATCTCATGCAGTGCTTG' *.fastq > count/B12273_Fm0.txt
agrep -0 -c 'TAGCTCCTTCCTCATAC' *.fastq > count/B12274_Fm0.txt
agrep -0 -c 'CTCTTGAAAACACGGCA' *.fastq > count/B12275_Fm0.txt
agrep -0 -c 'GTATGCTACTCCCAAAA' *.fastq > count/B12276_Fm0.txt
agrep -0 -c 'AACGGGGCCAGCTTCTT' *.fastq > count/B12277_Fm0.txt
agrep -0 -c 'GTCAGAGTGTTCGAAGA' *.fastq > count/B12278_Fm0.txt
agrep -0 -c 'CGACCTGCTAATGTAAC' *.fastq > count/B12279_Fm0.txt
agrep -0 -c 'CTAGAACATGGGTTGCT' *.fastq > count/B12280_Fm0.txt
agrep -0 -c 'ACGCAATTGGACCAGCA' *.fastq > count/B12281_Fm0.txt
agrep -0 -c 'AGGAAGTCGCTTAGACA' *.fastq > count/B12283_Fm0.txt
agrep -0 -c 'ATCATGGTTCGCACGCC' *.fastq > count/B12284_Fm0.txt
agrep -0 -c 'ATTTCAAGTACACCGGC' *.fastq > count/B12285_Fm0.txt
agrep -0 -c 'AGGGATGTCACGTACTA' *.fastq > count/B12287_Fm0.txt
agrep -0 -c 'TCTCGCACACCATACTA' *.fastq > count/B12288_Fm0.txt
agrep -0 -c 'GGTACGTCGAACACGAA' *.fastq > count/B12289_Fm0.txt
agrep -0 -c 'GGTTGTGTAATCGTACC' *.fastq > count/B12290_Fm0.txt
agrep -0 -c 'CAAAGTCCGGTTTTACG' *.fastq > count/B12291_Fm0.txt
agrep -0 -c 'CTCGTGTAAATCCTGAC' *.fastq > count/B12293_Fm0.txt
agrep -0 -c 'GTCGATTGTCGATACCG' *.fastq > count/B12294_Fm0.txt
agrep -0 -c 'GAGCCTGTGGTGAAACC' *.fastq > count/B12295_Fm0.txt
agrep -0 -c 'CATAACTCACCTGCATC' *.fastq > count/B12296_Fm0.txt
agrep -0 -c 'GGGATCACGTCGCTTTA' *.fastq > count/B12297_Fm0.txt
agrep -0 -c 'AATGCAGATTCCGGGCC' *.fastq > count/B12299_Fm0.txt
agrep -0 -c 'TGACAAACTGGTTCGTG' *.fastq > count/B12300_Fm0.txt
agrep -0 -c 'TGTCAGGTCCCCGTATG' *.fastq > count/B12301_Fm0.txt
agrep -0 -c 'TTCGCTACCCATTATCG' *.fastq > count/B12302_Fm0.txt
agrep -0 -c 'TTGAGCAGTAGAACGTA' *.fastq > count/B12303_Fm0.txt
agrep -0 -c 'CCTCGTTTCGTTGGGTA' *.fastq > count/B12304_Fm0.txt
agrep -0 -c 'ACCGCCATTCGATTCCG' *.fastq > count/B12305_Fm0.txt
agrep -0 -c 'TTGAGGGTGATAGCCTT' *.fastq > count/B12306_Fm0.txt
agrep -0 -c 'ACGAACCTTCAGTCCCG' *.fastq > count/B12307_Fm0.txt
agrep -0 -c 'CCGCTTGACTGGAGGAA' *.fastq > count/B12308_Fm0.txt
agrep -0 -c 'CGATAACAAGTAGCTGT' *.fastq > count/B12311_Fm0.txt
agrep -0 -c 'GTCATGAACTGACGGCG' *.fastq > count/B12312_Fm0.txt
agrep -0 -c 'CATGCCGGAAGTATGCC' *.fastq > count/B12313_Fm0.txt
agrep -0 -c 'TTATACTGCTCTCGAAC' *.fastq > count/B12314_Fm0.txt
agrep -0 -c 'CTCCCCGACACCTAAAT' *.fastq > count/B12315_Fm0.txt
agrep -0 -c 'TTGATAAACCACTCGAC' *.fastq > count/B12316_Fm0.txt
agrep -0 -c 'TTACACGTAGCATGGCG' *.fastq > count/B12317_Fm0.txt
agrep -0 -c 'GACGTACTACGACGTTC' *.fastq > count/B12318_Fm0.txt
agrep -0 -c 'ATTCGGAGTTCACGGTG' *.fastq > count/B12319_Fm0.txt
agrep -0 -c 'GTTGACTTAGGATAGCC' *.fastq > count/B12320_Fm0.txt
agrep -0 -c 'CTTGCTGACCACGTATC' *.fastq > count/B12322_Fm0.txt
agrep -0 -c 'ATGTTAGTTTTCCGCTC' *.fastq > count/B12325_Fm0.txt
agrep -0 -c 'GACTCCGTACTGAGCAA' *.fastq > count/B12327_Fm0.txt
agrep -0 -c 'ATCTGAGCGCCAGCCTA' *.fastq > count/B12328_Fm0.txt
agrep -0 -c 'GTGTTTCGCGCTTTCCT' *.fastq > count/B12329_Fm0.txt
agrep -0 -c 'TGTTCCGCCAATCAACA' *.fastq > count/B12330_Fm0.txt
agrep -0 -c 'AGGGCTAGTCTTCCGAG' *.fastq > count/B12332_Fm0.txt
agrep -0 -c 'GTAACCTACCTCTGACA' *.fastq > count/B12333_Fm0.txt
agrep -0 -c 'TTGCCCATCAATCGACA' *.fastq > count/B12334_Fm0.txt
agrep -0 -c 'GACCGATTTCTCCGAGG' *.fastq > count/B12335_Fm0.txt
agrep -0 -c 'AAGCAGCGAATTTGTGG' *.fastq > count/B12336_Fm0.txt
agrep -0 -c 'AGTCACACGGAAATGCC' *.fastq > count/B12337_Fm0.txt
agrep -0 -c 'CGACCCATATCCGTCAA' *.fastq > count/B12338_Fm0.txt
agrep -0 -c 'TGGACCAACTCCTTCAC' *.fastq > count/B12339_Fm0.txt
agrep -0 -c 'GTCCGAGTGGAAGTGTG' *.fastq > count/B12340_Fm0.txt
agrep -0 -c 'CAAGCCCTATCATGTGG' *.fastq > count/B12341_Fm0.txt
agrep -0 -c 'TTGACTACTCCGTCACG' *.fastq > count/B12342_Fm0.txt
agrep -0 -c 'TCAATAGGTCCGGACGC' *.fastq > count/B12343_Fm0.txt
agrep -0 -c 'ACATTAGGTCCGGATTG' *.fastq > count/B12344_Fm0.txt
agrep -0 -c 'ACTCAACTCGTTAGCGG' *.fastq > count/B12345_Fm0.txt
agrep -0 -c 'ACCCGTGGTAACAACTA' *.fastq > count/B12346_Fm0.txt
agrep -0 -c 'AGGAGCTCTCCATTCAT' *.fastq > count/B12347_Fm0.txt
agrep -0 -c 'AATTGGGCGCATTAGCG' *.fastq > count/B12348_Fm0.txt
agrep -0 -c 'CCGGTCAACAGTCTAGG' *.fastq > count/B12349_Fm0.txt
agrep -0 -c 'AAGCAAGCGGTAACCGA' *.fastq > count/B12350_Fm0.txt
agrep -0 -c 'AGTGAGTGTAAAGTCGC' *.fastq > count/B12351_Fm0.txt
agrep -0 -c 'CCTTCTCTAGCTTACTC' *.fastq > count/B12352_Fm0.txt
agrep -0 -c 'GCCCCTATGCAGATTGG' *.fastq > count/B12353_Fm0.txt
agrep -0 -c 'AGCGGAGATTCACGAAT' *.fastq > count/B12355_Fm0.txt
agrep -0 -c 'GATCTCGCTAGGGCATA' *.fastq > count/B12356_Fm0.txt
agrep -0 -c 'GTAGTCGGTTTACATCC' *.fastq > count/B12357_Fm0.txt
agrep -0 -c 'GGCTCTGATTGCAAGTT' *.fastq > count/B12358_Fm0.txt
agrep -0 -c 'AGTTACACGACATCGTC' *.fastq > count/B12359_Fm0.txt
agrep -0 -c 'AACGCTTAGACTTTTCG' *.fastq > count/B12360_Fm0.txt
agrep -0 -c 'TACATCACCTCGGACTG' *.fastq > count/B12361_Fm0.txt
agrep -0 -c 'GCACCACTCGGATTACA' *.fastq > count/B12363_Fm0.txt
agrep -0 -c 'AGTGGCAATTAGCTAGA' *.fastq > count/B12365_Fm0.txt
agrep -0 -c 'GGCTACACGGATCATTA' *.fastq > count/B12367_Fm0.txt
agrep -0 -c 'AACGCGCCAGGTTGACA' *.fastq > count/B12368_Fm0.txt
agrep -0 -c 'TATGGACGTCGTTAACC' *.fastq > count/B12369_Fm0.txt
agrep -0 -c 'AGCACCAACTAATATCC' *.fastq > count/B12370_Fm0.txt
agrep -0 -c 'ACTATTGGTAGGAGGGT' *.fastq > count/B12371_Fm0.txt
agrep -0 -c 'CCATTAGAGTAGTGGGT' *.fastq > count/B12373_Fm0.txt
agrep -0 -c 'CGTGAGATATGGTCTTT' *.fastq > count/B12375_Fm0.txt
agrep -0 -c 'GTCGCAACCTATGCATC' *.fastq > count/B12377_Fm0.txt
agrep -0 -c 'GTGTAGCGTGACACAAA' *.fastq > count/B12378_Fm0.txt
agrep -0 -c 'CTTAGGATTTCAGTCGG' *.fastq > count/B12379_Fm0.txt
agrep -0 -c 'CACAGCTTACGGGTTGA' *.fastq > count/B12380_Fm0.txt
agrep -0 -c 'CGTCATTGTGACTCCGC' *.fastq > count/B12381_Fm0.txt
agrep -0 -c 'GTGCACACAAAATGGAT' *.fastq > count/B12382_Fm0.txt
agrep -0 -c 'ATTACCCATATCCACGA' *.fastq > count/B12383_Fm0.txt
agrep -0 -c 'ATCTAACTGCCCTGTAA' *.fastq > count/B12384_Fm0.txt
agrep -0 -c 'AGTAGTGCGTACGCTGT' *.fastq > count/B12386_Fm0.txt
agrep -0 -c 'ACTATATCGCCCCATAA' *.fastq > count/B12387_Fm0.txt
agrep -0 -c 'TCGCGGTTTCGTTAAGA' *.fastq > count/B12388_Fm0.txt
agrep -0 -c 'CGAATCGAACTCCCATC' *.fastq > count/B12391_Fm0.txt
agrep -0 -c 'CTTAAAACGGTAGGATC' *.fastq > count/B12392_Fm0.txt
agrep -0 -c 'GAGGGGGGTTACTCGAT' *.fastq > count/B12393_Fm0.txt
agrep -0 -c 'AGCACTATTAGATGACC' *.fastq > count/B12394_Fm0.txt
agrep -0 -c 'CCTCGTGTTTTACAACG' *.fastq > count/B12395_Fm0.txt
agrep -0 -c 'CGCGGACTAATACAGTG' *.fastq > count/B12396_Fm0.txt
agrep -0 -c 'GGAGAAATAACTACGAG' *.fastq > count/B12397_Fm0.txt
agrep -0 -c 'ATTTCCTATTGCCCTCA' *.fastq > count/B12398_Fm0.txt
agrep -0 -c 'ACAAGATCCCCGCCTTG' *.fastq > count/B12400_Fm0.txt
agrep -0 -c 'ACTTACCTTTGGCGCTT' *.fastq > count/B12401_Fm0.txt
agrep -0 -c 'GGCTCTAGGAGGGTATT' *.fastq > count/B12402_Fm0.txt
agrep -0 -c 'CCGACCTCGTTTTTGTT' *.fastq > count/B12403_Fm0.txt
agrep -0 -c 'CGGGATACGGTTGGATC' *.fastq > count/B12404_Fm0.txt
agrep -0 -c 'AAGGTCTCGCACCCACT' *.fastq > count/B12405_Fm0.txt
agrep -0 -c 'TCTTGACCAGGAACGAC' *.fastq > count/B12406_Fm0.txt
agrep -0 -c 'GTGTTACGGGTGACGAA' *.fastq > count/B12411_Fm0.txt
agrep -0 -c 'CTTACGAAGCACCGTAC' *.fastq > count/B12412_Fm0.txt
agrep -0 -c 'CAATCGGCTTCTTTGCC' *.fastq > count/B12413_Fm0.txt
agrep -0 -c 'CGCGGATTTCATGTCCT' *.fastq > count/B12414_Fm0.txt
agrep -0 -c 'GTCACTGGGACTTCGTA' *.fastq > count/B12417_Fm0.txt
agrep -0 -c 'TAGGATACTGCACCCAA' *.fastq > count/B12418_Fm0.txt
agrep -0 -c 'TCGGTTATGGCAAGAGT' *.fastq > count/B12419_Fm0.txt
agrep -0 -c 'GCTCAGTTGGCTAAGCC' *.fastq > count/B12420_Fm0.txt
agrep -0 -c 'ACCGCAATACGCGACAA' *.fastq > count/B12422_Fm0.txt
agrep -0 -c 'TAAGGCCAAAGTAAAGG' *.fastq > count/B12423_Fm0.txt
agrep -0 -c 'CTAAACTCATTACGCTC' *.fastq > count/B12424_Fm0.txt
agrep -0 -c 'GTATTAGCTCCCATCTG' *.fastq > count/B12425_Fm0.txt
agrep -0 -c 'CTCCTTAAGAAGAGTGA' *.fastq > count/B12426_Fm0.txt
agrep -0 -c 'TACTCGCTTACCAGCAT' *.fastq > count/B12428_Fm0.txt
agrep -0 -c 'CACCTCTAAGGCCAGCA' *.fastq > count/B12429_Fm0.txt
agrep -0 -c 'ACTCGCAGAACTCAGGC' *.fastq > count/B12430_Fm0.txt
agrep -0 -c 'GATGGTCGGTGATGATC' *.fastq > count/B12431_Fm0.txt
agrep -0 -c 'CAGGGGGTTGAGAATTA' *.fastq > count/B12432_Fm0.txt
agrep -0 -c 'GTAACGGTAAGTAGGCG' *.fastq > count/B12433_Fm0.txt
agrep -0 -c 'TCGATCGACTGCTGACT' *.fastq > count/B12434_Fm0.txt
agrep -0 -c 'CCACGAGGACGTATGAG' *.fastq > count/B12435_Fm0.txt
agrep -0 -c 'AGTGTGCGCCATTGTGC' *.fastq > count/B12436_Fm0.txt
agrep -0 -c 'GTTCGTTACGGAATCCT' *.fastq > count/B12437_Fm0.txt
agrep -0 -c 'CGAAGGCATGCGTTGTT' *.fastq > count/B12438_Fm0.txt
agrep -0 -c 'TGTTGATCGTGTCCAAA' *.fastq > count/B12440_Fm0.txt
agrep -0 -c 'GCTTAGTATAAGCGGAC' *.fastq > count/B12441_Fm0.txt
agrep -0 -c 'AGATCCGAAGTGGACGC' *.fastq > count/B12442_Fm0.txt
agrep -0 -c 'GTGGTCATTGTCCGTTA' *.fastq > count/B12443_Fm0.txt
agrep -0 -c 'TGTAAGCCCGTCAACTG' *.fastq > count/B12444_Fm0.txt
agrep -0 -c 'TACTGTGAACACCCCAA' *.fastq > count/B12445_Fm0.txt
agrep -0 -c 'ATTCCACCAGTTAACCA' *.fastq > count/B12446_Fm0.txt
agrep -0 -c 'GTCTTAGTGCTCTACGG' *.fastq > count/B12447_Fm0.txt
agrep -0 -c 'CAGGAACAAGTTTACAC' *.fastq > count/B12449_Fm0.txt
agrep -0 -c 'TATCTGGCTCACCTTAA' *.fastq > count/B12450_Fm0.txt
agrep -0 -c 'ATGCATAAGCTCCGGAC' *.fastq > count/B12451_Fm0.txt
agrep -0 -c 'TCAAATGGAACGCCAAC' *.fastq > count/B12452_Fm0.txt
agrep -0 -c 'CGCAACGACGGAAAAAA' *.fastq > count/B12453_Fm0.txt
agrep -0 -c 'AAGGCTCGGTACCTGGA' *.fastq > count/B12455_Fm0.txt
agrep -0 -c 'AATGCGTATCTAGCACT' *.fastq > count/B12456_Fm0.txt
agrep -0 -c 'CCACAAATGCCTGCTAC' *.fastq > count/B12457_Fm0.txt
agrep -0 -c 'CCTTTTCGATACGACCG' *.fastq > count/B12458_Fm0.txt
agrep -0 -c 'ATCTAGTCCACCAGGAG' *.fastq > count/B12459_Fm0.txt
agrep -0 -c 'AACACTTACGCGCGTAT' *.fastq > count/B12461_Fm0.txt
agrep -0 -c 'ACTAAGCGCCATACCAC' *.fastq > count/B12462_Fm0.txt
agrep -0 -c 'TTCTAAATTGCGCGATC' *.fastq > count/B12464_Fm0.txt
agrep -0 -c 'CTATGAAAGTGGCCTAG' *.fastq > count/B12465_Fm0.txt
agrep -0 -c 'GTTCGCGGCTAAACAAA' *.fastq > count/B12467_Fm0.txt
agrep -0 -c 'ATTCGGACATAGTCGCT' *.fastq > count/B12468_Fm0.txt
agrep -0 -c 'GCCCTCTGACACTGGAA' *.fastq > count/B12469_Fm0.txt
agrep -0 -c 'GCGAGTTTATAGCCTAG' *.fastq > count/B12470_Fm0.txt
agrep -0 -c 'GCCTTATCAGCTGGGAC' *.fastq > count/B12472_Fm0.txt
agrep -0 -c 'AGTTGCTAACCATCGTT' *.fastq > count/B12473_Fm0.txt
agrep -0 -c 'AACAGACGAGTTCCTAA' *.fastq > count/B12474_Fm0.txt
agrep -0 -c 'ACTGGTGTATGCCGCTG' *.fastq > count/B12475_Fm0.txt
agrep -0 -c 'CGTATGCTTGTGGAGAA' *.fastq > count/B12476_Fm0.txt
agrep -0 -c 'CGCGTACTAGGAAGTCA' *.fastq > count/B12477_Fm0.txt
agrep -0 -c 'GGTACTACAATTTTCGC' *.fastq > count/B12478_Fm0.txt
agrep -0 -c 'CTAGAACATGTAAGCAG' *.fastq > count/B12479_Fm0.txt
agrep -0 -c 'ACTCCAACCAGAAACGG' *.fastq > count/B12480_Fm0.txt
agrep -0 -c 'CTCACTCGGAGGTATTC' *.fastq > count/B12481_Fm0.txt
agrep -0 -c 'GAGTGAGTACCGAACTC' *.fastq > count/B12482_Fm0.txt
agrep -0 -c 'ACGCGTGAAGCCTTACG' *.fastq > count/B12483_Fm0.txt
agrep -0 -c 'TGTACTTCGAGGCTTAC' *.fastq > count/B12485_Fm0.txt
agrep -0 -c 'TTGTCACCATGTTCCAT' *.fastq > count/B12486_Fm0.txt
agrep -0 -c 'ATGGTCGACACGAGTTG' *.fastq > count/B12487_Fm0.txt
agrep -0 -c 'GACCCCTTCGGCAATCT' *.fastq > count/B12488_Fm0.txt
agrep -0 -c 'ATAAAGTACTGGCCGTT' *.fastq > count/B12489_Fm0.txt
agrep -0 -c 'GCAGCTAAGCCTGACCT' *.fastq > count/B12490_Fm0.txt
agrep -0 -c 'CGCTGTACAATCATGTA' *.fastq > count/B12492_Fm0.txt
agrep -0 -c 'ACGATTACGGGCTTGGC' *.fastq > count/B12493_Fm0.txt
agrep -0 -c 'GAGTTACGCTTGCCGCA' *.fastq > count/B12495_Fm0.txt
agrep -0 -c 'TCGGCTTAAACAGGATC' *.fastq > count/B12496_Fm0.txt
agrep -0 -c 'ACTAATTATCCCGCTAG' *.fastq > count/B12497_Fm0.txt
agrep -0 -c 'TACTCGATTCAACAGTC' *.fastq > count/B12500_Fm0.txt
agrep -0 -c 'CTACACCCACAAACGTA' *.fastq > count/B12501_Fm0.txt
agrep -0 -c 'GTCCTTGATACTGCGCG' *.fastq > count/B12504_Fm0.txt
agrep -0 -c 'CGAGTCACCTTAACACG' *.fastq > count/B12505_Fm0.txt
agrep -0 -c 'CGGCCTAACATAACCCT' *.fastq > count/B12506_Fm0.txt
agrep -0 -c 'GATCTACGGTTCTTCTC' *.fastq > count/B12507_Fm0.txt
agrep -0 -c 'CTCGACGGATTCCTTGT' *.fastq > count/B12508_Fm0.txt
agrep -0 -c 'AGTGCTGGCCTCTGTCA' *.fastq > count/B12510_Fm0.txt
agrep -0 -c 'AATAACGGGGTCTCGCA' *.fastq > count/B12512_Fm0.txt
agrep -0 -c 'ATGACGGTGAAGGCCAG' *.fastq > count/B12513_Fm0.txt
agrep -0 -c 'ATCTACAGCCGTTGTCG' *.fastq > count/B12514_Fm0.txt
agrep -0 -c 'TGCAGCCTTGTTGCGGT' *.fastq > count/B12515_Fm0.txt
agrep -0 -c 'ACGGGTAGCAGTGGATA' *.fastq > count/B12516_Fm0.txt
agrep -0 -c 'TCGGATGGAAAGATCCA' *.fastq > count/B12517_Fm0.txt
agrep -0 -c 'TATGGCGAAAACACGTA' *.fastq > count/B12518_Fm0.txt
agrep -0 -c 'TCGTCATTCAGCTCAGT' *.fastq > count/B12519_Fm0.txt
agrep -0 -c 'GTAATCCTGAGAGTACC' *.fastq > count/B12520_Fm0.txt
agrep -0 -c 'AAGGACGTAGAAGGGGC' *.fastq > count/B12522_Fm0.txt
agrep -0 -c 'TTGTACCAGCCGTAAGC' *.fastq > count/B12523_Fm0.txt
agrep -0 -c 'TGCTCGCATTCAGATCT' *.fastq > count/B12524_Fm0.txt
agrep -0 -c 'GCATTTTACCCCAGATC' *.fastq > count/B12525_Fm0.txt
agrep -0 -c 'CACGGCCCTTCAAAGAT' *.fastq > count/B12526_Fm0.txt
agrep -0 -c 'GATGCTCCTATGTTTCC' *.fastq > count/B12528_Fm0.txt
agrep -0 -c 'ACTCCCCGTTTACCAGG' *.fastq > count/B12529_Fm0.txt
agrep -0 -c 'GTAATGGGACGTACCCC' *.fastq > count/B12530_Fm0.txt
agrep -0 -c 'CGAGTACACTCGGGTCT' *.fastq > count/B12531_Fm0.txt
agrep -0 -c 'AAGTAAGGCTCACTCTA' *.fastq > count/B12532_Fm0.txt
agrep -0 -c 'CAAATACGCATGTCCGT' *.fastq > count/B12533_Fm0.txt
agrep -0 -c 'ACAGTTATTACCGGGAT' *.fastq > count/B12535_Fm0.txt
agrep -0 -c 'ACGCAGGATCGTAATCT' *.fastq > count/B12537_Fm0.txt
agrep -0 -c 'CGGCACACCTTATCGTC' *.fastq > count/B12538_Fm0.txt
agrep -0 -c 'TAGGGAAGTTACTCTTG' *.fastq > count/B12539_Fm0.txt
agrep -0 -c 'GTAACGATACCATGTCG' *.fastq > count/B12540_Fm0.txt
agrep -0 -c 'TAGAATGCGAATCAGCA' *.fastq > count/B12541_Fm0.txt
agrep -0 -c 'TAAGGTTCCTTAACGTG' *.fastq > count/B12543_Fm0.txt
agrep -0 -c 'GGATGCTGTGAAACCGT' *.fastq > count/B12544_Fm0.txt
agrep -0 -c 'AGCGGCATTATGCACAT' *.fastq > count/B12545_Fm0.txt
agrep -0 -c 'ATTGTACCAACTAGCGG' *.fastq > count/B12546_Fm0.txt
agrep -0 -c 'ATCCCTAACTAGCAGGC' *.fastq > count/B12547_Fm0.txt
agrep -0 -c 'GTAGCCGCAATAACAAA' *.fastq > count/B12548_Fm0.txt
agrep -0 -c 'GGGTTGCATTGCGCTAG' *.fastq > count/B12549_Fm0.txt
agrep -0 -c 'TATGGTAGGTGAGTCAT' *.fastq > count/B12550_Fm0.txt
agrep -0 -c 'AATAACGGCTAACGGAC' *.fastq > count/B12551_Fm0.txt
agrep -0 -c 'AGGTTAACTGGGGGTCT' *.fastq > count/B12552_Fm0.txt
agrep -0 -c 'CCACCCCGTTCATACTC' *.fastq > count/B12553_Fm0.txt
agrep -0 -c 'CATTCTGCTGAGAACCA' *.fastq > count/B12554_Fm0.txt
agrep -0 -c 'TGACGATTATTGCTAGC' *.fastq > count/B12555_Fm0.txt
agrep -0 -c 'TGGAGTCTGCTACGGGA' *.fastq > count/B12557_Fm0.txt
agrep -0 -c 'CACGTCTCGTACGACTT' *.fastq > count/B12558_Fm0.txt
agrep -0 -c 'GCTCGACCTACTTAACT' *.fastq > count/B12559_Fm0.txt
agrep -0 -c 'CGTGTTCTCTCAAACCG' *.fastq > count/B12560_Fm0.txt
agrep -0 -c 'AGGTCTACGAATGATTG' *.fastq > count/B12561_Fm0.txt
agrep -0 -c 'GCGAGTCCTTGAAGTTT' *.fastq > count/B12563_Fm0.txt
agrep -0 -c 'CACCAGACAGTGTCGTG' *.fastq > count/B12564_Fm0.txt
agrep -0 -c 'CGTTTGCGCTTGAACGC' *.fastq > count/B12566_Fm0.txt
agrep -0 -c 'AAGGTAGTCCGTACGTA' *.fastq > count/B12567_Fm0.txt
agrep -0 -c 'AGCCTCTACCGCGTCAA' *.fastq > count/B12568_Fm0.txt
agrep -0 -c 'GGCGACTTACGTTCTTG' *.fastq > count/B12571_Fm0.txt
agrep -0 -c 'TATCGCATGAACGGTTA' *.fastq > count/B12572_Fm0.txt
agrep -0 -c 'CAGTGGTCTTAGTACAA' *.fastq > count/B12573_Fm0.txt
agrep -0 -c 'GATGCTACGCCCGATTG' *.fastq > count/B12574_Fm0.txt
agrep -0 -c 'GCGGCATGTCAATCGAT' *.fastq > count/B12578_Fm0.txt
agrep -0 -c 'GCAAAAGGCTTAATCGT' *.fastq > count/B12579_Fm0.txt
agrep -0 -c 'AGCGCTCGCTTCAAAGC' *.fastq > count/B12580_Fm0.txt
agrep -0 -c 'TATCAGGCTTCCTCCCA' *.fastq > count/B12581_Fm0.txt
agrep -0 -c 'TGAACAAGACAGTACGC' *.fastq > count/B12582_Fm0.txt
agrep -0 -c 'AAGTAGTGGAACCACAT' *.fastq > count/B12583_Fm0.txt
agrep -0 -c 'TTGCAAAAGGTCCCGTG' *.fastq > count/B12584_Fm0.txt
agrep -0 -c 'TGTCCCGAAGGTAGGTC' *.fastq > count/B12585_Fm0.txt
agrep -0 -c 'CGTCACAAAAGTTGAGT' *.fastq > count/B12586_Fm0.txt
agrep -0 -c 'CCTTCCGGCAAGATTCT' *.fastq > count/B12587_Fm0.txt
agrep -0 -c 'AGATGCGAGAAACACAC' *.fastq > count/B12588_Fm0.txt
agrep -0 -c 'GTGTTAGGAAACGTGTT' *.fastq > count/B12589_Fm0.txt
agrep -0 -c 'CATGCTGTACGTTGAAG' *.fastq > count/B12590_Fm0.txt
agrep -0 -c 'GCGAAGACTCGAGGTGT' *.fastq > count/B12591_Fm0.txt
agrep -0 -c 'ATTTGAGACATTGACGC' *.fastq > count/B12592_Fm0.txt
agrep -0 -c 'AAGCCGACAAGTCTTCG' *.fastq > count/B12593_Fm0.txt
agrep -0 -c 'GCACATTCGTGGCACAG' *.fastq > count/B12594_Fm0.txt
agrep -0 -c 'TTAGACGGGCCTCTAAG' *.fastq > count/B12595_Fm0.txt
agrep -0 -c 'CCAGCACGGTATAAGCA' *.fastq > count/B12596_Fm0.txt
agrep -0 -c 'CACAAGAATTTCCTTGG' *.fastq > count/B12597_Fm0.txt
agrep -0 -c 'GTAGTTGACCACTATCA' *.fastq > count/B12599_Fm0.txt
agrep -0 -c 'ACAGCTCAATCTGAAGC' *.fastq > count/B12600_Fm0.txt
agrep -0 -c 'TACGTACACAGCGGTAG' *.fastq > count/B12601_Fm0.txt
agrep -0 -c 'GCACGCGTCAAACTCTC' *.fastq > count/B12602_Fm0.txt
agrep -0 -c 'CAACGGAGAATGATCGA' *.fastq > count/B12604_Fm0.txt
agrep -0 -c 'AGGATGTCTTTACGAAC' *.fastq > count/B12606_Fm0.txt
agrep -0 -c 'GTCACCTACTTAACCGT' *.fastq > count/B12607_Fm0.txt
agrep -0 -c 'ACAGCCTTATCCCGTCA' *.fastq > count/B12609_Fm0.txt
agrep -0 -c 'TCGATGCTGAAAAATCC' *.fastq > count/B12610_Fm0.txt
agrep -0 -c 'TTGCAGTAGGTCAGGCA' *.fastq > count/B12611_Fm0.txt
agrep -0 -c 'ACTCGTCGTTACCCGAC' *.fastq > count/B12613_Fm0.txt
agrep -0 -c 'CTACACTGTTGAATACC' *.fastq > count/B12614_Fm0.txt
agrep -0 -c 'ACCGAGGTTACGCACTT' *.fastq > count/B12615_Fm0.txt
agrep -0 -c 'CCTCATGCACATGTCGG' *.fastq > count/B12616_Fm0.txt
agrep -0 -c 'TCTCCCACGTAACACCC' *.fastq > count/B12617_Fm0.txt
agrep -0 -c 'TGTGCCTATATCTAGGG' *.fastq > count/B12618_Fm0.txt
agrep -0 -c 'TTCACTCGGAGACAATT' *.fastq > count/B12620_Fm0.txt
agrep -0 -c 'GTATCATTCCAAGGCTA' *.fastq > count/B12621_Fm0.txt
agrep -0 -c 'AGTTCGTATGCATACTG' *.fastq > count/B12622_Fm0.txt
agrep -0 -c 'GATACCTTCTTGTTCTG' *.fastq > count/B12623_Fm0.txt
agrep -0 -c 'AATCAGGGCGATTCTCA' *.fastq > count/B12624_Fm0.txt
agrep -0 -c 'TCTTGCGCTTTCTGAGT' *.fastq > count/B12625_Fm0.txt
agrep -0 -c 'TCTCGTGAACTCATCAA' *.fastq > count/B12626_Fm0.txt
agrep -0 -c 'AACAAACTTGGATGTCC' *.fastq > count/B12627_Fm0.txt
agrep -0 -c 'GTCGTATCGTAGCATTA' *.fastq > count/B12630_Fm0.txt
agrep -0 -c 'CCTTCTCGGTCGAGTAA' *.fastq > count/B12631_Fm0.txt
agrep -0 -c 'TGCACTTTCAAGTATCG' *.fastq > count/B12632_Fm0.txt
agrep -0 -c 'CCTCGAACCGAGTTCGA' *.fastq > count/B12633_Fm0.txt
agrep -0 -c 'GGAGCCAAACTTCGTAG' *.fastq > count/B12634_Fm0.txt
agrep -0 -c 'GCACTTAGCTAACGTCT' *.fastq > count/B12636_Fm0.txt
agrep -0 -c 'TTCTAGCTTGGCTCCGG' *.fastq > count/B12637_Fm0.txt
agrep -0 -c 'ATCCATAGAATAGCGCT' *.fastq > count/B12638_Fm0.txt
agrep -0 -c 'CAGTGAACGCTAAAACA' *.fastq > count/B12639_Fm0.txt
agrep -0 -c 'GTCAAGTGCTACTAACA' *.fastq > count/B12640_Fm0.txt
agrep -0 -c 'TACACTATGTCTGCGGT' *.fastq > count/B12641_Fm0.txt
agrep -0 -c 'AGTGACGAGAGTGGAGT' *.fastq > count/B12642_Fm0.txt
agrep -0 -c 'GGAAGTTTTACTCGAGT' *.fastq > count/B12643_Fm0.txt
agrep -0 -c 'TGCGGAATCCAACGCTG' *.fastq > count/B12644_Fm0.txt
agrep -0 -c 'ATTTGTTGAGCTCTTCG' *.fastq > count/B12645_Fm0.txt
agrep -0 -c 'TCTTAGCGGTTGCAGCC' *.fastq > count/B12646_Fm0.txt
agrep -0 -c 'GCCAGTAGGATCGCTCA' *.fastq > count/B12648_Fm0.txt
agrep -0 -c 'TTCTTACACCTCCAAGG' *.fastq > count/B12650_Fm0.txt
agrep -0 -c 'CATTACAATCCAAACCG' *.fastq > count/B12651_Fm0.txt
agrep -0 -c 'TGTCCGGCGCATGTACA' *.fastq > count/B12652_Fm0.txt
agrep -0 -c 'AACATGACCCTGTGCAA' *.fastq > count/B12653_Fm0.txt
agrep -0 -c 'TGGCGTAAATTCGAGCT' *.fastq > count/B12654_Fm0.txt
agrep -0 -c 'AGGGAGTCACACGGCAT' *.fastq > count/B12656_Fm0.txt
agrep -0 -c 'TCGGTCGGGAGCATTTC' *.fastq > count/B12658_Fm0.txt
agrep -0 -c 'TGAGATGTATCGACACT' *.fastq > count/B12659_Fm0.txt
agrep -0 -c 'GTACGGGACCCGCTAAT' *.fastq > count/B12660_Fm0.txt
agrep -0 -c 'TACAGTATAGTCGATCG' *.fastq > count/B12661_Fm0.txt
agrep -0 -c 'GTTTCCAGGATCGCGCA' *.fastq > count/B12663_Fm0.txt
agrep -0 -c 'AATAGCCAGCTCCTCAC' *.fastq > count/B12664_Fm0.txt
agrep -0 -c 'GGTCGAGGTGTGTGAGA' *.fastq > count/B12665_Fm0.txt
agrep -0 -c 'TGGCCATAGAATATCCC' *.fastq > count/B12666_Fm0.txt
agrep -0 -c 'ACGCCTAAGTAGGACTA' *.fastq > count/B12667_Fm0.txt
agrep -0 -c 'TATGAGTGGGCATTGTA' *.fastq > count/B12668_Fm0.txt
agrep -0 -c 'GCCATATTCACCTCGAT' *.fastq > count/B12669_Fm0.txt
agrep -0 -c 'CAGGTATGTGCTACGCG' *.fastq > count/B12670_Fm0.txt
agrep -0 -c 'CATAGATCTACAGACAC' *.fastq > count/B12671_Fm0.txt
agrep -0 -c 'GTTCGACGCTGTGTAAA' *.fastq > count/B12672_Fm0.txt
agrep -0 -c 'TGTGCATCACCTGAGTC' *.fastq > count/B12673_Fm0.txt
agrep -0 -c 'AGGTCAGATGGCACACG' *.fastq > count/B12674_Fm0.txt
agrep -0 -c 'TGACTATACCTCTAACC' *.fastq > count/B12675_Fm0.txt
agrep -0 -c 'TTGGTAAGCAGAACGCG' *.fastq > count/B12677_Fm0.txt
agrep -0 -c 'CCGGTTCGGTACAAGTG' *.fastq > count/B12678_Fm0.txt
agrep -0 -c 'ACAGCTTGTACCGCGTC' *.fastq > count/B12679_Fm0.txt
agrep -0 -c 'GGAATGTGGAAGGTTAT' *.fastq > count/B12680_Fm0.txt
agrep -0 -c 'GGTCGTTTACCCGTTTG' *.fastq > count/B12681_Fm0.txt
agrep -0 -c 'CACACATGACACTTAAG' *.fastq > count/B12682_Fm0.txt
agrep -0 -c 'TCACCCGCTGCATACAA' *.fastq > count/B12683_Fm0.txt
agrep -0 -c 'AGACGGGTAGATAGGAC' *.fastq > count/B12684_Fm0.txt
agrep -0 -c 'ATCTTTCGGAAGCGTTT' *.fastq > count/B12685_Fm0.txt
agrep -0 -c 'TAGACGACGATTCATTG' *.fastq > count/B12686_Fm0.txt
agrep -0 -c 'CGCGAATTGGGCTAACT' *.fastq > count/B12687_Fm0.txt
agrep -0 -c 'CCTTCGGTAACACTATG' *.fastq > count/B12689_Fm0.txt
agrep -0 -c 'AACCTGCGTTAAAATCC' *.fastq > count/B12690_Fm0.txt
agrep -0 -c 'TATGGCGATTTGCATCA' *.fastq > count/B12691_Fm0.txt
agrep -0 -c 'CTTCGACTCGTAACCAT' *.fastq > count/B12692_Fm0.txt
agrep -0 -c 'TTACGGTCGATGGTCTT' *.fastq > count/B12694_Fm0.txt
agrep -0 -c 'ATCTACCACTCACGTTC' *.fastq > count/B12695_Fm0.txt
agrep -0 -c 'GTGATACAGGGTCGTCC' *.fastq > count/B12696_Fm0.txt
agrep -0 -c 'AGTGTCCATTCCCTGTC' *.fastq > count/B12697_Fm0.txt
agrep -0 -c 'TGTCATTGATCCATCGT' *.fastq > count/B12698_Fm0.txt
agrep -0 -c 'ACCTCCAGTGTGCTCCA' *.fastq > count/B12699_Fm0.txt
agrep -0 -c 'GGTTGTAGAGATCTTCG' *.fastq > count/B12700_Fm0.txt
agrep -0 -c 'GATGAGCATCGGCAGTC' *.fastq > count/B12701_Fm0.txt
agrep -0 -c 'TCTCGGGGGTAATCCTC' *.fastq > count/B12702_Fm0.txt
agrep -0 -c 'TGTCGACTGGCAGATCG' *.fastq > count/B12703_Fm0.txt
agrep -0 -c 'ACGCACTAATTGCTGAA' *.fastq > count/B12705_Fm0.txt
agrep -0 -c 'GCTCGTCAGCTTATGCG' *.fastq > count/B12706_Fm0.txt
agrep -0 -c 'CTCCCAACCTAGATAAG' *.fastq > count/B12707_Fm0.txt
agrep -0 -c 'TTGCTCTTGCTCAGCTG' *.fastq > count/B12708_Fm0.txt
agrep -0 -c 'GGAACGCTAAGGTGCCT' *.fastq > count/B12709_Fm0.txt
agrep -0 -c 'TAGTATACTTGCCAACC' *.fastq > count/B12710_Fm0.txt
agrep -0 -c 'GCTTCTGGTAACCACCG' *.fastq > count/B12711_Fm0.txt
agrep -0 -c 'TACGACGCAGATATTAG' *.fastq > count/B12712_Fm0.txt
agrep -0 -c 'CGAAACTGCCGGTGGAA' *.fastq > count/B12713_Fm0.txt
agrep -0 -c 'AGCTACAACGATCGTCA' *.fastq > count/B12715_Fm0.txt
agrep -0 -c 'GAGATTCGTCTTGTACT' *.fastq > count/B12716_Fm0.txt
agrep -0 -c 'ACGACGCCTATCTTCGC' *.fastq > count/B12717_Fm0.txt
agrep -0 -c 'GCGGCATTACCATCAGC' *.fastq > count/B12718_Fm0.txt
agrep -0 -c 'TTCAAGTTGCGGGTGAC' *.fastq > count/B12720_Fm0.txt
agrep -0 -c 'AAGCGCCGCTCAAATCC' *.fastq > count/B12722_Fm0.txt
agrep -0 -c 'AGTCCGATAACCTGATG' *.fastq > count/B12724_Fm0.txt
agrep -0 -c 'GGTAAAATACCCGGCTC' *.fastq > count/B12725_Fm0.txt
agrep -0 -c 'GAGAGGTCGATCCGCAA' *.fastq > count/B12727_Fm0.txt
agrep -0 -c 'GCAGGTTAGGACGTCAC' *.fastq > count/B12728_Fm0.txt
agrep -0 -c 'CCGCTTATTTGCCTTGT' *.fastq > count/B12729_Fm0.txt
agrep -0 -c 'GATGGCTCTTCGCTTCC' *.fastq > count/B12730_Fm0.txt
agrep -0 -c 'AGACGTAGGTACGGCTC' *.fastq > count/B12731_Fm0.txt
agrep -0 -c 'GTTACGCACTTGTATGG' *.fastq > count/B12732_Fm0.txt
agrep -0 -c 'ACCATTAGTGACCGAAC' *.fastq > count/B12733_Fm0.txt
agrep -0 -c 'CAATTAACTGGTGGCTA' *.fastq > count/B12734_Fm0.txt
agrep -0 -c 'TATCAAGCCTCCAACAT' *.fastq > count/B12735_Fm0.txt
agrep -0 -c 'ACCAGATCTTTGGTCTA' *.fastq > count/B12736_Fm0.txt
agrep -0 -c 'CTCTAATTAGAGGCCGA' *.fastq > count/B12738_Fm0.txt
agrep -0 -c 'CCGACACGAGCCGATAA' *.fastq > count/B12739_Fm0.txt
agrep -0 -c 'CCATCCGTCTGTATGTT' *.fastq > count/B12740_Fm0.txt
agrep -0 -c 'GTTGATGCCTTGTGCGT' *.fastq > count/B12742_Fm0.txt
agrep -0 -c 'GGTTTAGACCTGGTGGG' *.fastq > count/B12743_Fm0.txt
agrep -0 -c 'TGTAGAGTAACGACCAA' *.fastq > count/B12744_Fm0.txt
agrep -0 -c 'GCCCTGGTGTTAATATT' *.fastq > count/B12745_Fm0.txt
agrep -0 -c 'ACCCGATGCAGCCAAGA' *.fastq > count/B12746_Fm0.txt
agrep -0 -c 'CAATATCCCGAACTCAA' *.fastq > count/B12747_Fm0.txt
agrep -0 -c 'GAGATCAGCCAGATTTG' *.fastq > count/B12748_Fm0.txt
agrep -0 -c 'CGTCTGAGCAATGTCCA' *.fastq > count/B12749_Fm0.txt
agrep -0 -c 'CATACCCGTATTCAGGC' *.fastq > count/B12751_Fm0.txt
agrep -0 -c 'AACGGCCTTGTCCAACT' *.fastq > count/B12752_Fm0.txt
agrep -0 -c 'TTGTATGTGGTCAGTCC' *.fastq > count/B12753_Fm0.txt
agrep -0 -c 'GTTTCTGTTGCGTACGA' *.fastq > count/B12754_Fm0.txt
agrep -0 -c 'TCAACAGACTATGTACC' *.fastq > count/B12755_Fm0.txt
agrep -0 -c 'ATTCGAAACCGGCTAAT' *.fastq > count/B12757_Fm0.txt
agrep -0 -c 'GTAAGGTGCATCTTCCG' *.fastq > count/B12758_Fm0.txt
agrep -0 -c 'ATGGAAACGACGTTGAG' *.fastq > count/B12759_Fm0.txt
agrep -0 -c 'CTGCGTTGAGTGTCCAA' *.fastq > count/B12760_Fm0.txt
agrep -0 -c 'TACGTTCCGACGCGGAA' *.fastq > count/B12761_Fm0.txt
agrep -0 -c 'TACATACTGATTCCACC' *.fastq > count/B12762_Fm0.txt
agrep -0 -c 'ACCCAAAGCCCCACTTT' *.fastq > count/B12763_Fm0.txt
agrep -0 -c 'ATAAGCCACGAGAGTCT' *.fastq > count/B12764_Fm0.txt
agrep -0 -c 'GCCAAAGACCGGATGGA' *.fastq > count/B12765_Fm0.txt
agrep -0 -c 'GCTCGCAGCTAGTGTTC' *.fastq > count/B12766_Fm0.txt
agrep -0 -c 'CCACTCCGTCAAGTAAA' *.fastq > count/B12767_Fm0.txt
agrep -0 -c 'AGGTGCGGCTGCACTTT' *.fastq > count/B12769_Fm0.txt
agrep -0 -c 'ACTCGGGGAAGTTTAGC' *.fastq > count/B12770_Fm0.txt
agrep -0 -c 'AGCTATCACGGCTTGCC' *.fastq > count/B12771_Fm0.txt
agrep -0 -c 'GGTTCCTCCCAAGGACA' *.fastq > count/B12772_Fm0.txt
agrep -0 -c 'AAGACAGCTTACTTCAG' *.fastq > count/B12773_Fm0.txt
agrep -0 -c 'AGTAAACCCGGAGGGCA' *.fastq > count/B12774_Fm0.txt
agrep -0 -c 'AATACGTCCAACGAGAC' *.fastq > count/B12775_Fm0.txt
agrep -0 -c 'CGCCGAATGTCGTTACA' *.fastq > count/B12776_Fm0.txt
agrep -0 -c 'AGTCGGCGATCGACATT' *.fastq > count/B12777_Fm0.txt
agrep -0 -c 'CACGCGTTTGACAGCCT' *.fastq > count/B12778_Fm0.txt
agrep -0 -c 'TGAGCGAACTCTATCTC' *.fastq > count/B12779_Fm0.txt
agrep -0 -c 'AGGTCACAAAAGCTCGC' *.fastq > count/B12780_Fm0.txt
agrep -0 -c 'CTCTGGTTGCATGCAAT' *.fastq > count/B12781_Fm0.txt
agrep -0 -c 'GGTTAATGATTCAGCCA' *.fastq > count/B12782_Fm0.txt
agrep -0 -c 'ACTGCTATTGGAAGATC' *.fastq > count/B12784_Fm0.txt
agrep -0 -c 'AAGCCTTCCTGGTATTA' *.fastq > count/B12785_Fm0.txt
agrep -0 -c 'TCGCGCCTGTTGATTTG' *.fastq > count/B12787_Fm0.txt
agrep -0 -c 'GGGACGATGTACACGTA' *.fastq > count/B12788_Fm0.txt
agrep -0 -c 'GGCAGTCGGACGAAAGT' *.fastq > count/B12789_Fm0.txt
agrep -0 -c 'CACCGAAACCTCCGCTA' *.fastq > count/B12790_Fm0.txt
agrep -0 -c 'TCGGTTCACACCTCGCA' *.fastq > count/B12791_Fm0.txt
agrep -0 -c 'TGACAAGTACCCAGCGG' *.fastq > count/B12792_Fm0.txt
agrep -0 -c 'TTGATGAGGATCGCTCC' *.fastq > count/B12793_Fm0.txt
agrep -0 -c 'CATTGGGCTTCTCACGA' *.fastq > count/B12794_Fm0.txt
agrep -0 -c 'CATTACTCCGTCACCAG' *.fastq > count/B12795_Fm0.txt
agrep -0 -c 'ACAGCAACGTAGAGATC' *.fastq > count/B12796_Fm0.txt
agrep -0 -c 'GTTCTGTCGGATCTTAC' *.fastq > count/B12797_Fm0.txt
agrep -0 -c 'AAGCATAGTAGACCGTA' *.fastq > count/B12798_Fm0.txt
agrep -0 -c 'CCGACTGCAGGATGCAT' *.fastq > count/B12799_Fm0.txt
agrep -0 -c 'TTCAGCCTTAGCAGTTC' *.fastq > count/B12800_Fm0.txt
agrep -0 -c 'TACTGAGGACTCTCCTT' *.fastq > count/B12802_Fm0.txt
agrep -0 -c 'CCACATGTGTGGTTCAA' *.fastq > count/B12803_Fm0.txt
agrep -0 -c 'TCGACGATATATACCGG' *.fastq > count/B12804_Fm0.txt
agrep -0 -c 'CGAGATTTTGAACCGTT' *.fastq > count/B12805_Fm0.txt
agrep -0 -c 'GGTGCTAAATGGACGCG' *.fastq > count/B12808_Fm0.txt
agrep -0 -c 'AGCAATGCTACTGCAGG' *.fastq > count/B12809_Fm0.txt
agrep -0 -c 'GGGGATGACTAGTAAGT' *.fastq > count/B12810_Fm0.txt
agrep -0 -c 'ATCCGGGGGATCTCAAG' *.fastq > count/B12811_Fm0.txt
agrep -0 -c 'AACCTAACTGTGGAGGG' *.fastq > count/B12814_Fm0.txt
agrep -0 -c 'ATAGGTCGGGAGTCGGA' *.fastq > count/B12815_Fm0.txt
agrep -0 -c 'GCCCCGTCTTCACTTAC' *.fastq > count/B12816_Fm0.txt
agrep -0 -c 'TACTAGTCGCTCCACTC' *.fastq > count/B12819_Fm0.txt
agrep -0 -c 'ACGAGGGTCTGTTATCT' *.fastq > count/B12824_Fm0.txt
agrep -0 -c 'TGTCAGAGCGATCCATC' *.fastq > count/B12825_Fm0.txt
agrep -0 -c 'CGAGATCCCCATGCACA' *.fastq > count/B12826_Fm0.txt
agrep -0 -c 'TTGCTTACCAACAGCCA' *.fastq > count/B12827_Fm0.txt
agrep -0 -c 'GAGGACCGTATGTCCAG' *.fastq > count/B12828_Fm0.txt
agrep -0 -c 'GTGTAGCTTGTACGGAT' *.fastq > count/B12829_Fm0.txt
agrep -0 -c 'GCGCAATAATGGAGAGA' *.fastq > count/B12830_Fm0.txt
agrep -0 -c 'TGCGGACTTATTATCTG' *.fastq > count/B12831_Fm0.txt
agrep -0 -c 'GATCTAGAGTCACGACC' *.fastq > count/B12832_Fm0.txt
agrep -0 -c 'CGCACTCCTTGAGTGAT' *.fastq > count/B12833_Fm0.txt
agrep -0 -c 'TCAAAGAGCCCTCGGAG' *.fastq > count/B12834_Fm0.txt
agrep -0 -c 'CCAGTGGCTGCTATCGA' *.fastq > count/B12836_Fm0.txt
agrep -0 -c 'CGAACGCGAGTCTCATG' *.fastq > count/B12837_Fm0.txt
agrep -0 -c 'GATCTCTGTGTCGAATG' *.fastq > count/B12838_Fm0.txt
agrep -0 -c 'AAGGACTGAAGCGTGGC' *.fastq > count/B12839_Fm0.txt
agrep -0 -c 'TGGCCGATCTGGTTTGA' *.fastq > count/B12840_Fm0.txt
agrep -0 -c 'GAGACATTATAGGGTAC' *.fastq > count/B12841_Fm0.txt
agrep -0 -c 'GGCTCTCAAGCTTCAGT' *.fastq > count/B12842_Fm0.txt
agrep -0 -c 'GTGGACGTAGTGAATGG' *.fastq > count/B12843_Fm0.txt
agrep -0 -c 'TTGGTCTCGGGCGTATG' *.fastq > count/B12844_Fm0.txt
agrep -0 -c 'TTCCTCTAGTTCTTGTG' *.fastq > count/B12845_Fm0.txt
agrep -0 -c 'ACACTGTTCAGTCTTCG' *.fastq > count/B12846_Fm0.txt
agrep -0 -c 'CTACGCTGGCTGTGTAA' *.fastq > count/B12847_Fm0.txt
agrep -0 -c 'CGTTGTAGCCCAGCTGT' *.fastq > count/B12848_Fm0.txt
agrep -0 -c 'CGCAAACCGGAAAGGGT' *.fastq > count/B12849_Fm0.txt
agrep -0 -c 'TTGTCGACGGCAGTAGT' *.fastq > count/B12850_Fm0.txt
agrep -0 -c 'CTGTGCGGACAGAACGT' *.fastq > count/B12851_Fm0.txt
agrep -0 -c 'ACAACTCGAACTCGACG' *.fastq > count/B12852_Fm0.txt
agrep -0 -c 'ATCCAATACGTGACACG' *.fastq > count/B12853_Fm0.txt
agrep -0 -c 'GTTGCTCAACATAAGGG' *.fastq > count/B12855_Fm0.txt
agrep -0 -c 'GCGAGGTATGCTATCAG' *.fastq > count/B12856_Fm0.txt
agrep -0 -c 'CCTTATTGCACGGCTTC' *.fastq > count/B12857_Fm0.txt
agrep -0 -c 'CTACGAGTTGCGTTTGC' *.fastq > count/B12858_Fm0.txt
agrep -0 -c 'ATTCCTAACGCCACGGC' *.fastq > count/B12859_Fm0.txt
agrep -0 -c 'GACACTTTCGTTAGCTA' *.fastq > count/B12860_Fm0.txt
agrep -0 -c 'GATGTCGATTCCGCCTA' *.fastq > count/B12861_Fm0.txt
agrep -0 -c 'CATGAGAGTGCGACTGA' *.fastq > count/B12862_Fm0.txt
agrep -0 -c 'TCATCGTGAACCCTTTA' *.fastq > count/B12863_Fm0.txt
agrep -0 -c 'CAGTGCCAAACCCAAAA' *.fastq > count/B12864_Fm0.txt
agrep -0 -c 'TCATAGTGGGTAGGAAT' *.fastq > count/B12866_Fm0.txt
agrep -0 -c 'TTAACTAAGCTCCGAGC' *.fastq > count/B12867_Fm0.txt
agrep -0 -c 'TAGTGAGACTAGACTGG' *.fastq > count/B12868_Fm0.txt
agrep -0 -c 'CGGCTCTAAGTCAATGC' *.fastq > count/B12869_Fm0.txt
agrep -0 -c 'GTCGTAAACGGTGTCTG' *.fastq > count/B12870_Fm0.txt
agrep -0 -c 'ACCTTCCTTCCGCGAAA' *.fastq > count/B12872_Fm0.txt
agrep -0 -c 'ATCATCCCAAATTGGGG' *.fastq > count/B12873_Fm0.txt
agrep -0 -c 'TGAGGCGATCTAGAAAG' *.fastq > count/B12874_Fm0.txt
agrep -0 -c 'TACTGTGGCCATGAGGT' *.fastq > count/B12876_Fm0.txt
agrep -0 -c 'TGACCTAGCCGATAGTG' *.fastq > count/B12877_Fm0.txt
agrep -0 -c 'TGGACGAGGCCAATACG' *.fastq > count/B12878_Fm0.txt
agrep -0 -c 'GTTTCGTCAGCGTAGTG' *.fastq > count/B12879_Fm0.txt
agrep -0 -c 'AGGGAAGAACCGTAACA' *.fastq > count/B12880_Fm0.txt
agrep -0 -c 'TATGGACACCGCACTCA' *.fastq > count/B12882_Fm0.txt
agrep -0 -c 'TTACTAGGGGTGTGGGC' *.fastq > count/B12883_Fm0.txt
agrep -0 -c 'TCTCGTTCCCGTTACTC' *.fastq > count/B12884_Fm0.txt
agrep -0 -c 'ACCGGACACTCCATCTA' *.fastq > count/B12885_Fm0.txt
agrep -0 -c 'AGTCTAGGTTTTTCTCC' *.fastq > count/B12886_Fm0.txt
agrep -0 -c 'CTCCGCCAGTGATTCAG' *.fastq > count/B12887_Fm0.txt
agrep -0 -c 'AAGTTATGACGCTTCAC' *.fastq > count/B12888_Fm0.txt
agrep -0 -c 'ACCTAACTCGGCGTAAA' *.fastq > count/B12889_Fm0.txt
agrep -0 -c 'GATCATCTATGCCGCTG' *.fastq > count/B12890_Fm0.txt
agrep -0 -c 'TATGACAGTGGCGGTAG' *.fastq > count/B12891_Fm0.txt
agrep -0 -c 'GTACTAGCACTCTACGA' *.fastq > count/B12892_Fm0.txt
agrep -0 -c 'ATTACGCACCCAGTAGG' *.fastq > count/B12893_Fm0.txt
agrep -0 -c 'TTGGGTCTGTTTATCAC' *.fastq > count/B12894_Fm0.txt
agrep -0 -c 'CTAGGAACTCCCCAGGT' *.fastq > count/B12895_Fm0.txt
agrep -0 -c 'ACGCGAAAGCATATGAC' *.fastq > count/B12896_Fm0.txt
agrep -0 -c 'ATAAGGCCATTCGGGAC' *.fastq > count/B12897_Fm0.txt
agrep -0 -c 'CCGGATTTGACACTTAC' *.fastq > count/B12898_Fm0.txt
agrep -0 -c 'ACTCGTAGCCATTATCG' *.fastq > count/B12899_Fm0.txt
agrep -0 -c 'AGGCGATAGATTACCTG' *.fastq > count/B12900_Fm0.txt
agrep -0 -c 'TGTAGGGTCCGATCACC' *.fastq > count/B12901_Fm0.txt
agrep -0 -c 'CGTAGTTTGGCAAGGTC' *.fastq > count/B12902_Fm0.txt
agrep -0 -c 'AACAGGCGACGTTGCTC' *.fastq > count/B12903_Fm0.txt
agrep -0 -c 'GTGAAGGACTCGTGTTC' *.fastq > count/B12904_Fm0.txt
agrep -0 -c 'GTAAGGTGTCACTGCGG' *.fastq > count/B12905_Fm0.txt
agrep -0 -c 'AAGGGATGCCATCCCGT' *.fastq > count/B12906_Fm0.txt
agrep -0 -c 'AATATCCCAGCCCCTTC' *.fastq > count/B12907_Fm0.txt
agrep -0 -c 'ACCCCAAGGTTACCCAG' *.fastq > count/B12908_Fm0.txt
agrep -0 -c 'GGCTAATCCCGAAGTCT' *.fastq > count/B12909_Fm0.txt
agrep -0 -c 'GCAAACTCGGGTTACGT' *.fastq > count/B12910_Fm0.txt
agrep -0 -c 'ATGTCCCTTTTCCCCTG' *.fastq > count/B12911_Fm0.txt
agrep -0 -c 'TTGTTTGGGCACATTGG' *.fastq > count/B12912_Fm0.txt
agrep -0 -c 'ACCTGTGGGGTCGAACT' *.fastq > count/B12913_Fm0.txt
agrep -0 -c 'CGAGCATCAATGACTGT' *.fastq > count/B12914_Fm0.txt
agrep -0 -c 'TCGTAAGACATCTAGTG' *.fastq > count/B12916_Fm0.txt
agrep -0 -c 'CGAGGTGTGCGCATAAG' *.fastq > count/B12917_Fm0.txt
agrep -0 -c 'GTTCCTGATTATGAGAC' *.fastq > count/B12921_Fm0.txt
agrep -0 -c 'CGTCGTCGTCTCTAAGA' *.fastq > count/B12922_Fm0.txt
agrep -0 -c 'AACCGTCAGAATGAACT' *.fastq > count/B12923_Fm0.txt
agrep -0 -c 'TCTTAAACATGGTTGGC' *.fastq > count/B12925_Fm0.txt
agrep -0 -c 'CGTACACTGGGGAAGTC' *.fastq > count/B12926_Fm0.txt
agrep -0 -c 'TAAATCAGTGCGACGAA' *.fastq > count/B12927_Fm0.txt
agrep -0 -c 'ACAAAGCTCAGACAACA' *.fastq > count/B12928_Fm0.txt
agrep -0 -c 'GCCACCTCGCCTTCTAT' *.fastq > count/B12929_Fm0.txt
agrep -0 -c 'TCAGCTTGCCAAATTCT' *.fastq > count/B12930_Fm0.txt
agrep -0 -c 'TAACCCTAAGCTCTTGA' *.fastq > count/B12931_Fm0.txt
agrep -0 -c 'TATCCTTCTTCCGGCAT' *.fastq > count/B12932_Fm0.txt
agrep -0 -c 'GATACATCCTAGTACGG' *.fastq > count/B12933_Fm0.txt
agrep -0 -c 'TAAAGGCGAGGAATAGG' *.fastq > count/B12934_Fm0.txt
agrep -0 -c 'ATAATATGGCGCGACAG' *.fastq > count/B12935_Fm0.txt
agrep -0 -c 'GATGTCCCTAGTGGATT' *.fastq > count/B12936_Fm0.txt
agrep -0 -c 'AGTGTGCTCCTTGTTAG' *.fastq > count/B12938_Fm0.txt
agrep -0 -c 'GTAGGGTAAACGGTACA' *.fastq > count/B12940_Fm0.txt
agrep -0 -c 'TGCTGATTATCACCGCC' *.fastq > count/B12942_Fm0.txt
agrep -0 -c 'TTAATTCCGGCGCAGTT' *.fastq > count/B12944_Fm0.txt
agrep -0 -c 'TATGAACGGGTCTGATA' *.fastq > count/B12946_Fm0.txt
agrep -0 -c 'CTAACCCCGTCAAATTG' *.fastq > count/B12947_Fm0.txt
agrep -0 -c 'GTGAGATTTCTCACGAG' *.fastq > count/B12948_Fm0.txt
agrep -0 -c 'CGTGACAACTGGAATCA' *.fastq > count/B12949_Fm0.txt
agrep -0 -c 'GCTGCGTAAGTAATGAA' *.fastq > count/B12950_Fm0.txt
agrep -0 -c 'TCGTGAAGCCAACTCGC' *.fastq > count/B12951_Fm0.txt
agrep -0 -c 'GGTAAAAATCGTGCTGC' *.fastq > count/B12952_Fm0.txt
agrep -0 -c 'ACCAATAAGTCCTCCTA' *.fastq > count/B12954_Fm0.txt
agrep -0 -c 'AGAGGTATGAGATCAAG' *.fastq > count/B12956_Fm0.txt
agrep -0 -c 'GCAATCACTGTATGTAC' *.fastq > count/B12957_Fm0.txt
agrep -0 -c 'GTGATCACTGCACTTAA' *.fastq > count/B12958_Fm0.txt
agrep -0 -c 'CCGCTAGAGAGTATCAC' *.fastq > count/B12961_Fm0.txt
agrep -0 -c 'ATCTCGTTTACCAAGTC' *.fastq > count/B12964_Fm0.txt
agrep -0 -c 'AACATAGTTGTCGCCAC' *.fastq > count/B12965_Fm0.txt
agrep -0 -c 'TTGGTTTGAGCGGTTCC' *.fastq > count/B12966_Fm0.txt
agrep -0 -c 'AGCGGCAGTTTAGCCTG' *.fastq > count/B12967_Fm0.txt
agrep -0 -c 'TACGCAACAGTCCTGAT' *.fastq > count/B12968_Fm0.txt
agrep -0 -c 'CCGGGTTCATAAAGACC' *.fastq > count/B12969_Fm0.txt
agrep -0 -c 'CCAAGAGTAATGGGAAC' *.fastq > count/B12970_Fm0.txt
agrep -0 -c 'AACTGGATTCACAGTAG' *.fastq > count/B12971_Fm0.txt
agrep -0 -c 'TGTACCCGACGACTGCT' *.fastq > count/B12972_Fm0.txt
agrep -0 -c 'GTGACTGAGGCTTTGAT' *.fastq > count/B12974_Fm0.txt
agrep -0 -c 'CGGGCGAAACGAATCCA' *.fastq > count/B12975_Fm0.txt
agrep -0 -c 'ATCTCAAGCATAACCTG' *.fastq > count/B12976_Fm0.txt
agrep -0 -c 'GTGAACGAAGGGCACAT' *.fastq > count/B12977_Fm0.txt
agrep -0 -c 'TCTTGTCCAGAATTGAC' *.fastq > count/B12978_Fm0.txt
agrep -0 -c 'TCGATACCAGACTCCTT' *.fastq > count/B12980_Fm0.txt
agrep -0 -c 'ACACGGGAAATCAAGTT' *.fastq > count/B12981_Fm0.txt
agrep -0 -c 'CGTGAACGTTTAGGACA' *.fastq > count/B12982_Fm0.txt
agrep -0 -c 'GGATGACTCGTGTGACA' *.fastq > count/B12983_Fm0.txt
agrep -0 -c 'AATTCTGGACGGGTAAG' *.fastq > count/B12984_Fm0.txt
agrep -0 -c 'AGGAGCATAGCTTCGGG' *.fastq > count/B12985_Fm0.txt
agrep -0 -c 'GGTGACTTTTCGTGCAA' *.fastq > count/B12986_Fm0.txt
agrep -0 -c 'CCTTCACAGTTGGCGGA' *.fastq > count/B12987_Fm0.txt
agrep -0 -c 'AATCCACAACGCAGACC' *.fastq > count/B12988_Fm0.txt
agrep -0 -c 'TCAGGATGCTAGTGGCC' *.fastq > count/B12989_Fm0.txt
agrep -0 -c 'CGACGCTTTCACGATTA' *.fastq > count/B12990_Fm0.txt
agrep -0 -c 'TCGTAAGTACACGCGGG' *.fastq > count/B12991_Fm0.txt
agrep -0 -c 'AGAAATGTGCAGAGCCG' *.fastq > count/B12992_Fm0.txt
agrep -0 -c 'CATAGGTAGAAGGAGAC' *.fastq > count/B12994_Fm0.txt
agrep -0 -c 'TTGTTAGCGACGTAATG' *.fastq > count/B12995_Fm0.txt
agrep -0 -c 'CGCACGTATCAACAGTT' *.fastq > count/B12996_Fm0.txt
agrep -0 -c 'GGTGTTATGAGCTGACT' *.fastq > count/B12997_Fm0.txt
agrep -0 -c 'GCGAGACATAGAAAGGT' *.fastq > count/B12999_Fm0.txt
agrep -0 -c 'AACATTCCCTTTGCGAC' *.fastq > count/B13000_Fm0.txt
agrep -0 -c 'ACCGATTAATACGGGTT' *.fastq > count/B13002_Fm0.txt
agrep -0 -c 'GGGTCCAACATAGAAGT' *.fastq > count/B13003_Fm0.txt
agrep -0 -c 'CTGGCTATAGTGACATA' *.fastq > count/B13004_Fm0.txt
agrep -0 -c 'TGACGTCGGGTTTCTCT' *.fastq > count/B13005_Fm0.txt
agrep -0 -c 'GTGGCTGGACTCATGCT' *.fastq > count/B13006_Fm0.txt
agrep -0 -c 'CATCTAAATACCTTCGC' *.fastq > count/B13007_Fm0.txt
agrep -0 -c 'GACGGATGGTTTTTTAC' *.fastq > count/B13008_Fm0.txt
agrep -0 -c 'TCGAGGACGTGCGCAAT' *.fastq > count/B13009_Fm0.txt
agrep -0 -c 'GCACACGTGATTCATTA' *.fastq > count/B13013_Fm0.txt
agrep -0 -c 'TCGCATCCTTAAATGCG' *.fastq > count/B13014_Fm0.txt
agrep -0 -c 'TATCACTGATAGCGACG' *.fastq > count/B13015_Fm0.txt
agrep -0 -c 'CGTCAAGATTAACGAGA' *.fastq > count/B13016_Fm0.txt
agrep -0 -c 'CATACCCGTCGTTATTT' *.fastq > count/B13017_Fm0.txt
agrep -0 -c 'AGCAGCTTCCCTACTAC' *.fastq > count/B13018_Fm0.txt
agrep -0 -c 'AGCAGTAACGGTTCGAC' *.fastq > count/B13019_Fm0.txt
agrep -0 -c 'TACATACGGCTCAGATA' *.fastq > count/B13020_Fm0.txt
agrep -0 -c 'CAAATGGCGACTCCCGT' *.fastq > count/B13023_Fm0.txt
agrep -0 -c 'AGGCGTCACTACTCATG' *.fastq > count/B13024_Fm0.txt
agrep -0 -c 'GTCTGGCTCTAACGTAA' *.fastq > count/B13026_Fm0.txt
agrep -0 -c 'TAGTACGCAGCTACCTC' *.fastq > count/B13029_Fm0.txt
agrep -0 -c 'TTCCCAATTGTGGTGCA' *.fastq > count/B13030_Fm0.txt
agrep -0 -c 'ATCTACCTAGCCTAACA' *.fastq > count/B13031_Fm0.txt
agrep -0 -c 'CAAGCGTGAGTCTGTCT' *.fastq > count/B13037_Fm0.txt
agrep -0 -c 'TATGGAGGTATGCCGTA' *.fastq > count/B13038_Fm0.txt
agrep -0 -c 'TGTAAAGACGCAAGCGT' *.fastq > count/B13039_Fm0.txt
agrep -0 -c 'CAGCGTTATCACGCGTG' *.fastq > count/B13040_Fm0.txt
agrep -0 -c 'AACAGAAGCGTCACTTA' *.fastq > count/B13041_Fm0.txt
agrep -0 -c 'ATCGCCTAACAACCATG' *.fastq > count/B13042_Fm0.txt
agrep -0 -c 'GATTCTGGGACATTACG' *.fastq > count/B13043_Fm0.txt
agrep -0 -c 'ACTAGTCTGACCCCCTT' *.fastq > count/B13044_Fm0.txt
agrep -0 -c 'TTATGTCGAGTGTAGGT' *.fastq > count/B13045_Fm0.txt
agrep -0 -c 'AATTCGAGTGCACTGAA' *.fastq > count/B13047_Fm0.txt
agrep -0 -c 'ATCGCCGCTAGAACAAA' *.fastq > count/B13048_Fm0.txt
agrep -0 -c 'CTGTCACCGTTAAACGG' *.fastq > count/B13049_Fm0.txt
agrep -0 -c 'CAAACAATTGCCTAGGC' *.fastq > count/B13050_Fm0.txt
agrep -0 -c 'GCTACTCACAAATTGGC' *.fastq > count/B13051_Fm0.txt
agrep -0 -c 'TATCACGGGCAGATGAG' *.fastq > count/B13052_Fm0.txt
agrep -0 -c 'ATCTCCCGTCGCAGAAG' *.fastq > count/B13053_Fm0.txt
agrep -0 -c 'GGGCCACTCGTTTTCTC' *.fastq > count/B13054_Fm0.txt
agrep -0 -c 'CAGGGATAGGATCAATT' *.fastq > count/B13055_Fm0.txt
agrep -0 -c 'ACTTGCTACTCCAAACA' *.fastq > count/B13056_Fm0.txt
agrep -0 -c 'GCTGATACACAAATGGT' *.fastq > count/B13057_Fm0.txt
agrep -0 -c 'CCTCTCCCTTGTTCCAA' *.fastq > count/B13058_Fm0.txt
agrep -0 -c 'TTGTGAAGCGATAGTAC' *.fastq > count/B13060_Fm0.txt
agrep -0 -c 'TGCCTACCAAGTGTCCG' *.fastq > count/B13061_Fm0.txt
agrep -0 -c 'ACAGTGAAACGCTTGAT' *.fastq > count/B13062_Fm0.txt
agrep -0 -c 'GCTTAGCCACATATCCT' *.fastq > count/B13063_Fm0.txt
agrep -0 -c 'GAGTGAGTGCATTACGG' *.fastq > count/B13064_Fm0.txt
agrep -0 -c 'CGAAAACTTGAGTTAGG' *.fastq > count/B13065_Fm0.txt
agrep -0 -c 'GGAATTATGGGACAAGA' *.fastq > count/B13066_Fm0.txt
agrep -0 -c 'TCATGGACGCCTAGGCT' *.fastq > count/B13067_Fm0.txt
agrep -0 -c 'ATAACCCCGATGTCTTA' *.fastq > count/B13068_Fm0.txt
agrep -0 -c 'GGGATTCCTGCCTCACA' *.fastq > count/B13069_Fm0.txt
agrep -0 -c 'GGAAGTCCGATGCTTCG' *.fastq > count/B13072_Fm0.txt
agrep -0 -c 'CTCCACACATCGATAAT' *.fastq > count/B13073_Fm0.txt
agrep -0 -c 'CACGATTCGTTGTTGAA' *.fastq > count/B13074_Fm0.txt
agrep -0 -c 'AACTCGTAGCCCAAGCG' *.fastq > count/B13076_Fm0.txt
agrep -0 -c 'ATCCTTCCTATTGGGAG' *.fastq > count/B13078_Fm0.txt
agrep -0 -c 'AGTCTCGTCCTTATCTT' *.fastq > count/B13080_Fm0.txt
agrep -0 -c 'GCAGGAAGGAAATTCCG' *.fastq > count/B13081_Fm0.txt
agrep -0 -c 'CGTTCCAGTGCTGGTTC' *.fastq > count/B13083_Fm0.txt
agrep -0 -c 'TCATTCCGCTCACTCCG' *.fastq > count/B13084_Fm0.txt
agrep -0 -c 'CAAGATTCTAGTACACG' *.fastq > count/B13085_Fm0.txt
agrep -0 -c 'CTCGGGTTAATTTGACA' *.fastq > count/B13086_Fm0.txt
agrep -0 -c 'GGGACCGATCCCCAATA' *.fastq > count/B13087_Fm0.txt
agrep -0 -c 'TGACGCGCCCTTTATCT' *.fastq > count/B13088_Fm0.txt
agrep -0 -c 'ATGCACTTGCCCGTAAG' *.fastq > count/B13089_Fm0.txt
agrep -0 -c 'ATGTCTACGGGTGCCTA' *.fastq > count/B13090_Fm0.txt
agrep -0 -c 'AGCGAGCCACCGGATTT' *.fastq > count/B13091_Fm0.txt
agrep -0 -c 'CGCATCGGGGTGTCAAA' *.fastq > count/B13092_Fm0.txt
agrep -0 -c 'TACAGGCGAGTTCTCGG' *.fastq > count/B13093_Fm0.txt
agrep -0 -c 'CAAATTTGAAAGGTCCG' *.fastq > count/B13094_Fm0.txt
agrep -0 -c 'CCAACGCAATCGACCTG' *.fastq > count/B13096_Fm0.txt
agrep -0 -c 'GTGCACGGGCAGAAGAA' *.fastq > count/B13097_Fm0.txt
agrep -0 -c 'TTACATCGAAGGTGCCC' *.fastq > count/B13098_Fm0.txt
agrep -0 -c 'GTAAGCTTACGATCCGT' *.fastq > count/B13099_Fm0.txt
agrep -0 -c 'CCTTCAGCATACTAGTC' *.fastq > count/B13100_Fm0.txt
agrep -0 -c 'CATCCACTGTCCATTAG' *.fastq > count/B13101_Fm0.txt
agrep -0 -c 'CTACTCGTCTCGCTGTA' *.fastq > count/B13103_Fm0.txt
agrep -0 -c 'CGACTTTTCTTGCGGTG' *.fastq > count/B13104_Fm0.txt
agrep -0 -c 'TGTCCTAGTGTAGGTGT' *.fastq > count/B13105_Fm0.txt
agrep -0 -c 'GGCATTCGCATGATCAT' *.fastq > count/B13107_Fm0.txt
agrep -0 -c 'TACGGGTTCATACACGC' *.fastq > count/B13108_Fm0.txt
agrep -0 -c 'GTTCACAGCATCTAGGC' *.fastq > count/B13109_Fm0.txt
agrep -0 -c 'ATGGTTGTTGTACGCGA' *.fastq > count/B13110_Fm0.txt
agrep -0 -c 'CGACCACATACGTGTCT' *.fastq > count/B13112_Fm0.txt
agrep -0 -c 'ACCGAAGTTAAGATCGT' *.fastq > count/B13113_Fm0.txt
agrep -0 -c 'GACCATGAAACCCACTG' *.fastq > count/B13114_Fm0.txt
agrep -0 -c 'CGACAAGTTATCTAGAG' *.fastq > count/B13116_Fm0.txt
agrep -0 -c 'CTCTACTCGTACAGTCC' *.fastq > count/B13117_Fm0.txt
agrep -0 -c 'GGATGGTGATTAAAGGC' *.fastq > count/B13118_Fm0.txt
agrep -0 -c 'GCTAGTCGGGCGAATCT' *.fastq > count/B13119_Fm0.txt
agrep -0 -c 'ATAAGCCTCCGATCGCT' *.fastq > count/B13120_Fm0.txt
agrep -0 -c 'GTGATGACACTCACCGT' *.fastq > count/B13121_Fm0.txt
agrep -0 -c 'TAGACTCCATCCAACAT' *.fastq > count/B13122_Fm0.txt
agrep -0 -c 'GTTCGGGTCTTACACCG' *.fastq > count/B13124_Fm0.txt
agrep -0 -c 'TGCCCGGATCCTAGACT' *.fastq > count/B13125_Fm0.txt
agrep -0 -c 'CCGGCAAAACATGTTAG' *.fastq > count/B13127_Fm0.txt
agrep -0 -c 'CACAGCTGTAGCTGCCA' *.fastq > count/B13128_Fm0.txt
agrep -0 -c 'ATAAAGAGCAACGCTCA' *.fastq > count/B13129_Fm0.txt
agrep -0 -c 'ATGTTTGATGGAGTGGT' *.fastq > count/B13130_Fm0.txt
agrep -0 -c 'ACAGGCCTCAATACCGC' *.fastq > count/B13132_Fm0.txt
agrep -0 -c 'ACGCTCTAACATACGGG' *.fastq > count/B13133_Fm0.txt
agrep -0 -c 'GCAAAAAACCATCGATC' *.fastq > count/B13134_Fm0.txt
agrep -0 -c 'AGGCGAATTTGACGCTT' *.fastq > count/B13135_Fm0.txt
agrep -0 -c 'TCTAGTTGGTCCTCCAA' *.fastq > count/B13136_Fm0.txt
agrep -0 -c 'AGGACTGCGTAAAACAA' *.fastq > count/B13137_Fm0.txt
agrep -0 -c 'ACAATCGAGTCTGCTAT' *.fastq > count/B13139_Fm0.txt
agrep -0 -c 'TGCAACAGGTATTGTGC' *.fastq > count/B13140_Fm0.txt
agrep -0 -c 'TCATACCAACACTACGT' *.fastq > count/B13141_Fm0.txt
agrep -0 -c 'TTCTTATTGTTCCTCCG' *.fastq > count/B13142_Fm0.txt
agrep -0 -c 'CACACGATACCCACTGT' *.fastq > count/B13143_Fm0.txt
agrep -0 -c 'CATTCACTTGTAAGGTC' *.fastq > count/B13144_Fm0.txt
agrep -0 -c 'GGCGCTCAAAATTCTTT' *.fastq > count/B13145_Fm0.txt
agrep -0 -c 'TGGAACTACAATTCCCT' *.fastq > count/B13146_Fm0.txt
agrep -0 -c 'GCCCTCAACTATTTGAC' *.fastq > count/B13148_Fm0.txt
agrep -0 -c 'CGAAGCGTCACCACTTC' *.fastq > count/B13152_Fm0.txt
agrep -0 -c 'TAGGTTTCGACCCAGCA' *.fastq > count/B13153_Fm0.txt
agrep -0 -c 'ACTGACTCCATGCAACC' *.fastq > count/B13154_Fm0.txt
agrep -0 -c 'CCGTATTTGGACGTCCC' *.fastq > count/B13157_Fm0.txt
agrep -0 -c 'AAGGCGCTGTCATGTTA' *.fastq > count/B13158_Fm0.txt
agrep -0 -c 'GCCGTGTGTCGTCATTA' *.fastq > count/B13159_Fm0.txt
agrep -0 -c 'AGAGTAGAGTCTTCATC' *.fastq > count/B13160_Fm0.txt
agrep -0 -c 'AACTAAAAGCCGCTGAC' *.fastq > count/B13162_Fm0.txt
agrep -0 -c 'AGGGTTACGAGGGATAA' *.fastq > count/B13164_Fm0.txt
agrep -0 -c 'CACCGCTTTGGACCAGT' *.fastq > count/B13165_Fm0.txt
agrep -0 -c 'AAGGATGAGCCTCTGGC' *.fastq > count/B13166_Fm0.txt
agrep -0 -c 'TCGCCACTCCAGTTGAC' *.fastq > count/B13168_Fm0.txt
agrep -0 -c 'GATGTGGTTGTTCCGCC' *.fastq > count/B13169_Fm0.txt
agrep -0 -c 'TGCTTGGGGTTTGCGGA' *.fastq > count/B13170_Fm0.txt
agrep -0 -c 'ATGACCGCCTACGAGTA' *.fastq > count/B13171_Fm0.txt
agrep -0 -c 'GTCCGATACTATATCCC' *.fastq > count/B13172_Fm0.txt
agrep -0 -c 'AGGGCATATAGATGGCT' *.fastq > count/B13174_Fm0.txt
agrep -0 -c 'GAGTGATAGGGCACGCT' *.fastq > count/B13175_Fm0.txt
agrep -0 -c 'CGCTCACCTAACCAGAA' *.fastq > count/B13176_Fm0.txt
agrep -0 -c 'GGTTGATTGAGGTTTGT' *.fastq > count/B13178_Fm0.txt
agrep -0 -c 'TACGCGGCAGTACGAGA' *.fastq > count/B13179_Fm0.txt
agrep -0 -c 'GTAATACTAGTGTGCCG' *.fastq > count/B13180_Fm0.txt
agrep -0 -c 'GGCCTACTAATGCAAGC' *.fastq > count/B13181_Fm0.txt
agrep -0 -c 'CTCTAGCCTATTGTAGA' *.fastq > count/B13182_Fm0.txt
agrep -0 -c 'TCTTACCAGCGATCATA' *.fastq > count/B13183_Fm0.txt
agrep -0 -c 'ACAGAGTATCAGATCGC' *.fastq > count/B13186_Fm0.txt
agrep -0 -c 'CTCTCGGTGGTGCAAAC' *.fastq > count/B13187_Fm0.txt
agrep -0 -c 'TGAGCTAGTGATCCGCG' *.fastq > count/B13188_Fm0.txt
agrep -0 -c 'TAGCCCAGGTTCCGCTT' *.fastq > count/B13190_Fm0.txt
agrep -0 -c 'ACACGGGTATTATCCAG' *.fastq > count/B13191_Fm0.txt
agrep -0 -c 'CTTGGGTCTAGTCGAGC' *.fastq > count/B13192_Fm0.txt
agrep -0 -c 'TACGTTCGAGTTAGAGG' *.fastq > count/B13194_Fm0.txt
agrep -0 -c 'GCACTAAATCGAAGTCA' *.fastq > count/B13196_Fm0.txt
agrep -0 -c 'GGCCTCGATTATATAGT' *.fastq > count/B13197_Fm0.txt
agrep -0 -c 'TAGAGTCGTCGGTCCTC' *.fastq > count/B13198_Fm0.txt
agrep -0 -c 'CTGGATATCCCAGTTAT' *.fastq > count/B13199_Fm0.txt
agrep -0 -c 'CCGCGAAAGTTTCTGGG' *.fastq > count/B13200_Fm0.txt
agrep -0 -c 'GCTCTACATACGGGTTA' *.fastq > count/B13202_Fm0.txt
agrep -0 -c 'TTATGCTAACGTGTCCC' *.fastq > count/B13205_Fm0.txt
agrep -0 -c 'GGGTGTGTGTGGGTTAA' *.fastq > count/B13207_Fm0.txt
agrep -0 -c 'ATTACTGCCCTCCGGCA' *.fastq > count/B13208_Fm0.txt
agrep -0 -c 'CCGTGCTGTGTAACAGG' *.fastq > count/B13209_Fm0.txt
agrep -0 -c 'CCAGTTGGGGTTGCAAT' *.fastq > count/B13211_Fm0.txt
agrep -0 -c 'AGGGTTCTATATCAGCC' *.fastq > count/B13212_Fm0.txt
agrep -0 -c 'AGCGGAGACTTTACCTT' *.fastq > count/B13213_Fm0.txt
agrep -0 -c 'TTCAACTCCGGGGTGAT' *.fastq > count/B13214_Fm0.txt
agrep -0 -c 'ATACTGCGTTATCCCGC' *.fastq > count/B13215_Fm0.txt
agrep -0 -c 'GTCCGATACAGAAGTTG' *.fastq > count/B13217_Fm0.txt
agrep -0 -c 'AGTCCTCCGAGGGTGAT' *.fastq > count/B13218_Fm0.txt
agrep -0 -c 'CGGTACACACTGCAACC' *.fastq > count/B13219_Fm0.txt
agrep -0 -c 'AGTACCTCAGCGTGTGC' *.fastq > count/B13220_Fm0.txt
agrep -0 -c 'ATGGGTGAAGTTGCCAA' *.fastq > count/B13221_Fm0.txt
agrep -0 -c 'ACTCACGAATTTGCATG' *.fastq > count/B13222_Fm0.txt
agrep -0 -c 'GATCCAACGGAACAAGG' *.fastq > count/B13223_Fm0.txt
agrep -0 -c 'CGCGAATTGATCGTGAA' *.fastq > count/B13224_Fm0.txt
agrep -0 -c 'CGCCATAGGGTTTCTGC' *.fastq > count/B13226_Fm0.txt
agrep -0 -c 'ATGAGCTATTTATGGCC' *.fastq > count/B13227_Fm0.txt
agrep -0 -c 'TAGGACACGGGATGTTG' *.fastq > count/B13228_Fm0.txt
agrep -0 -c 'TTCGGGAATCTCACGGT' *.fastq > count/B13229_Fm0.txt
agrep -0 -c 'ACCATCACGTAGTATCT' *.fastq > count/B13230_Fm0.txt
agrep -0 -c 'TTAGTCTCGTCGCCGTT' *.fastq > count/B13231_Fm0.txt
agrep -0 -c 'AATTCAATAGGGGGTGC' *.fastq > count/B13232_Fm0.txt
agrep -0 -c 'CAGGGAATTCAACAGAT' *.fastq > count/B13233_Fm0.txt
agrep -0 -c 'CCTAGACACGACCCGTA' *.fastq > count/B13234_Fm0.txt
agrep -0 -c 'TGTTACGTGCGATTCTC' *.fastq > count/B13235_Fm0.txt
agrep -0 -c 'GACATTGTACCTTACGT' *.fastq > count/B13236_Fm0.txt
agrep -0 -c 'CTCCTGACTCACACAAG' *.fastq > count/B13237_Fm0.txt
agrep -0 -c 'CTATACGCCTGGGTGCT' *.fastq > count/B13238_Fm0.txt
agrep -0 -c 'CTGTGGATCAACACGGG' *.fastq > count/B13239_Fm0.txt
agrep -0 -c 'AAGGGATAACCTACACA' *.fastq > count/B13240_Fm0.txt
agrep -0 -c 'GCAGAACGTTGGAAGCG' *.fastq > count/B13241_Fm0.txt
agrep -0 -c 'TGTCTTCTGGGGTGCTC' *.fastq > count/B13242_Fm0.txt
agrep -0 -c 'TGCCATATGGAAGTGAT' *.fastq > count/B13244_Fm0.txt
agrep -0 -c 'CTGTCTAACAACTGTAC' *.fastq > count/B13246_Fm0.txt
agrep -0 -c 'GGGAATCGATCACCTAA' *.fastq > count/B13248_Fm0.txt
agrep -0 -c 'ACTATCTGGAACTAGGC' *.fastq > count/B13249_Fm0.txt
agrep -0 -c 'TTGGTCCTCATCGAATT' *.fastq > count/B13250_Fm0.txt
agrep -0 -c 'TGAAGGACGTCACGGTA' *.fastq > count/B13251_Fm0.txt
agrep -0 -c 'TACACACAATATACCGC' *.fastq > count/B13252_Fm0.txt
agrep -0 -c 'CTAGTAGGGTGCTCAAA' *.fastq > count/B13254_Fm0.txt
agrep -0 -c 'GACTACACGTTATCGGT' *.fastq > count/B13256_Fm0.txt
agrep -0 -c 'TGCAGCTCGAGACTGTT' *.fastq > count/B13259_Fm0.txt
agrep -0 -c 'ACGTCTTAAAGCGGCGA' *.fastq > count/B13261_Fm0.txt
agrep -0 -c 'ACCCGCTGATATACGAG' *.fastq > count/B13262_Fm0.txt
agrep -0 -c 'CCATCGGGCGACATGAT' *.fastq > count/B13263_Fm0.txt
agrep -0 -c 'CACATCGGGCACAAAAA' *.fastq > count/B13264_Fm0.txt
agrep -0 -c 'CTGGCTATTCCCGCTAT' *.fastq > count/B13265_Fm0.txt
agrep -0 -c 'GCATTGACTGTGCAATC' *.fastq > count/B13266_Fm0.txt
agrep -0 -c 'AGTCCCTATCAGGGGTA' *.fastq > count/B13267_Fm0.txt
agrep -0 -c 'ACCGAATATATTCTGCG' *.fastq > count/B13268_Fm0.txt
agrep -0 -c 'TACCACGACTTACTGTC' *.fastq > count/B13269_Fm0.txt
agrep -0 -c 'TTCGTCGTCAAACTGCA' *.fastq > count/B13271_Fm0.txt
agrep -0 -c 'TCATACGCCCGAACTGT' *.fastq > count/B13272_Fm0.txt
agrep -0 -c 'CACGCGGTACACTTTAA' *.fastq > count/B13273_Fm0.txt
agrep -0 -c 'GCGCACCTCAAGCTACA' *.fastq > count/B13274_Fm0.txt
agrep -0 -c 'TCTTCGTTCGCCCTACC' *.fastq > count/B13275_Fm0.txt
agrep -0 -c 'GTCGCGTTTAACTGCAC' *.fastq > count/B13276_Fm0.txt
agrep -0 -c 'GGCTAGCCGCCTTTTAG' *.fastq > count/B13277_Fm0.txt
agrep -0 -c 'CCTTTTGATGAACCGAG' *.fastq > count/B13278_Fm0.txt
agrep -0 -c 'AACATATCCACTGGGAA' *.fastq > count/B13279_Fm0.txt
agrep -0 -c 'TGAGCAGCACGTAGCAT' *.fastq > count/B13281_Fm0.txt
agrep -0 -c 'GTGAAACGTCCTAGGTC' *.fastq > count/B13282_Fm0.txt
agrep -0 -c 'TGCCTCCTTACATTCTC' *.fastq > count/B13283_Fm0.txt
agrep -0 -c 'CGCAGATAGTTGTACGG' *.fastq > count/B13284_Fm0.txt
agrep -0 -c 'TGCGCCTACGAGGTTTC' *.fastq > count/B13285_Fm0.txt
agrep -0 -c 'TCTTTACTCGGTCAAGC' *.fastq > count/B13286_Fm0.txt
agrep -0 -c 'TAGCTGCCATAATTGGG' *.fastq > count/B13287_Fm0.txt
agrep -0 -c 'AGTACGCGCAAGGAATT' *.fastq > count/B13288_Fm0.txt
agrep -0 -c 'AATGTGTATCCACGGTA' *.fastq > count/B13289_Fm0.txt
agrep -0 -c 'ATGAGCGAGAACGGGTG' *.fastq > count/B13290_Fm0.txt
agrep -0 -c 'CGTCGTTTGCGTAGACG' *.fastq > count/B13293_Fm0.txt
agrep -0 -c 'TCATTCAAGGGTGTTCG' *.fastq > count/B13294_Fm0.txt
agrep -0 -c 'GTTAGGTCGTATCCAGG' *.fastq > count/B13295_Fm0.txt
agrep -0 -c 'GCGGTTATATCCTTCAT' *.fastq > count/B13296_Fm0.txt
agrep -0 -c 'GGTCTTGGTAGCCAACA' *.fastq > count/B13300_Fm0.txt
agrep -0 -c 'AAGTACGGGCATCTTGC' *.fastq > count/B13301_Fm0.txt
agrep -0 -c 'CTACAGTGGCAAGAGAC' *.fastq > count/B13302_Fm0.txt
agrep -0 -c 'GACCTGTAGAAGTCTGC' *.fastq > count/B13303_Fm0.txt
agrep -0 -c 'CATTGGATTTGATCCAG' *.fastq > count/B13305_Fm0.txt
agrep -0 -c 'ATATCCTATGTTCCCCC' *.fastq > count/B13306_Fm0.txt
agrep -0 -c 'CGTTTCCGAACGCACAC' *.fastq > count/B13307_Fm0.txt
agrep -0 -c 'CTGGGACTCGTTGCCTA' *.fastq > count/B13309_Fm0.txt
agrep -0 -c 'CGAGACGCGCAATAGTC' *.fastq > count/B13310_Fm0.txt
agrep -0 -c 'GTTCTGCAGGAGCCAAC' *.fastq > count/B13311_Fm0.txt
agrep -0 -c 'CTGATCACCTCGAATGA' *.fastq > count/B13312_Fm0.txt
agrep -0 -c 'CCTCCAAATCGGATAAG' *.fastq > count/B13313_Fm0.txt
agrep -0 -c 'CCACTGACCGCCTAAAG' *.fastq > count/B13314_Fm0.txt
agrep -0 -c 'CCTATCGCCGGTAGTGA' *.fastq > count/B13315_Fm0.txt
agrep -0 -c 'AATCCACCGATCGAGCG' *.fastq > count/B13316_Fm0.txt
agrep -0 -c 'AACCATTGAGTGACTGG' *.fastq > count/B13317_Fm0.txt
agrep -0 -c 'CGACCACATGAAGCTAC' *.fastq > count/B13318_Fm0.txt
agrep -0 -c 'GCGGGAGAGATTTCCAT' *.fastq > count/B13319_Fm0.txt
agrep -0 -c 'CTTGTGCTTTCTAGGTG' *.fastq > count/B13320_Fm0.txt
agrep -0 -c 'TGACAACGACATGTAGG' *.fastq > count/B13321_Fm0.txt
agrep -0 -c 'AGGCGCAGCTCAGTATT' *.fastq > count/B13322_Fm0.txt
agrep -0 -c 'CGATAAAGCGGCGCTAG' *.fastq > count/B13324_Fm0.txt
agrep -0 -c 'GTTAAGAGTCGAGGCCG' *.fastq > count/B13325_Fm0.txt
agrep -0 -c 'TAAGTGCCTAACCACTA' *.fastq > count/B13326_Fm0.txt
agrep -0 -c 'AGTTGCGTCTCCGGTCA' *.fastq > count/B13330_Fm0.txt
agrep -0 -c 'AGGCTCGTGTACGTGTC' *.fastq > count/B13331_Fm0.txt
agrep -0 -c 'AGAGTTAGGATCGGAAT' *.fastq > count/B13332_Fm0.txt
agrep -0 -c 'GCTCACTGGAGTATGGC' *.fastq > count/B13333_Fm0.txt
agrep -0 -c 'TGCGCCTCTACACTACG' *.fastq > count/B13334_Fm0.txt
agrep -0 -c 'AACGTCAAATCACCGTT' *.fastq > count/B13336_Fm0.txt
agrep -0 -c 'TGATGCTTTCACAGCTT' *.fastq > count/B13337_Fm0.txt
agrep -0 -c 'CTTGAGGGGCTAGTCGA' *.fastq > count/B13338_Fm0.txt
agrep -0 -c 'ACCTGAACGAAGGTTTA' *.fastq > count/B13340_Fm0.txt
agrep -0 -c 'ACAATAACGGTACTGAC' *.fastq > count/B13341_Fm0.txt
agrep -0 -c 'TAAAAGCCTAGTCGAGA' *.fastq > count/B13343_Fm0.txt
agrep -0 -c 'GGCAATGCACAACGATG' *.fastq > count/B13344_Fm0.txt
agrep -0 -c 'TGGATTGGTATGGGAGC' *.fastq > count/B13345_Fm0.txt
agrep -0 -c 'ACGAACTACGCCGCTTT' *.fastq > count/B13346_Fm0.txt
agrep -0 -c 'AGACGCTGTGTCATAAT' *.fastq > count/B13348_Fm0.txt
agrep -0 -c 'AACTGACGGTACCCGTC' *.fastq > count/B13349_Fm0.txt
agrep -0 -c 'GTTACTATACACTGGCA' *.fastq > count/B13350_Fm0.txt
agrep -0 -c 'TTCCATCACTCAGCCTA' *.fastq > count/B13351_Fm0.txt
agrep -0 -c 'GATGCGTGCGATGGTTT' *.fastq > count/B13352_Fm0.txt
agrep -0 -c 'CACATGACGTTAGGTGG' *.fastq > count/B13354_Fm0.txt
agrep -0 -c 'CCTAGACACATTGACAA' *.fastq > count/B13355_Fm0.txt
agrep -0 -c 'TGTAAAGGTTTAGTCCG' *.fastq > count/B13357_Fm0.txt
agrep -0 -c 'CCGATCTCTTGGTTGCT' *.fastq > count/B13358_Fm0.txt
agrep -0 -c 'GCAAACCTGCCTCCATA' *.fastq > count/B13359_Fm0.txt
agrep -0 -c 'TTGAATAGGCGGACAAA' *.fastq > count/B13360_Fm0.txt
agrep -0 -c 'ACGTGAGTAGCAATGTT' *.fastq > count/B13361_Fm0.txt
agrep -0 -c 'CATTTCACAGGGATATC' *.fastq > count/B13362_Fm0.txt
agrep -0 -c 'GGTGTATATGCAGCCTG' *.fastq > count/B13363_Fm0.txt
agrep -0 -c 'AACCGCTACCCATACAA' *.fastq > count/B13364_Fm0.txt
agrep -0 -c 'GCGCATAGTCTTCCGAG' *.fastq > count/B13365_Fm0.txt
agrep -0 -c 'CATTGTAGCAGCCCAGA' *.fastq > count/B13366_Fm0.txt
agrep -0 -c 'TGATAGCCTCTTGACGA' *.fastq > count/B13367_Fm0.txt
agrep -0 -c 'GTATACGCTAGGCTAGC' *.fastq > count/B13368_Fm0.txt
agrep -0 -c 'AGAGAGTCATAGTGGCA' *.fastq > count/B13369_Fm0.txt
agrep -0 -c 'GTGGAAACGCATCCATA' *.fastq > count/B13370_Fm0.txt
agrep -0 -c 'ACTGTCGTGGGTTCAGT' *.fastq > count/B13371_Fm0.txt
agrep -0 -c 'CTCACCGTATATCGTTA' *.fastq > count/B13373_Fm0.txt
agrep -0 -c 'GATACCCCACTTAAGTT' *.fastq > count/B13375_Fm0.txt
agrep -0 -c 'CATCAAGCAGGTCACTC' *.fastq > count/B13376_Fm0.txt
agrep -0 -c 'TAAAGCCGGGGTGTAGT' *.fastq > count/B13377_Fm0.txt
agrep -0 -c 'GTCGAAAGATCGTGGTG' *.fastq > count/B13378_Fm0.txt
agrep -0 -c 'CTGGTTTTACCGGATCT' *.fastq > count/B13380_Fm0.txt
agrep -0 -c 'CAGGTGTGGCACTTACC' *.fastq > count/B13381_Fm0.txt
agrep -0 -c 'GCTGAATCCTTAATCGT' *.fastq > count/B13382_Fm0.txt
agrep -0 -c 'CGCCATCCTGGATTGGA' *.fastq > count/B13383_Fm0.txt
agrep -0 -c 'TGCGAGTGGACCCATTA' *.fastq > count/B13384_Fm0.txt
agrep -0 -c 'AATGCCCTAAGAAGGGC' *.fastq > count/B13385_Fm0.txt
agrep -0 -c 'GGGTAGCCGTAATCTAC' *.fastq > count/B13388_Fm0.txt
agrep -0 -c 'TGACTCCAGATAAACTC' *.fastq > count/B13391_Fm0.txt
agrep -0 -c 'CTAAAAGGAACCGGGGA' *.fastq > count/B13394_Fm0.txt
agrep -0 -c 'CTATTCCTTCCCTCTAA' *.fastq > count/B13396_Fm0.txt
agrep -0 -c 'CAGTGATCCGCAGCTGA' *.fastq > count/B13399_Fm0.txt
agrep -0 -c 'GGACAGATAGTAGACTC' *.fastq > count/B13400_Fm0.txt
agrep -0 -c 'GCTCCCAAATTCCGATC' *.fastq > count/B13401_Fm0.txt
agrep -0 -c 'CAATTTGATGTCCGGGT' *.fastq > count/B13402_Fm0.txt
agrep -0 -c 'AAGTTTGTCTCTTCTCG' *.fastq > count/B13403_Fm0.txt
agrep -0 -c 'CCGATGATATATTACGG' *.fastq > count/B13405_Fm0.txt
agrep -0 -c 'GGATTAGGGCCGTTGAT' *.fastq > count/B13406_Fm0.txt
agrep -0 -c 'TTAATACTCTCCTCAGC' *.fastq > count/B13407_Fm0.txt
agrep -0 -c 'CTGCCTACTAAACTCGT' *.fastq > count/B13408_Fm0.txt
agrep -0 -c 'TCTAGTGTGCACTTCGG' *.fastq > count/B13409_Fm0.txt
agrep -0 -c 'GTGCTCCTTCCAGTAAC' *.fastq > count/B13410_Fm0.txt
agrep -0 -c 'TGATAATCATGTCGCGT' *.fastq > count/B13411_Fm0.txt
agrep -0 -c 'ACCTGCCTTTGATCGCG' *.fastq > count/B13412_Fm0.txt
agrep -0 -c 'CCAACCTGGTTTGTGCC' *.fastq > count/B13413_Fm0.txt
agrep -0 -c 'AGGTTAACGTTTCTACG' *.fastq > count/B13414_Fm0.txt
agrep -0 -c 'CGCCATGAAGTCAGCTA' *.fastq > count/B13415_Fm0.txt
agrep -0 -c 'TCTGGTCATCATACCCC' *.fastq > count/B13417_Fm0.txt
agrep -0 -c 'GCGACAGATAGCTTATC' *.fastq > count/B13419_Fm0.txt
agrep -0 -c 'GTTCCTGGGTCTCCTCA' *.fastq > count/B13420_Fm0.txt
agrep -0 -c 'TCATGGACCATCTCTTG' *.fastq > count/B13423_Fm0.txt
agrep -0 -c 'ACCCGGGTTTCCAGTGT' *.fastq > count/B13424_Fm0.txt
agrep -0 -c 'CCGGACTCGACGAAATG' *.fastq > count/B13425_Fm0.txt
agrep -0 -c 'TGTATGATTGCGGGTCT' *.fastq > count/B13426_Fm0.txt
agrep -0 -c 'TCTACTACTCCGACAGA' *.fastq > count/B13427_Fm0.txt
agrep -0 -c 'CTAAATCCTGATGGGAG' *.fastq > count/B13428_Fm0.txt
agrep -0 -c 'CAGAGATTATACACGCT' *.fastq > count/B13429_Fm0.txt
agrep -0 -c 'CTTAATCACTGCGCCCC' *.fastq > count/B13430_Fm0.txt
agrep -0 -c 'GATTTGAAGCCTACCCG' *.fastq > count/B13431_Fm0.txt
agrep -0 -c 'GCTATCCGACTTAACTT' *.fastq > count/B13432_Fm0.txt
agrep -0 -c 'TTCCTGCGCTGCATTAT' *.fastq > count/B13433_Fm0.txt
agrep -0 -c 'AATCCTGCGCATCTGTC' *.fastq > count/B13434_Fm0.txt
agrep -0 -c 'CTGCATCAGTGTGGTTT' *.fastq > count/B13435_Fm0.txt
agrep -0 -c 'CATCAGCCACATGTCTC' *.fastq > count/B13436_Fm0.txt
agrep -0 -c 'GTAGCGAGTTGTGGCAC' *.fastq > count/B13438_Fm0.txt
agrep -0 -c 'TCGGGACGAGGTTAGAA' *.fastq > count/B13439_Fm0.txt
agrep -0 -c 'TGAAAGGTGTCCTGGAT' *.fastq > count/B13440_Fm0.txt
agrep -0 -c 'GACCTCCAATGTCTTGT' *.fastq > count/B13441_Fm0.txt
agrep -0 -c 'AACCCCAGAAACGTGGA' *.fastq > count/B13442_Fm0.txt
agrep -0 -c 'CATATCCCTTCGTTCTA' *.fastq > count/B13443_Fm0.txt
agrep -0 -c 'GATGGGGCTGATTCAGC' *.fastq > count/B13444_Fm0.txt
agrep -0 -c 'TTCTGCCGCAATATGCA' *.fastq > count/B13445_Fm0.txt
agrep -0 -c 'CGATAGCAGGATCGTCA' *.fastq > count/B13447_Fm0.txt
agrep -0 -c 'ATTCGACTGGCCCACAC' *.fastq > count/B13448_Fm0.txt
agrep -0 -c 'CATACGAATACCCTCGA' *.fastq > count/B13449_Fm0.txt
agrep -0 -c 'TGTATCTTTCGCCCAAA' *.fastq > count/B13450_Fm0.txt
agrep -0 -c 'GCCGCACATAAATGTCT' *.fastq > count/B13451_Fm0.txt
agrep -0 -c 'GTCCTTTATAGAGCCGG' *.fastq > count/B13453_Fm0.txt
agrep -0 -c 'AACTGGAAGTCGCTCCG' *.fastq > count/B13455_Fm0.txt
agrep -0 -c 'CCGACTTCTGTTTCGAG' *.fastq > count/B13456_Fm0.txt
agrep -0 -c 'CGAGATGTTTGCCAGCG' *.fastq > count/B13457_Fm0.txt
agrep -0 -c 'TAGAATAGTCCCTTGGA' *.fastq > count/B13458_Fm0.txt
agrep -0 -c 'ATTTACACACCCCCTCG' *.fastq > count/B13460_Fm0.txt
agrep -0 -c 'ACTAATATTCGGGTCCG' *.fastq > count/B13463_Fm0.txt
agrep -0 -c 'CAAAAGTGGTCTGCCTA' *.fastq > count/B13464_Fm0.txt
agrep -0 -c 'AGATAGTGAGTTCAGCC' *.fastq > count/B13465_Fm0.txt
agrep -0 -c 'CGATGCCTTATCCCAGA' *.fastq > count/B13467_Fm0.txt
agrep -0 -c 'CATCGGCGTCGTTCAAT' *.fastq > count/B13468_Fm0.txt
agrep -0 -c 'GTTCGTAGGATCGCGTA' *.fastq > count/B13470_Fm0.txt
agrep -0 -c 'TGCTAACCCCTACTTGG' *.fastq > count/B13471_Fm0.txt
agrep -0 -c 'CAAAATCCAAACCGGTC' *.fastq > count/B13472_Fm0.txt
agrep -0 -c 'ATTGGTCCTTAGAGTCC' *.fastq > count/B13473_Fm0.txt
agrep -0 -c 'AATTATCCGATGCGCCG' *.fastq > count/B13474_Fm0.txt
agrep -0 -c 'TGCTAGTAGTAACAAGC' *.fastq > count/B13475_Fm0.txt
agrep -0 -c 'CTTAACCTTACCGGAGA' *.fastq > count/B13476_Fm0.txt
agrep -0 -c 'GTGCTCCGCAAGCTTAC' *.fastq > count/B13477_Fm0.txt
agrep -0 -c 'ATTGAAGAGCCATAGGT' *.fastq > count/B13478_Fm0.txt
agrep -0 -c 'TGAGCCTATGGCATGGC' *.fastq > count/B13479_Fm0.txt
agrep -0 -c 'TCAGTCACATCATTGGC' *.fastq > count/B13480_Fm0.txt
agrep -0 -c 'GCGTCCCTGATGCTTTT' *.fastq > count/B13481_Fm0.txt
agrep -0 -c 'TCGAGTAGCAAGAAGTG' *.fastq > count/B13483_Fm0.txt
agrep -0 -c 'TTCCGAGAGCCTACTTG' *.fastq > count/B13484_Fm0.txt
agrep -0 -c 'CGTATTCCCAAGCTCCA' *.fastq > count/B13485_Fm0.txt
agrep -0 -c 'GGCGATGAGTGCATAGA' *.fastq > count/B13486_Fm0.txt
agrep -0 -c 'CCTGAAAGTCGCGTACC' *.fastq > count/B13487_Fm0.txt
agrep -0 -c 'CCTCAGGAACGTGATGT' *.fastq > count/B13488_Fm0.txt
agrep -0 -c 'CTTCTAGGGGACATATT' *.fastq > count/B13489_Fm0.txt
agrep -0 -c 'CGACCTGGCAATGCTCA' *.fastq > count/B13490_Fm0.txt
agrep -0 -c 'TCTTATCCGGCCAATGA' *.fastq > count/B13491_Fm0.txt
agrep -0 -c 'GTAACCAAGCCATCACG' *.fastq > count/B13492_Fm0.txt
agrep -0 -c 'ATGTAAAAGCCTCTCTC' *.fastq > count/B13493_Fm0.txt
agrep -0 -c 'ACATGAGCCTTTGTTTG' *.fastq > count/B13495_Fm0.txt
agrep -0 -c 'TTAGCCTCTACAATCCT' *.fastq > count/B13496_Fm0.txt
agrep -0 -c 'AGTATTCTGCCGATGGT' *.fastq > count/B13497_Fm0.txt
agrep -0 -c 'GACCTTTAAGTTTTGCG' *.fastq > count/B13498_Fm0.txt
agrep -0 -c 'GTTGTCCTACCTGATAA' *.fastq > count/B13499_Fm0.txt
agrep -0 -c 'GGGCCGTCCGTTATTAG' *.fastq > count/B13500_Fm0.txt
agrep -0 -c 'TATACGCACATTGATCC' *.fastq > count/B13501_Fm0.txt
agrep -0 -c 'ACGGTAGAAATTCTGGC' *.fastq > count/B13502_Fm0.txt
agrep -0 -c 'TAACCTGCATCGCTACA' *.fastq > count/B13503_Fm0.txt
agrep -0 -c 'CTCATATCCTGGAGCGC' *.fastq > count/B13504_Fm0.txt
agrep -0 -c 'GGGGCCTCCTCTGTTTT' *.fastq > count/B13505_Fm0.txt
agrep -0 -c 'ACCGTACACTAAAGATG' *.fastq > count/B13506_Fm0.txt
agrep -0 -c 'CATTCAGGACGAGATTC' *.fastq > count/B13508_Fm0.txt
agrep -0 -c 'CGTTAGCGTTAGTCATC' *.fastq > count/B13509_Fm0.txt
agrep -0 -c 'ATGCCTATTCCGCGAGG' *.fastq > count/B13511_Fm0.txt
agrep -0 -c 'ACGAGTCCGTACATCCG' *.fastq > count/B13512_Fm0.txt
agrep -0 -c 'GCGTTTTTCCCGCGAAG' *.fastq > count/B13513_Fm0.txt
agrep -0 -c 'GGCTTCGTTGACTGTTT' *.fastq > count/B13514_Fm0.txt
agrep -0 -c 'GTATTCCCAGGCCGCAT' *.fastq > count/B13515_Fm0.txt
agrep -0 -c 'TTGATAGTAGGATCCTG' *.fastq > count/B13516_Fm0.txt
agrep -0 -c 'GTACCGACAAGCAATGA' *.fastq > count/B13517_Fm0.txt
agrep -0 -c 'AGTTTGGCATCGGCGAG' *.fastq > count/B13518_Fm0.txt
agrep -0 -c 'GCAGAGTGGATTTCTTC' *.fastq > count/B13519_Fm0.txt
agrep -0 -c 'GGTTAGATTTTGTTGGG' *.fastq > count/B13521_Fm0.txt
agrep -0 -c 'CTTGTAGCCCTCGTTGC' *.fastq > count/B13522_Fm0.txt
agrep -0 -c 'TTACTGCGACCTGAACG' *.fastq > count/B13524_Fm0.txt
agrep -0 -c 'GTCACCAATGCAGTAAC' *.fastq > count/B13525_Fm0.txt
agrep -0 -c 'GGTGTCCAGATGCTTCA' *.fastq > count/B13526_Fm0.txt
agrep -0 -c 'CGTCCTGCGACTACAAG' *.fastq > count/B13528_Fm0.txt
agrep -0 -c 'CCGCAATCGGGAATGTC' *.fastq > count/B13529_Fm0.txt
agrep -0 -c 'AAGTAAGCAGGCACGGG' *.fastq > count/B13530_Fm0.txt
agrep -0 -c 'GATATACCACGGCATTA' *.fastq > count/B13531_Fm0.txt
agrep -0 -c 'CATGAGGGGCATTGAAT' *.fastq > count/B13533_Fm0.txt
agrep -0 -c 'CATCCAGTGTCGGGTTG' *.fastq > count/B13534_Fm0.txt
agrep -0 -c 'CGCTAAAATGCCCCTTT' *.fastq > count/B13536_Fm0.txt
agrep -0 -c 'TAGACGCCGTAGGTTTG' *.fastq > count/B13537_Fm0.txt
agrep -0 -c 'TGCCATGAAGTATCGCC' *.fastq > count/B13538_Fm0.txt
agrep -0 -c 'ACCTGGGGTACCACTGA' *.fastq > count/B13539_Fm0.txt
agrep -0 -c 'ATTAGAGGCCGTGCTAC' *.fastq > count/B13540_Fm0.txt
agrep -0 -c 'GAGCATATCAGGGAGAA' *.fastq > count/B13541_Fm0.txt
agrep -0 -c 'CTTCAAGTGCACGTTGA' *.fastq > count/B13542_Fm0.txt
agrep -0 -c 'CTAGAACGACAGAAAGA' *.fastq > count/B13543_Fm0.txt
agrep -0 -c 'ATAGACCTCTAATCGCC' *.fastq > count/B13544_Fm0.txt
agrep -0 -c 'ACGATAGGCCCAGTTTG' *.fastq > count/B13546_Fm0.txt
agrep -0 -c 'TATGGAGACGGTATCCT' *.fastq > count/B13547_Fm0.txt
agrep -0 -c 'AGGCGGCTCGTTACAAT' *.fastq > count/B13548_Fm0.txt
agrep -0 -c 'GCTCTACAGCTAAACAT' *.fastq > count/B13549_Fm0.txt
agrep -0 -c 'GAGTCGTTCGGACCATC' *.fastq > count/B13551_Fm0.txt
agrep -0 -c 'GATAGGGTGAAAGGGGG' *.fastq > count/B13552_Fm0.txt
agrep -0 -c 'CAGTGCTTGGCAATCCG' *.fastq > count/B13553_Fm0.txt
agrep -0 -c 'TTGTGGGAATTGACGGG' *.fastq > count/B13554_Fm0.txt
agrep -0 -c 'ATAGACAGGCTTAACGC' *.fastq > count/B13555_Fm0.txt
agrep -0 -c 'AAGGACGGCCGGTATCA' *.fastq > count/B13556_Fm0.txt
agrep -0 -c 'GCGCCTGGTGTGTTCAT' *.fastq > count/B13557_Fm0.txt
agrep -0 -c 'GCCCGGAGACAAGTTAC' *.fastq > count/B13559_Fm0.txt
agrep -0 -c 'ATGGGTAGACATCGTGC' *.fastq > count/B13560_Fm0.txt
agrep -0 -c 'CCGATCCCACTACTCAA' *.fastq > count/B13562_Fm0.txt
agrep -0 -c 'CACGTAGCGACCTCAAT' *.fastq > count/B13564_Fm0.txt
agrep -0 -c 'TCGCCAGTGTAGCGTTA' *.fastq > count/B13565_Fm0.txt
agrep -0 -c 'TGCGTTATAGGGCCGAT' *.fastq > count/B13566_Fm0.txt
agrep -0 -c 'AGATGATAGTCGTAGGT' *.fastq > count/B13567_Fm0.txt
agrep -0 -c 'GTGCGCGACCTGTTCAT' *.fastq > count/B13568_Fm0.txt
agrep -0 -c 'GACCTCGTGTAAGTGCC' *.fastq > count/B13569_Fm0.txt
agrep -0 -c 'ATCCTGCCGATGTCGTC' *.fastq > count/B13570_Fm0.txt
agrep -0 -c 'GCCGCGTCATTGTTCTA' *.fastq > count/B13571_Fm0.txt
agrep -0 -c 'TCAGGTTTCCCTAGTGA' *.fastq > count/B13573_Fm0.txt
agrep -0 -c 'CATCGGGCAATTTGCGG' *.fastq > count/B13574_Fm0.txt
agrep -0 -c 'ATAGACGTAATAACCCG' *.fastq > count/B13575_Fm0.txt
agrep -0 -c 'TAAGCGCTCGAAAAGAC' *.fastq > count/B13576_Fm0.txt
agrep -0 -c 'TATTGGCGGTGAGGAAC' *.fastq > count/B13578_Fm0.txt
agrep -0 -c 'TGAACGAAGGACTGCCT' *.fastq > count/B13579_Fm0.txt
agrep -0 -c 'AAGATTCACCGACCACA' *.fastq > count/B13581_Fm0.txt
agrep -0 -c 'TTCGATAGATCCGCGTA' *.fastq > count/B13582_Fm0.txt
agrep -0 -c 'TCTATCAGGCCCACTAG' *.fastq > count/B13583_Fm0.txt
agrep -0 -c 'ACGTAGGGACCCATTAA' *.fastq > count/B13585_Fm0.txt
agrep -0 -c 'TGGACGCGAACACGGAA' *.fastq > count/B13587_Fm0.txt
agrep -0 -c 'TGCCCTCAGTTCTCGCT' *.fastq > count/B13588_Fm0.txt
agrep -0 -c 'AGTTGTAACCGCCCTCA' *.fastq > count/B13589_Fm0.txt
agrep -0 -c 'ACGCGTTATCCACCTAA' *.fastq > count/B13590_Fm0.txt
agrep -0 -c 'TCACCACTGGTAACGGG' *.fastq > count/B13591_Fm0.txt
agrep -0 -c 'ATATTCACGCCTACGTA' *.fastq > count/B13592_Fm0.txt
agrep -0 -c 'GCCGACCTGAGGTACAA' *.fastq > count/B13593_Fm0.txt
agrep -0 -c 'CTGATGGGAGCTCCTCT' *.fastq > count/B13595_Fm0.txt
agrep -0 -c 'TAGCCGTTAGTAGAAGA' *.fastq > count/B13596_Fm0.txt
agrep -0 -c 'ACAGCATGACCGTTCTG' *.fastq > count/B13597_Fm0.txt
agrep -0 -c 'ATGTGCGGTTACGCCTA' *.fastq > count/B13598_Fm0.txt
agrep -0 -c 'AATGGACTTGGGTACAC' *.fastq > count/B13599_Fm0.txt
agrep -0 -c 'TCATCGCTTCGAATCTT' *.fastq > count/B13600_Fm0.txt
agrep -0 -c 'CGAGTTGGAGATCGACC' *.fastq > count/B13601_Fm0.txt
agrep -0 -c 'CTGTTGGACATTCTGAT' *.fastq > count/B13604_Fm0.txt
agrep -0 -c 'AGGCGGCATGATTGTAC' *.fastq > count/B13605_Fm0.txt
agrep -0 -c 'GTAGAACAGTCGCCATT' *.fastq > count/B13606_Fm0.txt
agrep -0 -c 'GTGATTGTCAAGCGTCC' *.fastq > count/B13607_Fm0.txt
agrep -0 -c 'TACGCGAACGCGCTTAC' *.fastq > count/B13609_Fm0.txt
agrep -0 -c 'ATCACAAGAGGGCAATT' *.fastq > count/B13610_Fm0.txt
agrep -0 -c 'CTGTTTTCATTCCCCGG' *.fastq > count/B13611_Fm0.txt
agrep -0 -c 'ACTTGGCTCGGCCAGAA' *.fastq > count/B13612_Fm0.txt
agrep -0 -c 'AACCTGTTGTTGGCGCG' *.fastq > count/B13613_Fm0.txt
agrep -0 -c 'GACTGATGTGATGATTC' *.fastq > count/B13614_Fm0.txt
agrep -0 -c 'ACCGGAGTAGTGAGACC' *.fastq > count/B13615_Fm0.txt
agrep -0 -c 'TACCTTACGTGAGTGTG' *.fastq > count/B13617_Fm0.txt
agrep -0 -c 'GCGTTTATAGGAAGCGA' *.fastq > count/B13618_Fm0.txt
agrep -0 -c 'ACCGGGTAATCAAGGGG' *.fastq > count/B13619_Fm0.txt
agrep -0 -c 'AGAGGCCCGCAAGCTAT' *.fastq > count/B13620_Fm0.txt
agrep -0 -c 'CGCATGCCCATAACGGT' *.fastq > count/B13621_Fm0.txt
agrep -0 -c 'GATAGAATCTAGTCCGA' *.fastq > count/B13622_Fm0.txt
agrep -0 -c 'ACTAGTTCTACGCCGTC' *.fastq > count/B13624_Fm0.txt
agrep -0 -c 'ACCTCCTAAGAACGGTT' *.fastq > count/B13625_Fm0.txt
agrep -0 -c 'CTTGTTAATAACCGGGA' *.fastq > count/B13626_Fm0.txt
agrep -0 -c 'TAGGATGCTGAACACAT' *.fastq > count/B13627_Fm0.txt
agrep -0 -c 'TTACACGCGTTACTTGA' *.fastq > count/B13628_Fm0.txt
agrep -0 -c 'AGCGATTTAACGAGATG' *.fastq > count/B13629_Fm0.txt
agrep -0 -c 'TGCTCGTGGGGTAAGTT' *.fastq > count/B13631_Fm0.txt
agrep -0 -c 'TGTGTTGTGTGAGCCGC' *.fastq > count/B13632_Fm0.txt
agrep -0 -c 'TACACGCAGACTTGTAA' *.fastq > count/B13633_Fm0.txt
agrep -0 -c 'AACGCGCCAACACGATG' *.fastq > count/B13634_Fm0.txt
agrep -0 -c 'CCAGACATAATGTGTGT' *.fastq > count/B13636_Fm0.txt
agrep -0 -c 'GTCCTGTGCATTCCGGA' *.fastq > count/B13637_Fm0.txt
agrep -0 -c 'GACTGGGCTATTTCCGC' *.fastq > count/B13638_Fm0.txt
agrep -0 -c 'GTCAACTATGCTACAGA' *.fastq > count/B13640_Fm0.txt
agrep -0 -c 'AGGTTCTCGAATCACCG' *.fastq > count/B13642_Fm0.txt
agrep -0 -c 'GATCTAGTTCAGAAGAC' *.fastq > count/B13644_Fm0.txt
agrep -0 -c 'TGACAGCCTCTCAAATA' *.fastq > count/B13645_Fm0.txt
agrep -0 -c 'GGTTCGCAATACCGGAA' *.fastq > count/B13646_Fm0.txt
agrep -0 -c 'AATACAAATTGCGGGGG' *.fastq > count/B13647_Fm0.txt
agrep -0 -c 'ACTAACCCCCGATGTCT' *.fastq > count/B13648_Fm0.txt
agrep -0 -c 'CATGGACGGCGATTGTA' *.fastq > count/B13649_Fm0.txt
agrep -0 -c 'TCACAGCGAGCCTGAAG' *.fastq > count/B13650_Fm0.txt
agrep -0 -c 'GCAGGTACGGATATTAA' *.fastq > count/B13651_Fm0.txt
agrep -0 -c 'AGTTACGTACGTTGGCC' *.fastq > count/B13652_Fm0.txt
agrep -0 -c 'CGTGGAGTAATAGGCCC' *.fastq > count/B13654_Fm0.txt
agrep -0 -c 'TCTAACTGGGACCTTGA' *.fastq > count/B13655_Fm0.txt
agrep -0 -c 'TAAGTAGAGGTGAGTGT' *.fastq > count/B13656_Fm0.txt
agrep -0 -c 'GGGCACGGTACATATGA' *.fastq > count/B13657_Fm0.txt
agrep -0 -c 'GGGTTCACTTGTCATCC' *.fastq > count/B13658_Fm0.txt
agrep -0 -c 'CGAGTCTCAACTTCACC' *.fastq > count/B13659_Fm0.txt
agrep -0 -c 'GAGGTTCACTGCGAGTT' *.fastq > count/B13660_Fm0.txt
agrep -0 -c 'TAGCCCAAAGGGTTCGC' *.fastq > count/B13661_Fm0.txt
agrep -0 -c 'CCGATCGAAATTACTGT' *.fastq > count/B13663_Fm0.txt
agrep -0 -c 'GCGTAATGTATTTAGGG' *.fastq > count/B13664_Fm0.txt
agrep -0 -c 'AGGTGCAGCGTCGTGTA' *.fastq > count/B13665_Fm0.txt
agrep -0 -c 'AGCATACACTGAACGCG' *.fastq > count/B13666_Fm0.txt
agrep -0 -c 'GACTGCAAGACGTTAGA' *.fastq > count/B13667_Fm0.txt
agrep -0 -c 'TAACTCTCAAGGGCTCT' *.fastq > count/B13668_Fm0.txt
agrep -0 -c 'CCTGATACTAAGCCCTT' *.fastq > count/B13669_Fm0.txt
agrep -0 -c 'CATGAGTGAATCGTTAG' *.fastq > count/B13671_Fm0.txt
agrep -0 -c 'TGAGACAACTCAGGTTA' *.fastq > count/B13672_Fm0.txt
agrep -0 -c 'CCTAGCCTGTCTTGACC' *.fastq > count/B13673_Fm0.txt
agrep -0 -c 'GTCAAGTAGTCTGAACA' *.fastq > count/B13674_Fm0.txt
agrep -0 -c 'GACTTCGATCAGCGAGT' *.fastq > count/B13675_Fm0.txt
agrep -0 -c 'GCTATCCACTATCTGGA' *.fastq > count/B13677_Fm0.txt
agrep -0 -c 'ACCGTAGGTTGTTCCCA' *.fastq > count/B13678_Fm0.txt
agrep -0 -c 'ATGAACACATGGGTAGC' *.fastq > count/B13680_Fm0.txt
agrep -0 -c 'GCCCATTTACACTAGTG' *.fastq > count/B13681_Fm0.txt
agrep -0 -c 'GGCACGTGACTGACTTG' *.fastq > count/B13682_Fm0.txt
agrep -0 -c 'TGTGCGCGTCGACATTG' *.fastq > count/B13683_Fm0.txt
agrep -0 -c 'TAATCAGGACCAGCACC' *.fastq > count/B13684_Fm0.txt
agrep -0 -c 'GTGTTAGCGGGCCTATT' *.fastq > count/B13685_Fm0.txt
agrep -0 -c 'GTCAGTTGATCCTTGAT' *.fastq > count/B13686_Fm0.txt
agrep -0 -c 'GATTCGCGGGAGAGCTA' *.fastq > count/B13687_Fm0.txt
agrep -0 -c 'TATCTGCATAGGTGTGC' *.fastq > count/B13689_Fm0.txt
agrep -0 -c 'GGTCATGGAGTGTTTGA' *.fastq > count/B13691_Fm0.txt
agrep -0 -c 'GCACGTATATCAGAAGC' *.fastq > count/B13692_Fm0.txt
agrep -0 -c 'GAGGTTATAGCCAGCTC' *.fastq > count/B13693_Fm0.txt
agrep -0 -c 'TTGGGGATAAATTTGGC' *.fastq > count/B13695_Fm0.txt
agrep -0 -c 'GCCCACAACCCACGATT' *.fastq > count/B13697_Fm0.txt
agrep -0 -c 'CTGGATTTTGGATATGG' *.fastq > count/B13698_Fm0.txt
agrep -0 -c 'CAGGCCCCAATTGACCA' *.fastq > count/B13699_Fm0.txt
agrep -0 -c 'ATTCAGCATGTACGTTC' *.fastq > count/B13700_Fm0.txt
agrep -0 -c 'CCACCCAGGTTATAAGA' *.fastq > count/B13701_Fm0.txt
agrep -0 -c 'GACCGCCACAATGCAAG' *.fastq > count/B13702_Fm0.txt
agrep -0 -c 'CTTCTCTATAGAGTCCA' *.fastq > count/B13703_Fm0.txt
agrep -0 -c 'CTCACGTTGAGGAAACA' *.fastq > count/B13704_Fm0.txt
agrep -0 -c 'GCCTACACACTTCGACG' *.fastq > count/B13705_Fm0.txt
agrep -0 -c 'CGTCAAGCGAGACGAAT' *.fastq > count/B13706_Fm0.txt
agrep -0 -c 'TAACGCATTACCACCAT' *.fastq > count/B13708_Fm0.txt
agrep -0 -c 'CCAATCGAAGTTCCCTA' *.fastq > count/B13709_Fm0.txt
agrep -0 -c 'TAAGAAGGCACTCAGAT' *.fastq > count/B13710_Fm0.txt
agrep -0 -c 'AGGATGTTCTCCGTACT' *.fastq > count/B13711_Fm0.txt
agrep -0 -c 'GCAGACGTCAGTCCGAA' *.fastq > count/B13712_Fm0.txt
agrep -0 -c 'CGTGAAATACCTGGAGA' *.fastq > count/B13714_Fm0.txt
agrep -0 -c 'AGAAAATCTCTAGTGCG' *.fastq > count/B13715_Fm0.txt
agrep -0 -c 'ACCACAGACCGACAACG' *.fastq > count/B13716_Fm0.txt
agrep -0 -c 'GATGCTTCCAGTCGGGA' *.fastq > count/B13717_Fm0.txt
agrep -0 -c 'GCACATTACCCCGATGT' *.fastq > count/B13719_Fm0.txt
agrep -0 -c 'GCAGGCTCCGAGTTATT' *.fastq > count/B13720_Fm0.txt
agrep -0 -c 'GGCACGTCCTTAATCCG' *.fastq > count/B13721_Fm0.txt
agrep -0 -c 'TGATCGTTCGAGCTTAG' *.fastq > count/B13722_Fm0.txt
agrep -0 -c 'TCATAGCGCGTTGGTTT' *.fastq > count/B13723_Fm0.txt
agrep -0 -c 'GCCTCATCCTGAGACAG' *.fastq > count/B13725_Fm0.txt
agrep -0 -c 'TCGCACCTTGTTCGTCG' *.fastq > count/B13726_Fm0.txt
agrep -0 -c 'GAGCTATCTCTTGCTCA' *.fastq > count/B13727_Fm0.txt
agrep -0 -c 'CCGTTAACTTGTCGAAA' *.fastq > count/B13728_Fm0.txt
agrep -0 -c 'CTCTCTTCAGCTAACGA' *.fastq > count/B13729_Fm0.txt
agrep -0 -c 'TGAAACTTCGGCGGCAA' *.fastq > count/B13730_Fm0.txt
agrep -0 -c 'TATGCCTAAGCAGCCGC' *.fastq > count/B13732_Fm0.txt
agrep -0 -c 'GAGACCGTATTATGTAC' *.fastq > count/B13733_Fm0.txt
agrep -0 -c 'GGATATATGGGACAAGT' *.fastq > count/B13734_Fm0.txt
agrep -0 -c 'ACATAACCGTAGACTTG' *.fastq > count/B13735_Fm0.txt
agrep -0 -c 'CTAGCCACGTTGTTCAA' *.fastq > count/B13736_Fm0.txt
agrep -0 -c 'TGTCCCTATGTCCGAGG' *.fastq > count/B13739_Fm0.txt
agrep -0 -c 'ATCGCCGTACCTACAGC' *.fastq > count/B13740_Fm0.txt
agrep -0 -c 'CGGTTTCTTCACTGCGA' *.fastq > count/B13741_Fm0.txt
agrep -0 -c 'ACTGTACGTGAGTGTCA' *.fastq > count/B13742_Fm0.txt
agrep -0 -c 'GAGGTCTAACAGCACAT' *.fastq > count/B13744_Fm0.txt
agrep -0 -c 'CTTCCTAAGGCAACGAG' *.fastq > count/B13745_Fm0.txt
agrep -0 -c 'CGTCGAATTCGCGTATG' *.fastq > count/B13746_Fm0.txt
agrep -0 -c 'ATCGCTAGAAACAACTC' *.fastq > count/B13747_Fm0.txt
agrep -0 -c 'ATCTTCTGCGCAGAATA' *.fastq > count/B13748_Fm0.txt
agrep -0 -c 'ATCCCCATTGCATCCCG' *.fastq > count/B13749_Fm0.txt
agrep -0 -c 'GAGCCACGCTCCATTGA' *.fastq > count/B13750_Fm0.txt
agrep -0 -c 'CAGTTCGAAAATCTGAG' *.fastq > count/B13751_Fm0.txt
agrep -0 -c 'TAGAAACTGAGCACGCC' *.fastq > count/B13753_Fm0.txt
agrep -0 -c 'GACCAGGAGTAAGACTG' *.fastq > count/B13754_Fm0.txt
agrep -0 -c 'ATTCGTTCCATTCACGC' *.fastq > count/B13756_Fm0.txt
agrep -0 -c 'GGTAGTCGAACTGAGTC' *.fastq > count/B13758_Fm0.txt
agrep -0 -c 'CGTATTTTAGAGGGCGC' *.fastq > count/B13760_Fm0.txt
agrep -0 -c 'AGTTATCGCCCTTACGT' *.fastq > count/B13762_Fm0.txt
agrep -0 -c 'TGTAGCCTTTAAGGGTA' *.fastq > count/B13763_Fm0.txt
agrep -0 -c 'GACCCAGGCAGCAATCT' *.fastq > count/B13764_Fm0.txt
agrep -0 -c 'ACTTGCTCCAGTACTGA' *.fastq > count/B13765_Fm0.txt
agrep -0 -c 'ACTTGTATTGCCACCTT' *.fastq > count/B13766_Fm0.txt
agrep -0 -c 'CATGAGTTCCGACTTTT' *.fastq > count/B13767_Fm0.txt
agrep -0 -c 'CTCCTGATCACTATTGT' *.fastq > count/B13768_Fm0.txt
agrep -0 -c 'CTAATTGGCGCGGGCTT' *.fastq > count/B13770_Fm0.txt
agrep -0 -c 'CTAGAAAGCCTAGGTGT' *.fastq > count/B13771_Fm0.txt
agrep -0 -c 'CGGCTGACACCTCTTTT' *.fastq > count/B13772_Fm0.txt
agrep -0 -c 'ATGGCTTGCTGGTCAGT' *.fastq > count/B13773_Fm0.txt
agrep -0 -c 'GAGCTAGGGTCACGATG' *.fastq > count/B13774_Fm0.txt
agrep -0 -c 'AGTAGGTGTGTTCACGG' *.fastq > count/B13775_Fm0.txt
agrep -0 -c 'GGTAGTCCGCCTGTTGA' *.fastq > count/B13776_Fm0.txt
agrep -0 -c 'CAAGCGCTGGTACTGAA' *.fastq > count/B13778_Fm0.txt
agrep -0 -c 'GAGCACGTCAATACCCC' *.fastq > count/B13780_Fm0.txt
agrep -0 -c 'CTCAGTTCCCAGCCGTT' *.fastq > count/B13782_Fm0.txt
agrep -0 -c 'CGAAACTGGTCCTACCA' *.fastq > count/B13783_Fm0.txt
agrep -0 -c 'TAGAGTCCACACGGGCA' *.fastq > count/B13784_Fm0.txt
agrep -0 -c 'CCAATAATCCCGATCCA' *.fastq > count/B13785_Fm0.txt
agrep -0 -c 'GCAAATCTACCCGCGGT' *.fastq > count/B13788_Fm0.txt
agrep -0 -c 'CTTGATCCGATGAGGCC' *.fastq > count/B13789_Fm0.txt
agrep -0 -c 'ATTATTCGTATCCCGCG' *.fastq > count/B13791_Fm0.txt
agrep -0 -c 'GTAGGCTCTCCTTACTC' *.fastq > count/B13792_Fm0.txt
agrep -0 -c 'AGATATCACCCCTGTAC' *.fastq > count/B13793_Fm0.txt
agrep -0 -c 'AGTCCTCATATAGAGTC' *.fastq > count/B13794_Fm0.txt
agrep -0 -c 'TGTTTATGCATCTAGGC' *.fastq > count/B13795_Fm0.txt
agrep -0 -c 'TAAGGTCATCATCGTGA' *.fastq > count/B13796_Fm0.txt
agrep -0 -c 'TCGAACTGACGATGTCC' *.fastq > count/B13797_Fm0.txt
agrep -0 -c 'CCATTAGTGAAACGGGG' *.fastq > count/B13798_Fm0.txt
agrep -0 -c 'AGCCTCATTTCGCACTT' *.fastq > count/B13799_Fm0.txt
agrep -0 -c 'TCGCAACACGTTTCGAC' *.fastq > count/B13800_Fm0.txt
agrep -0 -c 'TGGCTATCAAGTGGTGA' *.fastq > count/B13802_Fm0.txt
agrep -0 -c 'CAGAATGGCGAGTACCG' *.fastq > count/B13803_Fm0.txt
agrep -0 -c 'AAGACCGTCCAGCCTGA' *.fastq > count/B13804_Fm0.txt
agrep -0 -c 'CACCGCGCAGCCTAAAT' *.fastq > count/B13805_Fm0.txt
agrep -0 -c 'ACACAATCAGCCGCGTT' *.fastq > count/B13806_Fm0.txt
agrep -0 -c 'CCTAGACTAAAAGGCCG' *.fastq > count/B13807_Fm0.txt
agrep -0 -c 'TGCTGATACGACGACAC' *.fastq > count/B13808_Fm0.txt
agrep -0 -c 'TCAGTTGGTACGCGCAT' *.fastq > count/B13809_Fm0.txt
agrep -0 -c 'ATAAGAAGGCTTCAGGT' *.fastq > count/B13810_Fm0.txt
agrep -0 -c 'CGAAATGTAAGCCACCA' *.fastq > count/B13811_Fm0.txt
agrep -0 -c 'TACTCAGGCGTGTTCTG' *.fastq > count/B13813_Fm0.txt
agrep -0 -c 'CTTAGGGATGATCGGAT' *.fastq > count/B13815_Fm0.txt
agrep -0 -c 'TAGTCACTGCGAGAATA' *.fastq > count/B13816_Fm0.txt
agrep -0 -c 'GCGCTCTAGCGGATGAT' *.fastq > count/B13817_Fm0.txt
agrep -0 -c 'GCCTTGCTAGCGCCATT' *.fastq > count/B13819_Fm0.txt
agrep -0 -c 'CGACATAGAAATACTCG' *.fastq > count/B13820_Fm0.txt
agrep -0 -c 'CGGTAATTCGACTATGC' *.fastq > count/B13821_Fm0.txt
agrep -0 -c 'TTGCGAGTTATAGCCTA' *.fastq > count/B13823_Fm0.txt
agrep -0 -c 'TACGGGGAGTGTCTGGA' *.fastq > count/B13825_Fm0.txt
agrep -0 -c 'ACTGTTCTGGACGAGGG' *.fastq > count/B13826_Fm0.txt
agrep -0 -c 'CGCGATCCAGATGTAAG' *.fastq > count/B13827_Fm0.txt
agrep -0 -c 'AGTTTCGCTCTACCGTT' *.fastq > count/B13828_Fm0.txt
agrep -0 -c 'ACAGACACGCCATTGGA' *.fastq > count/B13830_Fm0.txt
agrep -0 -c 'CGCTCGTAACATTATGA' *.fastq > count/B13833_Fm0.txt
agrep -0 -c 'CGTAGGGTTTTAGTAGT' *.fastq > count/B13834_Fm0.txt
agrep -0 -c 'GGAGGACAAGTGCGTAC' *.fastq > count/B13835_Fm0.txt
agrep -0 -c 'AAGGCGGTCTGATCGGT' *.fastq > count/B13836_Fm0.txt
agrep -0 -c 'TAAAGCCGAATCGCCCA' *.fastq > count/B13838_Fm0.txt
agrep -0 -c 'AGTGGGCTGATTACGGG' *.fastq > count/B13839_Fm0.txt
agrep -0 -c 'GTTGGGTTCTCCGATGA' *.fastq > count/B13840_Fm0.txt
agrep -0 -c 'ATATCGGCAGCACAGTA' *.fastq > count/B13841_Fm0.txt
agrep -0 -c 'CAAGGGGCCTTGTTCAG' *.fastq > count/B13842_Fm0.txt
agrep -0 -c 'TTCGGTGTTTGCGTCCT' *.fastq > count/B13844_Fm0.txt
agrep -0 -c 'GTCTGCTTGGCTCTTTG' *.fastq > count/B13845_Fm0.txt
agrep -0 -c 'CAAACCGTTTCGTCGGC' *.fastq > count/B13847_Fm0.txt
agrep -0 -c 'CGTCCATCTTACGATAA' *.fastq > count/B13848_Fm0.txt
agrep -0 -c 'GCGCCTGTCCATGGTAA' *.fastq > count/B13849_Fm0.txt
agrep -0 -c 'TCGGCCTTTCACATGGT' *.fastq > count/B13850_Fm0.txt
agrep -0 -c 'GCAACTAAATTTCACGC' *.fastq > count/B13851_Fm0.txt
agrep -0 -c 'TCTGTTTACATGCGCGT' *.fastq > count/B13852_Fm0.txt
agrep -0 -c 'GGTCTGGTTGAGTACCG' *.fastq > count/B13853_Fm0.txt
agrep -0 -c 'AGGGTTCGCGACTCAGA' *.fastq > count/B13854_Fm0.txt
agrep -0 -c 'GTTCTGTCGCAATTTGT' *.fastq > count/B13855_Fm0.txt
agrep -0 -c 'ACCGTGTCCGACGGTTT' *.fastq > count/B13856_Fm0.txt
agrep -0 -c 'TGAGTTAGAGGAACGAA' *.fastq > count/B13857_Fm0.txt
agrep -0 -c 'ACCTTGTCGCACGAGAT' *.fastq > count/B13858_Fm0.txt
agrep -0 -c 'ATCACTTCCAGGACCCC' *.fastq > count/B13860_Fm0.txt
agrep -0 -c 'GTTCTGGGAAGTACCAC' *.fastq > count/B13861_Fm0.txt
agrep -0 -c 'TTCTCTAAGACCATCTG' *.fastq > count/B13862_Fm0.txt
agrep -0 -c 'ACCGTACCTCGGATTGC' *.fastq > count/B13863_Fm0.txt
agrep -0 -c 'GCAGTTACGTGCACCAA' *.fastq > count/B13864_Fm0.txt
agrep -0 -c 'ATAAGGCAGACACGCTA' *.fastq > count/B13865_Fm0.txt
agrep -0 -c 'GAGTATACGGCGCAGCT' *.fastq > count/B13867_Fm0.txt
agrep -0 -c 'GTTGTTAGACGAAGCAA' *.fastq > count/B13868_Fm0.txt
agrep -0 -c 'CTCGAGACGATCCACAG' *.fastq > count/B13870_Fm0.txt
agrep -0 -c 'TAAGTGGGATAAGCCGG' *.fastq > count/B13871_Fm0.txt
agrep -0 -c 'CACGATTCTTCATTCAG' *.fastq > count/B13872_Fm0.txt
agrep -0 -c 'TGTACTCGGTGTCCCAG' *.fastq > count/B13873_Fm0.txt
agrep -0 -c 'CCAATGCAGGCAAATCT' *.fastq > count/B13874_Fm0.txt
agrep -0 -c 'GTCCCAGCCGAATCATA' *.fastq > count/B13875_Fm0.txt
agrep -0 -c 'ACGTGCGCGAATTTGTT' *.fastq > count/B13876_Fm0.txt
agrep -0 -c 'GTGGTACTCATAAGCGA' *.fastq > count/B13877_Fm0.txt
agrep -0 -c 'ACCGATAATACCATGCC' *.fastq > count/B13878_Fm0.txt
agrep -0 -c 'TCGATTCCTATGCGCAA' *.fastq > count/B13879_Fm0.txt
agrep -0 -c 'TGTCGTGCGGGCAATAG' *.fastq > count/B13881_Fm0.txt
agrep -0 -c 'GTCAATAGTCCGGCTTG' *.fastq > count/B13884_Fm0.txt
agrep -0 -c 'CAGGTGGCCGTCTAACA' *.fastq > count/B13885_Fm0.txt
agrep -0 -c 'AGTACCAGCGGGAAACT' *.fastq > count/B13886_Fm0.txt
agrep -0 -c 'TGACAGAATGGTCGTCT' *.fastq > count/B13887_Fm0.txt
agrep -0 -c 'TTCTGCTAGTTTCGTCT' *.fastq > count/B13888_Fm0.txt
agrep -0 -c 'CGGACTGACTGCCTCTA' *.fastq > count/B13889_Fm0.txt
agrep -0 -c 'AGAACAAGCTACTACGC' *.fastq > count/B13890_Fm0.txt
agrep -0 -c 'AGAAAAGCGAGCCTTAT' *.fastq > count/B13891_Fm0.txt
agrep -0 -c 'ACCTGCAGGAAGCTTTA' *.fastq > count/B13893_Fm0.txt
agrep -0 -c 'TGGCAGTCCCGATTATC' *.fastq > count/B13894_Fm0.txt
agrep -0 -c 'AGTCGTACTTTCGAGCT' *.fastq > count/B13895_Fm0.txt
agrep -0 -c 'CCACACGGATCAGTTTG' *.fastq > count/B13896_Fm0.txt
agrep -0 -c 'TTATGTCGAGGAGCTCC' *.fastq > count/B13899_Fm0.txt
agrep -0 -c 'GATGACATGTATCGGCT' *.fastq > count/B13900_Fm0.txt
agrep -0 -c 'TCGGCGCAATCTCCATA' *.fastq > count/B13902_Fm0.txt
agrep -0 -c 'ACCACTTCGACGTTTTA' *.fastq > count/B13906_Fm0.txt
agrep -0 -c 'ACGTTCGGTATGTCGGG' *.fastq > count/B13907_Fm0.txt
agrep -0 -c 'GACTTTTGACAGGGACA' *.fastq > count/B13908_Fm0.txt
agrep -0 -c 'GACAGACTCTAAAAGTC' *.fastq > count/B13909_Fm0.txt
agrep -0 -c 'TGCAATCAGGACCTAAC' *.fastq > count/B13910_Fm0.txt
agrep -0 -c 'GGATGTCTCTGGGATTC' *.fastq > count/B13912_Fm0.txt
agrep -0 -c 'CTAGGGTTCGTGTTTTG' *.fastq > count/B13913_Fm0.txt
agrep -0 -c 'ATCCCGTCTAATCAGAA' *.fastq > count/B13914_Fm0.txt
agrep -0 -c 'GGGAGCTTACATTTGCC' *.fastq > count/B13915_Fm0.txt
agrep -0 -c 'GCTGACGGCTTGGTCTT' *.fastq > count/B13916_Fm0.txt
agrep -0 -c 'GGAACTCGTAGCCCAAG' *.fastq > count/B13917_Fm0.txt
agrep -0 -c 'GGAGGGGAACCATTTCT' *.fastq > count/B13918_Fm0.txt
agrep -0 -c 'CACATGTTTTACGGTTC' *.fastq > count/B13919_Fm0.txt
agrep -0 -c 'CGCCCTTGTGAGTGAGA' *.fastq > count/B13920_Fm0.txt
agrep -0 -c 'CTAAAGTCTAATCGCTC' *.fastq > count/B13921_Fm0.txt
agrep -0 -c 'GTCCATTGCTCTGAGCT' *.fastq > count/B13922_Fm0.txt
agrep -0 -c 'GTCCTAGCTAACTTGAT' *.fastq > count/B13923_Fm0.txt
agrep -0 -c 'GGCCTGAAGCAGACTAA' *.fastq > count/B13924_Fm0.txt
agrep -0 -c 'TCTGTTAAGAGGGGTTT' *.fastq > count/B13925_Fm0.txt
agrep -0 -c 'AGAGCTTTAAGTGATCG' *.fastq > count/B13927_Fm0.txt
agrep -0 -c 'AACGCCCGCTACATTTC' *.fastq > count/B13928_Fm0.txt
agrep -0 -c 'GAGCGTTGTTTATTAGG' *.fastq > count/B13930_Fm0.txt
agrep -0 -c 'ATATGTGCGGTTTGGCC' *.fastq > count/B13931_Fm0.txt
agrep -0 -c 'TAGTTTCGTTACTAGCG' *.fastq > count/B13932_Fm0.txt
agrep -0 -c 'GTGTAATAGTCTTCTGG' *.fastq > count/B13933_Fm0.txt
agrep -0 -c 'TCTCACGATCGTTAGTG' *.fastq > count/B13934_Fm0.txt
agrep -0 -c 'GATGCTCGGAAATGTTT' *.fastq > count/B13936_Fm0.txt
agrep -0 -c 'GAGGTAACAATAGAGTG' *.fastq > count/B13938_Fm0.txt
agrep -0 -c 'GCCGGTTTAGCCATTAT' *.fastq > count/B13939_Fm0.txt
agrep -0 -c 'GGCCTATGTACAATGTT' *.fastq > count/B13940_Fm0.txt
agrep -0 -c 'CGACTACGTCAATGAAA' *.fastq > count/B13941_Fm0.txt
agrep -0 -c 'TCACTATTGGGAATCGA' *.fastq > count/B13942_Fm0.txt
agrep -0 -c 'CAGTGAATCAGATCAAC' *.fastq > count/B13945_Fm0.txt
agrep -0 -c 'GATAAGGCCTTGGCTTA' *.fastq > count/B13947_Fm0.txt
agrep -0 -c 'GAGGACGATACTTCTCA' *.fastq > count/B13949_Fm0.txt
agrep -0 -c 'GCACTAGGGTGATTCGC' *.fastq > count/B13950_Fm0.txt
agrep -0 -c 'GGTGCAGAATCTTCGTG' *.fastq > count/B13951_Fm0.txt
agrep -0 -c 'CAAGTACACAAGGTTCG' *.fastq > count/B13952_Fm0.txt
agrep -0 -c 'TTGGCGTGTTCGGCTAA' *.fastq > count/B13953_Fm0.txt
agrep -0 -c 'TGGCACCCATGAATAGA' *.fastq > count/B13954_Fm0.txt
agrep -0 -c 'GTAATTCGCGGGGCGTA' *.fastq > count/B13955_Fm0.txt
agrep -0 -c 'CTATAAGATCCGCTTGA' *.fastq > count/B13956_Fm0.txt
agrep -0 -c 'CGTCCAGTAGACAAGTG' *.fastq > count/B13959_Fm0.txt
agrep -0 -c 'CCGCCGGGAAATCATTT' *.fastq > count/B13960_Fm0.txt
agrep -0 -c 'CCGTAATCTAGACCCGC' *.fastq > count/B13961_Fm0.txt
agrep -0 -c 'ACACGCCGTTTAACCTC' *.fastq > count/B13962_Fm0.txt
agrep -0 -c 'GAGAGGACCCCAAAATT' *.fastq > count/B13964_Fm0.txt
agrep -0 -c 'GGATGACGAGTAACGGC' *.fastq > count/B13965_Fm0.txt
agrep -0 -c 'CCTTGCTCGTGATCGAG' *.fastq > count/B13966_Fm0.txt
agrep -0 -c 'GGGTGCATACTGCGGAA' *.fastq > count/B13967_Fm0.txt
agrep -0 -c 'TCAACCGATCTCTCGTC' *.fastq > count/B13968_Fm0.txt
agrep -0 -c 'GTGAATCAAGGTGATGG' *.fastq > count/B13970_Fm0.txt
agrep -0 -c 'CATCTTAGGTTGTGCTC' *.fastq > count/B13971_Fm0.txt
agrep -0 -c 'CGTCCTTTATCACCTAC' *.fastq > count/B13972_Fm0.txt
agrep -0 -c 'AATCCGAATGATGCCAG' *.fastq > count/B13973_Fm0.txt
agrep -0 -c 'TGTGAGCAGGCCACTCT' *.fastq > count/B13974_Fm0.txt
agrep -0 -c 'ACCGTTAGGTTGTGTGC' *.fastq > count/B13975_Fm0.txt
agrep -0 -c 'AGCTCGATAAACGACGT' *.fastq > count/B13977_Fm0.txt
agrep -0 -c 'AATGCTCCGGGCTGACA' *.fastq > count/B13979_Fm0.txt
agrep -0 -c 'AAGTGGTTCGTTTCCGA' *.fastq > count/B13980_Fm0.txt
agrep -0 -c 'CGCTTTCTTTTCCGCGA' *.fastq > count/B13984_Fm0.txt
agrep -0 -c 'GAGAAACGCTATTGGAT' *.fastq > count/B13985_Fm0.txt
agrep -0 -c 'TCTCCGCTGGTAAGGTG' *.fastq > count/B13986_Fm0.txt
agrep -0 -c 'TCGCTACCTATTAACCT' *.fastq > count/B13987_Fm0.txt
agrep -0 -c 'ATGATAGGGCCAGGACT' *.fastq > count/B13989_Fm0.txt
agrep -0 -c 'AGTGTTCGGTCTTCGGC' *.fastq > count/B13990_Fm0.txt
agrep -0 -c 'CATTCTCGTTCACCCAA' *.fastq > count/B13993_Fm0.txt
agrep -0 -c 'TTCAGTAGGAGTAGCTC' *.fastq > count/B13994_Fm0.txt
agrep -0 -c 'CAAAAAGCACGGCCGAG' *.fastq > count/B13995_Fm0.txt
agrep -0 -c 'TGTCCCTGGCCAGATAA' *.fastq > count/B13996_Fm0.txt
agrep -0 -c 'ATATACCCGAGAACACT' *.fastq > count/B13997_Fm0.txt
agrep -0 -c 'CGTGCCAGGGATGCATT' *.fastq > count/B14001_Fm0.txt
agrep -0 -c 'CAACTGCCAAAGTAGAG' *.fastq > count/B14002_Fm0.txt
agrep -0 -c 'GACTCGTCGTGATCGTC' *.fastq > count/B14003_Fm0.txt
agrep -0 -c 'GGTCACCATTATACTGT' *.fastq > count/B14004_Fm0.txt
agrep -0 -c 'GTGACTAGTAGGGGGTG' *.fastq > count/B14005_Fm0.txt
agrep -0 -c 'TAGAAGTAACTTGTGCG' *.fastq > count/B14006_Fm0.txt
agrep -0 -c 'TGGCCTGGAAACCGTCT' *.fastq > count/B14007_Fm0.txt
agrep -0 -c 'CATACGGTCGACACCGA' *.fastq > count/B14008_Fm0.txt
agrep -0 -c 'GCCTCCCATCAGTTAGG' *.fastq > count/B14009_Fm0.txt
agrep -0 -c 'ATCCGAATAGTTGTTCC' *.fastq > count/B14010_Fm0.txt
agrep -0 -c 'TAAAAAGTAGGCTCGCA' *.fastq > count/B14013_Fm0.txt
agrep -0 -c 'ATCCTAGGCATCGCACA' *.fastq > count/B14014_Fm0.txt
agrep -0 -c 'TATTTAAAGGCCGGATC' *.fastq > count/B14015_Fm0.txt
agrep -0 -c 'TCGCGATTGACGTATCA' *.fastq > count/B14016_Fm0.txt
agrep -0 -c 'AATGTAGACAGAGCGCA' *.fastq > count/B14017_Fm0.txt
agrep -0 -c 'GCGTAGAGAAGACCAGT' *.fastq > count/B14018_Fm0.txt
agrep -0 -c 'CTATAAACCCTACCGTT' *.fastq > count/B14019_Fm0.txt
agrep -0 -c 'GCATTCAGCCAGTAGTG' *.fastq > count/B14020_Fm0.txt
agrep -0 -c 'CTGGTGTAGGTCGAAAA' *.fastq > count/B14021_Fm0.txt
agrep -0 -c 'CAATGGGTCGCTCTGAG' *.fastq > count/B14023_Fm0.txt
agrep -0 -c 'AGCTGTAGAATCATCGC' *.fastq > count/B14024_Fm0.txt
agrep -0 -c 'TTCCCTGCGCGATCTTA' *.fastq > count/B14025_Fm0.txt
agrep -0 -c 'CCTTGTTAGGTGCTCAT' *.fastq > count/B14027_Fm0.txt
agrep -0 -c 'TGTGCAGTACGCTAGGA' *.fastq > count/B14028_Fm0.txt
agrep -0 -c 'GGTAGTATGGTAGGCAT' *.fastq > count/B14029_Fm0.txt
agrep -0 -c 'TCAGGTACATTCCGCGA' *.fastq > count/B14030_Fm0.txt
agrep -0 -c 'GCAGTCGTTTTGGCCCA' *.fastq > count/B14032_Fm0.txt
agrep -0 -c 'CACGTGTACAGAGCTGG' *.fastq > count/B14033_Fm0.txt
agrep -0 -c 'TAGTAGTGGTGTGCAGG' *.fastq > count/B14035_Fm0.txt
agrep -0 -c 'CGGGCGAATGATGATGG' *.fastq > count/B14036_Fm0.txt
agrep -0 -c 'ATATACGCCGTGTTATG' *.fastq > count/B14037_Fm0.txt
agrep -0 -c 'TATTTCCTAGCCACATC' *.fastq > count/B14038_Fm0.txt
agrep -0 -c 'CTTATGGCGCACGAACT' *.fastq > count/B14039_Fm0.txt
agrep -0 -c 'TAGAAAATTAACCGGCG' *.fastq > count/B14040_Fm0.txt
agrep -0 -c 'CGTGAGATGACGGATTA' *.fastq > count/B14041_Fm0.txt
agrep -0 -c 'GAGCTATGACGCTCGAT' *.fastq > count/B14042_Fm0.txt
agrep -0 -c 'CTCTAGAACCTAGAAGC' *.fastq > count/B14044_Fm0.txt
agrep -0 -c 'GGGATGCATTGTGACCG' *.fastq > count/B14045_Fm0.txt
agrep -0 -c 'AGACCAACAGCCCAGAT' *.fastq > count/B14046_Fm0.txt
agrep -0 -c 'ATAGCTCACTGCGGAGA' *.fastq > count/B14048_Fm0.txt
agrep -0 -c 'TTCCGGCTACGCAAGAC' *.fastq > count/B14050_Fm0.txt
agrep -0 -c 'GTTGCCCATTCGCAGAT' *.fastq > count/B14051_Fm0.txt
agrep -0 -c 'CCAACAAAGGATGTACT' *.fastq > count/B14052_Fm0.txt
agrep -0 -c 'TCGTCCTGTATCTGTAA' *.fastq > count/B14053_Fm0.txt
agrep -0 -c 'TCGGAACGGGGCTGAAA' *.fastq > count/B14054_Fm0.txt
agrep -0 -c 'ATCTCTGTCTAGTTCGC' *.fastq > count/B14055_Fm0.txt
agrep -0 -c 'TTGGCTCCCTTATATCC' *.fastq > count/B14057_Fm0.txt
agrep -0 -c 'TAATTCCCTCGTGCTAT' *.fastq > count/B14058_Fm0.txt
agrep -0 -c 'CCTGCCTCTAAGTTTTC' *.fastq > count/B14059_Fm0.txt
agrep -0 -c 'GTGTCTTATAAGAACCC' *.fastq > count/B14060_Fm0.txt
agrep -0 -c 'GACATAGCCTCAAGGTC' *.fastq > count/B14061_Fm0.txt
agrep -0 -c 'TCTACCAGACTACATCC' *.fastq > count/B14063_Fm0.txt
agrep -0 -c 'GCCTGACTAGTACGCTC' *.fastq > count/B14064_Fm0.txt
agrep -0 -c 'CATGGGGTTTGGGGTTA' *.fastq > count/B14065_Fm0.txt
agrep -0 -c 'ACGATCACGTGGCACGA' *.fastq > count/B14067_Fm0.txt
agrep -0 -c 'CATAGTTAATCGACCGA' *.fastq > count/B14068_Fm0.txt
agrep -0 -c 'GGTAAACGTAATCAGCA' *.fastq > count/B14069_Fm0.txt
agrep -0 -c 'CATGTCGCAAGCACAGG' *.fastq > count/B14070_Fm0.txt
agrep -0 -c 'CCGGATGCCTCATAGAG' *.fastq > count/B14071_Fm0.txt
agrep -0 -c 'ACGAATTAGGCTACTGC' *.fastq > count/B14072_Fm0.txt
agrep -0 -c 'GTTGTCGATGACACCAT' *.fastq > count/B14073_Fm0.txt
agrep -0 -c 'GTTCTAATCGGATCACC' *.fastq > count/B14074_Fm0.txt
agrep -0 -c 'AACAACTGCGTTGTTCT' *.fastq > count/B14075_Fm0.txt
agrep -0 -c 'TGTCAGTTAGGCTAAAC' *.fastq > count/B14077_Fm0.txt
agrep -0 -c 'TGCGGGTCTATATGATA' *.fastq > count/B14078_Fm0.txt
agrep -0 -c 'CTACACCCCATGCACAA' *.fastq > count/B14079_Fm0.txt
agrep -0 -c 'GCAATAACACACTTCTG' *.fastq > count/B14080_Fm0.txt
agrep -0 -c 'ACGTGAAACCCCAGCGA' *.fastq > count/B14081_Fm0.txt
agrep -0 -c 'GTCGAAACCTGCCAACT' *.fastq > count/B14082_Fm0.txt
agrep -0 -c 'GCTCTCATGAGCCCATG' *.fastq > count/B14083_Fm0.txt
agrep -0 -c 'CTGGAATAAAAGTCAGG' *.fastq > count/B14084_Fm0.txt
agrep -0 -c 'GACTTCTGGGTAGTAAA' *.fastq > count/B14085_Fm0.txt
agrep -0 -c 'TGACCAAGTGTACTGCC' *.fastq > count/B14086_Fm0.txt
agrep -0 -c 'AAGATAAACGAACGTCG' *.fastq > count/B14088_Fm0.txt
agrep -0 -c 'GGCTGTGTTAATGGGAT' *.fastq > count/B14089_Fm0.txt
agrep -0 -c 'TGAAGTAGGTAAGACGC' *.fastq > count/B14090_Fm0.txt
agrep -0 -c 'ACAATCCGTGAATGACT' *.fastq > count/B14092_Fm0.txt
agrep -0 -c 'GCCCAGTTCACAAATAC' *.fastq > count/B14093_Fm0.txt
agrep -0 -c 'CCAGAGAACCTCGCGAT' *.fastq > count/B14094_Fm0.txt
agrep -0 -c 'CGACCCCATTTCGGAAT' *.fastq > count/B14095_Fm0.txt
agrep -0 -c 'CTCCCTACAACGAGCGT' *.fastq > count/B14096_Fm0.txt
agrep -0 -c 'TTCGGACGATGGAGCGT' *.fastq > count/B14097_Fm0.txt
agrep -0 -c 'ACTATCACCGAACTTCA' *.fastq > count/B14098_Fm0.txt
agrep -0 -c 'CTATCCTCCTACTAGCG' *.fastq > count/B14102_Fm0.txt
agrep -0 -c 'GTTCGACGGTATGGGGA' *.fastq > count/B14104_Fm0.txt
agrep -0 -c 'TGCTCTACTGAAACATG' *.fastq > count/B14105_Fm0.txt
agrep -0 -c 'AACGGGTGTATCGTCGT' *.fastq > count/B14107_Fm0.txt
agrep -0 -c 'TGCACCATAAAACCCCG' *.fastq > count/B14108_Fm0.txt
agrep -0 -c 'ATGTACGGCGCGCCTAA' *.fastq > count/B14109_Fm0.txt
agrep -0 -c 'CTCATAGCAAACCTAAC' *.fastq > count/B14110_Fm0.txt
agrep -0 -c 'GTTGCTCGGTGATACGG' *.fastq > count/B14111_Fm0.txt
agrep -0 -c 'ACATCTGGCAATTTGCG' *.fastq > count/B14112_Fm0.txt
agrep -0 -c 'GTTCGTTCGTCGAAATC' *.fastq > count/B14113_Fm0.txt
agrep -0 -c 'TCTACGTCATGACTATC' *.fastq > count/B14114_Fm0.txt
agrep -0 -c 'GTTGAGGAATTAGTAGC' *.fastq > count/B14115_Fm0.txt
agrep -0 -c 'TATGGTTGCAATGCAGA' *.fastq > count/B14116_Fm0.txt
agrep -0 -c 'GGAGAAACGCGATGCGT' *.fastq > count/B14117_Fm0.txt
agrep -0 -c 'TCACTCCAGAAGAGTTC' *.fastq > count/B14118_Fm0.txt
agrep -0 -c 'CTACGGCAGTCTTTTGT' *.fastq > count/B14119_Fm0.txt
agrep -0 -c 'GGGGGTATGCTAGTTAT' *.fastq > count/B14120_Fm0.txt
agrep -0 -c 'ACAGTTTATCCGCTACA' *.fastq > count/B14121_Fm0.txt
agrep -0 -c 'ATGTTAATCGGACTCCC' *.fastq > count/B14122_Fm0.txt
agrep -0 -c 'ACTTATCATGGTACCCC' *.fastq > count/B14123_Fm0.txt
agrep -0 -c 'GGCTGCCATACCTCTTT' *.fastq > count/B14124_Fm0.txt
agrep -0 -c 'ATTGGGGCTCAATAGCT' *.fastq > count/B14125_Fm0.txt
agrep -0 -c 'CTGAGCGTGCCACTTAC' *.fastq > count/B14127_Fm0.txt
agrep -0 -c 'AATTTTCTCAGCAAGCC' *.fastq > count/B14128_Fm0.txt
agrep -0 -c 'ATCGAATCTCACCTCGA' *.fastq > count/B14129_Fm0.txt
agrep -0 -c 'CGCTTGAAGCCTACGTT' *.fastq > count/B14130_Fm0.txt
agrep -0 -c 'GCATGTCTCTAAGCTAT' *.fastq > count/B14131_Fm0.txt
agrep -0 -c 'AATCCGAGAGGGTACTT' *.fastq > count/B14132_Fm0.txt
agrep -0 -c 'TTCTCTCAATCGTCTCG' *.fastq > count/B14133_Fm0.txt
agrep -0 -c 'GTGGGGCGTCTATATAC' *.fastq > count/B14134_Fm0.txt
agrep -0 -c 'TTGAGCCGCCTTTTCGA' *.fastq > count/B14135_Fm0.txt
agrep -0 -c 'GGTCGGGCTGAGACTAT' *.fastq > count/B14137_Fm0.txt
agrep -0 -c 'CCGTTAAAAGTCCCGGC' *.fastq > count/B14138_Fm0.txt
agrep -0 -c 'CTGGACCTACTTCTACT' *.fastq > count/B14139_Fm0.txt
agrep -0 -c 'GCAGTTAGGAGTAGCTG' *.fastq > count/B14140_Fm0.txt
agrep -0 -c 'CTAGCTTGAGTGAGACG' *.fastq > count/B14141_Fm0.txt
agrep -0 -c 'AAGTAGGACTTCGTGAT' *.fastq > count/B14142_Fm0.txt
agrep -0 -c 'ATGGTCCTTTTACGAAG' *.fastq > count/B14143_Fm0.txt
agrep -0 -c 'ATTCGGGGTATCCGATT' *.fastq > count/B14144_Fm0.txt
agrep -0 -c 'TTAGCTGAGATGCGGTC' *.fastq > count/B14147_Fm0.txt
agrep -0 -c 'GCCACATAGGTTGGCAG' *.fastq > count/B14149_Fm0.txt
agrep -0 -c 'AAGTAGCTTTAACCCTC' *.fastq > count/B14150_Fm0.txt
agrep -0 -c 'AGCAAGGGCGATAGAAC' *.fastq > count/B14151_Fm0.txt
agrep -0 -c 'GCATCACCCCTAAGACA' *.fastq > count/B14152_Fm0.txt
agrep -0 -c 'ATATATGAGTAGCGCGA' *.fastq > count/B14153_Fm0.txt
agrep -0 -c 'ACAACCTCGGCCTGTAC' *.fastq > count/B14154_Fm0.txt
agrep -0 -c 'CGGTACAATTCAGTTTG' *.fastq > count/B14155_Fm0.txt
agrep -0 -c 'AGGATTCGAGTTGAGCC' *.fastq > count/B14156_Fm0.txt
agrep -0 -c 'TAGTAGCCTGCATAGAT' *.fastq > count/B14158_Fm0.txt
agrep -0 -c 'TGAGGCTATAAACGTGT' *.fastq > count/B14159_Fm0.txt
agrep -0 -c 'AGGGTCGCATTCTACAA' *.fastq > count/B14160_Fm0.txt
agrep -0 -c 'AAGCACCCCGCTCTACT' *.fastq > count/B14162_Fm0.txt
agrep -0 -c 'TTGCGACGAGCAAGTAC' *.fastq > count/B14163_Fm0.txt
agrep -0 -c 'CTGAAGAGCGTAACTCG' *.fastq > count/B14164_Fm0.txt
agrep -0 -c 'GTGCGAAGAGATGAACG' *.fastq > count/B14165_Fm0.txt
agrep -0 -c 'ACCAGATCGCGGATTGC' *.fastq > count/B14166_Fm0.txt
agrep -0 -c 'AGACCTCGTCAATAATG' *.fastq > count/B14167_Fm0.txt
agrep -0 -c 'GTGGTCGGTCGTTTTCA' *.fastq > count/B14168_Fm0.txt
agrep -0 -c 'TACTCTCACTTTCAGCA' *.fastq > count/B14169_Fm0.txt
agrep -0 -c 'AGTCAGAACCGATATCT' *.fastq > count/B14170_Fm0.txt
agrep -0 -c 'ACGGATACAGCTAATCC' *.fastq > count/B14171_Fm0.txt
agrep -0 -c 'GGATTTCATCGATCTCC' *.fastq > count/B14172_Fm0.txt
agrep -0 -c 'TATGCAGCTCTAGAGGT' *.fastq > count/B14173_Fm0.txt
agrep -0 -c 'GCCGCTTAGGTTAGCAT' *.fastq > count/B14175_Fm0.txt
agrep -0 -c 'CAGGATCGAACCAGTTG' *.fastq > count/B14176_Fm0.txt
agrep -0 -c 'GGCGAAAGGTTGCTCGA' *.fastq > count/B14177_Fm0.txt
agrep -0 -c 'GTAATGACTGCGAATGA' *.fastq > count/B14178_Fm0.txt
agrep -0 -c 'AGCTTTCGGAAAGCAGC' *.fastq > count/B14179_Fm0.txt
agrep -0 -c 'GTGGTTGATTCCTTCTC' *.fastq > count/B14180_Fm0.txt
agrep -0 -c 'TAGATGCTACCACCTAG' *.fastq > count/B14181_Fm0.txt
agrep -0 -c 'AGGACCCCTTTAGGCAT' *.fastq > count/B14182_Fm0.txt
agrep -0 -c 'GTGAACCTACGTCTATG' *.fastq > count/B14184_Fm0.txt
agrep -0 -c 'TGACGTCGAAATCGAAT' *.fastq > count/B14185_Fm0.txt
agrep -0 -c 'TGCACGATCGAGTAGGT' *.fastq > count/B14186_Fm0.txt
agrep -0 -c 'CGACAAGACCACTGGAT' *.fastq > count/B14187_Fm0.txt
agrep -0 -c 'CGCATACTTTAAGTGCT' *.fastq > count/B14188_Fm0.txt
agrep -0 -c 'GTGGCCTCCTTGATTCC' *.fastq > count/B14190_Fm0.txt
agrep -0 -c 'TGATCGCTCGTAACGCG' *.fastq > count/B14191_Fm0.txt
agrep -0 -c 'TAATGGCCGGATTCAAC' *.fastq > count/B14192_Fm0.txt
agrep -0 -c 'CCATTTCGCTCAGCCTG' *.fastq > count/B14193_Fm0.txt
agrep -0 -c 'CCATAACTCTGAATGGA' *.fastq > count/B14194_Fm0.txt
agrep -0 -c 'AGGATGCCCTAGGATTC' *.fastq > count/B14196_Fm0.txt
agrep -0 -c 'AGGCTCATACGAAGTGT' *.fastq > count/B14197_Fm0.txt
agrep -0 -c 'GGATCTCGCTCCAGAAC' *.fastq > count/B14198_Fm0.txt
agrep -0 -c 'GGTATATAAGACCGGAC' *.fastq > count/B14199_Fm0.txt
agrep -0 -c 'GTAACCAGTCTGGGTGC' *.fastq > count/B14200_Fm0.txt
agrep -0 -c 'AACAGGGCTGATCCTTG' *.fastq > count/B14201_Fm0.txt
agrep -0 -c 'ATCCCTGATCTATACCT' *.fastq > count/B14202_Fm0.txt
agrep -0 -c 'GTCCTGGGAAAAACATG' *.fastq > count/B14203_Fm0.txt
agrep -0 -c 'ACCAGGGATATTGCGAG' *.fastq > count/B14204_Fm0.txt
agrep -0 -c 'CTACAGAAGTACGTGCG' *.fastq > count/B14205_Fm0.txt
agrep -0 -c 'TCAAAACGTTTGACAGC' *.fastq > count/B14206_Fm0.txt
agrep -0 -c 'TGTATAAATAGTCGGGG' *.fastq > count/B14207_Fm0.txt
agrep -0 -c 'TGATCTACCGGGTTATG' *.fastq > count/B14208_Fm0.txt
agrep -0 -c 'TCTCTTCATCTGCGGGA' *.fastq > count/B14209_Fm0.txt
agrep -0 -c 'AAGTGGTTAACCGACGT' *.fastq > count/B14210_Fm0.txt
agrep -0 -c 'GTCGGTCGGTTATAAAA' *.fastq > count/B14211_Fm0.txt
agrep -0 -c 'TCTCTTTAGAGCACGCG' *.fastq > count/B14212_Fm0.txt
agrep -0 -c 'ACCTGTACTCCGGATCG' *.fastq > count/B14213_Fm0.txt
agrep -0 -c 'TTCTAATCCACCCCTCG' *.fastq > count/B14214_Fm0.txt
agrep -0 -c 'CTCAGCTTTAAGTTCGC' *.fastq > count/B14215_Fm0.txt
agrep -0 -c 'ATACCATCCATCAAGTG' *.fastq > count/B14216_Fm0.txt
agrep -0 -c 'TCATGAGTTACCAGTGA' *.fastq > count/B14217_Fm0.txt
agrep -0 -c 'TAGTCTGTACCATCCGC' *.fastq > count/B14218_Fm0.txt
agrep -0 -c 'CTACGTACATACTGACA' *.fastq > count/B14219_Fm0.txt
agrep -0 -c 'AGTCCAGAACGAGCGAG' *.fastq > count/B14220_Fm0.txt
agrep -0 -c 'TCGCCTGTATGGTCCAA' *.fastq > count/B14221_Fm0.txt
agrep -0 -c 'TAGGGAGACTGACACCC' *.fastq > count/B14223_Fm0.txt
agrep -0 -c 'GGTTGCGGTAAAGGCAT' *.fastq > count/B14224_Fm0.txt
agrep -0 -c 'AGGCGCATCACGAGTTG' *.fastq > count/B14225_Fm0.txt
agrep -0 -c 'AATAGGATTCTCAGGCC' *.fastq > count/B14226_Fm0.txt
agrep -0 -c 'CCGTCATCCTTGGATGA' *.fastq > count/B14227_Fm0.txt
agrep -0 -c 'GATTGGGAGCACTACAC' *.fastq > count/B14228_Fm0.txt
agrep -0 -c 'CGTCGGGTCACAGTAAA' *.fastq > count/B14229_Fm0.txt
agrep -0 -c 'GACGTCTGAGTCAAGAG' *.fastq > count/B14230_Fm0.txt
agrep -0 -c 'TAATCAGTCGACCCTAC' *.fastq > count/B14231_Fm0.txt
agrep -0 -c 'TTAATTTGCGGCCGCTC' *.fastq > count/B14233_Fm0.txt
agrep -0 -c 'TCGCACGATCGAAATAC' *.fastq > count/B14235_Fm0.txt
agrep -0 -c 'CGTCGTAGCCCGTTTGA' *.fastq > count/B14236_Fm0.txt
agrep -0 -c 'GTACTCGCCCTAAAGCA' *.fastq > count/B14238_Fm0.txt
agrep -0 -c 'CTACATGACACAACACG' *.fastq > count/B14239_Fm0.txt
agrep -0 -c 'ACATGCCAAAACCCGAT' *.fastq > count/B14240_Fm0.txt
agrep -0 -c 'AACCGGAACTGACAAAT' *.fastq > count/B14241_Fm0.txt
agrep -0 -c 'AACAGTACGCTGATTGT' *.fastq > count/B14242_Fm0.txt
agrep -0 -c 'GCGTGACAGATAAGTCT' *.fastq > count/B14244_Fm0.txt
agrep -0 -c 'TAGAGATATCTGGCACC' *.fastq > count/B14245_Fm0.txt
agrep -0 -c 'TGCCAAGCCCCACATTG' *.fastq > count/B14247_Fm0.txt
agrep -0 -c 'CGTAAGATGATGGTGTG' *.fastq > count/B14248_Fm0.txt
agrep -0 -c 'ATGGTAAGACTAGCGTT' *.fastq > count/B14249_Fm0.txt
agrep -0 -c 'CCGCAAGTCTTATTCCT' *.fastq > count/B14250_Fm0.txt
agrep -0 -c 'TAAAGGCCAACGCGAAC' *.fastq > count/B14252_Fm0.txt
agrep -0 -c 'GCTCACAGACCGTGTGT' *.fastq > count/B14253_Fm0.txt
agrep -0 -c 'ATGTAGATGGTGCGTTA' *.fastq > count/B14254_Fm0.txt
agrep -0 -c 'GATCGATCTTTCCTGGT' *.fastq > count/B14255_Fm0.txt
agrep -0 -c 'CACTATCGGAGAGCATT' *.fastq > count/B14256_Fm0.txt
agrep -0 -c 'GGCTACTAAGGTCGTCT' *.fastq > count/B14258_Fm0.txt
agrep -0 -c 'TCTTGCAAGTTCGCATT' *.fastq > count/B14259_Fm0.txt
agrep -0 -c 'CTTGGGTTTCGATCTCC' *.fastq > count/B14260_Fm0.txt
agrep -0 -c 'TCAACGGGTACGGACCA' *.fastq > count/B14261_Fm0.txt
agrep -0 -c 'TGTTAGCCCGGAAGCCA' *.fastq > count/B14262_Fm0.txt
agrep -0 -c 'ACAAACCGGGAAGAGAC' *.fastq > count/B14263_Fm0.txt
agrep -0 -c 'TTGTGGTCTTACGCTCC' *.fastq > count/B14264_Fm0.txt
agrep -0 -c 'CAGAGGTTGCTAAAGGT' *.fastq > count/B14265_Fm0.txt
agrep -0 -c 'CACAATCGCATGTTGAC' *.fastq > count/B14266_Fm0.txt
agrep -0 -c 'GCTATGAGCAACGTACC' *.fastq > count/B14267_Fm0.txt
agrep -0 -c 'GCCTGACTCGCCATACA' *.fastq > count/B14269_Fm0.txt
agrep -0 -c 'TCATAACAACTGGGGGT' *.fastq > count/B14270_Fm0.txt
agrep -0 -c 'GGGTCTCCGAAACTGTA' *.fastq > count/B14271_Fm0.txt
agrep -0 -c 'CAGGCCTTGTAGAGATC' *.fastq > count/B14272_Fm0.txt
agrep -0 -c 'CGATAGAACGAATTAGC' *.fastq > count/B14273_Fm0.txt
agrep -0 -c 'AATGGCCTTATGACGGT' *.fastq > count/B14275_Fm0.txt
agrep -0 -c 'GCAAACCTACTGGGCTG' *.fastq > count/B14276_Fm0.txt
agrep -0 -c 'GTCCGTTGCAATTATCT' *.fastq > count/B14277_Fm0.txt
agrep -0 -c 'ACTACGTTTCTGCGGTA' *.fastq > count/B14278_Fm0.txt
agrep -0 -c 'AGACAAAGTGGGACGCC' *.fastq > count/B14279_Fm0.txt
agrep -0 -c 'ACCTTGAGCGGGGATTT' *.fastq > count/B14280_Fm0.txt
agrep -0 -c 'CGAGGATTATTCCTAGC' *.fastq > count/B14281_Fm0.txt
agrep -0 -c 'GTGAACGAAAGCGGACC' *.fastq > count/B14282_Fm0.txt
agrep -0 -c 'CCAATCTCGGACGGTGT' *.fastq > count/B14283_Fm0.txt
agrep -0 -c 'CCGCTGCGTTACATCCT' *.fastq > count/B14284_Fm0.txt
agrep -0 -c 'GTTTAGAGGCACGGGTG' *.fastq > count/B14285_Fm0.txt
agrep -0 -c 'CACAAACGTCCAACAGA' *.fastq > count/B14286_Fm0.txt
agrep -0 -c 'ATTGCACCTTCTTACAG' *.fastq > count/B14288_Fm0.txt
agrep -0 -c 'CCTAGGCAACATGCTGT' *.fastq > count/B14289_Fm0.txt
agrep -0 -c 'TAGCACTAATCGTGCCT' *.fastq > count/B14290_Fm0.txt
agrep -0 -c 'AGCTGTGAAGACATCGG' *.fastq > count/B14291_Fm0.txt
agrep -0 -c 'CTATGTACTGATGCTCT' *.fastq > count/B14292_Fm0.txt
agrep -0 -c 'CCAAGACGACCCTAAGG' *.fastq > count/B14294_Fm0.txt
agrep -0 -c 'GCAGCCGTTAGCACCAT' *.fastq > count/B14295_Fm0.txt
agrep -0 -c 'AGCCCTTGACAGTGAAT' *.fastq > count/B14297_Fm0.txt
agrep -0 -c 'GGATCCACAACGACGAA' *.fastq > count/B14298_Fm0.txt
agrep -0 -c 'GGATAGTTTAGCGACCC' *.fastq > count/B14299_Fm0.txt
agrep -0 -c 'TCGATTTGTCAAACCAG' *.fastq > count/B14300_Fm0.txt
agrep -0 -c 'ATCGAGAGTTAATGCGA' *.fastq > count/B14302_Fm0.txt
agrep -0 -c 'AATCTAAGGATGCGCTG' *.fastq > count/B14303_Fm0.txt
agrep -0 -c 'ATCGCTGATTTGCCTGG' *.fastq > count/B14305_Fm0.txt
agrep -0 -c 'GCAACTCTGAGTCAACA' *.fastq > count/B14306_Fm0.txt
agrep -0 -c 'AAGTGCTTGGTGTCCGA' *.fastq > count/B14307_Fm0.txt
agrep -0 -c 'AATGGGACTTTGATCGC' *.fastq > count/B14308_Fm0.txt
agrep -0 -c 'AGGTGTAAGCAACAGGT' *.fastq > count/B14309_Fm0.txt
agrep -0 -c 'AAGGGCGTGTAGCGTAG' *.fastq > count/B14310_Fm0.txt
agrep -0 -c 'AGCTATCCTTGGTCTTC' *.fastq > count/B14311_Fm0.txt
agrep -0 -c 'TTGATCGTGGCCTCAAG' *.fastq > count/B14312_Fm0.txt
agrep -0 -c 'CACTAGGCCATTGCACG' *.fastq > count/B14314_Fm0.txt
agrep -0 -c 'TCTTAACGTAGGACCCA' *.fastq > count/B14315_Fm0.txt
agrep -0 -c 'CGTAGCCTTCTTTCAGC' *.fastq > count/B14316_Fm0.txt
agrep -0 -c 'ACCGGTGCCATTACCTG' *.fastq > count/B14318_Fm0.txt
agrep -0 -c 'TGCCCAAACGGTATAAA' *.fastq > count/B14319_Fm0.txt
agrep -0 -c 'TTCGGGATTCATGTAGC' *.fastq > count/B14321_Fm0.txt
agrep -0 -c 'ACCGTAACCCGCTTGAC' *.fastq > count/B14322_Fm0.txt
agrep -0 -c 'AATCACCCGAGTAAGAC' *.fastq > count/B14324_Fm0.txt
agrep -0 -c 'CAAGCCCACTGCCTACA' *.fastq > count/B14325_Fm0.txt
agrep -0 -c 'ATCATCAACAGGGAACG' *.fastq > count/B14326_Fm0.txt
agrep -0 -c 'ACAACTGATCAGGTACC' *.fastq > count/B14327_Fm0.txt
agrep -0 -c 'TCGTTTATGTAGGGTTG' *.fastq > count/B14330_Fm0.txt
agrep -0 -c 'GGACTTCTCAGATTAGG' *.fastq > count/B14331_Fm0.txt
agrep -0 -c 'GGAGGGAGTATTTTTCT' *.fastq > count/B14332_Fm0.txt
agrep -0 -c 'ACAAGACTACCTCTAAC' *.fastq > count/B14333_Fm0.txt
agrep -0 -c 'GGTTCACCTGGATTTTA' *.fastq > count/B14335_Fm0.txt
agrep -0 -c 'CATACGCGTCGAAAATA' *.fastq > count/B14336_Fm0.txt
agrep -0 -c 'CAGTCTAGGTATACAGA' *.fastq > count/B14337_Fm0.txt
agrep -0 -c 'GTTCTGAGAGGGGGGTA' *.fastq > count/B14338_Fm0.txt
agrep -0 -c 'GGGACGCACTCACCATA' *.fastq > count/B14339_Fm0.txt
agrep -0 -c 'TGTCGAAGTATCTGGAA' *.fastq > count/B14340_Fm0.txt
agrep -0 -c 'CTGGGGTCAATAACGAT' *.fastq > count/B14341_Fm0.txt
agrep -0 -c 'GCACATAAGGCTCATGG' *.fastq > count/B14342_Fm0.txt
agrep -0 -c 'CGGATGTCCCGATTAGA' *.fastq > count/B14343_Fm0.txt
agrep -0 -c 'CGCTTAGTGGATGTAAA' *.fastq > count/B14344_Fm0.txt
agrep -0 -c 'ATCAGGCGACGTCACTG' *.fastq > count/B14345_Fm0.txt
agrep -0 -c 'AACGTATGACTGGTGTA' *.fastq > count/B14346_Fm0.txt
agrep -0 -c 'GTATGTACGTCGAGCCT' *.fastq > count/B14347_Fm0.txt
agrep -0 -c 'TAGCTGTGAGCCTAGCG' *.fastq > count/B14349_Fm0.txt
agrep -0 -c 'AGCTCCCATGGCTCGTT' *.fastq > count/B14350_Fm0.txt
agrep -0 -c 'AGGTCCAATGTATGGAA' *.fastq > count/B14352_Fm0.txt
agrep -0 -c 'CATTGCTTCACTTGCAC' *.fastq > count/B14353_Fm0.txt
agrep -0 -c 'AATGCGTTGTACACAAC' *.fastq > count/B14354_Fm0.txt
agrep -0 -c 'CATAAGACACGTTCCTC' *.fastq > count/B14355_Fm0.txt
agrep -0 -c 'GCGACAGGTTGACTAAA' *.fastq > count/B14357_Fm0.txt
agrep -0 -c 'TAACACCACCTAGCCGT' *.fastq > count/B14358_Fm0.txt
agrep -0 -c 'AGATTGGGAGTACAGAT' *.fastq > count/B14359_Fm0.txt
agrep -0 -c 'AGACTAGAACCGACCCA' *.fastq > count/B14360_Fm0.txt
agrep -0 -c 'GCGCGATAAAGGCAATA' *.fastq > count/B14361_Fm0.txt
agrep -0 -c 'ATTTGCATTCGGGGACC' *.fastq > count/B14362_Fm0.txt
agrep -0 -c 'CACGTCCGATGAAACTC' *.fastq > count/B14363_Fm0.txt
agrep -0 -c 'TGTGGTGACCCGAATCT' *.fastq > count/B14364_Fm0.txt
agrep -0 -c 'CTGGCTCTTTTTTCGCG' *.fastq > count/B14365_Fm0.txt
agrep -0 -c 'TTATCGTGGGAGACGTC' *.fastq > count/B14366_Fm0.txt
agrep -0 -c 'CATGGAGAACGGTCACG' *.fastq > count/B14367_Fm0.txt
agrep -0 -c 'GGAACTGCGTCAGTGAC' *.fastq > count/B14368_Fm0.txt
agrep -0 -c 'CTGTCGAGCGGATTAAC' *.fastq > count/B14369_Fm0.txt
agrep -0 -c 'GGTAGGTCGGAATAGAT' *.fastq > count/B14370_Fm0.txt
agrep -0 -c 'TCGGTATGCAGAACCGC' *.fastq > count/B14371_Fm0.txt
agrep -0 -c 'GGCTTGTAAGCGCGATT' *.fastq > count/B14372_Fm0.txt
agrep -0 -c 'TAGGCGCACTACGTGAG' *.fastq > count/B14373_Fm0.txt
agrep -0 -c 'AACCATGGAAAATGCCC' *.fastq > count/B14374_Fm0.txt
agrep -0 -c 'CTCGCCTAGTAGGTACT' *.fastq > count/B14375_Fm0.txt
agrep -0 -c 'TTACATTCTCGGAGCTG' *.fastq > count/B14377_Fm0.txt
agrep -0 -c 'GGTACAGACATGTATTG' *.fastq > count/B14378_Fm0.txt
agrep -0 -c 'ATTACCGGCTTGTCAAT' *.fastq > count/B14380_Fm0.txt
agrep -0 -c 'TCAAGCCAGTCTCGGTT' *.fastq > count/B14381_Fm0.txt
agrep -0 -c 'ATTCCACACCTTTGTCC' *.fastq > count/B14383_Fm0.txt
agrep -0 -c 'TTATGTCCAGGTGCGGT' *.fastq > count/B14384_Fm0.txt
agrep -0 -c 'AGGCCTAAGGTTTATGT' *.fastq > count/B14385_Fm0.txt
agrep -0 -c 'AGAAGGTAAACTGGCTG' *.fastq > count/B14386_Fm0.txt
agrep -0 -c 'AGTTGCAATCCTTACGC' *.fastq > count/B14387_Fm0.txt
agrep -0 -c 'TTCAAGACATCTCCCAA' *.fastq > count/B14388_Fm0.txt
agrep -0 -c 'GATCTATAGAGGAGGCT' *.fastq > count/B14390_Fm0.txt
agrep -0 -c 'TGCTTGTTCGGCATCAG' *.fastq > count/B14391_Fm0.txt
agrep -0 -c 'AGGCTGACAGCGAGTTA' *.fastq > count/B14392_Fm0.txt
agrep -0 -c 'CGTATAACAGCTCGTAC' *.fastq > count/B14393_Fm0.txt
agrep -0 -c 'CTGTTATACCCTAGCCA' *.fastq > count/B14394_Fm0.txt
agrep -0 -c 'GACGCGCTATCCACGTA' *.fastq > count/B14395_Fm0.txt
agrep -0 -c 'CGAGTTAAGCGTCTCCA' *.fastq > count/B14396_Fm0.txt
agrep -0 -c 'TTCAACGTCCGTGAGAG' *.fastq > count/B14397_Fm0.txt
agrep -0 -c 'ATATGGCTCTTGAAGCA' *.fastq > count/B14398_Fm0.txt
agrep -0 -c 'ACTGGACAGCGCAACTC' *.fastq > count/B14399_Fm0.txt
agrep -0 -c 'GTATTGATGGGACCCGG' *.fastq > count/B14400_Fm0.txt
agrep -0 -c 'AGTGAAGTTCCCGACGT' *.fastq > count/B14401_Fm0.txt
agrep -0 -c 'GCAGAACCGGCGAGTAA' *.fastq > count/B14402_Fm0.txt
agrep -0 -c 'TCAACCTAGATGGTCTC' *.fastq > count/B14403_Fm0.txt
agrep -0 -c 'TGTGTTTGTTGTCGGTC' *.fastq > count/B14404_Fm0.txt
agrep -0 -c 'TATTAGAAGCGCCTACA' *.fastq > count/B14405_Fm0.txt
agrep -0 -c 'CGAGGTTGCCGAGTAAC' *.fastq > count/B14406_Fm0.txt
agrep -0 -c 'ATGTACGCTAGACGATC' *.fastq > count/B14407_Fm0.txt
agrep -0 -c 'CGAGCTCCATCCGAGAT' *.fastq > count/B14408_Fm0.txt
agrep -0 -c 'CTATCCAAGCGAGGTCT' *.fastq > count/B14409_Fm0.txt
agrep -0 -c 'TGTTTCGCATTATAGGC' *.fastq > count/B14410_Fm0.txt
agrep -0 -c 'GTAATCGTCATGGCGGT' *.fastq > count/B14411_Fm0.txt
agrep -0 -c 'GGATCGTGTGTAGAATG' *.fastq > count/B14412_Fm0.txt
agrep -0 -c 'TCTATAACTCCTCTGGC' *.fastq > count/B14413_Fm0.txt
agrep -0 -c 'TACCCCACACTAATGTT' *.fastq > count/B14414_Fm0.txt
agrep -0 -c 'TGTCTATGCACCTTATG' *.fastq > count/B14415_Fm0.txt
agrep -0 -c 'CGAAACCACACCGACAA' *.fastq > count/B14417_Fm0.txt
agrep -0 -c 'ATATTGGGCAATGCGAC' *.fastq > count/B14418_Fm0.txt
agrep -0 -c 'GTGAACAACCGTTAGAT' *.fastq > count/B14419_Fm0.txt
agrep -0 -c 'CGATGCACTCCAATCCC' *.fastq > count/B14420_Fm0.txt
agrep -0 -c 'CCACCCTGCACGCTTTA' *.fastq > count/B14422_Fm0.txt
agrep -0 -c 'CTGCGCATTACATCAAC' *.fastq > count/B14425_Fm0.txt
agrep -0 -c 'CGTATGGAACACTACCA' *.fastq > count/B14426_Fm0.txt
agrep -0 -c 'ATCCGGACATATGCGAG' *.fastq > count/B14427_Fm0.txt
agrep -0 -c 'CCGGTACAAAATAAACC' *.fastq > count/B14428_Fm0.txt
agrep -0 -c 'TTCGAAGAACCCTGCGT' *.fastq > count/B14429_Fm0.txt
agrep -0 -c 'ATAGTCCTGCGGGTCAC' *.fastq > count/B14430_Fm0.txt
agrep -0 -c 'AACGCCAGTCATCGATG' *.fastq > count/B14431_Fm0.txt
agrep -0 -c 'GCGCGAATACATATCCC' *.fastq > count/B14432_Fm0.txt
agrep -0 -c 'TGTCTAGCTGGATAAGC' *.fastq > count/B14433_Fm0.txt
agrep -0 -c 'AAGCTCGCCGAAAACGA' *.fastq > count/B14434_Fm0.txt
agrep -0 -c 'GCTCTCTCGTCATGACC' *.fastq > count/B14435_Fm0.txt
agrep -0 -c 'GTAGAGGCTACCTCCTA' *.fastq > count/B14436_Fm0.txt
agrep -0 -c 'TCGTACTCCAAGAATCT' *.fastq > count/B14440_Fm0.txt
agrep -0 -c 'GCACTTAAGCGTCTACA' *.fastq > count/B14441_Fm0.txt
agrep -0 -c 'ACGACTAAAGGATCGAA' *.fastq > count/B14442_Fm0.txt
agrep -0 -c 'TGCCCGTGAATATGGCT' *.fastq > count/B14443_Fm0.txt
agrep -0 -c 'TAGTCCAATAGTGGCGT' *.fastq > count/B14444_Fm0.txt
agrep -0 -c 'GTGGTCCTACCCTGATG' *.fastq > count/B14445_Fm0.txt
agrep -0 -c 'GCTGGGTTTCGGTTATC' *.fastq > count/B14446_Fm0.txt
agrep -0 -c 'GGGTAATTCTTACGCTA' *.fastq > count/B14447_Fm0.txt
agrep -0 -c 'TCGGGTACTATACCTGT' *.fastq > count/B14449_Fm0.txt
agrep -0 -c 'CACTGATCGACCCTCTT' *.fastq > count/B14450_Fm0.txt
agrep -0 -c 'AGTTCGGAAGGGGGAGA' *.fastq > count/B14451_Fm0.txt
agrep -0 -c 'TCGTCTGTAGTCCTATC' *.fastq > count/B14453_Fm0.txt
agrep -0 -c 'TCGTATCGGCATAGGAC' *.fastq > count/B14454_Fm0.txt
agrep -0 -c 'AGGTTAGCACATTGGGG' *.fastq > count/B14457_Fm0.txt
agrep -0 -c 'TGAACAACCCCAAGCCG' *.fastq > count/B14458_Fm0.txt
agrep -0 -c 'TTGCTAACTAGGGATGT' *.fastq > count/B14459_Fm0.txt
agrep -0 -c 'TATTCGTTGATACCGCT' *.fastq > count/B14461_Fm0.txt
agrep -0 -c 'GGACTGACATGAACTCG' *.fastq > count/B14462_Fm0.txt
agrep -0 -c 'AGAGCTAGCTGCGCACT' *.fastq > count/B14463_Fm0.txt
agrep -0 -c 'ATGTACACCTGGCTCCC' *.fastq > count/B14464_Fm0.txt
agrep -0 -c 'TTCGAACCGACTGGAAG' *.fastq > count/B14465_Fm0.txt
agrep -0 -c 'ATCTCACCGAAAGTTAC' *.fastq > count/B14466_Fm0.txt
agrep -0 -c 'TTAAACAGCCGAAGCTG' *.fastq > count/B14467_Fm0.txt
agrep -0 -c 'GCTCCGCTAAAAGGTCG' *.fastq > count/B14469_Fm0.txt
agrep -0 -c 'CCTGTCTGACGTACGTT' *.fastq > count/B14470_Fm0.txt
agrep -0 -c 'ACCCACCGAGCCAAACA' *.fastq > count/B14471_Fm0.txt
agrep -0 -c 'GGCCAGACTTTAGTGGT' *.fastq > count/B14472_Fm0.txt
agrep -0 -c 'GTAAGGATCCCACGCTC' *.fastq > count/B14474_Fm0.txt
agrep -0 -c 'TGTCTCTACCAGGTGGC' *.fastq > count/B14475_Fm0.txt
agrep -0 -c 'TAACACGGACCCTTTGC' *.fastq > count/B14476_Fm0.txt
agrep -0 -c 'AGAAAGGAGGCGCCGTT' *.fastq > count/B14477_Fm0.txt
agrep -0 -c 'GGAGAGTCCCTGAACAG' *.fastq > count/B14478_Fm0.txt
agrep -0 -c 'ACTGACTACCAGCGGAC' *.fastq > count/B14479_Fm0.txt
agrep -0 -c 'CGATGGTGCTCTAATAC' *.fastq > count/B14481_Fm0.txt
agrep -0 -c 'ACGAGATAAACTGAACC' *.fastq > count/B14482_Fm0.txt
agrep -0 -c 'CCAGCTACGATTTGATA' *.fastq > count/B14483_Fm0.txt
agrep -0 -c 'GGATGGTACATCACGCC' *.fastq > count/B14485_Fm0.txt
agrep -0 -c 'CCAACTAGCGTTGGTAT' *.fastq > count/B14486_Fm0.txt
agrep -0 -c 'CACCCTTTGGCAACCGA' *.fastq > count/B14487_Fm0.txt
agrep -0 -c 'CTTGATCTGCAATACGT' *.fastq > count/B14488_Fm0.txt
agrep -0 -c 'CTAGATTCTGTGCTGCT' *.fastq > count/B14489_Fm0.txt
agrep -0 -c 'AGTACACCGAATGTAAG' *.fastq > count/B14491_Fm0.txt
agrep -0 -c 'TAGCCCCTAAATCGCAG' *.fastq > count/B14494_Fm0.txt
agrep -0 -c 'CACTGTGAGACGTCTAA' *.fastq > count/B14495_Fm0.txt
agrep -0 -c 'CCTGATCCTCCCGAAAG' *.fastq > count/B14497_Fm0.txt
agrep -0 -c 'TTAGGCTCTCGGGTGTC' *.fastq > count/B14500_Fm0.txt
agrep -0 -c 'TGCGTGAAACGTGCACC' *.fastq > count/B14501_Fm0.txt
agrep -0 -c 'CTCCAAGTACACGTAAT' *.fastq > count/B14502_Fm0.txt
agrep -0 -c 'CAGAGCTCACTCCCACT' *.fastq > count/B14504_Fm0.txt
agrep -0 -c 'TATGGATCAACTGACGA' *.fastq > count/B14505_Fm0.txt
agrep -0 -c 'AGGAGCACTCAAAAGTC' *.fastq > count/B14506_Fm0.txt
agrep -0 -c 'GTGGTATTGTGGATGGG' *.fastq > count/B14509_Fm0.txt
agrep -0 -c 'GAGGACGAGTTGAGGGT' *.fastq > count/B14511_Fm0.txt
agrep -0 -c 'TTGGTGTGCAATAGGCT' *.fastq > count/B14512_Fm0.txt
agrep -0 -c 'TCAACGCCAGCGGCATA' *.fastq > count/B14513_Fm0.txt
agrep -0 -c 'TTGTCTACAAACGGATG' *.fastq > count/B14514_Fm0.txt
agrep -0 -c 'GCGAGAACGCCGAAGTA' *.fastq > count/B14515_Fm0.txt
agrep -0 -c 'ATGACTCCGTGCATGCA' *.fastq > count/B14516_Fm0.txt
agrep -0 -c 'TTCTCTTAGCTCCTGGT' *.fastq > count/B14517_Fm0.txt
agrep -0 -c 'CACAAACCCGTAACCAC' *.fastq > count/B14518_Fm0.txt
agrep -0 -c 'ATTTAACTGTAAGCGGC' *.fastq > count/B14519_Fm0.txt
agrep -0 -c 'AATCGCACCCGACGTAC' *.fastq > count/B14521_Fm0.txt
agrep -0 -c 'TCGGGTGAGAGTAGAAC' *.fastq > count/B14522_Fm0.txt
agrep -0 -c 'ATAATGACCCCGATGAA' *.fastq > count/B14524_Fm0.txt
agrep -0 -c 'CTAAGTGGATTTCCCGT' *.fastq > count/B14525_Fm0.txt
agrep -0 -c 'CCAAGGTTTTCGCACCC' *.fastq > count/B14526_Fm0.txt
agrep -0 -c 'TAAACTAGTGGTAACGG' *.fastq > count/B14527_Fm0.txt
agrep -0 -c 'AATCGAGGGACTACGAC' *.fastq > count/B14528_Fm0.txt
agrep -0 -c 'TTCGTTGAACGTCCAGC' *.fastq > count/B14530_Fm0.txt
agrep -0 -c 'GGCAATTGAATTCAGCC' *.fastq > count/B14532_Fm0.txt
agrep -0 -c 'AGCTCGAACACCAATGA' *.fastq > count/B14533_Fm0.txt
agrep -0 -c 'AGGCTAACCGGGTATGT' *.fastq > count/B14534_Fm0.txt
agrep -0 -c 'ATTATAGGGCTTTCTCC' *.fastq > count/B14535_Fm0.txt
agrep -0 -c 'GATATAGCCGTGGTCGC' *.fastq > count/B14536_Fm0.txt
agrep -0 -c 'CACTGCTCTACCATATG' *.fastq > count/B14537_Fm0.txt
agrep -0 -c 'AGCCGTTCTAGGAGGTA' *.fastq > count/B14538_Fm0.txt
agrep -0 -c 'CTTCCCTCGCTTACCTA' *.fastq > count/B14539_Fm0.txt
agrep -0 -c 'GCAAACGGTAGTGTTTT' *.fastq > count/B14540_Fm0.txt
agrep -0 -c 'GAGTCGAAACGGCACTA' *.fastq > count/B14541_Fm0.txt
agrep -0 -c 'GATCGTCGCCTTTGCTT' *.fastq > count/B14542_Fm0.txt
agrep -0 -c 'GATCGAACGGACGGACA' *.fastq > count/B14543_Fm0.txt
agrep -0 -c 'TCATTCGATGGTTGCTT' *.fastq > count/B14545_Fm0.txt
agrep -0 -c 'CAGGTCTCCTATTCGAT' *.fastq > count/B14546_Fm0.txt
agrep -0 -c 'CCAGCGGCATCTGAATA' *.fastq > count/B14547_Fm0.txt
agrep -0 -c 'TATGACGAGTGCCTCAA' *.fastq > count/B14548_Fm0.txt
agrep -0 -c 'CCATTAACGGAATCCTC' *.fastq > count/B14549_Fm0.txt
agrep -0 -c 'GACAAGGGTGGGCTCTT' *.fastq > count/B14550_Fm0.txt
agrep -0 -c 'ACGTGGTCCTTTCAAAG' *.fastq > count/B14551_Fm0.txt
agrep -0 -c 'GTCCCGTACACAATGCC' *.fastq > count/B14552_Fm0.txt
agrep -0 -c 'TACCGCTGGACCCTCAA' *.fastq > count/B14553_Fm0.txt
agrep -0 -c 'ACTACGCCTTATTAGTG' *.fastq > count/B14554_Fm0.txt
agrep -0 -c 'GACTGATGCTTACAGCC' *.fastq > count/B14555_Fm0.txt
agrep -0 -c 'GTTACGACAACTCGTCT' *.fastq > count/B14556_Fm0.txt
agrep -0 -c 'CCGCTTTGTCCGTTGAG' *.fastq > count/B14557_Fm0.txt
agrep -0 -c 'GTGCCTCACGAGATAAT' *.fastq > count/B14558_Fm0.txt
agrep -0 -c 'GCACCCACATATCGTAG' *.fastq > count/B14559_Fm0.txt
agrep -0 -c 'CAAACTGGCTTGCTTGT' *.fastq > count/B14561_Fm0.txt
agrep -0 -c 'AAGACGCGAACTCCACC' *.fastq > count/B14562_Fm0.txt
agrep -0 -c 'TGAATGAAGATACCCGG' *.fastq > count/B14563_Fm0.txt
agrep -0 -c 'ATGATATTAGGCGGCTT' *.fastq > count/B14564_Fm0.txt
agrep -0 -c 'CCATGCAGTATAAGAGA' *.fastq > count/B14565_Fm0.txt
agrep -0 -c 'CAACGGCTGTTATTAAG' *.fastq > count/B14566_Fm0.txt
agrep -0 -c 'ACTCGTGGAAAGATGAA' *.fastq > count/B14568_Fm0.txt
agrep -0 -c 'CCGCGGACCATACAGTA' *.fastq > count/B14569_Fm0.txt
agrep -0 -c 'GGACCTGTAATTGGCGT' *.fastq > count/B14570_Fm0.txt
agrep -0 -c 'CAAGATCCCATGACTAT' *.fastq > count/B14571_Fm0.txt
agrep -0 -c 'GTGTTCAATTCTGGATG' *.fastq > count/B14572_Fm0.txt
agrep -0 -c 'GTAATTGCCCAGCTTTC' *.fastq > count/B14573_Fm0.txt
agrep -0 -c 'TGACTTTAATGGCCCAA' *.fastq > count/B14574_Fm0.txt
agrep -0 -c 'AGGAGTATCCCGTCCGA' *.fastq > count/B14575_Fm0.txt
agrep -0 -c 'GTACTCTACTTTCGAAC' *.fastq > count/B14576_Fm0.txt
agrep -0 -c 'GCGCCCATCTAAGTCAT' *.fastq > count/B14577_Fm0.txt
agrep -0 -c 'GCAGTCCCTTAAATGCT' *.fastq > count/B14578_Fm0.txt
agrep -0 -c 'ACGTTACTCAAGAGGTC' *.fastq > count/B14579_Fm0.txt
agrep -0 -c 'GTGTTACGTACACCAGC' *.fastq > count/B14580_Fm0.txt
agrep -0 -c 'AGCTCGGCAGATCGAGA' *.fastq > count/B14581_Fm0.txt
agrep -0 -c 'GGGTCATCAGTCGAAGG' *.fastq > count/B14583_Fm0.txt
agrep -0 -c 'GAGTCGATATCTGACAT' *.fastq > count/B14584_Fm0.txt
agrep -0 -c 'ATTACAGGCCGTAACGG' *.fastq > count/B14586_Fm0.txt
agrep -0 -c 'ATAGAACGTTTGCGTCG' *.fastq > count/B14587_Fm0.txt
agrep -0 -c 'GATTAGCTCAGGTACCC' *.fastq > count/B14589_Fm0.txt
agrep -0 -c 'ACGGGAGTAATGACAGC' *.fastq > count/B14590_Fm0.txt
agrep -0 -c 'TCGTAGTAGGGCCAACA' *.fastq > count/B14591_Fm0.txt
agrep -0 -c 'GCAACGGTTACCCAGTT' *.fastq > count/B14592_Fm0.txt
agrep -0 -c 'TGAAGGAATCCCTGCGG' *.fastq > count/B14593_Fm0.txt
agrep -0 -c 'TCTCGCTGGTTTCCGTA' *.fastq > count/B14594_Fm0.txt
agrep -0 -c 'CTGCTAAGACGAGTTCG' *.fastq > count/B14596_Fm0.txt
agrep -0 -c 'GGGGGGTTCTATTGGAT' *.fastq > count/B14597_Fm0.txt
agrep -0 -c 'ATTGAGCGCGATCTCGC' *.fastq > count/B14598_Fm0.txt
agrep -0 -c 'TGTTGAGAACGGTCCGA' *.fastq > count/B14599_Fm0.txt
agrep -0 -c 'TGATCCGTAAAGCGGCA' *.fastq > count/B14600_Fm0.txt
agrep -0 -c 'GCATAGAAAATGTCCCG' *.fastq > count/B14601_Fm0.txt
agrep -0 -c 'TCTACTATGACTCTAGC' *.fastq > count/B14602_Fm0.txt
agrep -0 -c 'CGATGGGGACTAGGAAA' *.fastq > count/B14603_Fm0.txt
agrep -0 -c 'CAGCCCGTTAGAAGGTT' *.fastq > count/B14604_Fm0.txt
agrep -0 -c 'CGTCGATGGTCAAAGGG' *.fastq > count/B14606_Fm0.txt
agrep -0 -c 'AGACGAGCGCATGGGTT' *.fastq > count/B14607_Fm0.txt
agrep -0 -c 'CACGATTGCGCTGGTGT' *.fastq > count/B14608_Fm0.txt
agrep -0 -c 'CATTAAGGTGCCAGGGG' *.fastq > count/B14610_Fm0.txt
agrep -0 -c 'CTTGTAAAATCACTCGC' *.fastq > count/B14612_Fm0.txt
agrep -0 -c 'GTGTAGCGAACGTGTTA' *.fastq > count/B14613_Fm0.txt
agrep -0 -c 'GATGGCTAAGCATGCCT' *.fastq > count/B14614_Fm0.txt
agrep -0 -c 'GACGCTACCTACATAAA' *.fastq > count/B14615_Fm0.txt
agrep -0 -c 'TGAGTTAGCTAGGCCGT' *.fastq > count/B14616_Fm0.txt
agrep -0 -c 'TAAAGCGTCGCCACACC' *.fastq > count/B14618_Fm0.txt
agrep -0 -c 'TACGATGGCTGTATACG' *.fastq > count/B14619_Fm0.txt
agrep -0 -c 'TCACCGAAGAGATGGGG' *.fastq > count/B14620_Fm0.txt
agrep -0 -c 'GACTGAGGCACGGAATT' *.fastq > count/B14621_Fm0.txt
agrep -0 -c 'CCTTGCCTACTTGCGAG' *.fastq > count/B14622_Fm0.txt
agrep -0 -c 'GATCGGAACCGTAGGCA' *.fastq > count/B14623_Fm0.txt
agrep -0 -c 'AATTCTAAAAGTGCCCC' *.fastq > count/B14624_Fm0.txt
agrep -0 -c 'GAGTATGACTGGTTGAG' *.fastq > count/B14625_Fm0.txt
agrep -0 -c 'GATGAGTTATTGGTCCG' *.fastq > count/B14626_Fm0.txt
agrep -0 -c 'GATTAACCTAAACGGCC' *.fastq > count/B14628_Fm0.txt
agrep -0 -c 'ACTTATGGTCATAGAGC' *.fastq > count/B14629_Fm0.txt
agrep -0 -c 'CTGACAAGCGATAAGTT' *.fastq > count/B14630_Fm0.txt
agrep -0 -c 'CCGATGTCTAACACGGG' *.fastq > count/B14631_Fm0.txt
agrep -0 -c 'GCAGCAATCGACTTCGT' *.fastq > count/B14632_Fm0.txt
agrep -0 -c 'TCGTGCAGATTACAGCT' *.fastq > count/B14633_Fm0.txt
agrep -0 -c 'TCAGGGTCTTCTCCTAC' *.fastq > count/B14634_Fm0.txt
agrep -0 -c 'GTACAGACTACGATGAC' *.fastq > count/B14636_Fm0.txt
agrep -0 -c 'CGCAAACCTCACATAGA' *.fastq > count/B14637_Fm0.txt
agrep -0 -c 'GCTACTTAAGTCCGTCG' *.fastq > count/B14638_Fm0.txt
agrep -0 -c 'GGAGACATCTTACTTGA' *.fastq > count/B14639_Fm0.txt
agrep -0 -c 'GCGTCAACGGCTATGCT' *.fastq > count/B14641_Fm0.txt
agrep -0 -c 'TGTGTATCCGCAGAGGG' *.fastq > count/B14642_Fm0.txt
agrep -0 -c 'ACGTTCCTCATGGCAGA' *.fastq > count/B14643_Fm0.txt
agrep -0 -c 'AGAGCATATACCCGGAG' *.fastq > count/B14644_Fm0.txt
agrep -0 -c 'TGAAGTGAACGGAGGTG' *.fastq > count/B14645_Fm0.txt
agrep -0 -c 'CAATTTCGTATTTCGCC' *.fastq > count/B14646_Fm0.txt
agrep -0 -c 'TTCATGGCCCTCCATTA' *.fastq > count/B14647_Fm0.txt
agrep -0 -c 'AGTTTGGTTCGGAACGT' *.fastq > count/B14648_Fm0.txt
agrep -0 -c 'TCGAGCCGGGTAGATGT' *.fastq > count/B14649_Fm0.txt
agrep -0 -c 'GAGAATCAATGCCTTAG' *.fastq > count/B14650_Fm0.txt
agrep -0 -c 'AGAGAGCCCTGTGTAGG' *.fastq > count/B14651_Fm0.txt
agrep -0 -c 'CTGGAAGTTGAAGTTTG' *.fastq > count/B14652_Fm0.txt
agrep -0 -c 'TGCTACTTCAACCGCGG' *.fastq > count/B14653_Fm0.txt
agrep -0 -c 'CTGTGGCGCTAGATTAG' *.fastq > count/B14656_Fm0.txt
agrep -0 -c 'ATCCCCGCAGTTTTGGC' *.fastq > count/B14657_Fm0.txt
agrep -0 -c 'CAGCGGTGTAAACATGC' *.fastq > count/B14658_Fm0.txt
agrep -0 -c 'AACGTCGGCGATTGAAT' *.fastq > count/B14659_Fm0.txt
agrep -0 -c 'TACTGCGTCTGACATAG' *.fastq > count/B14660_Fm0.txt
agrep -0 -c 'TTAGAATGCCCTGGGCC' *.fastq > count/B14661_Fm0.txt
agrep -0 -c 'TACCGGCTTGTCCCTGA' *.fastq > count/B14662_Fm0.txt
agrep -0 -c 'ACCCCAGAGATTGGATT' *.fastq > count/B14663_Fm0.txt
agrep -0 -c 'CCGCAACGAAAATGATA' *.fastq > count/B14664_Fm0.txt
agrep -0 -c 'ATTACGTCGTGCCACGC' *.fastq > count/B14665_Fm0.txt
agrep -0 -c 'TGTTGAGCATCCACTCC' *.fastq > count/B14666_Fm0.txt
agrep -0 -c 'CTGGTTCTAAAAGAGAG' *.fastq > count/B14667_Fm0.txt
agrep -0 -c 'AACGGTACAGACATTTC' *.fastq > count/B14668_Fm0.txt
agrep -0 -c 'CTATCGGAACCTTCCTA' *.fastq > count/B14669_Fm0.txt
agrep -0 -c 'CTACTGATTACACACCA' *.fastq > count/B14671_Fm0.txt
agrep -0 -c 'ACACCGACTTGGTCTAA' *.fastq > count/B14672_Fm0.txt
agrep -0 -c 'ACCGCTGAGGGTTATTG' *.fastq > count/B14674_Fm0.txt
agrep -0 -c 'ATCAGGGTAGCGCAGAA' *.fastq > count/B14675_Fm0.txt
agrep -0 -c 'ATGCTAGGTATTTTGGG' *.fastq > count/B14676_Fm0.txt
agrep -0 -c 'TGTTAGCTGAATCCGTT' *.fastq > count/B14677_Fm0.txt
agrep -0 -c 'GGAACATGCGCCCGATT' *.fastq > count/B14678_Fm0.txt
agrep -0 -c 'GGAGTTCGGAATTGGTG' *.fastq > count/B14679_Fm0.txt
agrep -0 -c 'GGACTGTGTCAGTTCAG' *.fastq > count/B14680_Fm0.txt
agrep -0 -c 'CACCAGGGCTCAACAAT' *.fastq > count/B14681_Fm0.txt
agrep -0 -c 'GTTGCCTTCACTAGAAT' *.fastq > count/B14682_Fm0.txt
agrep -0 -c 'GCGTGACCTTTTCCAAC' *.fastq > count/B14683_Fm0.txt
agrep -0 -c 'CTTGTAGACCTTACAGG' *.fastq > count/B14684_Fm0.txt
agrep -0 -c 'TTACGATCCACACAGCG' *.fastq > count/B14685_Fm0.txt
agrep -0 -c 'CCAAGGGAACAAAGAAT' *.fastq > count/B14686_Fm0.txt
agrep -0 -c 'ATCGCAAGCTCAAGAGT' *.fastq > count/B14688_Fm0.txt
agrep -0 -c 'CTGACATCAGGCCTTAG' *.fastq > count/B14690_Fm0.txt
agrep -0 -c 'CATTATCGTGCCCTGAA' *.fastq > count/B14692_Fm0.txt
agrep -0 -c 'GGTAAAGACGTGGGAAC' *.fastq > count/B14694_Fm0.txt
agrep -0 -c 'CCTGTGGTTAGGTATCT' *.fastq > count/B14695_Fm0.txt
agrep -0 -c 'GTGAAGAAGGAGCCCAT' *.fastq > count/B14696_Fm0.txt
agrep -0 -c 'CAATTTAGGGACGTACT' *.fastq > count/B14698_Fm0.txt
agrep -0 -c 'GGGCCTGGATAAACGTT' *.fastq > count/B14699_Fm0.txt
agrep -0 -c 'GGTCCTTAGAGCAGACT' *.fastq > count/B14700_Fm0.txt
agrep -0 -c 'CCTTTACGTAGGGACTG' *.fastq > count/B14701_Fm0.txt
agrep -0 -c 'TGTCTCGGATGTGGTTT' *.fastq > count/B14702_Fm0.txt
agrep -0 -c 'ATACAATGAAGGCGCTT' *.fastq > count/B14703_Fm0.txt
agrep -0 -c 'AGGTCGGATTAGTACGG' *.fastq > count/B14704_Fm0.txt
agrep -0 -c 'GGGGGAGACATAACACT' *.fastq > count/B14705_Fm0.txt
agrep -0 -c 'ACGTCCCTTGCCAAGAT' *.fastq > count/B14706_Fm0.txt
agrep -0 -c 'AGCGTACATCAGGCGAG' *.fastq > count/B14707_Fm0.txt
agrep -0 -c 'ATTATGATTGACCGCCG' *.fastq > count/B14708_Fm0.txt
agrep -0 -c 'CGTAGCACAGTCGACTT' *.fastq > count/B14709_Fm0.txt
agrep -0 -c 'GATGATAGCCCAACAAA' *.fastq > count/B14711_Fm0.txt
agrep -0 -c 'CGGTCACACCCTTATCG' *.fastq > count/B14712_Fm0.txt
agrep -0 -c 'ACGATCTAGCTCGTAGG' *.fastq > count/B14713_Fm0.txt
agrep -0 -c 'ATCGTCCCTCATACCGT' *.fastq > count/B14715_Fm0.txt
agrep -0 -c 'ACGTAGCAGCGGTCTCA' *.fastq > count/B14716_Fm0.txt
agrep -0 -c 'CCAGTCACCTCTCATAG' *.fastq > count/B14717_Fm0.txt
agrep -0 -c 'GAGACAATAGCACGTTC' *.fastq > count/B14718_Fm0.txt
agrep -0 -c 'CCTCTGTTAATCGTTCT' *.fastq > count/B14719_Fm0.txt
agrep -0 -c 'GTCGGAAGGGTATTGGT' *.fastq > count/B14721_Fm0.txt
agrep -0 -c 'GCGCATTCTTAAAGTAG' *.fastq > count/B14722_Fm0.txt
agrep -0 -c 'CTAGGCGTTTCTAGTGG' *.fastq > count/B14723_Fm0.txt
agrep -0 -c 'GCCCAAAATATCGCGGA' *.fastq > count/B14724_Fm0.txt
agrep -0 -c 'GTCCTACCTGGTATGTA' *.fastq > count/B14726_Fm0.txt
agrep -0 -c 'ATGTTCTAAGCGCCAAT' *.fastq > count/B14727_Fm0.txt
agrep -0 -c 'TGTTCAACGGTAGGTAC' *.fastq > count/B14728_Fm0.txt
agrep -0 -c 'ATTCTAGGTAAGGTACG' *.fastq > count/B14729_Fm0.txt
agrep -0 -c 'TCGTTCATCCCCACTTA' *.fastq > count/B14730_Fm0.txt
agrep -0 -c 'CGTCCGTGTACGCACAA' *.fastq > count/B14732_Fm0.txt
agrep -0 -c 'CTAGACCAATTATTGCC' *.fastq > count/B14733_Fm0.txt
agrep -0 -c 'CTCTTGTGGCGAATCGT' *.fastq > count/B14734_Fm0.txt
agrep -0 -c 'GTGATCTAATGAGCGTA' *.fastq > count/B14735_Fm0.txt
agrep -0 -c 'GGGTCGCTCAATTCCCT' *.fastq > count/B14736_Fm0.txt
agrep -0 -c 'CCACAGGGGTCCTAATT' *.fastq > count/B14737_Fm0.txt
agrep -0 -c 'CACGCCGAGTGTAGATC' *.fastq > count/B14738_Fm0.txt
agrep -0 -c 'ATCTAAGGGTCGGTGAG' *.fastq > count/B14739_Fm0.txt
agrep -0 -c 'AGGTTATCCCGGTCACA' *.fastq > count/B14740_Fm0.txt
agrep -0 -c 'CTATGCAAGGGAACATC' *.fastq > count/B14741_Fm0.txt
agrep -0 -c 'GTGAGGATGATCTTCTG' *.fastq > count/B14742_Fm0.txt
agrep -0 -c 'GGGTCACGATGCAAACA' *.fastq > count/B14743_Fm0.txt
agrep -0 -c 'CTAAGCGGCATGAAAGC' *.fastq > count/B14744_Fm0.txt
agrep -0 -c 'ACGTCCATGTGCCTGCT' *.fastq > count/B14745_Fm0.txt
agrep -0 -c 'GCGAGCTAGACATATCT' *.fastq > count/B14747_Fm0.txt
agrep -0 -c 'CAAAAACGTGTGGGCCT' *.fastq > count/B14748_Fm0.txt
agrep -0 -c 'AGTCCACAGCGTTTGAT' *.fastq > count/B14749_Fm0.txt
agrep -0 -c 'TGTAAGCACACAGGCGA' *.fastq > count/B14751_Fm0.txt
agrep -0 -c 'CGCATTCTTTCGTGGCC' *.fastq > count/B14752_Fm0.txt
agrep -0 -c 'GTACCATGGAAGCACCG' *.fastq > count/B14753_Fm0.txt
agrep -0 -c 'TTATAAGTCCTCATGCG' *.fastq > count/B14755_Fm0.txt
agrep -0 -c 'GCACCAGAGTATCCGAC' *.fastq > count/B14757_Fm0.txt
agrep -0 -c 'CTTGGGCCGACTATTAC' *.fastq > count/B14758_Fm0.txt
agrep -0 -c 'CGGCGAAAATTGGGTGT' *.fastq > count/B14759_Fm0.txt
agrep -0 -c 'TAGCGTCGATTAGGTAC' *.fastq > count/B14760_Fm0.txt
agrep -0 -c 'TGAACACGATGGTCAGA' *.fastq > count/B14761_Fm0.txt
agrep -0 -c 'GTTTACGAGCACATCGG' *.fastq > count/B14763_Fm0.txt
agrep -0 -c 'GACGATCCTGCATTATG' *.fastq > count/B14765_Fm0.txt
agrep -0 -c 'AGATTCGTCGGAATCAA' *.fastq > count/B14766_Fm0.txt
agrep -0 -c 'GTCGTGAGCCTCTATCG' *.fastq > count/B14767_Fm0.txt
agrep -0 -c 'CCGGAGTTCGGCATGAA' *.fastq > count/B14768_Fm0.txt
agrep -0 -c 'TTCATGAGGACCGTCCT' *.fastq > count/B14769_Fm0.txt
agrep -0 -c 'GTATGACCCCTGCAGAT' *.fastq > count/B14770_Fm0.txt
agrep -0 -c 'ATTCCCCGAACTAGATC' *.fastq > count/B14771_Fm0.txt
agrep -0 -c 'GGATTGGTAAGAAAGGT' *.fastq > count/B14772_Fm0.txt
agrep -0 -c 'TAACATGCAACGACCAC' *.fastq > count/B14773_Fm0.txt
agrep -0 -c 'CGCGCTTGCGCTATAAT' *.fastq > count/B14774_Fm0.txt
agrep -0 -c 'AATCCGCTCTCGCTTTT' *.fastq > count/B14775_Fm0.txt
agrep -0 -c 'GCGTGGAAGGCTATAGC' *.fastq > count/B14778_Fm0.txt
agrep -0 -c 'GTAAGCAACGAGGCCGT' *.fastq > count/B14779_Fm0.txt
agrep -0 -c 'CCTTTAACGGGGTTAGC' *.fastq > count/B14780_Fm0.txt
agrep -0 -c 'CGGATGGTATCCCCGAA' *.fastq > count/B14781_Fm0.txt
agrep -0 -c 'GGCGTTCAAGAATACGG' *.fastq > count/B14782_Fm0.txt
agrep -0 -c 'GTTAAACGGCGAGCTTG' *.fastq > count/B14783_Fm0.txt
agrep -0 -c 'CGCAGTGCTGAACCTGA' *.fastq > count/B14784_Fm0.txt
agrep -0 -c 'ATATCCTAATGCACGGG' *.fastq > count/B14785_Fm0.txt
agrep -0 -c 'CGGCATGAGCGGATCTT' *.fastq > count/B14786_Fm0.txt
agrep -0 -c 'GCCGTAGTTCCGGCTAA' *.fastq > count/B14787_Fm0.txt
agrep -0 -c 'GCCGGAACATCATAATA' *.fastq > count/B14788_Fm0.txt
agrep -0 -c 'AGCCTAAAAGCGCTTTC' *.fastq > count/B14789_Fm0.txt
agrep -0 -c 'TCACGGTTGGCGCTAAA' *.fastq > count/B14790_Fm0.txt
agrep -0 -c 'ATTGTGCCGAAGTATTC' *.fastq > count/B14791_Fm0.txt
agrep -0 -c 'GCTATTATGCAACGTTC' *.fastq > count/B14792_Fm0.txt
agrep -0 -c 'GTAGACGATTTGATAGC' *.fastq > count/B14795_Fm0.txt
agrep -0 -c 'GTCGAGTAAAGATATGC' *.fastq > count/B14796_Fm0.txt
agrep -0 -c 'ATGACGGCGCTAGCACA' *.fastq > count/B14797_Fm0.txt
agrep -0 -c 'GTCGTATCGACGTCTAT' *.fastq > count/B14798_Fm0.txt
agrep -0 -c 'AGACGATAAGGACGGCA' *.fastq > count/B14799_Fm0.txt
agrep -0 -c 'CTTCTTCGTAGGAGGAG' *.fastq > count/B14800_Fm0.txt
agrep -0 -c 'TCACTTACCCTCCTATT' *.fastq > count/B14801_Fm0.txt
agrep -0 -c 'ATCGGGGAGTAGTGCGA' *.fastq > count/B14802_Fm0.txt
agrep -0 -c 'CATTCGTGGATTACCAT' *.fastq > count/B14803_Fm0.txt
agrep -0 -c 'TCTAAGCCTGGTGCTGC' *.fastq > count/B14806_Fm0.txt
agrep -0 -c 'CGTTCCCGTTTCGAGAT' *.fastq > count/B14807_Fm0.txt
agrep -0 -c 'AAGCTACGCACTGCATC' *.fastq > count/B14808_Fm0.txt
agrep -0 -c 'ATGTTCTGGGTTACAGA' *.fastq > count/B14809_Fm0.txt
agrep -0 -c 'GCTGACATATAGCACGA' *.fastq > count/B14810_Fm0.txt
agrep -0 -c 'GAGAGCCAATCGTACCA' *.fastq > count/B14811_Fm0.txt
agrep -0 -c 'GTTTAGGTTCATTCGGC' *.fastq > count/B14812_Fm0.txt
agrep -0 -c 'GATGTAATGAGTACTCG' *.fastq > count/B14813_Fm0.txt
agrep -0 -c 'GCCCAATTGTCTGAGCT' *.fastq > count/B14814_Fm0.txt
agrep -0 -c 'CTCTCTGTTCGGACCAG' *.fastq > count/B14815_Fm0.txt
agrep -0 -c 'TAACGCGCTAACTGGAT' *.fastq > count/B14816_Fm0.txt
agrep -0 -c 'CAAAGAGCCGACTTGAC' *.fastq > count/B14817_Fm0.txt
agrep -0 -c 'AGTAAGCAGGCGGTGTT' *.fastq > count/B14818_Fm0.txt
agrep -0 -c 'AGGCCAGCGGCTTATTA' *.fastq > count/B14819_Fm0.txt
agrep -0 -c 'AGCAGATCTGGACTACG' *.fastq > count/B14820_Fm0.txt
agrep -0 -c 'GCAATGTCCACACGAGG' *.fastq > count/B14821_Fm0.txt
agrep -0 -c 'TGCGTGACTGCTCTACA' *.fastq > count/B14822_Fm0.txt
agrep -0 -c 'TTGGGCCCTCCAATATC' *.fastq > count/B14823_Fm0.txt
agrep -0 -c 'GAGAGTCCAGGGAACGA' *.fastq > count/B14824_Fm0.txt
agrep -0 -c 'CAGTGGTCATCCAAGAG' *.fastq > count/B14826_Fm0.txt
agrep -0 -c 'ATTCGTCACCGCAGCAA' *.fastq > count/B14827_Fm0.txt
agrep -0 -c 'GCTGGCTAGTCCTAACG' *.fastq > count/B14828_Fm0.txt
agrep -0 -c 'TAATAACGCGGCTTAAC' *.fastq > count/B14829_Fm0.txt
agrep -0 -c 'AGCCGGTGTGGAAGTCT' *.fastq > count/B14830_Fm0.txt
agrep -0 -c 'TAGCGGGTACTAAATGC' *.fastq > count/B14831_Fm0.txt
agrep -0 -c 'CAGGTGACCCATTATAG' *.fastq > count/B14832_Fm0.txt
agrep -0 -c 'CAATGCGGAAACGAACT' *.fastq > count/B14833_Fm0.txt
agrep -0 -c 'TATTAGGGCTCTGCCGA' *.fastq > count/B14834_Fm0.txt
agrep -0 -c 'ATCCTGACAGCCCGAAT' *.fastq > count/B14835_Fm0.txt
agrep -0 -c 'CGACATCGCGTAATATC' *.fastq > count/B14836_Fm0.txt
agrep -0 -c 'CAGCGTTGGCGGTTTAT' *.fastq > count/B14837_Fm0.txt
agrep -0 -c 'GTTACGTGTAGTTGTAC' *.fastq > count/B14838_Fm0.txt
agrep -0 -c 'AAGCCGGCCGATAAAGC' *.fastq > count/B14839_Fm0.txt
agrep -0 -c 'ATGCTAATTGTCGCAGG' *.fastq > count/B14843_Fm0.txt
agrep -0 -c 'GCTATAGATCCGAATAC' *.fastq > count/B14844_Fm0.txt
agrep -0 -c 'AACCTCACGCGCTCTTA' *.fastq > count/B14845_Fm0.txt
agrep -0 -c 'TAGGTACTGTGAGCCGA' *.fastq > count/B14846_Fm0.txt
agrep -0 -c 'CTGCGAAGCTCATCTAA' *.fastq > count/B14847_Fm0.txt
agrep -0 -c 'GGATGCTAGCCATCAGC' *.fastq > count/B14848_Fm0.txt
agrep -0 -c 'AGAAAGACCTTTCGTCA' *.fastq > count/B14849_Fm0.txt
agrep -0 -c 'CTCACACGTCTGATCGT' *.fastq > count/B14850_Fm0.txt
agrep -0 -c 'CTACACGATACACCAAG' *.fastq > count/B14852_Fm0.txt
agrep -0 -c 'CGATGTAGGTGATGTGG' *.fastq > count/B14853_Fm0.txt
agrep -0 -c 'TCACAATCGAGGGTCAA' *.fastq > count/B14854_Fm0.txt
agrep -0 -c 'CAGGAAGGTCCGAAGAG' *.fastq > count/B14855_Fm0.txt
agrep -0 -c 'TCAATGACGCGACGGTT' *.fastq > count/B14857_Fm0.txt
agrep -0 -c 'TTCGGATGACCATCATC' *.fastq > count/B14858_Fm0.txt
agrep -0 -c 'GTAGTCGATATCAACAC' *.fastq > count/B14859_Fm0.txt
agrep -0 -c 'AGTCCTCAGATATCTCA' *.fastq > count/B14860_Fm0.txt
agrep -0 -c 'TTCACGTGACGGCAAGG' *.fastq > count/B14861_Fm0.txt
agrep -0 -c 'GTCTGTCCACGAGGGTT' *.fastq > count/B14862_Fm0.txt
agrep -0 -c 'TTGCTTGACGAGTTAGG' *.fastq > count/B14864_Fm0.txt
agrep -0 -c 'AGAGGTCATTGCAGATC' *.fastq > count/B14865_Fm0.txt
agrep -0 -c 'GACTATGGGCGGTTAGG' *.fastq > count/B14866_Fm0.txt
agrep -0 -c 'GAGCCCACTCGACCTAT' *.fastq > count/B14867_Fm0.txt
agrep -0 -c 'CTTGAACGGATCATTAC' *.fastq > count/B14868_Fm0.txt
agrep -0 -c 'ATTGGGCAACCGACACT' *.fastq > count/B14870_Fm0.txt
agrep -0 -c 'GTTGGCCTTTTCAATCG' *.fastq > count/B14871_Fm0.txt
agrep -0 -c 'TTATCTACGCGAGACAG' *.fastq > count/B14872_Fm0.txt
agrep -0 -c 'TACCTCGACCTCTAGAG' *.fastq > count/B14873_Fm0.txt
agrep -0 -c 'ATAGGATCTCAGGCGAC' *.fastq > count/B14874_Fm0.txt
agrep -0 -c 'GACCAAACCACGTTCCG' *.fastq > count/B14875_Fm0.txt
agrep -0 -c 'AATCCAGAGTAAAAGGC' *.fastq > count/B14876_Fm0.txt
agrep -0 -c 'TGATCTTACCTCCCCCC' *.fastq > count/B14877_Fm0.txt
agrep -0 -c 'TTCAGCGTTGCTTTCAT' *.fastq > count/B14878_Fm0.txt
agrep -0 -c 'ATACTAGGCATGGGCAT' *.fastq > count/B14879_Fm0.txt
agrep -0 -c 'CCATACTAGTTCGGTTT' *.fastq > count/B14880_Fm0.txt
agrep -0 -c 'CATTGTGAGTCAGTCAA' *.fastq > count/B14881_Fm0.txt
agrep -0 -c 'CAGGTTATATGACGGCG' *.fastq > count/B14882_Fm0.txt
agrep -0 -c 'AGAATTTGTCCGGGCAA' *.fastq > count/B14884_Fm0.txt
agrep -0 -c 'CCTATATACAACTCGCC' *.fastq > count/B14885_Fm0.txt
agrep -0 -c 'TGTGAACTAGGACGACG' *.fastq > count/B14887_Fm0.txt
agrep -0 -c 'GTAGGTCACAAACGCAG' *.fastq > count/B14888_Fm0.txt
agrep -0 -c 'ACGACCAGCTTAACGGT' *.fastq > count/B14889_Fm0.txt
agrep -0 -c 'ACACCCTGATTGATTGG' *.fastq > count/B14891_Fm0.txt
agrep -0 -c 'CCGGACTGTTCAAAGAA' *.fastq > count/B14894_Fm0.txt
agrep -0 -c 'GGGCCGCATAAACGATA' *.fastq > count/B14895_Fm0.txt
agrep -0 -c 'AGTGCTCTCTTATGGTG' *.fastq > count/B14896_Fm0.txt
agrep -0 -c 'TACACGTAGGCTTAATG' *.fastq > count/B14897_Fm0.txt
agrep -0 -c 'AGGCTTACTCGGTCTGT' *.fastq > count/B14898_Fm0.txt
agrep -0 -c 'TGAAGTTTAGAATGGGG' *.fastq > count/B14899_Fm0.txt
agrep -0 -c 'TACCTCCATCGTTAGAG' *.fastq > count/B14900_Fm0.txt
agrep -0 -c 'TGTACGCACCGCTTGTC' *.fastq > count/B14901_Fm0.txt
agrep -0 -c 'GATGCGAAGAGCCCGAA' *.fastq > count/B14902_Fm0.txt
agrep -0 -c 'GACGAGTCGAAAACAAA' *.fastq > count/B14903_Fm0.txt
agrep -0 -c 'GCCCGCCTTATAAGTAA' *.fastq > count/B14905_Fm0.txt
agrep -0 -c 'GTGACGATACGCTCATT' *.fastq > count/B14906_Fm0.txt
agrep -0 -c 'GTGGTCCAAAGACAGTC' *.fastq > count/B14907_Fm0.txt
agrep -0 -c 'TATAAGCACCCGGACTA' *.fastq > count/B14908_Fm0.txt
agrep -0 -c 'GACGCACAAGTATCCGG' *.fastq > count/B14911_Fm0.txt
agrep -0 -c 'TCGGAGTTATCTGAGCT' *.fastq > count/B14912_Fm0.txt
agrep -0 -c 'TGCGGATGATGTGGATC' *.fastq > count/B14913_Fm0.txt
agrep -0 -c 'CATAGAGGGTCGTCCTC' *.fastq > count/B14915_Fm0.txt
agrep -0 -c 'ACCGATCGTAGAGAGGT' *.fastq > count/B14917_Fm0.txt
agrep -0 -c 'CACAGCTGACTGTACTG' *.fastq > count/B14919_Fm0.txt
agrep -0 -c 'GCTACAGACATAACCTC' *.fastq > count/B14920_Fm0.txt
agrep -0 -c 'CCGCTTAACTATTGTCC' *.fastq > count/B14921_Fm0.txt
agrep -0 -c 'TCAAACTAGACGTGGTT' *.fastq > count/B14922_Fm0.txt
agrep -0 -c 'CAACTGACTTGAGGATA' *.fastq > count/B14923_Fm0.txt
agrep -0 -c 'GGAATACGGACTGCCGA' *.fastq > count/B14924_Fm0.txt
agrep -0 -c 'CTATACTACTGATGGAC' *.fastq > count/B14925_Fm0.txt
agrep -0 -c 'AGTGCTACATGCCGTCT' *.fastq > count/B14927_Fm0.txt
agrep -0 -c 'TGAGGTGATACGGACAG' *.fastq > count/B14929_Fm0.txt
agrep -0 -c 'TACCGGTATTTCGAAGT' *.fastq > count/B14930_Fm0.txt
agrep -0 -c 'CACATTCTTGCCTTTCG' *.fastq > count/B14931_Fm0.txt
agrep -0 -c 'TCGAGGTTTAGGCAGAG' *.fastq > count/B14932_Fm0.txt
agrep -0 -c 'TGGATTGATTTCCCGAG' *.fastq > count/B14933_Fm0.txt
agrep -0 -c 'CAACTAAGACTCGAGAC' *.fastq > count/B14934_Fm0.txt
agrep -0 -c 'GGGAGACAATTCATTGG' *.fastq > count/B14935_Fm0.txt
agrep -0 -c 'ATCTACAAAGGTCGATC' *.fastq > count/B14936_Fm0.txt
agrep -0 -c 'GCACTACTATATTGGAC' *.fastq > count/B14937_Fm0.txt
agrep -0 -c 'ATACGTTGAACGAGCCA' *.fastq > count/B14938_Fm0.txt
agrep -0 -c 'TATATTGAGCAGGGATG' *.fastq > count/B14939_Fm0.txt
agrep -0 -c 'ACCAAGTCTTGTCCTCG' *.fastq > count/B14940_Fm0.txt
agrep -0 -c 'GCCCCTTTCTTAGTGGT' *.fastq > count/B14941_Fm0.txt
agrep -0 -c 'GGTAGCCGTAACTGGGT' *.fastq > count/B14942_Fm0.txt
agrep -0 -c 'TCGTTAAGCCTCTAGGG' *.fastq > count/B14943_Fm0.txt
agrep -0 -c 'AGGAGTTCTTGATGCAG' *.fastq > count/B14944_Fm0.txt
agrep -0 -c 'TAATTGCCTGATTGGGG' *.fastq > count/B14945_Fm0.txt
agrep -0 -c 'TCGGATATGGGCTGTTG' *.fastq > count/B14946_Fm0.txt
agrep -0 -c 'TCGCAAGTCACGTGTTG' *.fastq > count/B14950_Fm0.txt
agrep -0 -c 'ACGGTTGAAGAAAGGAC' *.fastq > count/B14951_Fm0.txt
agrep -0 -c 'AATCTCCAGACGGAATG' *.fastq > count/B14952_Fm0.txt
agrep -0 -c 'ATGTGCTGGGTCTTTAT' *.fastq > count/B14953_Fm0.txt
agrep -0 -c 'AGGGTTGACTCTCATTC' *.fastq > count/B14954_Fm0.txt
agrep -0 -c 'ATATAGGACTTCGCTTC' *.fastq > count/B14955_Fm0.txt
agrep -0 -c 'TACTAGCCAATCGGTGA' *.fastq > count/B14956_Fm0.txt
agrep -0 -c 'CTCTCTGTACGATCGCT' *.fastq > count/B14958_Fm0.txt
agrep -0 -c 'CGTAGATTGTACTTCAG' *.fastq > count/B14959_Fm0.txt
agrep -0 -c 'TGGATGTACGGGGTGCA' *.fastq > count/B14961_Fm0.txt
agrep -0 -c 'ACTGCGATAACCGAGTT' *.fastq > count/B14962_Fm0.txt
agrep -0 -c 'TCGATCACAAGTGTGTA' *.fastq > count/B14963_Fm0.txt
agrep -0 -c 'ATATTGCTCACCAGGGT' *.fastq > count/B14964_Fm0.txt
agrep -0 -c 'GCCAAGAGCCGGTTATG' *.fastq > count/B14966_Fm0.txt
agrep -0 -c 'TTGCAATCCGAACGAGC' *.fastq > count/B14967_Fm0.txt
agrep -0 -c 'ATCACTCAACCGGTCAA' *.fastq > count/B14968_Fm0.txt
agrep -0 -c 'TGTAGGATGGCTAAGAC' *.fastq > count/B14969_Fm0.txt
agrep -0 -c 'ATGTACGGGCGCAATGA' *.fastq > count/B14970_Fm0.txt
agrep -0 -c 'TTCAAGTGGGCATTGGG' *.fastq > count/B14971_Fm0.txt
agrep -0 -c 'CAAGCGACATGATGCGT' *.fastq > count/B14972_Fm0.txt
agrep -0 -c 'CTCCGCCCGACATTTTC' *.fastq > count/B14973_Fm0.txt
agrep -0 -c 'AGCCAAAAGACTAGTCC' *.fastq > count/B14974_Fm0.txt
agrep -0 -c 'ATATCGGCCAAAGTCGA' *.fastq > count/B14975_Fm0.txt
agrep -0 -c 'CTGAAAAAGGGCCAACT' *.fastq > count/B14977_Fm0.txt
agrep -0 -c 'GAGGAAATCTGGATCCT' *.fastq > count/B14978_Fm0.txt
agrep -0 -c 'ACGGAGATGTTTACGCG' *.fastq > count/B14980_Fm0.txt
agrep -0 -c 'TCATTTACCGTCTGCAA' *.fastq > count/B14981_Fm0.txt
agrep -0 -c 'ACGAAGCCTAGCAGGTC' *.fastq > count/B14982_Fm0.txt
agrep -0 -c 'AAGGGAAGAAACGTAGA' *.fastq > count/B14983_Fm0.txt
agrep -0 -c 'ATGACGCGGGCATTATG' *.fastq > count/B14984_Fm0.txt
agrep -0 -c 'ACTGGGTTACCTAAACT' *.fastq > count/B14985_Fm0.txt
agrep -0 -c 'ACCACATAACGCGTTTA' *.fastq > count/B14986_Fm0.txt
agrep -0 -c 'TCGTGCAAACAGGATTG' *.fastq > count/B14987_Fm0.txt
agrep -0 -c 'AGCAGACGTATCAAGAA' *.fastq > count/B14988_Fm0.txt
agrep -0 -c 'AGGGACTCTTAGGTTTA' *.fastq > count/B14993_Fm0.txt
agrep -0 -c 'TGTAGGGCAATCAAACC' *.fastq > count/B14994_Fm0.txt
agrep -0 -c 'GCCTTGTTACGATGCAG' *.fastq > count/B14995_Fm0.txt
agrep -0 -c 'CCTGACTTCTGTCGTAT' *.fastq > count/B14996_Fm0.txt
agrep -0 -c 'GGAGTCGAATATAAAGC' *.fastq > count/B14997_Fm0.txt
agrep -0 -c 'TGTTATTCTACTCCCCT' *.fastq > count/B14999_Fm0.txt
agrep -0 -c 'GGTATCTTGCATCAGAC' *.fastq > count/B15000_Fm0.txt
agrep -0 -c 'CATGTAGCCCGCCATTG' *.fastq > count/B15001_Fm0.txt
agrep -0 -c 'TCTTGCGGTCCGTTGGT' *.fastq > count/B15002_Fm0.txt
agrep -0 -c 'GGACGCAAGTGAAACCC' *.fastq > count/B15003_Fm0.txt
agrep -0 -c 'ACGGAACCAACCCTGAG' *.fastq > count/B15004_Fm0.txt
agrep -0 -c 'GTCGGAACCGCAATTGC' *.fastq > count/B15005_Fm0.txt
agrep -0 -c 'ATTGTCACCCTCTATAC' *.fastq > count/B15006_Fm0.txt
agrep -0 -c 'GTGACATATTGTCCCTC' *.fastq > count/B15007_Fm0.txt
agrep -0 -c 'CATACGTTCGGTTAGGG' *.fastq > count/B15008_Fm0.txt
agrep -0 -c 'GTTGGTCATGAGGGCAC' *.fastq > count/B15010_Fm0.txt
agrep -0 -c 'CCATGCCCCCTATTATC' *.fastq > count/B15011_Fm0.txt
agrep -0 -c 'GCGCTTACATTAGTCCA' *.fastq > count/B15012_Fm0.txt
agrep -0 -c 'TAATCATCGGATACCTG' *.fastq > count/B15013_Fm0.txt
agrep -0 -c 'GATCGACTTCGCAATGT' *.fastq > count/B15014_Fm0.txt
agrep -0 -c 'TACATTCCCCCGAGGAT' *.fastq > count/B15015_Fm0.txt
agrep -0 -c 'CTAGCGGCTACAAGGAC' *.fastq > count/B15016_Fm0.txt
agrep -0 -c 'TCAGCAACGCGGTATAC' *.fastq > count/B15017_Fm0.txt
agrep -0 -c 'CTAAGCTCCGCTTCCAC' *.fastq > count/B15019_Fm0.txt
agrep -0 -c 'GATGGCGCGTTGTAGGA' *.fastq > count/B15020_Fm0.txt
agrep -0 -c 'CAGAACCTCAACAACTA' *.fastq > count/B15021_Fm0.txt
agrep -0 -c 'GCCTCGACCGCCATATT' *.fastq > count/B15022_Fm0.txt
agrep -0 -c 'ACAGGATCAATAGATCG' *.fastq > count/B15024_Fm0.txt
agrep -0 -c 'GCGCTTCCTATTGGTAG' *.fastq > count/B15026_Fm0.txt
agrep -0 -c 'ACACCTAGGCTTATCAG' *.fastq > count/B15029_Fm0.txt
agrep -0 -c 'TTCGATATACTTTCCGG' *.fastq > count/B15030_Fm0.txt
agrep -0 -c 'GTAACAGGGAGAAATCG' *.fastq > count/B15031_Fm0.txt
agrep -0 -c 'AACGTAGGGGTTCAAGG' *.fastq > count/B15032_Fm0.txt
agrep -0 -c 'GCAGTCCAAGTCGAATT' *.fastq > count/B15033_Fm0.txt
agrep -0 -c 'ATTTCTGGCCGAACAAT' *.fastq > count/B15034_Fm0.txt
agrep -0 -c 'GGTTCTAGATGAGCAAC' *.fastq > count/B15035_Fm0.txt
agrep -0 -c 'TTGACGCTTCTTCACCA' *.fastq > count/B15036_Fm0.txt
agrep -0 -c 'TCTCCTTTGCATAGCTG' *.fastq > count/B15037_Fm0.txt
agrep -0 -c 'TACGACTGCTAGTTGGG' *.fastq > count/B15038_Fm0.txt
agrep -0 -c 'GCTCATTCCGGTTTTTT' *.fastq > count/B15039_Fm0.txt
agrep -0 -c 'AACCGCATGCTTAAAGC' *.fastq > count/B15040_Fm0.txt
agrep -0 -c 'TAGTGAGTCGCACATTG' *.fastq > count/B15041_Fm0.txt
agrep -0 -c 'ATACGCGTGAATCGCAC' *.fastq > count/B15044_Fm0.txt
agrep -0 -c 'GACAAAGGTGACTTAAC' *.fastq > count/B15045_Fm0.txt
agrep -0 -c 'GTATCAAGCATGGCAAC' *.fastq > count/B15046_Fm0.txt
agrep -0 -c 'ATACGAACTAACCCATC' *.fastq > count/B15047_Fm0.txt
agrep -0 -c 'CTCGTGAACTAAGTGCT' *.fastq > count/B15048_Fm0.txt
agrep -0 -c 'CGACAGCATACTTTATC' *.fastq > count/B15049_Fm0.txt
agrep -0 -c 'TGCACCTGCTCACCCTT' *.fastq > count/B15050_Fm0.txt
agrep -0 -c 'AGCGGACACCCTTCCTA' *.fastq > count/B15052_Fm0.txt
agrep -0 -c 'AGTTATCCGACTGACAC' *.fastq > count/B15053_Fm0.txt
agrep -0 -c 'GATTGTAGTTAATCGGG' *.fastq > count/B15054_Fm0.txt
agrep -0 -c 'TCGGTGATATGAGCCAC' *.fastq > count/B15055_Fm0.txt
agrep -0 -c 'GACTTATGTAGCCCTCT' *.fastq > count/B15056_Fm0.txt
agrep -0 -c 'GATCGTACTTTGTAAGC' *.fastq > count/B15057_Fm0.txt
agrep -0 -c 'CTGGCCATACCAGTACC' *.fastq > count/B15058_Fm0.txt
agrep -0 -c 'CAATTAAGTCGTGCTAG' *.fastq > count/B15059_Fm0.txt
agrep -0 -c 'AGTGCCCTTCGGTGTCT' *.fastq > count/B15061_Fm0.txt
agrep -0 -c 'CAAATACGGACGCACCT' *.fastq > count/B15062_Fm0.txt
agrep -0 -c 'CGTGTCATCCTCAACGT' *.fastq > count/B15063_Fm0.txt
agrep -0 -c 'CTCACTCGGCAGTACTT' *.fastq > count/B15064_Fm0.txt
agrep -0 -c 'GCAGTATTATGCGCAAA' *.fastq > count/B15066_Fm0.txt
agrep -0 -c 'CAGCAAATTACGTATGC' *.fastq > count/B15067_Fm0.txt
agrep -0 -c 'AGTACCCATGACGATGT' *.fastq > count/B15069_Fm0.txt
agrep -0 -c 'CATCGTTTCACGACCCC' *.fastq > count/B15070_Fm0.txt
agrep -0 -c 'CGCCTATTACAGCCATT' *.fastq > count/B15071_Fm0.txt
agrep -0 -c 'ACTGCCGTCAATCCCAG' *.fastq > count/B15072_Fm0.txt
agrep -0 -c 'GGAATCTAACGCACCTC' *.fastq > count/B15073_Fm0.txt
agrep -0 -c 'TTGTTAGTCAGTCACTC' *.fastq > count/B15074_Fm0.txt
agrep -0 -c 'CTGCTGTATCGCGAGAC' *.fastq > count/B15075_Fm0.txt
agrep -0 -c 'ATTTGTCCCAGCCACGC' *.fastq > count/B15076_Fm0.txt
agrep -0 -c 'GGTCCAATTTATTCCGT' *.fastq > count/B15077_Fm0.txt
agrep -0 -c 'TGTCCCTACTATTGGTT' *.fastq > count/B15078_Fm0.txt
agrep -0 -c 'TAGAGACCGCATTCTTG' *.fastq > count/B15079_Fm0.txt
agrep -0 -c 'ACGACTTCTCGTTGGTT' *.fastq > count/B15080_Fm0.txt
agrep -0 -c 'GCATTACGAGGAGCGAC' *.fastq > count/B15081_Fm0.txt
agrep -0 -c 'TAACAACCCTGCGCAGG' *.fastq > count/B15082_Fm0.txt
agrep -0 -c 'CATAAAAAACGGACTCG' *.fastq > count/B15083_Fm0.txt
agrep -0 -c 'GAGTTCGATAGCAATGC' *.fastq > count/B15084_Fm0.txt
agrep -0 -c 'CCTTTCGTAACGTACGG' *.fastq > count/B15086_Fm0.txt
agrep -0 -c 'CCTAGCTGCAACTCCTA' *.fastq > count/B15087_Fm0.txt
agrep -0 -c 'GGACAGATCGAATAGGG' *.fastq > count/B15088_Fm0.txt
agrep -0 -c 'TGTCCGCCAAGTGATAT' *.fastq > count/B15089_Fm0.txt
agrep -0 -c 'GAGGAGTCTGAGATTCT' *.fastq > count/B15090_Fm0.txt
agrep -0 -c 'GATGACAGGGGTAAAAG' *.fastq > count/B15091_Fm0.txt
agrep -0 -c 'AAGGTCCGCAGCATAGC' *.fastq > count/B15094_Fm0.txt
agrep -0 -c 'CCTCTGCTTTCCGTCAG' *.fastq > count/B15095_Fm0.txt
agrep -0 -c 'GTCACCGGAATACATCC' *.fastq > count/B15096_Fm0.txt
agrep -0 -c 'TCAACGACAGACTAATC' *.fastq > count/B15098_Fm0.txt
agrep -0 -c 'CGCAGTACACGAAGCGT' *.fastq > count/B15099_Fm0.txt
agrep -0 -c 'ATCTTACGTTTCGGTGA' *.fastq > count/B15100_Fm0.txt
agrep -0 -c 'TTGGATGTCCGTATAGA' *.fastq > count/B15101_Fm0.txt
agrep -0 -c 'ATGATACCAAGGACGCT' *.fastq > count/B15103_Fm0.txt
agrep -0 -c 'TCACAAGTTGGCTACAG' *.fastq > count/B15104_Fm0.txt
agrep -0 -c 'AGCCAGCACGTTGGACT' *.fastq > count/B15105_Fm0.txt
agrep -0 -c 'TTACCAGGAGCCCAATG' *.fastq > count/B15106_Fm0.txt
agrep -0 -c 'ATCGCTACAGCCGAGTC' *.fastq > count/B15107_Fm0.txt
agrep -0 -c 'GATGTTCCGAACTGCAC' *.fastq > count/B15108_Fm0.txt
agrep -0 -c 'ATGACCCGCGTCATTGG' *.fastq > count/B15109_Fm0.txt
agrep -0 -c 'AACACGAGTTGATGAGT' *.fastq > count/B15111_Fm0.txt
agrep -0 -c 'TTGGGGCGTAGAGCTAT' *.fastq > count/B15112_Fm0.txt
agrep -0 -c 'CGTAGCGGAAAATCCCG' *.fastq > count/B15113_Fm0.txt
agrep -0 -c 'AGCAGGCTAGTCTAATT' *.fastq > count/B15115_Fm0.txt
agrep -0 -c 'TGCGGCAAGGAGGAGAA' *.fastq > count/B15116_Fm0.txt
agrep -0 -c 'TGACATCTTTCTCCAAG' *.fastq > count/B15120_Fm0.txt
agrep -0 -c 'TCACCGGGAGAAGTCGT' *.fastq > count/B15121_Fm0.txt
agrep -0 -c 'CGTACGGAGCGACTCAT' *.fastq > count/B15122_Fm0.txt
agrep -0 -c 'AGACTGGCCATGAGCCA' *.fastq > count/B15124_Fm0.txt
agrep -0 -c 'ACTGCGAACTCTACATT' *.fastq > count/B15126_Fm0.txt
agrep -0 -c 'CGAATCCGTATTCTCAA' *.fastq > count/B15127_Fm0.txt
agrep -0 -c 'CCAAGAAGCACGGTGGT' *.fastq > count/B15128_Fm0.txt
agrep -0 -c 'GCCAATACTCTATGTGG' *.fastq > count/B15129_Fm0.txt
agrep -0 -c 'GTACGTGCGACACCATG' *.fastq > count/B15130_Fm0.txt
agrep -0 -c 'AGCGCAGCCCGCATATA' *.fastq > count/B15131_Fm0.txt
agrep -0 -c 'TTCACTCTACCGGGGTT' *.fastq > count/B15132_Fm0.txt
agrep -0 -c 'ATCAGGCATCCGGACTC' *.fastq > count/B15133_Fm0.txt
agrep -0 -c 'ACCTGTTACCTGGATTA' *.fastq > count/B15134_Fm0.txt
agrep -0 -c 'AAGGCTCTACGTGACCT' *.fastq > count/B15136_Fm0.txt
agrep -0 -c 'TCGACATAGGCTGTCGC' *.fastq > count/B15137_Fm0.txt
agrep -0 -c 'TTGGTTGCTCTAACATC' *.fastq > count/B15138_Fm0.txt
agrep -0 -c 'ATAGGCTAGGTTGATCC' *.fastq > count/B15139_Fm0.txt
agrep -0 -c 'CGAATCCAGCCTATCAT' *.fastq > count/B15140_Fm0.txt
agrep -0 -c 'TTCGGCAGCGGTAATAC' *.fastq > count/B15141_Fm0.txt
agrep -0 -c 'GACATAGTTGCGCCTAA' *.fastq > count/B15142_Fm0.txt
agrep -0 -c 'TCGACCTCATCTCCCTG' *.fastq > count/B15143_Fm0.txt
agrep -0 -c 'ACCACCAACGATTTTCA' *.fastq > count/B15144_Fm0.txt
agrep -0 -c 'CTAGCGTTGTTGCCTTG' *.fastq > count/B15145_Fm0.txt
agrep -0 -c 'AACTCATGCTACGAACT' *.fastq > count/B15146_Fm0.txt
agrep -0 -c 'GGGCAGGCGTCTATACT' *.fastq > count/B15147_Fm0.txt
agrep -0 -c 'TCGGTCTATGCGCGTAG' *.fastq > count/B15148_Fm0.txt
agrep -0 -c 'TAGAGGCTGGCGGAAAT' *.fastq > count/B15149_Fm0.txt
agrep -0 -c 'AGCCTCTAGCCTACTTG' *.fastq > count/B15150_Fm0.txt
agrep -0 -c 'ACATGGGAAACGCGTAT' *.fastq > count/B15151_Fm0.txt
agrep -0 -c 'GGTTCATACGACTGGAT' *.fastq > count/B15152_Fm0.txt
agrep -0 -c 'ACAACCTATCCGTATCC' *.fastq > count/B15153_Fm0.txt
agrep -0 -c 'GCAGGCGGAAACATCGA' *.fastq > count/B15154_Fm0.txt
agrep -0 -c 'ATACGGGTCTCACTGGT' *.fastq > count/B15156_Fm0.txt
agrep -0 -c 'AGTGCACCTGAGTGAAA' *.fastq > count/B15157_Fm0.txt
agrep -0 -c 'GATGGGTACACCCATTG' *.fastq > count/B15158_Fm0.txt
agrep -0 -c 'TGATGGTGAGGACATAC' *.fastq > count/B15159_Fm0.txt
agrep -0 -c 'CAGTGGGAAGACGTAGG' *.fastq > count/B15160_Fm0.txt
agrep -0 -c 'ATCCAGCTTAGGGGAGA' *.fastq > count/B15161_Fm0.txt
agrep -0 -c 'TAGTGTAGATGCCTGCA' *.fastq > count/B15162_Fm0.txt
agrep -0 -c 'TTGACACGCACTGTCCC' *.fastq > count/B15163_Fm0.txt
agrep -0 -c 'TATCGCTACTGAAGTGT' *.fastq > count/B15164_Fm0.txt
agrep -0 -c 'CACTTTCGCCAGCCTAC' *.fastq > count/B15165_Fm0.txt
agrep -0 -c 'ACTATGCAGTATGGCGC' *.fastq > count/B15166_Fm0.txt
agrep -0 -c 'GTCATCGAGCGTTTTGG' *.fastq > count/B15167_Fm0.txt
agrep -0 -c 'TCTGGCGTGATAACATT' *.fastq > count/B15168_Fm0.txt
agrep -0 -c 'GCCGATAGCTTCTTCCT' *.fastq > count/B15169_Fm0.txt
agrep -0 -c 'GCCCATTCTTGCCACAT' *.fastq > count/B15170_Fm0.txt
agrep -0 -c 'CCGAGTCCCAACTACAT' *.fastq > count/B15171_Fm0.txt
agrep -0 -c 'TACCGGGGACATGGCAT' *.fastq > count/B15172_Fm0.txt
agrep -0 -c 'CGGCGTGGTATAATACT' *.fastq > count/B15173_Fm0.txt
agrep -0 -c 'GCTCGCTTTAGAGACCT' *.fastq > count/B15174_Fm0.txt
agrep -0 -c 'AGTTGGCCTATGCATTA' *.fastq > count/B15175_Fm0.txt
agrep -0 -c 'AAGACGACCAAACTCTC' *.fastq > count/B15176_Fm0.txt
agrep -0 -c 'TTATCGGCAGTCGGTGG' *.fastq > count/B15178_Fm0.txt
agrep -0 -c 'AGTGCTCAAGAGCCAGA' *.fastq > count/B15179_Fm0.txt
agrep -0 -c 'TAATCACACCCCTGGTT' *.fastq > count/B15181_Fm0.txt
agrep -0 -c 'TTGTCCTATCGTACGTA' *.fastq > count/B15182_Fm0.txt
agrep -0 -c 'CGCTAACTGATCAGCAA' *.fastq > count/B15183_Fm0.txt
agrep -0 -c 'GCGTGGCCGATTCAATT' *.fastq > count/B15185_Fm0.txt
agrep -0 -c 'CCGGTTGAATTTTCCAC' *.fastq > count/B15186_Fm0.txt
agrep -0 -c 'CCTGTAACTCCCAGGTC' *.fastq > count/B15187_Fm0.txt
agrep -0 -c 'GTTCGATCCTCTAGTGG' *.fastq > count/B15188_Fm0.txt
agrep -0 -c 'ATGCTGGCAACGAATGG' *.fastq > count/B15189_Fm0.txt
agrep -0 -c 'ACCTGAATTCGAATACC' *.fastq > count/B15190_Fm0.txt
agrep -0 -c 'TCGCTTTTAAGCGGTGG' *.fastq > count/B15192_Fm0.txt
agrep -0 -c 'AACACTGTTGTAATGGG' *.fastq > count/B15193_Fm0.txt
agrep -0 -c 'GCGATTTCTATGACTGC' *.fastq > count/B15194_Fm0.txt
agrep -0 -c 'GTATACAGACATCGCGA' *.fastq > count/B15195_Fm0.txt
agrep -0 -c 'AGTGCTCTAGTAACCCT' *.fastq > count/B15196_Fm0.txt
agrep -0 -c 'CATTACGGATACGTGAT' *.fastq > count/B15197_Fm0.txt
agrep -0 -c 'GTGTCACACTTCCCGTG' *.fastq > count/B15198_Fm0.txt
agrep -0 -c 'AACGCCTCTAGTAGGCA' *.fastq > count/B15199_Fm0.txt
agrep -0 -c 'GGGATCTATGCGGACGT' *.fastq > count/B15200_Fm0.txt
agrep -0 -c 'AGGGCATACCGAATCCT' *.fastq > count/B15202_Fm0.txt
agrep -0 -c 'GGGTTCATACTCTTGTC' *.fastq > count/B15203_Fm0.txt
agrep -0 -c 'GTCGTCCAAGTAGCCGT' *.fastq > count/B15205_Fm0.txt
agrep -0 -c 'ACGGAAACCCATGATCG' *.fastq > count/B15206_Fm0.txt
agrep -0 -c 'CGAGATTATGACAGACT' *.fastq > count/B15207_Fm0.txt
agrep -0 -c 'GCATCCGTCTGAACATG' *.fastq > count/B15208_Fm0.txt
agrep -0 -c 'GATGCGGACCATACGAC' *.fastq > count/B15209_Fm0.txt
agrep -0 -c 'CCGCTGCGACAATGCAT' *.fastq > count/B15210_Fm0.txt
agrep -0 -c 'AGAAGAGTCCACGCACC' *.fastq > count/B15211_Fm0.txt
agrep -0 -c 'CCTTGTGAGCTTAAGGG' *.fastq > count/B15212_Fm0.txt
agrep -0 -c 'AGCGCCCAAACAAGGCT' *.fastq > count/B15213_Fm0.txt
agrep -0 -c 'TCAATTTGTGCTACGGC' *.fastq > count/B15214_Fm0.txt
agrep -0 -c 'GTACGCTTACGGGATCA' *.fastq > count/B15215_Fm0.txt
agrep -0 -c 'CGTACTCTTACCAGAAC' *.fastq > count/B15216_Fm0.txt
agrep -0 -c 'CCTAGGTGAATTGTCGT' *.fastq > count/B15217_Fm0.txt
agrep -0 -c 'TAATGGTTTGGCGTGCG' *.fastq > count/B15218_Fm0.txt
agrep -0 -c 'GTGTGGACAGTGACTAC' *.fastq > count/B15219_Fm0.txt
agrep -0 -c 'TAACGCGTCACTGTACA' *.fastq > count/B15220_Fm0.txt
agrep -0 -c 'ATATTGTACCGCGGACG' *.fastq > count/B15222_Fm0.txt
agrep -0 -c 'CTACATTAAGCTTGACC' *.fastq > count/B15224_Fm0.txt
agrep -0 -c 'GGCCTCTAAATCACGAT' *.fastq > count/B15226_Fm0.txt
agrep -0 -c 'TTCGCCAGCGTGGTATT' *.fastq > count/B15227_Fm0.txt
agrep -0 -c 'TTAGACCGAACAATAGG' *.fastq > count/B15228_Fm0.txt
agrep -0 -c 'CGTCATTAGTCACGGAC' *.fastq > count/B15229_Fm0.txt
agrep -0 -c 'TCTCAGGGTTGACCCTC' *.fastq > count/B15230_Fm0.txt
agrep -0 -c 'ACTGACTCTAGCAGAGC' *.fastq > count/B15231_Fm0.txt
agrep -0 -c 'AACAAGTCACGGACGTC' *.fastq > count/B15232_Fm0.txt
agrep -0 -c 'CACTGGATTCATTTCCC' *.fastq > count/B15233_Fm0.txt
agrep -0 -c 'GCTCCTTCGGTGATGGT' *.fastq > count/B15234_Fm0.txt
agrep -0 -c 'TTCGTGTAACGGTTCCT' *.fastq > count/B15235_Fm0.txt
agrep -0 -c 'GGTGTCAGTATCACCGC' *.fastq > count/B15236_Fm0.txt
agrep -0 -c 'ATTGCATGCTGCCCATC' *.fastq > count/B15238_Fm0.txt
agrep -0 -c 'CGGACTAGGACGACATG' *.fastq > count/B15239_Fm0.txt
agrep -0 -c 'GAGTTTACTATGGCAGC' *.fastq > count/B15240_Fm0.txt
agrep -0 -c 'GGTTAACGAGTAGGCCG' *.fastq > count/B15241_Fm0.txt
agrep -0 -c 'TAGCCATTATAGGGGGG' *.fastq > count/B15242_Fm0.txt
agrep -0 -c 'TAAGGGTAAGCTACCAC' *.fastq > count/B15243_Fm0.txt
agrep -0 -c 'ACTACGGGCGATGGTTT' *.fastq > count/B15244_Fm0.txt
agrep -0 -c 'GGATCAAGAGCGTATTA' *.fastq > count/B15246_Fm0.txt
agrep -0 -c 'CCTTACACTACCAACAA' *.fastq > count/B15247_Fm0.txt
agrep -0 -c 'CAACGGGGAGGTTGCTT' *.fastq > count/B15248_Fm0.txt
agrep -0 -c 'TGAATGGGTTCAACGAA' *.fastq > count/B15250_Fm0.txt
agrep -0 -c 'TATCGACCAGGGAATAT' *.fastq > count/B15253_Fm0.txt
agrep -0 -c 'GAGGTAGCTGACAACCC' *.fastq > count/B15254_Fm0.txt
agrep -0 -c 'CAGAATCTTTAGGACGA' *.fastq > count/B15255_Fm0.txt
agrep -0 -c 'GGAGTTCATGGGTCGAG' *.fastq > count/B15256_Fm0.txt
agrep -0 -c 'GTCACCTTAGTCACTAC' *.fastq > count/B15257_Fm0.txt
agrep -0 -c 'AACCAATGGACCTTGGC' *.fastq > count/B15260_Fm0.txt
agrep -0 -c 'TCGTGTAGAATAAGTCG' *.fastq > count/B15261_Fm0.txt
agrep -0 -c 'GTTGACTGTGACTACTT' *.fastq > count/B15262_Fm0.txt
agrep -0 -c 'TAAGCAAGCGCATCGGG' *.fastq > count/B15263_Fm0.txt
agrep -0 -c 'AGGAGCCAATCAGTCGT' *.fastq > count/B15264_Fm0.txt
agrep -0 -c 'ATCTCCATCGACCTTAG' *.fastq > count/B15265_Fm0.txt
agrep -0 -c 'GGTACGATGTGTCCTCG' *.fastq > count/B15266_Fm0.txt
agrep -0 -c 'GAGGTCAACGAGAGCGT' *.fastq > count/B15267_Fm0.txt
agrep -0 -c 'GGAACGGTCTAGACTAA' *.fastq > count/B15268_Fm0.txt
agrep -0 -c 'CGTCGACAGGCCTTTTT' *.fastq > count/B15269_Fm0.txt
agrep -0 -c 'ATCCGCGGGAGCTTTTT' *.fastq > count/B15270_Fm0.txt
agrep -0 -c 'GTTTGGACCCCACAGCA' *.fastq > count/B15271_Fm0.txt
agrep -0 -c 'CTAGGATCGCCATAACG' *.fastq > count/B15272_Fm0.txt
agrep -0 -c 'AAGGGCTCGCCATTGAA' *.fastq > count/B15273_Fm0.txt
agrep -0 -c 'ATAGTAGCCGCCGTTCG' *.fastq > count/B15274_Fm0.txt
agrep -0 -c 'CCACTATGCCGTATGGC' *.fastq > count/B15275_Fm0.txt
agrep -0 -c 'CGTAGTGAGCGGAAGCT' *.fastq > count/B15276_Fm0.txt
agrep -0 -c 'TCAACTGATCGGCTTTA' *.fastq > count/B15277_Fm0.txt
agrep -0 -c 'TGCTGAAAAATAGGCTC' *.fastq > count/B15278_Fm0.txt
agrep -0 -c 'CTGCAAGACTCATCAAG' *.fastq > count/B15279_Fm0.txt
agrep -0 -c 'ATTCAACGGGGTGTAAG' *.fastq > count/B15280_Fm0.txt
agrep -0 -c 'CCATAGGTCACTTGATA' *.fastq > count/B15281_Fm0.txt
agrep -0 -c 'GGCTCGTTGTCAAAAAC' *.fastq > count/B15282_Fm0.txt
agrep -0 -c 'CAATCGTGCAATGGTGA' *.fastq > count/B15283_Fm0.txt
agrep -0 -c 'CTAAAAATCGCTTGCCA' *.fastq > count/B15285_Fm0.txt
agrep -0 -c 'TAGTCCAATGACGGTGA' *.fastq > count/B15288_Fm0.txt
agrep -0 -c 'ACTCCCTCCTTAGACGG' *.fastq > count/B15290_Fm0.txt
agrep -0 -c 'TCTTCTATCCGAGTGTA' *.fastq > count/B15291_Fm0.txt
agrep -0 -c 'GCTGTAGTAGTATGACA' *.fastq > count/B15292_Fm0.txt
agrep -0 -c 'GCTCTGCCTCATATTAG' *.fastq > count/B15293_Fm0.txt
agrep -0 -c 'GCTGTTAGGGAGTTCCG' *.fastq > count/B15294_Fm0.txt
agrep -0 -c 'ACAGCAAAAAACTCCAG' *.fastq > count/B15298_Fm0.txt
agrep -0 -c 'TTGGCCCTTAGAGATGT' *.fastq > count/B15299_Fm0.txt
agrep -0 -c 'GCATGGACGTGTGGTTA' *.fastq > count/B15302_Fm0.txt
agrep -0 -c 'CGCAGCTCACTAACAAT' *.fastq > count/B15303_Fm0.txt
agrep -0 -c 'AAGAAGGTCCGGTCTTG' *.fastq > count/B15304_Fm0.txt
agrep -0 -c 'GGAGGAATGATGATCTG' *.fastq > count/B15305_Fm0.txt
agrep -0 -c 'TGAGGTACTACGAGAAG' *.fastq > count/B15306_Fm0.txt
agrep -0 -c 'TCAACCCGGTGTGGAAG' *.fastq > count/B15307_Fm0.txt
agrep -0 -c 'GGGGTCAGCAACTACTA' *.fastq > count/B15308_Fm0.txt
agrep -0 -c 'GGGTCAAGCGATATAAC' *.fastq > count/B15309_Fm0.txt
agrep -0 -c 'GGTGTGCTTGCTTTCAT' *.fastq > count/B15310_Fm0.txt
agrep -0 -c 'CAGCACAACGAGCCTAT' *.fastq > count/B15311_Fm0.txt
agrep -0 -c 'GTAGTCCCCGTCGATCA' *.fastq > count/B15312_Fm0.txt
agrep -0 -c 'CCGAAATACGCGCATAC' *.fastq > count/B15313_Fm0.txt
agrep -0 -c 'AAGTATGAAGAGGAGAC' *.fastq > count/B15314_Fm0.txt
agrep -0 -c 'TGGATTACAAGACTTGC' *.fastq > count/B15315_Fm0.txt
agrep -0 -c 'ACGGGCTTTTGATTTCA' *.fastq > count/B15316_Fm0.txt
agrep -0 -c 'GGTATATCGTTGACGCC' *.fastq > count/B15317_Fm0.txt
agrep -0 -c 'CTCGGGATTGGCTATGT' *.fastq > count/B15318_Fm0.txt
agrep -0 -c 'AACGAGGTTGCTACTGA' *.fastq > count/B15319_Fm0.txt
agrep -0 -c 'GTATTGACTCATACTGC' *.fastq > count/B15320_Fm0.txt
agrep -0 -c 'GTGTAGCTTAGAGCGAC' *.fastq > count/B15321_Fm0.txt
agrep -0 -c 'TGATCCCTATTTCGTCA' *.fastq > count/B15322_Fm0.txt
agrep -0 -c 'TTAACGTTGTGCCCCTT' *.fastq > count/B15323_Fm0.txt
agrep -0 -c 'CACCGACGTATGGTACT' *.fastq > count/B15324_Fm0.txt
agrep -0 -c 'CTAATTCTCACTACCTG' *.fastq > count/B15325_Fm0.txt
agrep -0 -c 'GAGCTACAGCCCACGAA' *.fastq > count/B15326_Fm0.txt
agrep -0 -c 'ATAAGGGTACAGCCACT' *.fastq > count/B15327_Fm0.txt
agrep -0 -c 'TGCCCCTAACTATAGCG' *.fastq > count/B15328_Fm0.txt
agrep -0 -c 'TATAGACGAGGCGAAAC' *.fastq > count/B15330_Fm0.txt
agrep -0 -c 'GTGAGGGATAGGTTGAA' *.fastq > count/B15331_Fm0.txt
agrep -0 -c 'TTCTCGGCAAGATGGTA' *.fastq > count/B15332_Fm0.txt
agrep -0 -c 'CGATTTGGAAGCCTTCA' *.fastq > count/B15333_Fm0.txt
agrep -0 -c 'CGTTTAGAAAGACGCAA' *.fastq > count/B15334_Fm0.txt
agrep -0 -c 'CGTGATGCGAAATTAGG' *.fastq > count/B15336_Fm0.txt
agrep -0 -c 'GATTCGGTATTGCCTAA' *.fastq > count/B15337_Fm0.txt
agrep -0 -c 'ATGAACACCCCCGGAGA' *.fastq > count/B15338_Fm0.txt
agrep -0 -c 'CAAGACCTCCTTGACTA' *.fastq > count/B15339_Fm0.txt
agrep -0 -c 'GACCGTTGATCATCTCT' *.fastq > count/B15340_Fm0.txt
agrep -0 -c 'CGTACTCGTGTGTTCGC' *.fastq > count/B15341_Fm0.txt
agrep -0 -c 'ACGGGCAAAGGCAGAAA' *.fastq > count/B15342_Fm0.txt
agrep -0 -c 'GGAGGATCAACCACGAT' *.fastq > count/B15344_Fm0.txt
agrep -0 -c 'GGAGCATGCCTTACGCT' *.fastq > count/B15345_Fm0.txt
agrep -0 -c 'AGGGAACTACATTGTCC' *.fastq > count/B15347_Fm0.txt
agrep -0 -c 'CGATCGAGAGGCCTCTT' *.fastq > count/B15348_Fm0.txt
agrep -0 -c 'TAGCGATCTTTCCTGTG' *.fastq > count/B15350_Fm0.txt
agrep -0 -c 'GTCTGTTGGCACCGGAT' *.fastq > count/B15352_Fm0.txt
agrep -0 -c 'GTGATAACGCGCGTTGC' *.fastq > count/B15353_Fm0.txt
agrep -0 -c 'AAGCAGGCTCAGGTTAA' *.fastq > count/B15355_Fm0.txt
agrep -0 -c 'ACGGCGAAGTCCTATAG' *.fastq > count/B15356_Fm0.txt
agrep -0 -c 'TCGTAAGATAAACTCCG' *.fastq > count/B15357_Fm0.txt
agrep -0 -c 'TGACTGCGATCAAATGT' *.fastq > count/B15359_Fm0.txt
agrep -0 -c 'TGCACGCCGAGAAAGCA' *.fastq > count/B15360_Fm0.txt
agrep -0 -c 'TTCTAGGAGGTTCTCGA' *.fastq > count/B15361_Fm0.txt
agrep -0 -c 'TGCGTTGCTAGGCGCAA' *.fastq > count/B15363_Fm0.txt
agrep -0 -c 'AGTACATACTGATCCGC' *.fastq > count/B15365_Fm0.txt
agrep -0 -c 'TGAAATGGCACCCCATG' *.fastq > count/B15368_Fm0.txt
agrep -0 -c 'ACGACGCTTGTTAAAGT' *.fastq > count/B15369_Fm0.txt
agrep -0 -c 'ACACACGAATTAGGGTT' *.fastq > count/B15370_Fm0.txt
agrep -0 -c 'TAGGTTACATGTCCATG' *.fastq > count/B15371_Fm0.txt
agrep -0 -c 'ATAGCCAGTATGATGCC' *.fastq > count/B15373_Fm0.txt
agrep -0 -c 'CCGGCCCCAAAGGTTTA' *.fastq > count/B15375_Fm0.txt
agrep -0 -c 'CCTACACAGCGGCTTTT' *.fastq > count/B15376_Fm0.txt
agrep -0 -c 'AGTGTTGAGCGAGACTG' *.fastq > count/B15379_Fm0.txt
agrep -0 -c 'TGTTGTTTGAACCGGCA' *.fastq > count/B15380_Fm0.txt
agrep -0 -c 'CACAATATGTGCTTCGG' *.fastq > count/B15381_Fm0.txt
agrep -0 -c 'CGAAACGGACGTTACTT' *.fastq > count/B15383_Fm0.txt
agrep -0 -c 'ACAGAATGCTGCGAGAA' *.fastq > count/B15384_Fm0.txt
agrep -0 -c 'TACACAATCCGTTCGTT' *.fastq > count/B15386_Fm0.txt
agrep -0 -c 'TATTGCGTGCCAACGTT' *.fastq > count/B15387_Fm0.txt
agrep -0 -c 'TAGCGGGTCGGATCGAT' *.fastq > count/B15388_Fm0.txt
agrep -0 -c 'CCTCTTCTCCGTTGCTC' *.fastq > count/B15389_Fm0.txt
agrep -0 -c 'GCATTCGCTGAATATGA' *.fastq > count/B15390_Fm0.txt
agrep -0 -c 'GTGAATGCGAAGTGCAC' *.fastq > count/B15391_Fm0.txt
agrep -0 -c 'AAGTATCTCTCTGGGTT' *.fastq > count/B15392_Fm0.txt
agrep -0 -c 'ACACTTAATGGCCCGGC' *.fastq > count/B15393_Fm0.txt
agrep -0 -c 'ATTTCCCTTAGATCGGT' *.fastq > count/B15394_Fm0.txt
agrep -0 -c 'GTGCTCAATCGTAGGAA' *.fastq > count/B15395_Fm0.txt
agrep -0 -c 'ATAACTGGCAGACTGGG' *.fastq > count/B15398_Fm0.txt
agrep -0 -c 'ACCCAAAGTATCAAACG' *.fastq > count/B15399_Fm0.txt
agrep -0 -c 'TTATGGCATTCAGGACC' *.fastq > count/B15400_Fm0.txt
agrep -0 -c 'AGACCTGTGAGACCCTA' *.fastq > count/B15401_Fm0.txt
agrep -0 -c 'GGGCCAACGATGTTTAA' *.fastq > count/B15402_Fm0.txt
agrep -0 -c 'AGCACGTCCCGGAATTA' *.fastq > count/B15403_Fm0.txt
agrep -0 -c 'CGACTCATTGGGGTCGT' *.fastq > count/B15404_Fm0.txt
agrep -0 -c 'ACCGACTAAAGGCGTTC' *.fastq > count/B15405_Fm0.txt
agrep -0 -c 'ACCTGTCAGGATCATCG' *.fastq > count/B15406_Fm0.txt
agrep -0 -c 'CTCTTTCCATCAGGAGG' *.fastq > count/B15408_Fm0.txt
agrep -0 -c 'AATTGGGTCGTGCGCTG' *.fastq > count/B15409_Fm0.txt
agrep -0 -c 'AGCTCCTAAAGGGTCAC' *.fastq > count/B15410_Fm0.txt
agrep -0 -c 'GCGTAAAAGGTGGTCAC' *.fastq > count/B15411_Fm0.txt
agrep -0 -c 'TATAGTGTCTACTGCGT' *.fastq > count/B15412_Fm0.txt
agrep -0 -c 'CGACTAATAAAGGACGT' *.fastq > count/B15413_Fm0.txt
agrep -0 -c 'AAGGTGGGACACTAAAT' *.fastq > count/B15415_Fm0.txt
agrep -0 -c 'CGCAAAAACCATTCGCA' *.fastq > count/B15416_Fm0.txt
agrep -0 -c 'TATCGTTAGGCTCACTT' *.fastq > count/B15417_Fm0.txt
agrep -0 -c 'CCGAGACGGCTAGTTTA' *.fastq > count/B15418_Fm0.txt
agrep -0 -c 'AGAAGTTCCGCTCAGTC' *.fastq > count/B15419_Fm0.txt
agrep -0 -c 'ATGCACGTCTGCTCGTA' *.fastq > count/B15420_Fm0.txt
agrep -0 -c 'ATGTCTACAATCACCAG' *.fastq > count/B15421_Fm0.txt
agrep -0 -c 'ACGCCCGAAATGACAAT' *.fastq > count/B15422_Fm0.txt
agrep -0 -c 'AAGTAGAGGGGTCGAGT' *.fastq > count/B15423_Fm0.txt
agrep -0 -c 'AAGGCCCTCGCCTGTTA' *.fastq > count/B15424_Fm0.txt
agrep -0 -c 'AGCCAGAAGTTATCAAG' *.fastq > count/B15426_Fm0.txt
agrep -0 -c 'AGCATAATCCGAGTTCG' *.fastq > count/B15427_Fm0.txt
agrep -0 -c 'GAGGAGTATGTAGGCTA' *.fastq > count/B15428_Fm0.txt
agrep -0 -c 'TACTAAGATCCTGCTAG' *.fastq > count/B15429_Fm0.txt
agrep -0 -c 'ACTTTTGCGACATCGAA' *.fastq > count/B15430_Fm0.txt
agrep -0 -c 'ATCATCCAAGATCTGGA' *.fastq > count/B15432_Fm0.txt
agrep -0 -c 'TAGCGATGAGGCCACCT' *.fastq > count/B15434_Fm0.txt
agrep -0 -c 'TCATACTGACTCTTGGC' *.fastq > count/B15436_Fm0.txt
agrep -0 -c 'GACTCAGGACCTATTGG' *.fastq > count/B15437_Fm0.txt
agrep -0 -c 'CGCCGTTTAACAAGCGA' *.fastq > count/B15438_Fm0.txt
agrep -0 -c 'AATAACTCTTACCGACG' *.fastq > count/B15439_Fm0.txt
agrep -0 -c 'CATCGGATAAGCGGTCC' *.fastq > count/B15441_Fm0.txt
agrep -0 -c 'TGCGCTTAGTTCTAGTA' *.fastq > count/B15442_Fm0.txt
agrep -0 -c 'GGAGCTATACAGAGTCC' *.fastq > count/B15443_Fm0.txt
agrep -0 -c 'CCATCGTGAGACAAAGC' *.fastq > count/B15444_Fm0.txt
agrep -0 -c 'CTCTACAACTCAGGTTG' *.fastq > count/B15445_Fm0.txt
agrep -0 -c 'GTAGTACGAGCCTACGC' *.fastq > count/B15446_Fm0.txt
agrep -0 -c 'CATTATTCACTGCGAAG' *.fastq > count/B15447_Fm0.txt
agrep -0 -c 'TCGGGTATCAGAAAAAG' *.fastq > count/B15448_Fm0.txt
agrep -0 -c 'CGGGTATCCGTAAGACC' *.fastq > count/B15449_Fm0.txt
agrep -0 -c 'GTCTCGGTGAGGGTTAT' *.fastq > count/B15450_Fm0.txt
agrep -0 -c 'TCGATTTAGCCCGCCGT' *.fastq > count/B15451_Fm0.txt
agrep -0 -c 'CTAGTCCTTAGGTGTAG' *.fastq > count/B15452_Fm0.txt
agrep -0 -c 'CTTCTCGATCAGTACGT' *.fastq > count/B15453_Fm0.txt
agrep -0 -c 'ATATCGGCAGTTGCATT' *.fastq > count/B15454_Fm0.txt
agrep -0 -c 'ATACGCTTGAACAGTAC' *.fastq > count/B15455_Fm0.txt
agrep -0 -c 'TCAGAATCTAGAGTACG' *.fastq > count/B15456_Fm0.txt
agrep -0 -c 'GACTCACCTGTCTGTGC' *.fastq > count/B15458_Fm0.txt
agrep -0 -c 'CAGTAAGCAAACGTAGA' *.fastq > count/B15459_Fm0.txt
agrep -0 -c 'CGTTCTGAGTCACTAAA' *.fastq > count/B15460_Fm0.txt
agrep -0 -c 'TAAGGTAAGCTCGTGTC' *.fastq > count/B15461_Fm0.txt
agrep -0 -c 'AGATGTCCTCGCAAACC' *.fastq > count/B15462_Fm0.txt
agrep -0 -c 'CCGTGTTCGGTTGATCG' *.fastq > count/B15463_Fm0.txt
agrep -0 -c 'TCAACATTAGCGGACGA' *.fastq > count/B15464_Fm0.txt
agrep -0 -c 'TTCACTCCAGCTTCGCA' *.fastq > count/B15465_Fm0.txt
agrep -0 -c 'ATTAACCGTAGGACGGT' *.fastq > count/B15466_Fm0.txt
agrep -0 -c 'CGACATGCCAAGCACAT' *.fastq > count/B15468_Fm0.txt
agrep -0 -c 'GGCTCTGTACGCTAGCA' *.fastq > count/B15469_Fm0.txt
agrep -0 -c 'ACGTGGTCGATACAAGG' *.fastq > count/B15470_Fm0.txt
agrep -0 -c 'TGATCTTGCTGGCCTCG' *.fastq > count/B15471_Fm0.txt
agrep -0 -c 'AGGTTTTCCGGCGAATG' *.fastq > count/B15472_Fm0.txt
agrep -0 -c 'TGCGGATACAGCACTGT' *.fastq > count/B15473_Fm0.txt
agrep -0 -c 'GTGCTGACCCGTAGATT' *.fastq > count/B15474_Fm0.txt
agrep -0 -c 'AGGCTGCCTTCTCATCA' *.fastq > count/B15475_Fm0.txt
agrep -0 -c 'CACATGTGAATACTCGT' *.fastq > count/B15476_Fm0.txt
agrep -0 -c 'GGCGAGTGGTTTTGTAT' *.fastq > count/B15477_Fm0.txt
agrep -0 -c 'CCGAGATCCTCGACAAC' *.fastq > count/B15478_Fm0.txt
agrep -0 -c 'TCGTTGCCTAGTACTCA' *.fastq > count/B15479_Fm0.txt
agrep -0 -c 'GTCACCGCAGTAACAAT' *.fastq > count/B15482_Fm0.txt
agrep -0 -c 'ATACACCAGACCGCTAC' *.fastq > count/B15483_Fm0.txt
agrep -0 -c 'CGATCCTACAACGACTG' *.fastq > count/B15484_Fm0.txt
agrep -0 -c 'CGTCAAACAGGACCTAA' *.fastq > count/B15485_Fm0.txt
agrep -0 -c 'TTGTGGTCTGCTTGGTC' *.fastq > count/B15486_Fm0.txt
agrep -0 -c 'CTTAGGGACGGCTGTAG' *.fastq > count/B15488_Fm0.txt
agrep -0 -c 'CGTGGCGCCGTTTTTAG' *.fastq > count/B15490_Fm0.txt
agrep -0 -c 'TAATACGGGTCCACCTT' *.fastq > count/B15492_Fm0.txt
agrep -0 -c 'ATCCCCACGTATATGTA' *.fastq > count/B15493_Fm0.txt
agrep -0 -c 'CACCAGTAGGTCGCTAG' *.fastq > count/B15494_Fm0.txt
agrep -0 -c 'ACCAATAGATTGCTGCA' *.fastq > count/B15495_Fm0.txt
agrep -0 -c 'CGACAGTAAGTGGGGGT' *.fastq > count/B15498_Fm0.txt
agrep -0 -c 'TACTGTAGTCGCCTTGA' *.fastq > count/B15499_Fm0.txt
agrep -0 -c 'TCGAATGGCAGTAGCTA' *.fastq > count/B15501_Fm0.txt
agrep -0 -c 'CGGCTATTGCTATTTTC' *.fastq > count/B15502_Fm0.txt
agrep -0 -c 'ACGATTAACTCGTCGCT' *.fastq > count/B15503_Fm0.txt
agrep -0 -c 'TGTGGATCTGCCCTATT' *.fastq > count/B15504_Fm0.txt
agrep -0 -c 'GTTACTGGCCGACTGTG' *.fastq > count/B15506_Fm0.txt
agrep -0 -c 'TCTGGGGCTAAGCCTTA' *.fastq > count/B15508_Fm0.txt
agrep -0 -c 'CTTATTGACCCGCGCGA' *.fastq > count/B15509_Fm0.txt
agrep -0 -c 'ACGCGACTAAATGCTTA' *.fastq > count/B15510_Fm0.txt
agrep -0 -c 'GCCGCTACAATTCGTCG' *.fastq > count/B15511_Fm0.txt
agrep -0 -c 'AGGCGTAGGCTGTTGAT' *.fastq > count/B15512_Fm0.txt
agrep -0 -c 'GTGCTGATCGAGGCCTT' *.fastq > count/B15513_Fm0.txt
agrep -0 -c 'ACCATACTGGACAGGCT' *.fastq > count/B15514_Fm0.txt
agrep -0 -c 'GATGTTACCCCCGTACA' *.fastq > count/B15515_Fm0.txt
agrep -0 -c 'TGGAACTCCCGAACGTT' *.fastq > count/B15516_Fm0.txt
agrep -0 -c 'CGATGCTTCTGGAAGAA' *.fastq > count/B15518_Fm0.txt
agrep -0 -c 'CGGTATGACCATTAGAG' *.fastq > count/B15519_Fm0.txt
agrep -0 -c 'GCTGACCACACGTTTAA' *.fastq > count/B15520_Fm0.txt
agrep -0 -c 'TTGACGAAGACTGATAC' *.fastq > count/B15521_Fm0.txt
agrep -0 -c 'ACTACTCTGCAAGGGGG' *.fastq > count/B15522_Fm0.txt
agrep -0 -c 'ACATTGTGGCGGACTGC' *.fastq > count/B15523_Fm0.txt
agrep -0 -c 'CCGTGTTGTTCCTTTCA' *.fastq > count/B15524_Fm0.txt
agrep -0 -c 'CTAGGTAGTCACGGGCT' *.fastq > count/B15525_Fm0.txt
agrep -0 -c 'GCTCTACTTGCACATGG' *.fastq > count/B15526_Fm0.txt
agrep -0 -c 'TGCGTGGGTAGTTAGCA' *.fastq > count/B15527_Fm0.txt
agrep -0 -c 'TCGACTGTGACGTGGGA' *.fastq > count/B15529_Fm0.txt
agrep -0 -c 'GTCTATGTAGCGATTGG' *.fastq > count/B15530_Fm0.txt
agrep -0 -c 'GGTCATTATCGCTGCTG' *.fastq > count/B15531_Fm0.txt
agrep -0 -c 'TGTTTGGAATGAGTACC' *.fastq > count/B15532_Fm0.txt
agrep -0 -c 'GTCGCTGTGATAAACTT' *.fastq > count/B15534_Fm0.txt
agrep -0 -c 'TGCTAATGCGCGCGTAA' *.fastq > count/B15535_Fm0.txt
agrep -0 -c 'CGATAAAGTCATTGCCC' *.fastq > count/B15536_Fm0.txt
agrep -0 -c 'ACGTACGGAAAAAGTAC' *.fastq > count/B15537_Fm0.txt
agrep -0 -c 'GCACGTACGGAAATTGC' *.fastq > count/B15538_Fm0.txt
agrep -0 -c 'CTATGCAGCCGCGAAAA' *.fastq > count/B15539_Fm0.txt
agrep -0 -c 'TATACTGTCTAGACCGG' *.fastq > count/B15542_Fm0.txt
agrep -0 -c 'CCGGACGGTTACATTTA' *.fastq > count/B15543_Fm0.txt
agrep -0 -c 'AGTTCGCTAAATCGGGA' *.fastq > count/B15544_Fm0.txt
agrep -0 -c 'GCAATGCAAGTTTACTC' *.fastq > count/B15546_Fm0.txt
agrep -0 -c 'CGCCTGAACGCTTTCAT' *.fastq > count/B15547_Fm0.txt
agrep -0 -c 'AAGAGCGATAAGAGGTG' *.fastq > count/B15548_Fm0.txt
agrep -0 -c 'AACCGACCCTACTACGT' *.fastq > count/B15549_Fm0.txt
agrep -0 -c 'CTGTTGTTGGTGTCGGC' *.fastq > count/B15550_Fm0.txt
agrep -0 -c 'CGGTCTGGAAAGGTTAA' *.fastq > count/B15551_Fm0.txt
agrep -0 -c 'ATGCAGCCATTATAACG' *.fastq > count/B15552_Fm0.txt
agrep -0 -c 'GGAGTTAAACCGGAGTG' *.fastq > count/B15553_Fm0.txt
agrep -0 -c 'CCTACATAGTCAAGGTC' *.fastq > count/B15554_Fm0.txt
agrep -0 -c 'CGGTATATCTACACGTG' *.fastq > count/B15555_Fm0.txt
agrep -0 -c 'TGCCACAAGCGCCATTA' *.fastq > count/B15556_Fm0.txt
agrep -0 -c 'TCGAGCAGAGACTAGCC' *.fastq > count/B15557_Fm0.txt
agrep -0 -c 'GCACGTGGAATAACGGG' *.fastq > count/B15558_Fm0.txt
agrep -0 -c 'GATAATGCTTGACATCG' *.fastq > count/B15559_Fm0.txt
agrep -0 -c 'GCAACTATAAGATGGAC' *.fastq > count/B15561_Fm0.txt
agrep -0 -c 'GCCTCACGCATCACATG' *.fastq > count/B15562_Fm0.txt
agrep -0 -c 'GGATGAGAAAAACAGCG' *.fastq > count/B15564_Fm0.txt
agrep -0 -c 'AGCTGTCCGTAATTCTC' *.fastq > count/B15565_Fm0.txt
agrep -0 -c 'GGGGAAGTTGGACTAGT' *.fastq > count/B15568_Fm0.txt
agrep -0 -c 'CAACATACCGGACCGAC' *.fastq > count/B15569_Fm0.txt
agrep -0 -c 'CCGGACCTTCAGTACTG' *.fastq > count/B15570_Fm0.txt
agrep -0 -c 'CGTCTAGGCTTCACTCT' *.fastq > count/B15571_Fm0.txt
agrep -0 -c 'ACAAGGGGCTTTAGGGT' *.fastq > count/B15572_Fm0.txt
agrep -0 -c 'TACACTATAGCCGCCGC' *.fastq > count/B15574_Fm0.txt
agrep -0 -c 'ACGGAAAACTGGTTACG' *.fastq > count/B15576_Fm0.txt
agrep -0 -c 'CGCGATCCTCTGTCTAG' *.fastq > count/B15577_Fm0.txt
agrep -0 -c 'TAGGTGTTGTGGGCGAT' *.fastq > count/B15579_Fm0.txt
agrep -0 -c 'GGTGTAGGTACGACTTA' *.fastq > count/B15580_Fm0.txt
agrep -0 -c 'GCAGAATCAACATCCCC' *.fastq > count/B15581_Fm0.txt
agrep -0 -c 'ACGGTTCCGCCGTCTTA' *.fastq > count/B15582_Fm0.txt
agrep -0 -c 'GACGCATTAGGAACAAC' *.fastq > count/B15583_Fm0.txt
agrep -0 -c 'CAGACGACCGTTCAGTG' *.fastq > count/B15584_Fm0.txt
agrep -0 -c 'TCTAGAATTGGGGTTCC' *.fastq > count/B15585_Fm0.txt
agrep -0 -c 'AGTTGCTCGCGAAGAAA' *.fastq > count/B15586_Fm0.txt
agrep -0 -c 'CTAAAGCGCAGGTTCTT' *.fastq > count/B15588_Fm0.txt
agrep -0 -c 'TGAGGTAGGTTCGAATG' *.fastq > count/B15589_Fm0.txt
agrep -0 -c 'AGTACGAAGGCCGTTGT' *.fastq > count/B15590_Fm0.txt
agrep -0 -c 'CAGATCGATGCTGTGAT' *.fastq > count/B15592_Fm0.txt
agrep -0 -c 'TGTTATGCGGTGTGAGG' *.fastq > count/B15593_Fm0.txt
agrep -0 -c 'CAGGCGTTTACACCATA' *.fastq > count/B15594_Fm0.txt
agrep -0 -c 'TCACGACGACCCGCATT' *.fastq > count/B15595_Fm0.txt
agrep -0 -c 'ACCAGATCGGCCAGACA' *.fastq > count/B15596_Fm0.txt
agrep -0 -c 'ACCATCGTGCAGAGGTT' *.fastq > count/B15598_Fm0.txt
agrep -0 -c 'TAAGGCCCTGTGTCGCA' *.fastq > count/B15599_Fm0.txt
agrep -0 -c 'TGACCAGGTTATTGGGG' *.fastq > count/B15600_Fm0.txt
agrep -0 -c 'CCATTTGACTTTGCCAG' *.fastq > count/B15601_Fm0.txt
agrep -0 -c 'CCTCTGCGCAACATCTG' *.fastq > count/B15603_Fm0.txt
agrep -0 -c 'GCGTCGTGGACTAATTG' *.fastq > count/B15604_Fm0.txt
agrep -0 -c 'GATTCCTTCACATACCC' *.fastq > count/B15605_Fm0.txt
agrep -0 -c 'TTCCGTAACCACTTACA' *.fastq > count/B15606_Fm0.txt
agrep -0 -c 'CTGACCTTAAGTGCATC' *.fastq > count/B15607_Fm0.txt
agrep -0 -c 'AAGACCGTTAATTCGGC' *.fastq > count/B15608_Fm0.txt
agrep -0 -c 'GGGCCAATCTTTCATGA' *.fastq > count/B15609_Fm0.txt
agrep -0 -c 'GAGAGACTCGGCTTTGT' *.fastq > count/B15610_Fm0.txt
agrep -0 -c 'ATTGGCTCTGGTTAGTA' *.fastq > count/B15612_Fm0.txt
agrep -0 -c 'CGTGCTATAGGGATCGG' *.fastq > count/B15613_Fm0.txt
agrep -0 -c 'CAATATCCTGCTTACGG' *.fastq > count/B15614_Fm0.txt
agrep -0 -c 'AGTTTCTTAGGCCGGAA' *.fastq > count/B15615_Fm0.txt
agrep -0 -c 'ATCGAGTTCTCTGATGA' *.fastq > count/B15616_Fm0.txt
agrep -0 -c 'CAGGCCTTGGAAAAGAT' *.fastq > count/B15617_Fm0.txt
agrep -0 -c 'AATTACCGCGGTAAGAT' *.fastq > count/B15618_Fm0.txt
agrep -0 -c 'GACTTCTTTGAATGTGG' *.fastq > count/B15619_Fm0.txt
agrep -0 -c 'GCGACCTTTACCTAGCT' *.fastq > count/B15620_Fm0.txt
agrep -0 -c 'CCGTGACTAGATGGTTC' *.fastq > count/B15621_Fm0.txt
agrep -0 -c 'AGCCATACGGATACCAT' *.fastq > count/B15622_Fm0.txt
agrep -0 -c 'TATTATGAACTGCCGAG' *.fastq > count/B15623_Fm0.txt
agrep -0 -c 'TGTTCCTCCACCATAGA' *.fastq > count/B15624_Fm0.txt
agrep -0 -c 'ACTTTCCGCCAAGGATT' *.fastq > count/B15625_Fm0.txt
agrep -0 -c 'GCTGACAGTACTCTAGA' *.fastq > count/B15627_Fm0.txt
agrep -0 -c 'GGGCGTTAAACGGATTA' *.fastq > count/B15629_Fm0.txt
agrep -0 -c 'AGTGAGTGACGTCGGTC' *.fastq > count/B15630_Fm0.txt
agrep -0 -c 'ATGACAGCAGCGGCTGA' *.fastq > count/B15632_Fm0.txt
agrep -0 -c 'CGACACTACATCGAATA' *.fastq > count/B15633_Fm0.txt
agrep -0 -c 'TGTGATCGTTCGCTTGC' *.fastq > count/B15635_Fm0.txt
agrep -0 -c 'ATCTTATCCTACAGGCA' *.fastq > count/B15636_Fm0.txt
agrep -0 -c 'GCCTACACTCAGCCAAA' *.fastq > count/B15637_Fm0.txt
agrep -0 -c 'AGCATGTACTTGGTGTT' *.fastq > count/B15638_Fm0.txt
agrep -0 -c 'TCAACTGTCTCGAACCC' *.fastq > count/B15639_Fm0.txt
agrep -0 -c 'TCGCGATTTTTGGCTCC' *.fastq > count/B15640_Fm0.txt
agrep -0 -c 'CTAAGGGCGCAAACAGG' *.fastq > count/B15641_Fm0.txt
agrep -0 -c 'ACATGTATCCGAGTGTA' *.fastq > count/B15642_Fm0.txt
agrep -0 -c 'ATGAAAGGCTGGAGTGC' *.fastq > count/B15643_Fm0.txt
agrep -0 -c 'TCGCCACAGCTCCTCTA' *.fastq > count/B15644_Fm0.txt
agrep -0 -c 'ATGCCTCCGATACATCG' *.fastq > count/B15645_Fm0.txt
agrep -0 -c 'GTGTACGCGATACTTTG' *.fastq > count/B15646_Fm0.txt
agrep -0 -c 'TGTAATACACAAGTCGG' *.fastq > count/B15647_Fm0.txt
agrep -0 -c 'TCAGGTGACACCTTAAA' *.fastq > count/B15649_Fm0.txt
agrep -0 -c 'CGTTAAGCTGGTACGTC' *.fastq > count/B15650_Fm0.txt
agrep -0 -c 'GGTAACAGTTCTACCTT' *.fastq > count/B15651_Fm0.txt
agrep -0 -c 'GGGGTTCGACTACCTGA' *.fastq > count/B15652_Fm0.txt
agrep -0 -c 'ACCTCCGCTTCGAGATG' *.fastq > count/B15653_Fm0.txt
agrep -0 -c 'TTCCATTGCAGTCTGCA' *.fastq > count/B15655_Fm0.txt
agrep -0 -c 'GATCACCCACATTCTTA' *.fastq > count/B15656_Fm0.txt
agrep -0 -c 'CTAATGGTGGGTCGTAT' *.fastq > count/B15657_Fm0.txt
agrep -0 -c 'GTTAGAGCGTCTAGGCG' *.fastq > count/B15658_Fm0.txt
agrep -0 -c 'TATGGTCTACCTATGGA' *.fastq > count/B15659_Fm0.txt
agrep -0 -c 'CGAGACTAGCTTCTGGA' *.fastq > count/B15660_Fm0.txt
agrep -0 -c 'AGCGTGGTCGAGGATAT' *.fastq > count/B15661_Fm0.txt
agrep -0 -c 'ATCCGCACTGAAGTGGT' *.fastq > count/B15662_Fm0.txt
agrep -0 -c 'AAGTACGGCTTATCGCG' *.fastq > count/B15663_Fm0.txt
agrep -0 -c 'TGTCATTTCTAACGGAC' *.fastq > count/B15664_Fm0.txt
agrep -0 -c 'CTAGACCTCCGTATTAG' *.fastq > count/B15665_Fm0.txt
agrep -0 -c 'ATTGAGCGAGTGTAGTT' *.fastq > count/B15667_Fm0.txt
agrep -0 -c 'CGTCGTAAGCCAGCAGA' *.fastq > count/B15668_Fm0.txt
agrep -0 -c 'CCACTTCACTTGGCTTG' *.fastq > count/B15669_Fm0.txt
agrep -0 -c 'TTGTCGCAAGGCTTAGC' *.fastq > count/B15670_Fm0.txt
agrep -0 -c 'ATCGTTGCCACCTACTT' *.fastq > count/B15671_Fm0.txt
agrep -0 -c 'ACTCCACAGACACGTAT' *.fastq > count/B15672_Fm0.txt
agrep -0 -c 'AATGCAGACTTCCAGCT' *.fastq > count/B15673_Fm0.txt
agrep -0 -c 'ATTTCGAATCCAGCTCT' *.fastq > count/B15674_Fm0.txt
agrep -0 -c 'TACACCTTTCCGATATG' *.fastq > count/B15675_Fm0.txt
agrep -0 -c 'GACACGATGGATAGTAA' *.fastq > count/B15676_Fm0.txt
agrep -0 -c 'CTGGAGCCGGTAAATCT' *.fastq > count/B15677_Fm0.txt
agrep -0 -c 'AGCTAGGAGCCGAGGTA' *.fastq > count/B15678_Fm0.txt
agrep -0 -c 'AGGCTGACAAATCATCC' *.fastq > count/B15679_Fm0.txt
agrep -0 -c 'GTGACTGTCCCAAAGTT' *.fastq > count/B15680_Fm0.txt
agrep -0 -c 'AGTCGGTAACGTCACGT' *.fastq > count/B15681_Fm0.txt
agrep -0 -c 'CGACTAAAGTTGACTCT' *.fastq > count/B15682_Fm0.txt
agrep -0 -c 'GTCCTGTTGGTCATAAC' *.fastq > count/B15683_Fm0.txt
agrep -0 -c 'TACAGGGACGAAATTGC' *.fastq > count/B15684_Fm0.txt
agrep -0 -c 'TACCTTATCGTTTTCGG' *.fastq > count/B15685_Fm0.txt
agrep -0 -c 'GCTATGGATCGCCATAC' *.fastq > count/B15686_Fm0.txt
agrep -0 -c 'GTGTAACGATGCTTAGT' *.fastq > count/B15687_Fm0.txt
agrep -0 -c 'GGATGATACCTATCGAT' *.fastq > count/B15688_Fm0.txt
agrep -0 -c 'TGATTCGCAGGAACCGA' *.fastq > count/B15689_Fm0.txt
agrep -0 -c 'GCGTTTTAGCGCTCAGA' *.fastq > count/B15691_Fm0.txt
agrep -0 -c 'AACACCCATCCGGCAAC' *.fastq > count/B15694_Fm0.txt
agrep -0 -c 'CGATCGTAGCTATTAAC' *.fastq > count/B15695_Fm0.txt
agrep -0 -c 'GGTGGTCGACATCTGTC' *.fastq > count/B15696_Fm0.txt
agrep -0 -c 'GCCATTTTGTAAGCCAG' *.fastq > count/B15697_Fm0.txt
agrep -0 -c 'ACGTCGTCCATGGAACG' *.fastq > count/B15698_Fm0.txt
agrep -0 -c 'CTGTGTGCTTCCGCTTG' *.fastq > count/B15699_Fm0.txt
agrep -0 -c 'TAGACTTACCGGTCAGC' *.fastq > count/B15700_Fm0.txt
agrep -0 -c 'ACAATGCGAAATAGGGG' *.fastq > count/B15701_Fm0.txt
agrep -0 -c 'GGATATTGCAGCAACGC' *.fastq > count/B15702_Fm0.txt
agrep -0 -c 'TGTCGTACAGACCTAGA' *.fastq > count/B15703_Fm0.txt
agrep -0 -c 'GTCAGCCTCCGTTGATG' *.fastq > count/B15704_Fm0.txt
agrep -0 -c 'GGATCCGCAAAATGCAC' *.fastq > count/B15705_Fm0.txt
agrep -0 -c 'TGATTAGTCTGGACACA' *.fastq > count/B15706_Fm0.txt
agrep -0 -c 'CCTATCTGCTGGCCATC' *.fastq > count/B15708_Fm0.txt
agrep -0 -c 'CGGGGCAACATGCAGAT' *.fastq > count/B15709_Fm0.txt
agrep -0 -c 'ACCGATCTAGGAGCACC' *.fastq > count/B15710_Fm0.txt
agrep -0 -c 'TGAGAAGGGCATCCTAA' *.fastq > count/B15711_Fm0.txt
agrep -0 -c 'GGGGGACACATGCTGAT' *.fastq > count/B15712_Fm0.txt
agrep -0 -c 'GGTGAATGTTCCGCCTG' *.fastq > count/B15713_Fm0.txt
agrep -0 -c 'GCCGATCATAGAAAGAG' *.fastq > count/B15714_Fm0.txt
agrep -0 -c 'GAGTGGAACAGATTTCC' *.fastq > count/B15715_Fm0.txt
agrep -0 -c 'ATTCGTGGTACCCCCCA' *.fastq > count/B15716_Fm0.txt
agrep -0 -c 'TCTCAAAGTTTCGCCTA' *.fastq > count/B15717_Fm0.txt
agrep -0 -c 'CTGAATATCGCTACCAA' *.fastq > count/B15718_Fm0.txt
agrep -0 -c 'TTGCACCAATGTCGTTG' *.fastq > count/B15719_Fm0.txt
agrep -0 -c 'TGAGACAACGTACGGTC' *.fastq > count/B15720_Fm0.txt
agrep -0 -c 'GGCTCTATATAACCTAC' *.fastq > count/B15721_Fm0.txt
agrep -0 -c 'CGCAACGGGCGTTTAGA' *.fastq > count/B15723_Fm0.txt
agrep -0 -c 'GTTGTACTGCTATCTCG' *.fastq > count/B15727_Fm0.txt
agrep -0 -c 'TGAAGTCGCGAACCAAT' *.fastq > count/B15728_Fm0.txt
agrep -0 -c 'TACAGCGGACAGTCATT' *.fastq > count/B15729_Fm0.txt
agrep -0 -c 'GGCCGCAATAGAAGCAG' *.fastq > count/B15730_Fm0.txt
agrep -0 -c 'TAGTCAAGGCGCATCTT' *.fastq > count/B15731_Fm0.txt
agrep -0 -c 'AGGGTTAAGTCAAGCTC' *.fastq > count/B15732_Fm0.txt
agrep -0 -c 'GCGTAATCCTTGGATAA' *.fastq > count/B15733_Fm0.txt
agrep -0 -c 'ATAGCTGGCCCGAGGAA' *.fastq > count/B15734_Fm0.txt
agrep -0 -c 'CCGGGTTGTGCATCTCT' *.fastq > count/B15735_Fm0.txt
agrep -0 -c 'GCATTAAAGTGCCAGTA' *.fastq > count/B15736_Fm0.txt
agrep -0 -c 'CTTCGTCAGCCTCATGC' *.fastq > count/B15737_Fm0.txt
agrep -0 -c 'CAGCGCTGGCACTGTTA' *.fastq > count/B15738_Fm0.txt
agrep -0 -c 'AACAGGCACGCCACTGA' *.fastq > count/B15739_Fm0.txt
agrep -0 -c 'CAATCCTGGAAGAGACC' *.fastq > count/B15740_Fm0.txt
agrep -0 -c 'TGAGTGAGTAGGATCTC' *.fastq > count/B15741_Fm0.txt
agrep -0 -c 'TGACAGTCCTCTCTGGG' *.fastq > count/B15742_Fm0.txt
agrep -0 -c 'GCCCGGTATTGTAGATT' *.fastq > count/B15743_Fm0.txt
agrep -0 -c 'CAGCATCAATGCAACGG' *.fastq > count/B15744_Fm0.txt
agrep -0 -c 'GACTCGTGTGCAGCTAC' *.fastq > count/B15745_Fm0.txt
agrep -0 -c 'TTCCAACCTAGAGAGCG' *.fastq > count/B15746_Fm0.txt
agrep -0 -c 'GCAGTTCCTTAACTTCT' *.fastq > count/B15747_Fm0.txt
agrep -0 -c 'GGGGTTTTTTTCTTGGC' *.fastq > count/B15748_Fm0.txt
agrep -0 -c 'CTCTTTTGCCGAGTCAA' *.fastq > count/B15750_Fm0.txt
agrep -0 -c 'CAAGCATCGGCGGTATA' *.fastq > count/B15751_Fm0.txt
agrep -0 -c 'TTGCTAAGTCCCCGATA' *.fastq > count/B15752_Fm0.txt
agrep -0 -c 'GCCATTAGTGTAGACAA' *.fastq > count/B15753_Fm0.txt
agrep -0 -c 'ACTTACCTGCCATCCCA' *.fastq > count/B15754_Fm0.txt
agrep -0 -c 'TCTGAGTGCTCTTTTGC' *.fastq > count/B15755_Fm0.txt
agrep -0 -c 'ATCACCTCCCCCTAACG' *.fastq > count/B15756_Fm0.txt
agrep -0 -c 'CCTGTTACCACTACCGG' *.fastq > count/B15758_Fm0.txt
agrep -0 -c 'GGTAGACATGATGGGCG' *.fastq > count/B15759_Fm0.txt
agrep -0 -c 'TCTAATGCATACCGTAG' *.fastq > count/B15760_Fm0.txt
agrep -0 -c 'TTCGGAAGATAAGACCG' *.fastq > count/B15762_Fm0.txt
agrep -0 -c 'CCGTCATCATGTATAGT' *.fastq > count/B15763_Fm0.txt
agrep -0 -c 'AAGTCTATACAGTGTCG' *.fastq > count/B15764_Fm0.txt
agrep -0 -c 'GTACTGATTCGTACGAG' *.fastq > count/B15766_Fm0.txt
agrep -0 -c 'TGATCTAAGTCACGCTC' *.fastq > count/B15767_Fm0.txt
agrep -0 -c 'CGCTGGGTCACACTACA' *.fastq > count/B15768_Fm0.txt
agrep -0 -c 'AGGCCCCCTGATTTTCC' *.fastq > count/B15769_Fm0.txt
agrep -0 -c 'CAGCGAGTTCGTATCAC' *.fastq > count/B15770_Fm0.txt
agrep -0 -c 'GTCATGAGTCTACTACT' *.fastq > count/B15771_Fm0.txt
agrep -0 -c 'TGAGGTATGTCCTCTAA' *.fastq > count/B15772_Fm0.txt
agrep -0 -c 'TATTAGTCCTGGGATAC' *.fastq > count/B15773_Fm0.txt
agrep -0 -c 'GACTGAGTTACTTCGGC' *.fastq > count/B15774_Fm0.txt
agrep -0 -c 'CACTCTGACGGTTACCT' *.fastq > count/B15775_Fm0.txt
agrep -0 -c 'GACGCCAGCATCTTGTT' *.fastq > count/B15776_Fm0.txt
agrep -0 -c 'CGGACAATCCGTATCCC' *.fastq > count/B15777_Fm0.txt
agrep -0 -c 'CTCGCGACTATCTAAGG' *.fastq > count/B15778_Fm0.txt
agrep -0 -c 'GTCACGCAAGCTTGTAA' *.fastq > count/B15779_Fm0.txt
agrep -0 -c 'GTTACCTACCCTGAATG' *.fastq > count/B15780_Fm0.txt
agrep -0 -c 'ACGCCAGTATGATGCAT' *.fastq > count/B15782_Fm0.txt
agrep -0 -c 'TACCACGGAAGACGAAT' *.fastq > count/B15783_Fm0.txt
agrep -0 -c 'CGCGTCCTGCTTCCATT' *.fastq > count/B15784_Fm0.txt
agrep -0 -c 'GCGTAATGAAGAGTTCC' *.fastq > count/B15785_Fm0.txt
agrep -0 -c 'TGACTGTAACTGGCCCA' *.fastq > count/B15786_Fm0.txt
agrep -0 -c 'ACATCTACGTTATGCAG' *.fastq > count/B15789_Fm0.txt
agrep -0 -c 'GGCGACTCGCCTATTCA' *.fastq > count/B15790_Fm0.txt
agrep -0 -c 'TTACAGGCCTTCGGATG' *.fastq > count/B15791_Fm0.txt
agrep -0 -c 'CCATGTGCCAAACTTAC' *.fastq > count/B15792_Fm0.txt
agrep -0 -c 'GCCCGGAAACTCTACCA' *.fastq > count/B15793_Fm0.txt
agrep -0 -c 'TATTACCCTGCCGAGGT' *.fastq > count/B15794_Fm0.txt
agrep -0 -c 'TTCCTTCCTCCGAACTT' *.fastq > count/B15796_Fm0.txt
agrep -0 -c 'GACAATACGGGGCATTA' *.fastq > count/B15797_Fm0.txt
agrep -0 -c 'AGCTTCTGTTATCCGGA' *.fastq > count/B15799_Fm0.txt
agrep -0 -c 'GTGTCGGAACGCGATTA' *.fastq > count/B15800_Fm0.txt
agrep -0 -c 'GGATTTAACGGTGCGCG' *.fastq > count/B15801_Fm0.txt
agrep -0 -c 'CCATTGGCATGAACCAT' *.fastq > count/B15803_Fm0.txt
agrep -0 -c 'GACGAAGGTAGGAAGTG' *.fastq > count/B15804_Fm0.txt
agrep -0 -c 'AAGTCCCCCGTTAGTTC' *.fastq > count/B15805_Fm0.txt
agrep -0 -c 'CTGGCCAGATTTCAATG' *.fastq > count/B15806_Fm0.txt
agrep -0 -c 'GGGAGCTCGTTGATGAA' *.fastq > count/B15807_Fm0.txt
agrep -0 -c 'TTGACAGTGCGAGCGAA' *.fastq > count/B15808_Fm0.txt
agrep -0 -c 'CATCTAATGGAACGTGG' *.fastq > count/B15809_Fm0.txt
agrep -0 -c 'TAGGCCCACACCGGTTA' *.fastq > count/B15812_Fm0.txt
agrep -0 -c 'TCGGTTCCGCTAGGATT' *.fastq > count/B15813_Fm0.txt
agrep -0 -c 'AACGGTAGTTCCAATTG' *.fastq > count/B15814_Fm0.txt
agrep -0 -c 'TTCCGCAAGTCCGTACA' *.fastq > count/B15815_Fm0.txt
agrep -0 -c 'GGCACTGCAACTGTATT' *.fastq > count/B15816_Fm0.txt
agrep -0 -c 'AATCAAATCCCGTACGC' *.fastq > count/B15817_Fm0.txt
agrep -0 -c 'CGGTGCTTTCCGAAGAG' *.fastq > count/B15818_Fm0.txt
agrep -0 -c 'CGCAGAAAATGGCCAAA' *.fastq > count/B15819_Fm0.txt
agrep -0 -c 'ACGCGAACACGACTCTC' *.fastq > count/B15820_Fm0.txt
agrep -0 -c 'GCTAAGTCACGATCAGC' *.fastq > count/B15821_Fm0.txt
agrep -0 -c 'TACGAGGCATGGATTAC' *.fastq > count/B15823_Fm0.txt
agrep -0 -c 'GGATGGGTTGCTCTACC' *.fastq > count/B15824_Fm0.txt
agrep -0 -c 'GGTCTAACCTGAACGCG' *.fastq > count/B15825_Fm0.txt
agrep -0 -c 'GGATGCGATCACTGAGT' *.fastq > count/B15826_Fm0.txt
agrep -0 -c 'ATATGTAGAGCTCCCAC' *.fastq > count/B15827_Fm0.txt
agrep -0 -c 'GCTGGATTGTGATGCGG' *.fastq > count/B15829_Fm0.txt
agrep -0 -c 'AACCGATCCTCATGAAC' *.fastq > count/B15830_Fm0.txt
agrep -0 -c 'GCAAAATGTGCAGGACT' *.fastq > count/B15831_Fm0.txt
agrep -0 -c 'TACCATCGGACCATCTT' *.fastq > count/B15832_Fm0.txt
agrep -0 -c 'ATGGCCGGCAAAGATCC' *.fastq > count/B15833_Fm0.txt
agrep -0 -c 'ACCACTCCCAAGCTTAA' *.fastq > count/B15834_Fm0.txt
agrep -0 -c 'TCGGTTACCGCACTTCG' *.fastq > count/B15837_Fm0.txt
agrep -0 -c 'CGTCATATCTCAAGAAG' *.fastq > count/B15838_Fm0.txt
agrep -0 -c 'ACGAAGGGAAGTACTTA' *.fastq > count/B15839_Fm0.txt
agrep -0 -c 'TGCCTATCGAGGACTCA' *.fastq > count/B15840_Fm0.txt
agrep -0 -c 'TACAGTAGTTCTGGATG' *.fastq > count/B15841_Fm0.txt
agrep -0 -c 'TTACCAAGTCGCCGATG' *.fastq > count/B15842_Fm0.txt
agrep -0 -c 'CGGACAAGTCACGCTAC' *.fastq > count/B15843_Fm0.txt
agrep -0 -c 'AAGCCGAGTTCTTCATG' *.fastq > count/B15844_Fm0.txt
agrep -0 -c 'ACCATTTGCGGGGTGTT' *.fastq > count/B15845_Fm0.txt
agrep -0 -c 'AGGTTAGCCGGACCTGT' *.fastq > count/B15846_Fm0.txt
agrep -0 -c 'TCTAGGTATGGCGACAA' *.fastq > count/B15847_Fm0.txt
agrep -0 -c 'GCTGACGCTGCAAACAG' *.fastq > count/B15849_Fm0.txt
agrep -0 -c 'TCGTACGAAGACAACCC' *.fastq > count/B15851_Fm0.txt
agrep -0 -c 'GTCCACAGACCGTTTTT' *.fastq > count/B15853_Fm0.txt
agrep -0 -c 'CTGATCGGTACCGCGTT' *.fastq > count/B15854_Fm0.txt
agrep -0 -c 'GCACTAGTTGACCAACT' *.fastq > count/B15855_Fm0.txt
agrep -0 -c 'CTGCTAATTCGCGTTTT' *.fastq > count/B15856_Fm0.txt
agrep -0 -c 'CGCTTATATCCCCGGAC' *.fastq > count/B15857_Fm0.txt
agrep -0 -c 'CTAATCGGCCAGAATAA' *.fastq > count/B15858_Fm0.txt
agrep -0 -c 'GATGTCCATACTTCTGA' *.fastq > count/B15860_Fm0.txt
agrep -0 -c 'TACCGAGTACTGCAACG' *.fastq > count/B15861_Fm0.txt
agrep -0 -c 'CTATTCTCAGGATTGGT' *.fastq > count/B15862_Fm0.txt
agrep -0 -c 'GCACACAGTTTGGTGGG' *.fastq > count/B15863_Fm0.txt
agrep -0 -c 'CGTCGCTACAAATAGGG' *.fastq > count/B15864_Fm0.txt
agrep -0 -c 'CTGGGTTATTTTGCGCG' *.fastq > count/B15865_Fm0.txt
agrep -0 -c 'GGAGGCGAGGATTATGA' *.fastq > count/B15866_Fm0.txt
agrep -0 -c 'AGTGGCCTGGTTTTAGG' *.fastq > count/B15867_Fm0.txt
agrep -0 -c 'GCGCCCTGTTAACTGTG' *.fastq > count/B15868_Fm0.txt
agrep -0 -c 'GGTGCTTATTACATCGA' *.fastq > count/B15869_Fm0.txt
agrep -0 -c 'TAACTGCGGTACTACAA' *.fastq > count/B15870_Fm0.txt
agrep -0 -c 'GATATCATCTATCCGGA' *.fastq > count/B15871_Fm0.txt
agrep -0 -c 'CTACGAGTCTACCGATG' *.fastq > count/B15872_Fm0.txt
agrep -0 -c 'AACAGGCTGATCCTTCT' *.fastq > count/B15874_Fm0.txt
agrep -0 -c 'AACACAGGTTTGTGGTT' *.fastq > count/B15875_Fm0.txt
agrep -0 -c 'CGCAACTGCGTAGTTAA' *.fastq > count/B15877_Fm0.txt
agrep -0 -c 'GCTGTCGACCGAATTCA' *.fastq > count/B15879_Fm0.txt
agrep -0 -c 'ACCTCTTTCGCACAGCG' *.fastq > count/B15881_Fm0.txt
agrep -0 -c 'CACGTACATAGTGCCAG' *.fastq > count/B15882_Fm0.txt
agrep -0 -c 'CATGTGCCAGCGTCACA' *.fastq > count/B15883_Fm0.txt
agrep -0 -c 'CAACTCGTAAGCTCGTC' *.fastq > count/B15884_Fm0.txt
agrep -0 -c 'CTCTGAGCTACCTGGTT' *.fastq > count/B15885_Fm0.txt
agrep -0 -c 'CGAAGAGCACCCACATC' *.fastq > count/B15886_Fm0.txt
agrep -0 -c 'CGGCCACTTACAAATCA' *.fastq > count/B15888_Fm0.txt
agrep -0 -c 'TAATCCCCTTTCGGCGG' *.fastq > count/B15889_Fm0.txt
agrep -0 -c 'AAGTCGCAGCCTAACAG' *.fastq > count/B15890_Fm0.txt
agrep -0 -c 'CTGATCGATAACGACGA' *.fastq > count/B15892_Fm0.txt
agrep -0 -c 'CGTAGCCGCTCCATTCA' *.fastq > count/B15893_Fm0.txt
agrep -0 -c 'TAGAGCGTTCCGGTAGC' *.fastq > count/B15894_Fm0.txt
agrep -0 -c 'ACTAAATGCCCCCATTC' *.fastq > count/B15895_Fm0.txt
agrep -0 -c 'TCAACGTGATTGGTTCC' *.fastq > count/B15896_Fm0.txt
agrep -0 -c 'GACTCCGCTCCTCCATT' *.fastq > count/B15897_Fm0.txt
agrep -0 -c 'GATACGAGACCGTCCTA' *.fastq > count/B15898_Fm0.txt
agrep -0 -c 'GCCCTCTTAACGCGATC' *.fastq > count/B15899_Fm0.txt
agrep -0 -c 'TTCGCGCACAAAACAGC' *.fastq > count/B15903_Fm0.txt
agrep -0 -c 'GTCACCTACAGACCCGA' *.fastq > count/B15904_Fm0.txt
agrep -0 -c 'AGCCAATTAGTCAACTC' *.fastq > count/B15905_Fm0.txt
agrep -0 -c 'CGCGAACCTATACCGTC' *.fastq > count/B15906_Fm0.txt
agrep -0 -c 'AGGTAACCATGTAGTTG' *.fastq > count/B15907_Fm0.txt
agrep -0 -c 'ACCTTGTACCCTCTTCC' *.fastq > count/B15908_Fm0.txt
agrep -0 -c 'CAGCTACGGGTTAACGC' *.fastq > count/B15909_Fm0.txt
agrep -0 -c 'GTGGGATATGCTATCAA' *.fastq > count/B15910_Fm0.txt
agrep -0 -c 'CCAGCAATTGGATGTCA' *.fastq > count/B15911_Fm0.txt
agrep -0 -c 'GCGAGTGTATACGGATT' *.fastq > count/B15912_Fm0.txt
agrep -0 -c 'TGTAGCCGCTAAGCGTG' *.fastq > count/B15915_Fm0.txt
agrep -0 -c 'TGAACGTGCACCATATA' *.fastq > count/B15917_Fm0.txt
agrep -0 -c 'CGGAGCAACCAGTGACT' *.fastq > count/B15919_Fm0.txt
agrep -0 -c 'CGCGATGCTACATACCA' *.fastq > count/B15920_Fm0.txt
agrep -0 -c 'AGCCTGCTTGTCCAAGG' *.fastq > count/B15921_Fm0.txt
agrep -0 -c 'GGAAGGTCTCTGCAATC' *.fastq > count/B15922_Fm0.txt
agrep -0 -c 'GCAAAGATCACGACCTG' *.fastq > count/B15923_Fm0.txt
agrep -0 -c 'AACAGGATATAAGCAGG' *.fastq > count/B15925_Fm0.txt
agrep -0 -c 'TTACTGAACTGACCATG' *.fastq > count/B15927_Fm0.txt
agrep -0 -c 'ATACGTTCGAGACCAAC' *.fastq > count/B15928_Fm0.txt
agrep -0 -c 'CTGCTTTGGCTTATGGA' *.fastq > count/B15929_Fm0.txt
agrep -0 -c 'CGCGAACTCGAGGTAGT' *.fastq > count/B15931_Fm0.txt
agrep -0 -c 'GATAACTACGGCCGCAC' *.fastq > count/B15933_Fm0.txt
agrep -0 -c 'AAGTGATAGTCATTCGG' *.fastq > count/B15934_Fm0.txt
agrep -0 -c 'CATCTATCGTTTTGCCT' *.fastq > count/B15935_Fm0.txt
agrep -0 -c 'TGATGTCGCAATATCCG' *.fastq > count/B15936_Fm0.txt
agrep -0 -c 'GCTAACTTAGCGGGCTC' *.fastq > count/B15938_Fm0.txt
agrep -0 -c 'GATAACAGCCGCCTACG' *.fastq > count/B15939_Fm0.txt
agrep -0 -c 'CTCGAACACACGGAAAT' *.fastq > count/B15941_Fm0.txt
agrep -0 -c 'GATGCCGAATAAAGCAT' *.fastq > count/B15942_Fm0.txt
agrep -0 -c 'TGCGGGTGAGGCATAAC' *.fastq > count/B15943_Fm0.txt
agrep -0 -c 'CAAAATTCGCGGAAAGA' *.fastq > count/B15944_Fm0.txt
agrep -0 -c 'GGACATCTCATGTGAGG' *.fastq > count/B15945_Fm0.txt
agrep -0 -c 'TGGAGAAGTCTACTTTC' *.fastq > count/B15946_Fm0.txt
agrep -0 -c 'CGTCCATTACCTAGCCT' *.fastq > count/B15947_Fm0.txt
agrep -0 -c 'GACGATGACTGATTCGA' *.fastq > count/B15948_Fm0.txt
agrep -0 -c 'CTAAGTGCGTCGACATG' *.fastq > count/B15949_Fm0.txt
agrep -0 -c 'TAGTTCAGACCCCCTCG' *.fastq > count/B15950_Fm0.txt
agrep -0 -c 'CTCCTCACGCATCGATT' *.fastq > count/B15952_Fm0.txt
agrep -0 -c 'AGTGGTACGTCCTCCGA' *.fastq > count/B15953_Fm0.txt
agrep -0 -c 'ACATCCCCATTCGCGTT' *.fastq > count/B15954_Fm0.txt
agrep -0 -c 'GTTGTTCTGTATCAACG' *.fastq > count/B15955_Fm0.txt
agrep -0 -c 'ATGGGTTGCCCTACATG' *.fastq > count/B15956_Fm0.txt
agrep -0 -c 'CGACTCGTAAACACTAA' *.fastq > count/B15957_Fm0.txt
agrep -0 -c 'GTCGGGTTTGAAGTGAG' *.fastq > count/B15958_Fm0.txt
agrep -0 -c 'TCTGATCAACTTCCTCG' *.fastq > count/B15959_Fm0.txt
agrep -0 -c 'TTGAAGTAGACATGGCG' *.fastq > count/B15960_Fm0.txt
agrep -0 -c 'GAGTAGACTGGGTTATT' *.fastq > count/B15961_Fm0.txt
agrep -0 -c 'TGCCCAAATAAAGCACC' *.fastq > count/B15963_Fm0.txt
agrep -0 -c 'GCGGCGTCTCAAAAATC' *.fastq > count/B15964_Fm0.txt
agrep -0 -c 'AGGCGGCTCAAAAATCT' *.fastq > count/B15965_Fm0.txt
agrep -0 -c 'CGAAACTCCGAGCAGAC' *.fastq > count/B15966_Fm0.txt
agrep -0 -c 'TGCATAAGGAACGGATA' *.fastq > count/B15967_Fm0.txt
agrep -0 -c 'TACACAGCTTGACAGCG' *.fastq > count/B15968_Fm0.txt
agrep -0 -c 'CGCCATTACCCGTCCTT' *.fastq > count/B15969_Fm0.txt
agrep -0 -c 'TAACGAACAGGCTTTGC' *.fastq > count/B15970_Fm0.txt
agrep -0 -c 'GTTCTTCCGCAAAGCTG' *.fastq > count/B15971_Fm0.txt
agrep -0 -c 'GTATACAATCATGGCCG' *.fastq > count/B15973_Fm0.txt
agrep -0 -c 'CTTCACGTACAGGTGTC' *.fastq > count/B15974_Fm0.txt
agrep -0 -c 'AAGGCCCAGCTATCTTC' *.fastq > count/B15975_Fm0.txt
agrep -0 -c 'GCGTAGGTTTAGTTACC' *.fastq > count/B15979_Fm0.txt
agrep -0 -c 'AACTCGTTTCGCGCGTG' *.fastq > count/B15981_Fm0.txt
agrep -0 -c 'CAACGGAGCCCTACCAA' *.fastq > count/B15982_Fm0.txt
agrep -0 -c 'CCGAGACCTCGTATATT' *.fastq > count/B15983_Fm0.txt
agrep -0 -c 'GATGTCGCCAAGGCTAC' *.fastq > count/B15984_Fm0.txt
agrep -0 -c 'CCGTCGCTTAATACTTC' *.fastq > count/B15987_Fm0.txt
agrep -0 -c 'ACGTATGTCTAACCGCG' *.fastq > count/B15990_Fm0.txt
agrep -0 -c 'GGGGTGGTACACTTAGG' *.fastq > count/B15991_Fm0.txt
agrep -0 -c 'AGCACGTACATGTCTTC' *.fastq > count/B15992_Fm0.txt
agrep -0 -c 'TTGGCCCATTCCCAATT' *.fastq > count/B15993_Fm0.txt
agrep -0 -c 'AGTATCCTAGCCAGCAT' *.fastq > count/B15994_Fm0.txt
agrep -0 -c 'CATACCTAACGAGACTC' *.fastq > count/B15995_Fm0.txt
agrep -0 -c 'ACAACTATCGCATTTCG' *.fastq > count/B15996_Fm0.txt
agrep -0 -c 'ATGGGCAGTGTGTTTAG' *.fastq > count/B15999_Fm0.txt
agrep -0 -c 'CTACGCTATTATCCCCT' *.fastq > count/B16000_Fm0.txt
agrep -0 -c 'ACTGCTATTTGCTCAGG' *.fastq > count/B16001_Fm0.txt
agrep -0 -c 'CGCCTCACCCCTATTCT' *.fastq > count/B16002_Fm0.txt
agrep -0 -c 'TATGGGTCTTCACCTTC' *.fastq > count/B16003_Fm0.txt
agrep -0 -c 'TGAGGCGCACCACGTAA' *.fastq > count/B16004_Fm0.txt
agrep -0 -c 'AGCGCTGTTGCACGTAG' *.fastq > count/B16005_Fm0.txt
agrep -0 -c 'TCGGGAGCCGTATTAGC' *.fastq > count/B16006_Fm0.txt
agrep -0 -c 'ACAACCTGCTTTGTGCT' *.fastq > count/B16007_Fm0.txt
agrep -0 -c 'TTATGTCCGCGTCTGGT' *.fastq > count/B16008_Fm0.txt
agrep -0 -c 'TAACGGAGTATCGCGAA' *.fastq > count/B16009_Fm0.txt
agrep -0 -c 'CCGGTATCAGAGTTATT' *.fastq > count/B16010_Fm0.txt
agrep -0 -c 'CAGAATACTAACACGTC' *.fastq > count/B16011_Fm0.txt
agrep -0 -c 'GGCTTAAGCCCACTAGT' *.fastq > count/B16012_Fm0.txt
agrep -0 -c 'GTGTGGATTGTTCATAC' *.fastq > count/B16013_Fm0.txt
agrep -0 -c 'TGTGAACGTCAGTCGAA' *.fastq > count/B16014_Fm0.txt
agrep -0 -c 'GACTCACATGAACAACC' *.fastq > count/B16015_Fm0.txt
agrep -0 -c 'CGAAGCGGATTCGGAGA' *.fastq > count/B16016_Fm0.txt
agrep -0 -c 'GTGAACCTGAATTGCCC' *.fastq > count/B16017_Fm0.txt
agrep -0 -c 'CATCCCCAGAAATTGTA' *.fastq > count/B16018_Fm0.txt
agrep -0 -c 'TATCCCACCCGATGATC' *.fastq > count/B16019_Fm0.txt
agrep -0 -c 'TCGGAGATGGGAGTATT' *.fastq > count/B16020_Fm0.txt
agrep -0 -c 'AATCGTGCGACAATCAA' *.fastq > count/B16021_Fm0.txt
agrep -0 -c 'GGCCATGTGAATTTCTC' *.fastq > count/B16022_Fm0.txt
agrep -0 -c 'ACGAACCATAGATCCCT' *.fastq > count/B16023_Fm0.txt
agrep -0 -c 'TCTTATGGTAGCTGACC' *.fastq > count/B16024_Fm0.txt
agrep -0 -c 'CGAATACGATCATGCAT' *.fastq > count/B16025_Fm0.txt
agrep -0 -c 'ATGGGGGTCTAAACGCG' *.fastq > count/B16026_Fm0.txt
agrep -0 -c 'AGCAGAATCGTTGGGCT' *.fastq > count/B16027_Fm0.txt
agrep -0 -c 'CATGAGAGCCTATGTTG' *.fastq > count/B16029_Fm0.txt
agrep -0 -c 'GTACAGCCAACGTTACG' *.fastq > count/B16030_Fm0.txt
agrep -0 -c 'CACTTTTGGTCTCCAGC' *.fastq > count/B16031_Fm0.txt
agrep -0 -c 'CGGAGCCCTTTAAAAAG' *.fastq > count/B16032_Fm0.txt
agrep -0 -c 'ACGAACGAACCGATACC' *.fastq > count/B16033_Fm0.txt
agrep -0 -c 'CTGCTTAACGTCTCTAT' *.fastq > count/B16036_Fm0.txt
agrep -0 -c 'GCAATCGATGTATCCTG' *.fastq > count/B16037_Fm0.txt
agrep -0 -c 'GACTGATGGCAACGCCT' *.fastq > count/B16038_Fm0.txt
agrep -0 -c 'TTGGCACGATCGTCAAT' *.fastq > count/B16039_Fm0.txt
agrep -0 -c 'GCGGGGAAGATTTAGGA' *.fastq > count/B16040_Fm0.txt
agrep -0 -c 'GGCGTGTAACCAATGCT' *.fastq > count/B16041_Fm0.txt
agrep -0 -c 'TCGGAGAGTTCAGACCT' *.fastq > count/B16042_Fm0.txt
agrep -0 -c 'CTGCTAGCGAAATCATG' *.fastq > count/B16043_Fm0.txt
agrep -0 -c 'AGATAGGATCCAGGTAC' *.fastq > count/B16044_Fm0.txt
agrep -0 -c 'AATATCGAGCAACGGTC' *.fastq > count/B16046_Fm0.txt
agrep -0 -c 'GAGAAGACCGTCGGACA' *.fastq > count/B16047_Fm0.txt
agrep -0 -c 'AGCGGGTACCTAGAGTT' *.fastq > count/B16048_Fm0.txt
agrep -0 -c 'GTGAGCACGAAGGACTT' *.fastq > count/B16049_Fm0.txt
agrep -0 -c 'TACCGGTTGGTCTTGTT' *.fastq > count/B16050_Fm0.txt
agrep -0 -c 'CTACGTTACAGAATGTG' *.fastq > count/B16051_Fm0.txt
agrep -0 -c 'TCGTTTAGGGGTGAGGT' *.fastq > count/B16052_Fm0.txt
agrep -0 -c 'GCCACACATTTGGCGTA' *.fastq > count/B16053_Fm0.txt
agrep -0 -c 'TGAGTATCGGAGTGGGG' *.fastq > count/B16054_Fm0.txt
agrep -0 -c 'CACTTCCGTCCAGCTTC' *.fastq > count/B16055_Fm0.txt
agrep -0 -c 'TCTCCGAATCGCCTTGC' *.fastq > count/B16057_Fm0.txt
agrep -0 -c 'AAGGTTTTGTCAACGCA' *.fastq > count/B16058_Fm0.txt
agrep -0 -c 'CGGTTCATTGAGACGAG' *.fastq > count/B16059_Fm0.txt
agrep -0 -c 'GCGAGCCTTCGCACTTT' *.fastq > count/B16060_Fm0.txt
agrep -0 -c 'CTGAAGTCTTCCAGTGG' *.fastq > count/B16061_Fm0.txt
agrep -0 -c 'CTGCTCCCCCTGTAATG' *.fastq > count/B16062_Fm0.txt
agrep -0 -c 'ATTCACACTAGGAGGTT' *.fastq > count/B16063_Fm0.txt
agrep -0 -c 'GATAAGTTGGTTCGGGA' *.fastq > count/B16064_Fm0.txt
agrep -0 -c 'CTTAAGGAACTGGGTTG' *.fastq > count/B16065_Fm0.txt
agrep -0 -c 'GTAACATCTCCTTCGCA' *.fastq > count/B16066_Fm0.txt
agrep -0 -c 'CTGGCGGACCCGATATT' *.fastq > count/B16068_Fm0.txt
agrep -0 -c 'TACCAGCGCTTTATCTG' *.fastq > count/B16069_Fm0.txt
agrep -0 -c 'TGATAAAGGGGCCGTTG' *.fastq > count/B16070_Fm0.txt
agrep -0 -c 'AGCCGCTGGCTACTTGA' *.fastq > count/B16071_Fm0.txt
agrep -0 -c 'GTCAGCCTCCACCACTA' *.fastq > count/B16072_Fm0.txt
agrep -0 -c 'TAACGTAGATGCATGAC' *.fastq > count/B16073_Fm0.txt
agrep -0 -c 'TCGCTGACGAATGTTCA' *.fastq > count/B16074_Fm0.txt
agrep -0 -c 'ATACCAGACCTATCGTC' *.fastq > count/B16078_Fm0.txt
agrep -0 -c 'AGGATCGTCCCAATTTA' *.fastq > count/B16080_Fm0.txt
agrep -0 -c 'TGTGGCGCAGTATACAG' *.fastq > count/B16081_Fm0.txt
agrep -0 -c 'TTGGATACATGGGTCGC' *.fastq > count/B16082_Fm0.txt
agrep -0 -c 'TCGAGGACTGTTAGTAT' *.fastq > count/B16083_Fm0.txt
agrep -0 -c 'CAAGTAGTTAGCCGTAG' *.fastq > count/B16084_Fm0.txt
agrep -0 -c 'ACTATTCCCCGGCTGCT' *.fastq > count/B16085_Fm0.txt
agrep -0 -c 'GCTCTAGTTGAGTGAGG' *.fastq > count/B16086_Fm0.txt
agrep -0 -c 'AGACCCTTATCCAAGTC' *.fastq > count/B16088_Fm0.txt
agrep -0 -c 'CGCTTTCAACATTGCGT' *.fastq > count/B16089_Fm0.txt
agrep -0 -c 'GTTAGCCTCGCAAGTAC' *.fastq > count/B16090_Fm0.txt
agrep -0 -c 'AGCGCTAGAGCCTTTCG' *.fastq > count/B16091_Fm0.txt
agrep -0 -c 'ACACGTCGTAAAGTTGT' *.fastq > count/B16092_Fm0.txt
agrep -0 -c 'CATGCAACGAGAGGGCT' *.fastq > count/B16093_Fm0.txt
agrep -0 -c 'GAGCGCATATCGATAAG' *.fastq > count/B16094_Fm0.txt
agrep -0 -c 'GTGAGGTGCAATTTGCT' *.fastq > count/B16095_Fm0.txt
agrep -0 -c 'ACCTCAGTGGATCTGGC' *.fastq > count/B16096_Fm0.txt
agrep -0 -c 'ACATGGACGGATCTAAT' *.fastq > count/B16097_Fm0.txt
agrep -0 -c 'ATTTTGCCCGAGCACTA' *.fastq > count/B16098_Fm0.txt
agrep -0 -c 'CAGGAAGAACTTTAGGA' *.fastq > count/B16101_Fm0.txt
agrep -0 -c 'GGCCAACTTACGTTGCT' *.fastq > count/B16102_Fm0.txt
agrep -0 -c 'TTGATACAGCAAACGGC' *.fastq > count/B16103_Fm0.txt
agrep -0 -c 'TAAGGACGTGTAAGAGG' *.fastq > count/B16104_Fm0.txt
agrep -0 -c 'CAAATCCACGTTAGAAG' *.fastq > count/B16105_Fm0.txt
agrep -0 -c 'ACGACATGTCAGATATG' *.fastq > count/B16108_Fm0.txt
agrep -0 -c 'GCGTCCACTGCATGGTT' *.fastq > count/B16109_Fm0.txt
agrep -0 -c 'GAGTGTTACGCTCCTGC' *.fastq > count/B16110_Fm0.txt
agrep -0 -c 'ACACAAACTGGATGTGT' *.fastq > count/B16111_Fm0.txt
agrep -0 -c 'GACCGGTTACCTTGTTG' *.fastq > count/B16113_Fm0.txt
agrep -0 -c 'GACAATTTGTTGGTCCG' *.fastq > count/B16114_Fm0.txt
agrep -0 -c 'GCTGGTCATTTCTTACG' *.fastq > count/B16115_Fm0.txt
agrep -0 -c 'GACCTTGGGGTAATCCC' *.fastq > count/B16117_Fm0.txt
agrep -0 -c 'GTATACGTGGAGGAGGT' *.fastq > count/B16118_Fm0.txt
agrep -0 -c 'ACTAAAGTGGCATCGCG' *.fastq > count/B16119_Fm0.txt
agrep -0 -c 'CGTAGGATAACCGCCGT' *.fastq > count/B16120_Fm0.txt
agrep -0 -c 'TATTGTGAGACGGCCCC' *.fastq > count/B16121_Fm0.txt
agrep -0 -c 'TCGCCTAGATCGACAAG' *.fastq > count/B16122_Fm0.txt
agrep -0 -c 'CGCGCTCCTTGTTACTA' *.fastq > count/B16123_Fm0.txt
agrep -0 -c 'GATTCGATATTGAGCAC' *.fastq > count/B16124_Fm0.txt
agrep -0 -c 'GTCGTGCAATTTTGCTA' *.fastq > count/B16125_Fm0.txt
agrep -0 -c 'CGTGGCGAGTCTTAAGG' *.fastq > count/B16126_Fm0.txt
agrep -0 -c 'ACGCCATCGCGAGATAC' *.fastq > count/B16127_Fm0.txt
agrep -0 -c 'AGGTTTGTCGCGGTAGG' *.fastq > count/B16128_Fm0.txt
agrep -0 -c 'AGCAGTCGCAACACGGA' *.fastq > count/B16129_Fm0.txt
agrep -0 -c 'GAGGCTCTCGTTCGGTA' *.fastq > count/B16130_Fm0.txt
agrep -0 -c 'ACCATGCGACATCGTCC' *.fastq > count/B16132_Fm0.txt
agrep -0 -c 'CACTGCTTAGCGGGGTT' *.fastq > count/B16133_Fm0.txt
agrep -0 -c 'TCGAAGCCTTGCACCGT' *.fastq > count/B16137_Fm0.txt
agrep -0 -c 'TCGGCAGATATAGTCTC' *.fastq > count/B16138_Fm0.txt
agrep -0 -c 'CACGGAAGACATTACCG' *.fastq > count/B16139_Fm0.txt
agrep -0 -c 'ACAAAGAACCGGTTCCA' *.fastq > count/B16140_Fm0.txt
agrep -0 -c 'TCGCATCTACTGACGTG' *.fastq > count/B16141_Fm0.txt
agrep -0 -c 'ACGCATCACAGTCATAT' *.fastq > count/B16143_Fm0.txt
agrep -0 -c 'GCGTTGATGATCCGCTC' *.fastq > count/B16144_Fm0.txt
agrep -0 -c 'AGCGATCGCAGATTTAG' *.fastq > count/B16145_Fm0.txt
agrep -0 -c 'CTAAGGTCTGCCATGAG' *.fastq > count/B16146_Fm0.txt
agrep -0 -c 'TGACGCATTTCCGGTGT' *.fastq > count/B16147_Fm0.txt
agrep -0 -c 'GAGCTGTGAAAACTACG' *.fastq > count/B16149_Fm0.txt
agrep -0 -c 'CCTTACTCGAGTCAGGA' *.fastq > count/B16150_Fm0.txt
agrep -0 -c 'ATAGTCCGGGGAACGAA' *.fastq > count/B16151_Fm0.txt
agrep -0 -c 'ACTTATTATCTGCCACC' *.fastq > count/B16152_Fm0.txt
agrep -0 -c 'TATTGCGCATCGTGAGG' *.fastq > count/B16153_Fm0.txt
agrep -0 -c 'CACGACCCGTAGACCTA' *.fastq > count/B16154_Fm0.txt
agrep -0 -c 'TCACGGCATCAAAGGCC' *.fastq > count/B16155_Fm0.txt
agrep -0 -c 'ATCTGTAATAGGCCTGG' *.fastq > count/B16157_Fm0.txt
agrep -0 -c 'CGTCGTAGTATCGTTAG' *.fastq > count/B16158_Fm0.txt
agrep -0 -c 'AGTCTCATGACAATCCG' *.fastq > count/B16159_Fm0.txt
agrep -0 -c 'CTCGCTGAGAAACAAGC' *.fastq > count/B16160_Fm0.txt
agrep -0 -c 'ACGGTATATGGCCTCGA' *.fastq > count/B16161_Fm0.txt
agrep -0 -c 'GTTAAACGGCGATATGA' *.fastq > count/B16163_Fm0.txt
agrep -0 -c 'ACTAGTGCGCGCCAAAG' *.fastq > count/B16164_Fm0.txt
agrep -0 -c 'ACTAGGGGGTACGAGGA' *.fastq > count/B16165_Fm0.txt
agrep -0 -c 'TTGCACTCGTGAATGGA' *.fastq > count/B16166_Fm0.txt
agrep -0 -c 'GTCAAAGGATTGACGCC' *.fastq > count/B16167_Fm0.txt
agrep -0 -c 'GGGTAGATCCGCACATC' *.fastq > count/B16168_Fm0.txt
agrep -0 -c 'TACACGGCCGACGTGTA' *.fastq > count/B16169_Fm0.txt
agrep -0 -c 'ATACGGCACGTTTCAAA' *.fastq > count/B16170_Fm0.txt
agrep -0 -c 'TATCGACAGCAGACCCT' *.fastq > count/B16171_Fm0.txt
agrep -0 -c 'TTGCCACCCCGCGATTA' *.fastq > count/B16172_Fm0.txt
agrep -0 -c 'ACGGAACACGCTTAGTA' *.fastq > count/B16173_Fm0.txt
agrep -0 -c 'GGCAAAAACCATCGGTA' *.fastq > count/B16174_Fm0.txt
agrep -0 -c 'CGTTTGTAGTCGAAACG' *.fastq > count/B16175_Fm0.txt
agrep -0 -c 'GACCTTTGCGTCGAGCT' *.fastq > count/B16176_Fm0.txt
agrep -0 -c 'AGCTGTACATTGGCATA' *.fastq > count/B16177_Fm0.txt
agrep -0 -c 'ATCCGAGGTTTTCCATA' *.fastq > count/B16178_Fm0.txt
agrep -0 -c 'CGGGCGATTGGATCATT' *.fastq > count/B16180_Fm0.txt
agrep -0 -c 'CTGCAGTTTTACGGTTT' *.fastq > count/B16181_Fm0.txt
agrep -0 -c 'CAGGCAACTTCCTCGCA' *.fastq > count/B16182_Fm0.txt
agrep -0 -c 'CGTTTTACACACGGCGG' *.fastq > count/B16183_Fm0.txt
agrep -0 -c 'GCCGAAACTCGGTGAAT' *.fastq > count/B16184_Fm0.txt
agrep -0 -c 'CCTGATGGTTGCGCCAT' *.fastq > count/B16186_Fm0.txt
agrep -0 -c 'CTCGAAGATTTACGGCC' *.fastq > count/B16187_Fm0.txt
agrep -0 -c 'AGCGGTTAGTGACCTTG' *.fastq > count/B16188_Fm0.txt
agrep -0 -c 'TGCTCAGCGTGCTTCTA' *.fastq > count/B16189_Fm0.txt
agrep -0 -c 'CAGCATTCTGCTAGGCG' *.fastq > count/B16191_Fm0.txt
agrep -0 -c 'ATTAGCACTCCCGACTG' *.fastq > count/B16192_Fm0.txt
agrep -0 -c 'CATTGCGAGTGTGTGTT' *.fastq > count/B16193_Fm0.txt
agrep -0 -c 'ATCTCGTAGTCGCACAC' *.fastq > count/B16194_Fm0.txt
agrep -0 -c 'ACATGAACTGAGGTGCG' *.fastq > count/B16196_Fm0.txt
agrep -0 -c 'CGCAACCAGATCCCTTA' *.fastq > count/B16198_Fm0.txt
agrep -0 -c 'TGAAACTCGGCCCATAT' *.fastq > count/B16199_Fm0.txt
agrep -0 -c 'TCGACGCTATACAGGGT' *.fastq > count/B16201_Fm0.txt
agrep -0 -c 'AGACTGCTCCCGGTCTA' *.fastq > count/B16202_Fm0.txt
agrep -0 -c 'ACAGTCGGTGAGATAAA' *.fastq > count/B16203_Fm0.txt
agrep -0 -c 'TGACACGCACCTGGTAC' *.fastq > count/B16204_Fm0.txt
agrep -0 -c 'GATTGCGTACGGTGTGC' *.fastq > count/B16205_Fm0.txt
agrep -0 -c 'AAGAGGAATCTGCTCGC' *.fastq > count/B16207_Fm0.txt
agrep -0 -c 'ACGTTTCGTGGCCTGAG' *.fastq > count/B16209_Fm0.txt
agrep -0 -c 'CTGTTCAGATGATGCGC' *.fastq > count/B16210_Fm0.txt
agrep -0 -c 'TATAACACGATGACCCG' *.fastq > count/B16211_Fm0.txt
agrep -0 -c 'CTCGGTTCCGATGGTAG' *.fastq > count/B16212_Fm0.txt
agrep -0 -c 'GCCAATTCGATGCGAAT' *.fastq > count/B16215_Fm0.txt
agrep -0 -c 'GTGTCTCTGCTTAAAGA' *.fastq > count/B16216_Fm0.txt
agrep -0 -c 'CGAGCCAGCGACGTTAA' *.fastq > count/B16217_Fm0.txt
agrep -0 -c 'CTAAGTCCGCACTTCGC' *.fastq > count/B16219_Fm0.txt
agrep -0 -c 'CCACACACGCGAGATAA' *.fastq > count/B16220_Fm0.txt
agrep -0 -c 'TCGAGACCGCTACACTT' *.fastq > count/B16221_Fm0.txt
agrep -0 -c 'TCGCAAAAATAACGGTC' *.fastq > count/B16222_Fm0.txt
agrep -0 -c 'GATCTCGTCCCTCATCG' *.fastq > count/B16223_Fm0.txt
agrep -0 -c 'CGCAATTGAGTTACCGG' *.fastq > count/B16224_Fm0.txt
agrep -0 -c 'CTAGTGTAGGGTTCTGA' *.fastq > count/B16225_Fm0.txt
agrep -0 -c 'ATCTTGACTCCGAGCCT' *.fastq > count/B16226_Fm0.txt
agrep -0 -c 'AAGTGCTGCCTGGTATA' *.fastq > count/B16227_Fm0.txt
agrep -0 -c 'GGATGTATCCAGGAAAC' *.fastq > count/B16228_Fm0.txt
agrep -0 -c 'AACCCAACCGCTGCATT' *.fastq > count/B16229_Fm0.txt
agrep -0 -c 'CTCTCGTTCACTGGATA' *.fastq > count/B16230_Fm0.txt
agrep -0 -c 'ATGTGACCCGAAGTCCT' *.fastq > count/B16231_Fm0.txt
agrep -0 -c 'ACACGGGCACGTAACCT' *.fastq > count/B16232_Fm0.txt
agrep -0 -c 'GTGTTTCGAGCAAGGTG' *.fastq > count/B16234_Fm0.txt
agrep -0 -c 'CACCGGGAGGCGTTAAT' *.fastq > count/B16235_Fm0.txt
agrep -0 -c 'GTAAGCTTGAGCATGCA' *.fastq > count/B16236_Fm0.txt
agrep -0 -c 'GGTACTAATGCTTCGGG' *.fastq > count/B16239_Fm0.txt
agrep -0 -c 'AGCGCCTTCACTGGTTT' *.fastq > count/B16240_Fm0.txt
agrep -0 -c 'AGGTCTTAAACCTCTCA' *.fastq > count/B16241_Fm0.txt
agrep -0 -c 'AGTGCTTCCTCGCTGGA' *.fastq > count/B16242_Fm0.txt
agrep -0 -c 'TCTTGACCAACTGTCTG' *.fastq > count/B16243_Fm0.txt
agrep -0 -c 'GGAGGTAGTTCATGGTC' *.fastq > count/B16244_Fm0.txt
agrep -0 -c 'AACACATACTGATCGGC' *.fastq > count/B16245_Fm0.txt
agrep -0 -c 'TACATTCTCCTGGCTTT' *.fastq > count/B16247_Fm0.txt
agrep -0 -c 'TATTATAGCACCTCCGG' *.fastq > count/B16249_Fm0.txt
agrep -0 -c 'ACGAACTCTAGCTTTGC' *.fastq > count/B16250_Fm0.txt
agrep -0 -c 'GCACCGAATAACCTCGA' *.fastq > count/B16251_Fm0.txt
agrep -0 -c 'GTAACGAGATATAGAGC' *.fastq > count/B16252_Fm0.txt
agrep -0 -c 'TATGGTTCCCCCCGTGA' *.fastq > count/B16253_Fm0.txt
agrep -0 -c 'ACGAGCAGTTTAACAGG' *.fastq > count/B16254_Fm0.txt
agrep -0 -c 'GTATACGACACCTTTTC' *.fastq > count/B16256_Fm0.txt
agrep -0 -c 'CCATAGCGCAATGCGTT' *.fastq > count/B16257_Fm0.txt
agrep -0 -c 'GGAATGCTGTTCGCTCT' *.fastq > count/B16258_Fm0.txt
agrep -0 -c 'CTGGATCACGGCTACGT' *.fastq > count/B16259_Fm0.txt
agrep -0 -c 'TCGGTCGGAGTTATGCA' *.fastq > count/B16263_Fm0.txt
agrep -0 -c 'AGTGAATCGTGTACACA' *.fastq > count/B16264_Fm0.txt
agrep -0 -c 'ATGAAAAGGCTCGCCCA' *.fastq > count/B16265_Fm0.txt
agrep -0 -c 'GTCTATGTGGTGGTCGA' *.fastq > count/B16266_Fm0.txt
agrep -0 -c 'ACGCCGTGATTCTTCGC' *.fastq > count/B16267_Fm0.txt
agrep -0 -c 'GCCATAACACACACGAA' *.fastq > count/B16268_Fm0.txt
agrep -0 -c 'AACATCCGTTATGGCCT' *.fastq > count/B16269_Fm0.txt
agrep -0 -c 'TCGACCTCTGATCAGGA' *.fastq > count/B16271_Fm0.txt
agrep -0 -c 'TTGAGGAGTCGCGCAAT' *.fastq > count/B16272_Fm0.txt
agrep -0 -c 'CATTAGTGCGGAAGCGT' *.fastq > count/B16273_Fm0.txt
agrep -0 -c 'TTGATCCACACTGCCCA' *.fastq > count/B16274_Fm0.txt
agrep -0 -c 'TAGCCTGAGACTAACGC' *.fastq > count/B16275_Fm0.txt
agrep -0 -c 'CTGAATTATTGGAGTCG' *.fastq > count/B16277_Fm0.txt
agrep -0 -c 'TAGAGATCGAGTCAAGT' *.fastq > count/B16278_Fm0.txt
agrep -0 -c 'CAAACGGAACGGACTTT' *.fastq > count/B16279_Fm0.txt
agrep -0 -c 'GTCCATGGTTTCCGTTA' *.fastq > count/B16280_Fm0.txt
agrep -0 -c 'ACCACTTGACATGCGGT' *.fastq > count/B16281_Fm0.txt
agrep -0 -c 'CTCGCTTGCACGATACG' *.fastq > count/B16282_Fm0.txt
agrep -0 -c 'CAGAGCCCGCCTATATT' *.fastq > count/B16283_Fm0.txt
agrep -0 -c 'GTACTCCGCGTCAATCC' *.fastq > count/B16284_Fm0.txt
agrep -0 -c 'CCACTGAGGCAGTACCT' *.fastq > count/B16285_Fm0.txt
agrep -0 -c 'TTCGCCAAACAGCAGTG' *.fastq > count/B16286_Fm0.txt
agrep -0 -c 'GTACACAACCTAAGTGC' *.fastq > count/B16287_Fm0.txt
agrep -0 -c 'TTCAGCCGCAGTCTACC' *.fastq > count/B16288_Fm0.txt
agrep -0 -c 'GGGTGGTTTATCGCCAT' *.fastq > count/B16289_Fm0.txt
agrep -0 -c 'AGGAATGTCGCGACTCG' *.fastq > count/B16292_Fm0.txt
agrep -0 -c 'ACCCGACCAGACATAGG' *.fastq > count/B16293_Fm0.txt
agrep -0 -c 'GGGGGTAAAAGTATAGT' *.fastq > count/B16294_Fm0.txt
agrep -0 -c 'AGCTGTCCGCACTTCTT' *.fastq > count/B16295_Fm0.txt
agrep -0 -c 'TGGCATTGGTCTCATTG' *.fastq > count/B16297_Fm0.txt
agrep -0 -c 'CATTGAACCCTATAGGT' *.fastq > count/B16298_Fm0.txt
agrep -0 -c 'ACGGCTGGAACCTGTAA' *.fastq > count/B16299_Fm0.txt
agrep -0 -c 'CATATGACTCCTGTACG' *.fastq > count/B16300_Fm0.txt
agrep -0 -c 'TAAATACCGTAAGACCC' *.fastq > count/B16301_Fm0.txt
agrep -0 -c 'AACGGAGATGCTACAAA' *.fastq > count/B16303_Fm0.txt
agrep -0 -c 'GCCAATTGCCCTTAACG' *.fastq > count/B16304_Fm0.txt
agrep -0 -c 'ATTTGAGTGTCCGCCGG' *.fastq > count/B16305_Fm0.txt
agrep -0 -c 'GTCTGCTAACTTTCATC' *.fastq > count/B16306_Fm0.txt
agrep -0 -c 'TCGGCTTGCTCTTTCGA' *.fastq > count/B16307_Fm0.txt
agrep -0 -c 'ACCTCTGCCCAACCATT' *.fastq > count/B16308_Fm0.txt
agrep -0 -c 'CCATCTCTGATCGAAAA' *.fastq > count/B16309_Fm0.txt
agrep -0 -c 'GCCGCTTCATGCGTTAA' *.fastq > count/B16310_Fm0.txt
agrep -0 -c 'GGATGCAGTGGGTTCAA' *.fastq > count/B16311_Fm0.txt
agrep -0 -c 'TTAGATCTGCGCTGTGG' *.fastq > count/B16312_Fm0.txt
agrep -0 -c 'TATACTCCCAAAGACGG' *.fastq > count/B16313_Fm0.txt
agrep -0 -c 'TCGTCCACCACTTTATA' *.fastq > count/B16314_Fm0.txt
agrep -0 -c 'TATAGGTCAGTCGATGA' *.fastq > count/B16316_Fm0.txt
agrep -0 -c 'GGCAACTAGTCAATCCT' *.fastq > count/B16317_Fm0.txt
agrep -0 -c 'TTGTGCCCCAAGCCCTT' *.fastq > count/B16318_Fm0.txt
agrep -0 -c 'CATTCAGTGCGATCCTG' *.fastq > count/B16319_Fm0.txt
agrep -0 -c 'GGGATTTAGTGTGGTGC' *.fastq > count/B16320_Fm0.txt
agrep -0 -c 'CGCTGACAGGCAACTGA' *.fastq > count/B16322_Fm0.txt
agrep -0 -c 'AATTCCGTTTCGAACTG' *.fastq > count/B16323_Fm0.txt
agrep -0 -c 'ACGAGTTTACCGAGCCA' *.fastq > count/B16324_Fm0.txt
agrep -0 -c 'CTAATGTAGCCAAAGGA' *.fastq > count/B16326_Fm0.txt
agrep -0 -c 'CTCGCTCGTGATGGTCT' *.fastq > count/B16328_Fm0.txt
agrep -0 -c 'CCTGTACAAGTAGTCCG' *.fastq > count/B16329_Fm0.txt
agrep -0 -c 'TATCGCAGAGTTCGTAG' *.fastq > count/B16330_Fm0.txt
agrep -0 -c 'ATAAACGCGGAAATCCG' *.fastq > count/B16331_Fm0.txt
agrep -0 -c 'CTGCGATCTATGATGCT' *.fastq > count/B16333_Fm0.txt
agrep -0 -c 'AGCAAATCCCCCCCATA' *.fastq > count/B16335_Fm0.txt
agrep -0 -c 'GGACTCATAGTGTACTT' *.fastq > count/B16336_Fm0.txt
agrep -0 -c 'GGGGCTTGCGATAACTA' *.fastq > count/B16337_Fm0.txt
agrep -0 -c 'GTCGTTTATCCAGGTAA' *.fastq > count/B16338_Fm0.txt
agrep -0 -c 'TAATTGGAGCGATGGAA' *.fastq > count/B16339_Fm0.txt
agrep -0 -c 'AGTTCAACCGTATGCGG' *.fastq > count/B16341_Fm0.txt
agrep -0 -c 'CTACAACGCATGACTAA' *.fastq > count/B16342_Fm0.txt
agrep -0 -c 'TTATCTTACGAGCTCCC' *.fastq > count/B16343_Fm0.txt
agrep -0 -c 'GTAATGGTAGAGACCGC' *.fastq > count/B16344_Fm0.txt
agrep -0 -c 'ATGGAAGCGGCAATGGT' *.fastq > count/B16345_Fm0.txt
agrep -0 -c 'CGACGGTTCCAACATAG' *.fastq > count/B16346_Fm0.txt
agrep -0 -c 'TGTCAGGGCGACCTTGT' *.fastq > count/B16347_Fm0.txt
agrep -0 -c 'ATCGCGCGAGGATAACG' *.fastq > count/B16348_Fm0.txt
agrep -0 -c 'CGATCGGTCATTATCAA' *.fastq > count/B16349_Fm0.txt
agrep -0 -c 'GGAATAGTTCCCTGGAA' *.fastq > count/B16350_Fm0.txt
agrep -0 -c 'TAAGGCACCTACGGGAA' *.fastq > count/B16352_Fm0.txt
agrep -0 -c 'CGCATGTGTGTGAGGCA' *.fastq > count/B16353_Fm0.txt
agrep -0 -c 'TAGTCCACGGTAAATCA' *.fastq > count/B16354_Fm0.txt
agrep -0 -c 'AGCGAAACGTTCTCAGT' *.fastq > count/B16355_Fm0.txt
agrep -0 -c 'CCTCATCTAGCTCGCCT' *.fastq > count/B16357_Fm0.txt
agrep -0 -c 'AGTTCGGCTTCCATATC' *.fastq > count/B16360_Fm0.txt
agrep -0 -c 'GGCGTCTCAATGAAAAT' *.fastq > count/B16361_Fm0.txt
agrep -0 -c 'AATCCTCAGTCTCGCTC' *.fastq > count/B16362_Fm0.txt
agrep -0 -c 'GCGTCTTTTTAGGACTC' *.fastq > count/B16366_Fm0.txt
agrep -0 -c 'GATAACAGACGCCGAGG' *.fastq > count/B16367_Fm0.txt
agrep -0 -c 'CTGAGGTTTAACTAGAG' *.fastq > count/B16369_Fm0.txt
agrep -0 -c 'CCAGGTAGCATATGTAG' *.fastq > count/B16370_Fm0.txt
agrep -0 -c 'GATCAGTCACTGCCCAG' *.fastq > count/B16371_Fm0.txt
agrep -0 -c 'ATGGGACAATTCCGTCC' *.fastq > count/B16372_Fm0.txt
agrep -0 -c 'GTTCGTCGATCTGAGGG' *.fastq > count/B16373_Fm0.txt
agrep -0 -c 'TATCCGACAGGAGGAGC' *.fastq > count/B16374_Fm0.txt
agrep -0 -c 'TGCGCGATCTGAAAGGC' *.fastq > count/B16375_Fm0.txt
agrep -0 -c 'GTCGCAATAAGGGGCAT' *.fastq > count/B16376_Fm0.txt
agrep -0 -c 'GGGGACGTAAGATCCGT' *.fastq > count/B16377_Fm0.txt
agrep -0 -c 'CTGAGTCCTAGAGACTA' *.fastq > count/B16378_Fm0.txt
agrep -0 -c 'CAGTCCCCGCTTTGATA' *.fastq > count/B16379_Fm0.txt
agrep -0 -c 'GCCCATTTGCGAATTAG' *.fastq > count/B16380_Fm0.txt
agrep -0 -c 'GGTGGCGGAAAAACTAC' *.fastq > count/B16381_Fm0.txt
agrep -0 -c 'TGTAACAATCACCCACG' *.fastq > count/B16384_Fm0.txt
agrep -0 -c 'CACATATCTGGGAGAGT' *.fastq > count/B16385_Fm0.txt
agrep -0 -c 'CTCGTTACCAATGCGGA' *.fastq > count/B16387_Fm0.txt
agrep -0 -c 'GGTACACCCGCCACATA' *.fastq > count/B16388_Fm0.txt
agrep -0 -c 'TGGCTGAGCCCCTAACA' *.fastq > count/B16389_Fm0.txt
agrep -0 -c 'AGGGCGCTCCTTGGTAA' *.fastq > count/B16390_Fm0.txt
agrep -0 -c 'CACGTATCTCTACATGT' *.fastq > count/B16391_Fm0.txt
agrep -0 -c 'GTAAGGTCTAGAAGAAG' *.fastq > count/B16392_Fm0.txt
agrep -0 -c 'ATGGATGCGTCCTGGTG' *.fastq > count/B16395_Fm0.txt
agrep -0 -c 'TATATTACTGCGGTGAG' *.fastq > count/B16396_Fm0.txt
agrep -0 -c 'TCGGTCTCGTGTCTTCA' *.fastq > count/B16397_Fm0.txt
agrep -0 -c 'GTTGTCATACCAGTTCG' *.fastq > count/B16398_Fm0.txt
agrep -0 -c 'ACAGTGCTTGACGTAGA' *.fastq > count/B16400_Fm0.txt
agrep -0 -c 'TAGGTAGGATGCTTTCC' *.fastq > count/B16401_Fm0.txt
agrep -0 -c 'CAGGTGATGAACGCTGG' *.fastq > count/B16402_Fm0.txt
agrep -0 -c 'TGGAAGGTGACTCGTGA' *.fastq > count/B16403_Fm0.txt
agrep -0 -c 'GTCCGTTGCCTATTCGT' *.fastq > count/B16404_Fm0.txt
agrep -0 -c 'GGATGTAAGGTGCACCT' *.fastq > count/B16405_Fm0.txt
agrep -0 -c 'ATTACGTGCGACAGGGG' *.fastq > count/B16406_Fm0.txt
agrep -0 -c 'TGATCCCACGCACCGTA' *.fastq > count/B16408_Fm0.txt
agrep -0 -c 'GGATTAGCATAAGGTCG' *.fastq > count/B16410_Fm0.txt
agrep -0 -c 'AAGTAGGCTTTTCGCTG' *.fastq > count/B16413_Fm0.txt
agrep -0 -c 'GTTTCTCGACGTCCCAC' *.fastq > count/B16414_Fm0.txt
agrep -0 -c 'TATCTTATTACGTGCCC' *.fastq > count/B16415_Fm0.txt
agrep -0 -c 'ACCCCCGCCTATATTTT' *.fastq > count/B16416_Fm0.txt
agrep -0 -c 'ACTAGGCTGGTACCGGT' *.fastq > count/B16417_Fm0.txt
agrep -0 -c 'ATTGCGAGTGGTGATGA' *.fastq > count/B16418_Fm0.txt
agrep -0 -c 'GGAGTATGTCGTCTAGA' *.fastq > count/B16419_Fm0.txt
agrep -0 -c 'GTTAAGCAGCGTGAAGA' *.fastq > count/B16420_Fm0.txt
agrep -0 -c 'GTGCTCGAGAGTGAATA' *.fastq > count/B16421_Fm0.txt
agrep -0 -c 'GTTAGCCAGTAGTTCCG' *.fastq > count/B16422_Fm0.txt
agrep -0 -c 'TAAAAGCAGTTCGGCTG' *.fastq > count/B16423_Fm0.txt
agrep -0 -c 'GGTTAGTCACGAGAACT' *.fastq > count/B16424_Fm0.txt
agrep -0 -c 'GTTTATTTCACCGCGAC' *.fastq > count/B16425_Fm0.txt
agrep -0 -c 'ACGGTCGAACAACAAAC' *.fastq > count/B16426_Fm0.txt
agrep -0 -c 'CACAAAGGGTCCGATAG' *.fastq > count/B16427_Fm0.txt
agrep -0 -c 'GGTTTCTAGGATGCTCG' *.fastq > count/B16428_Fm0.txt
agrep -0 -c 'ACCCATTGTACACCCAT' *.fastq > count/B16429_Fm0.txt
agrep -0 -c 'AGCCCTCTAATGGTGAT' *.fastq > count/B16430_Fm0.txt
agrep -0 -c 'GAGTTTGTGGAGTATCA' *.fastq > count/B16431_Fm0.txt
agrep -0 -c 'GTTGATTGCCAGCGTAC' *.fastq > count/B16433_Fm0.txt
agrep -0 -c 'TTATGGTCGCCGGATTT' *.fastq > count/B16434_Fm0.txt
agrep -0 -c 'TCAGCCAGTTTATAGCG' *.fastq > count/B16435_Fm0.txt
agrep -0 -c 'ATGATCACGACACCCGA' *.fastq > count/B16438_Fm0.txt
agrep -0 -c 'GTCCTTACTTTGACTAC' *.fastq > count/B16439_Fm0.txt
agrep -0 -c 'CTAAGAGTGTGATCAAG' *.fastq > count/B16440_Fm0.txt
agrep -0 -c 'CGCTGTTACGCGTTATT' *.fastq > count/B16441_Fm0.txt
agrep -0 -c 'AGCAATCCCTTTTGGAC' *.fastq > count/B16442_Fm0.txt
agrep -0 -c 'AATCCCGAAGACCATGC' *.fastq > count/B16443_Fm0.txt
agrep -0 -c 'ATTGGTGCCGGAGCTGT' *.fastq > count/B16444_Fm0.txt
agrep -0 -c 'TACTCGCGTTAAAGGAA' *.fastq > count/B16446_Fm0.txt
agrep -0 -c 'GATAGCCGCGCATTCAG' *.fastq > count/B16447_Fm0.txt
agrep -0 -c 'TTGATGAATTCCGGGTT' *.fastq > count/B16448_Fm0.txt
agrep -0 -c 'GGACACATGCGCTAGTA' *.fastq > count/B16449_Fm0.txt
agrep -0 -c 'CCAAGTGGCAGCTTTCC' *.fastq > count/B16450_Fm0.txt
agrep -0 -c 'GTTACACCTATGGGGCG' *.fastq > count/B16451_Fm0.txt
agrep -0 -c 'AGTAACCTTGGCTCAGC' *.fastq > count/B16452_Fm0.txt
agrep -0 -c 'CTGGGACTCCTACATGC' *.fastq > count/B16454_Fm0.txt
agrep -0 -c 'ACCTGAGTAGCCGCCTA' *.fastq > count/B16455_Fm0.txt
agrep -0 -c 'GTTGTTCAGCAATGGGC' *.fastq > count/B16456_Fm0.txt
agrep -0 -c 'AGGTGCGATCATTTGCG' *.fastq > count/B16457_Fm0.txt
agrep -0 -c 'ACTGGGTTAAGTGGCAA' *.fastq > count/B16459_Fm0.txt
agrep -0 -c 'GTTGTCCATGCATCGTC' *.fastq > count/B16460_Fm0.txt
agrep -0 -c 'TGAATTGCTGCTGGGCC' *.fastq > count/B16461_Fm0.txt
agrep -0 -c 'GGCGATCCCATATACCA' *.fastq > count/B16462_Fm0.txt
agrep -0 -c 'GGGTATCCATCATGTTG' *.fastq > count/B16463_Fm0.txt
agrep -0 -c 'GGGGGCTTAGGTTGTAC' *.fastq > count/B16465_Fm0.txt
agrep -0 -c 'CGATGAGTTCACATCAC' *.fastq > count/B16466_Fm0.txt
agrep -0 -c 'GCTATAGGGGCTTACAC' *.fastq > count/B16467_Fm0.txt
agrep -0 -c 'CCTGATCTGCCTTACTA' *.fastq > count/B16468_Fm0.txt
agrep -0 -c 'TGACATATGCGTATCTG' *.fastq > count/B16470_Fm0.txt
agrep -0 -c 'GGGATAAGAATGTCGGA' *.fastq > count/B16471_Fm0.txt
agrep -0 -c 'TGTCTATATCCGCTGGG' *.fastq > count/B16473_Fm0.txt
agrep -0 -c 'TGGAACAAGGGTCCGAA' *.fastq > count/B16474_Fm0.txt
agrep -0 -c 'CTAGTCACCGCTTCAGT' *.fastq > count/B16475_Fm0.txt
agrep -0 -c 'AATCTCACGGAGCCTAA' *.fastq > count/B16476_Fm0.txt
agrep -0 -c 'ATACCGTCGAATATAGC' *.fastq > count/B16477_Fm0.txt
agrep -0 -c 'GCGTGTTATGCAGCTAG' *.fastq > count/B16478_Fm0.txt
agrep -0 -c 'CAGGAAAACGTTCCTTA' *.fastq > count/B16479_Fm0.txt
agrep -0 -c 'CTAGTCAGATGCAGTCC' *.fastq > count/B16481_Fm0.txt
agrep -0 -c 'ATATGCGACTCTGAGCT' *.fastq > count/B16482_Fm0.txt
agrep -0 -c 'AGTTGTAGGCATCCGGG' *.fastq > count/B16483_Fm0.txt
agrep -0 -c 'AGTGGTCCCAAATTGAA' *.fastq > count/B16484_Fm0.txt
agrep -0 -c 'TGTCACAAGCGTCCGGA' *.fastq > count/B16485_Fm0.txt
agrep -0 -c 'GCAACGCTTCTCAGTGG' *.fastq > count/B16486_Fm0.txt
agrep -0 -c 'TTCTTGTTGACAGCAGG' *.fastq > count/B16487_Fm0.txt
agrep -0 -c 'CCGCACAGATAGGTAAT' *.fastq > count/B16488_Fm0.txt
agrep -0 -c 'CTACATGAGTCGAGGAA' *.fastq > count/B16489_Fm0.txt
agrep -0 -c 'AGCACACGAGTCATTGA' *.fastq > count/B16490_Fm0.txt
agrep -0 -c 'GTCTGCTGCTACCAAGT' *.fastq > count/B16491_Fm0.txt
agrep -0 -c 'AGTGCGATTCATCATGG' *.fastq > count/B16492_Fm0.txt
agrep -0 -c 'CCGACTACCAACAAGTC' *.fastq > count/B16493_Fm0.txt
agrep -0 -c 'AACCTCGTCATAAAGCT' *.fastq > count/B16494_Fm0.txt
agrep -0 -c 'GTGCGTGACTCATTGTA' *.fastq > count/B16495_Fm0.txt
agrep -0 -c 'TGTGCTCAGCAATGGAC' *.fastq > count/B16497_Fm0.txt
agrep -0 -c 'GCCACTTTAATCGACAG' *.fastq > count/B16499_Fm0.txt
agrep -0 -c 'AGATCGTCGAATCCCAC' *.fastq > count/B16500_Fm0.txt
agrep -0 -c 'TTGTTGGTTCCGCGTAA' *.fastq > count/B16501_Fm0.txt
agrep -0 -c 'GTTATGGTCCACGGAGC' *.fastq > count/B16502_Fm0.txt
agrep -0 -c 'ACCGCACTGTGGCGAAT' *.fastq > count/B16503_Fm0.txt
agrep -0 -c 'CCGGCTGATAGCGATAA' *.fastq > count/B16504_Fm0.txt
agrep -0 -c 'AACTTGACACACAGCGC' *.fastq > count/B16505_Fm0.txt
agrep -0 -c 'TTCTGCGAATCGATGAA' *.fastq > count/B16506_Fm0.txt
agrep -0 -c 'CGACTCTCTTCGATCGG' *.fastq > count/B16507_Fm0.txt
agrep -0 -c 'CGTGCTACATGCATTCG' *.fastq > count/B16508_Fm0.txt
agrep -0 -c 'CCACATATATGGTGACT' *.fastq > count/B16509_Fm0.txt
agrep -0 -c 'CACGCTACAATTTCTCC' *.fastq > count/B16510_Fm0.txt
agrep -0 -c 'AAGATCATAGGTCCTGC' *.fastq > count/B16511_Fm0.txt
agrep -0 -c 'TGACAGGTTGTTGGACC' *.fastq > count/B16512_Fm0.txt
agrep -0 -c 'CAGTTCTGCCCCAAACT' *.fastq > count/B16513_Fm0.txt
agrep -0 -c 'TAATGCGTCACAGCATG' *.fastq > count/B16514_Fm0.txt
agrep -0 -c 'GATATGTACGGTACCCG' *.fastq > count/B16515_Fm0.txt
agrep -0 -c 'CGCCAAGTCAAGCAATA' *.fastq > count/B16516_Fm0.txt
agrep -0 -c 'ATCGCCCCTTTTATGCG' *.fastq > count/B16517_Fm0.txt
agrep -0 -c 'AGTTACCATAGGCACCG' *.fastq > count/B16518_Fm0.txt
agrep -0 -c 'GTTTTCGATGGACACCC' *.fastq > count/B16519_Fm0.txt
agrep -0 -c 'CGAATGGTGCGACACTC' *.fastq > count/B16520_Fm0.txt
agrep -0 -c 'GTGGAGGTGTCTCTACA' *.fastq > count/B16521_Fm0.txt
agrep -0 -c 'CTCGAGCAGCCCAGTTT' *.fastq > count/B16522_Fm0.txt
agrep -0 -c 'TAGGCAAGGGTTCTCGA' *.fastq > count/B16523_Fm0.txt
agrep -0 -c 'CGAACGCTCAGCTGAGT' *.fastq > count/B16524_Fm0.txt
agrep -0 -c 'CAGCCTTTAGCGCTACC' *.fastq > count/B16525_Fm0.txt
agrep -0 -c 'GTCTTAAGACGTGTCAT' *.fastq > count/B16526_Fm0.txt
agrep -0 -c 'CGGGGCATCTCATTTCC' *.fastq > count/B16527_Fm0.txt
agrep -0 -c 'CGTGAGTTTTGAAGCCG' *.fastq > count/B16528_Fm0.txt
agrep -0 -c 'GCAAGGAGTGAGAAGCC' *.fastq > count/B16529_Fm0.txt
agrep -0 -c 'TCATGGCCCCCATAAGC' *.fastq > count/B16531_Fm0.txt
agrep -0 -c 'CAGTCGTTAATTACACG' *.fastq > count/B16532_Fm0.txt
agrep -0 -c 'CATATGGCGTAATCGAA' *.fastq > count/B16534_Fm0.txt
agrep -0 -c 'GCCTGGTTATGATGACA' *.fastq > count/B16535_Fm0.txt
agrep -0 -c 'TAAAGGAGATAACCAGG' *.fastq > count/B16536_Fm0.txt
agrep -0 -c 'TGACCTCCTAGTCAGCT' *.fastq > count/B16537_Fm0.txt
agrep -0 -c 'ACCTGTATGTCGCTCTC' *.fastq > count/B16538_Fm0.txt
agrep -0 -c 'GCGGCTTGGGTATGTCT' *.fastq > count/B16539_Fm0.txt
agrep -0 -c 'CGTCCCATTCTAGTTAG' *.fastq > count/B16540_Fm0.txt
agrep -0 -c 'TCATTAAACCGCGGTCC' *.fastq > count/B16541_Fm0.txt
agrep -0 -c 'CTAGTGTAAAGGAAGCG' *.fastq > count/B16542_Fm0.txt
agrep -0 -c 'ATGCGGTATGCACCCAT' *.fastq > count/B16543_Fm0.txt
agrep -0 -c 'GCCGGTAATTGGCCATT' *.fastq > count/B16544_Fm0.txt
agrep -0 -c 'GAGTTTACGTGTCGGCT' *.fastq > count/B16545_Fm0.txt
agrep -0 -c 'TGTTTGCTAGCTACTCA' *.fastq > count/B16546_Fm0.txt
agrep -0 -c 'GCATTTTTGCTTAGGTC' *.fastq > count/B16547_Fm0.txt
agrep -0 -c 'TACGTCGGGCATACTGG' *.fastq > count/B16548_Fm0.txt
agrep -0 -c 'CTATGGTCGAGTATAAG' *.fastq > count/B16549_Fm0.txt
agrep -0 -c 'AGAGCTTGATGTTGGCG' *.fastq > count/B16550_Fm0.txt
agrep -0 -c 'GTTTAATCCGAGCTGAC' *.fastq > count/B16551_Fm0.txt
agrep -0 -c 'CTTCAGAGAAACGAGTC' *.fastq > count/B16552_Fm0.txt
agrep -0 -c 'TACGCTTTTGGCGAGTA' *.fastq > count/B16553_Fm0.txt
agrep -0 -c 'CAGTCCGCTTTTAGCTA' *.fastq > count/B16554_Fm0.txt
agrep -0 -c 'CGCCCAGAATTTAGTTA' *.fastq > count/B16555_Fm0.txt
agrep -0 -c 'GGATCTCGCGTAATCAA' *.fastq > count/B16556_Fm0.txt
agrep -0 -c 'CTCACACCCGAATTGCG' *.fastq > count/B16558_Fm0.txt
agrep -0 -c 'TCACCGAATACTGGACT' *.fastq > count/B16560_Fm0.txt
agrep -0 -c 'TGTTTCGCATTCGAGGG' *.fastq > count/B16561_Fm0.txt
agrep -0 -c 'TCTATACCGGCTTGTAC' *.fastq > count/B16562_Fm0.txt
agrep -0 -c 'CGTCGATGCATATATCT' *.fastq > count/B16563_Fm0.txt
agrep -0 -c 'GTTGTTTTCCGCATTGA' *.fastq > count/B16565_Fm0.txt
agrep -0 -c 'CACGCGCCAAATAGACG' *.fastq > count/B16567_Fm0.txt
agrep -0 -c 'GCTGCACGAGGTAAGCT' *.fastq > count/B16568_Fm0.txt
agrep -0 -c 'AGGAGGCGAATCCATTA' *.fastq > count/B16569_Fm0.txt
agrep -0 -c 'GCGTTCGCAAAAGATAA' *.fastq > count/B16570_Fm0.txt
agrep -0 -c 'GTCGCGCAAGCATGAAG' *.fastq > count/B16573_Fm0.txt
agrep -0 -c 'TGTGCTGGGTCGCTTAG' *.fastq > count/B16574_Fm0.txt
agrep -0 -c 'GACGGACGCTTTTCTAA' *.fastq > count/B16576_Fm0.txt
agrep -0 -c 'AGCTGTTGGAGGTATAT' *.fastq > count/B16577_Fm0.txt
agrep -0 -c 'AGACGATTCACTACACC' *.fastq > count/B16578_Fm0.txt
agrep -0 -c 'GACCCGAAGACCTATTT' *.fastq > count/B16579_Fm0.txt
agrep -0 -c 'CGAATGGGCCAAGTGAA' *.fastq > count/B16580_Fm0.txt
agrep -0 -c 'TACGCCATCTGTCCATT' *.fastq > count/B16581_Fm0.txt
agrep -0 -c 'CGGTGGTGAGCTATATC' *.fastq > count/B16582_Fm0.txt
agrep -0 -c 'ATGCTGGCTAACTCTCG' *.fastq > count/B16583_Fm0.txt
agrep -0 -c 'CGATATCCTTACGGAAC' *.fastq > count/B16584_Fm0.txt
agrep -0 -c 'CGCATCAATGGTGGGCA' *.fastq > count/B16585_Fm0.txt
agrep -0 -c 'TTATATCGGCAGACACG' *.fastq > count/B16586_Fm0.txt
agrep -0 -c 'TCTATGCGGCCAACTGA' *.fastq > count/B16587_Fm0.txt
agrep -0 -c 'ACGCACGGGACTAAAAA' *.fastq > count/B16589_Fm0.txt
agrep -0 -c 'GTAATACGTATCGGAGA' *.fastq > count/B16590_Fm0.txt
agrep -0 -c 'TCTACTCGATACCACTT' *.fastq > count/B16591_Fm0.txt
agrep -0 -c 'TCATACCCCATAGCGGA' *.fastq > count/B16593_Fm0.txt
agrep -0 -c 'GGGACCTTAACTGCGGT' *.fastq > count/B16594_Fm0.txt
agrep -0 -c 'ACCAGTCCAATCAACAC' *.fastq > count/B16595_Fm0.txt
agrep -0 -c 'TGAGACCTGCTTTAGGA' *.fastq > count/B16596_Fm0.txt
agrep -0 -c 'GCTACCCGGAAAAGTTA' *.fastq > count/B16597_Fm0.txt
agrep -0 -c 'CAAGCTGGTAGAATACG' *.fastq > count/B16598_Fm0.txt
agrep -0 -c 'AGCGTCGAGTGCAAAGT' *.fastq > count/B16599_Fm0.txt
agrep -0 -c 'CGCAGATATGGTTTCGT' *.fastq > count/B16600_Fm0.txt
agrep -0 -c 'ATTTAGGGGCGGTGGTA' *.fastq > count/B16602_Fm0.txt
agrep -0 -c 'GCCCCCTAAGGCAAAAG' *.fastq > count/B16603_Fm0.txt
agrep -0 -c 'CTCGTATACTCTATGAC' *.fastq > count/B16604_Fm0.txt
agrep -0 -c 'GGTCCTGAATGGGCACA' *.fastq > count/B16605_Fm0.txt
agrep -0 -c 'TAGTTGAGAGGTGACTT' *.fastq > count/B16606_Fm0.txt
agrep -0 -c 'GTGAAAGGAACCTCCGC' *.fastq > count/B16607_Fm0.txt
agrep -0 -c 'TTGGAGTGCGTAACCTC' *.fastq > count/B16608_Fm0.txt
agrep -0 -c 'CTACCGATTGGAGCATG' *.fastq > count/B16612_Fm0.txt
agrep -0 -c 'CTCGCCAAGTACTGTCG' *.fastq > count/B16613_Fm0.txt
agrep -0 -c 'CCGGAGACGTGTCCAAT' *.fastq > count/B16614_Fm0.txt
agrep -0 -c 'AACGTATGCGTCGTGTG' *.fastq > count/B16615_Fm0.txt
agrep -0 -c 'ATCTGCTCGCGAACTGT' *.fastq > count/B16616_Fm0.txt
agrep -0 -c 'TTGGCTAAACGTCGGTT' *.fastq > count/B16617_Fm0.txt
agrep -0 -c 'GGTCTCTAAATTTCGCA' *.fastq > count/B16618_Fm0.txt
agrep -0 -c 'CTATTCGTCTGACATGT' *.fastq > count/B16619_Fm0.txt
agrep -0 -c 'ATCGATTGATGCCGTGG' *.fastq > count/B16622_Fm0.txt
agrep -0 -c 'CAGCAAATCGAGACTTC' *.fastq > count/B16623_Fm0.txt
agrep -0 -c 'TGACTTAGCGAGATTGG' *.fastq > count/B16624_Fm0.txt
agrep -0 -c 'ACACAATGAGGCCCAAC' *.fastq > count/B16625_Fm0.txt
agrep -0 -c 'AATAGTCATTCTCGGCC' *.fastq > count/B16626_Fm0.txt
agrep -0 -c 'TCAAAATGACTCAGTCC' *.fastq > count/B16627_Fm0.txt
agrep -0 -c 'GACGTTAGTTCGCAGTC' *.fastq > count/B16628_Fm0.txt
agrep -0 -c 'ATAGCGGCTATTCAACA' *.fastq > count/B16629_Fm0.txt
agrep -0 -c 'AGCAAGATTGCGTGTAG' *.fastq > count/B16630_Fm0.txt
agrep -0 -c 'GCAGTTCAGGTTAACGA' *.fastq > count/B16632_Fm0.txt
agrep -0 -c 'TGCCCCTACAAGCTAAA' *.fastq > count/B16634_Fm0.txt
agrep -0 -c 'GACGAGCGGTTAGTATT' *.fastq > count/B16635_Fm0.txt
agrep -0 -c 'TTCCGTATGGTGGAGGC' *.fastq > count/B16636_Fm0.txt
agrep -0 -c 'AGGAGAGGATCCATAAT' *.fastq > count/B16637_Fm0.txt
agrep -0 -c 'TGCTTAGGGATAAAGCA' *.fastq > count/B16639_Fm0.txt
agrep -0 -c 'TGACTATTTTGATCGGG' *.fastq > count/B16640_Fm0.txt
agrep -0 -c 'GTCTTCTTCAGCTCCCT' *.fastq > count/B16641_Fm0.txt
agrep -0 -c 'AGCGTATGCCCGAAATG' *.fastq > count/B16642_Fm0.txt
agrep -0 -c 'GTTCGAATGCCTGATGA' *.fastq > count/B16644_Fm0.txt
agrep -0 -c 'ATCCTGGGTCAATAATC' *.fastq > count/B16646_Fm0.txt
agrep -0 -c 'CACTCTAAGTCCGCACA' *.fastq > count/B16648_Fm0.txt
agrep -0 -c 'TAGCGCCTCTATCAATT' *.fastq > count/B16649_Fm0.txt
agrep -0 -c 'GTCGGGAGTCGCGAATA' *.fastq > count/B16650_Fm0.txt
agrep -0 -c 'GTTGAGTTTTTCCAGAG' *.fastq > count/B16651_Fm0.txt
agrep -0 -c 'TAGAACAAGTTCTACCG' *.fastq > count/B16652_Fm0.txt
agrep -0 -c 'GCAACGCGATTACGGCT' *.fastq > count/B16653_Fm0.txt
agrep -0 -c 'GTCTCGGAAGGCCCAAT' *.fastq > count/B16654_Fm0.txt
agrep -0 -c 'ATTGCGAACCACGTTTG' *.fastq > count/B16655_Fm0.txt
agrep -0 -c 'CTGAGGTGTACCTGTCG' *.fastq > count/B16656_Fm0.txt
agrep -0 -c 'TAGGGTCACCACCCCTA' *.fastq > count/B16658_Fm0.txt
agrep -0 -c 'GAGAGAACTCAGCCATC' *.fastq > count/B16659_Fm0.txt
agrep -0 -c 'TATTCCCGGACGGATTT' *.fastq > count/B16663_Fm0.txt
agrep -0 -c 'ATCCGAAGTATCGGATG' *.fastq > count/B16664_Fm0.txt
agrep -0 -c 'TGATTCCGGCCCATTAT' *.fastq > count/B16666_Fm0.txt
agrep -0 -c 'GACACCAACTTCGCGTT' *.fastq > count/B16668_Fm0.txt
agrep -0 -c 'AGGTGAATAGGAGTGAC' *.fastq > count/B16669_Fm0.txt
agrep -0 -c 'CTATGAAAGCCAACAGT' *.fastq > count/B16670_Fm0.txt
agrep -0 -c 'TCTTCTACATATACCGG' *.fastq > count/B16671_Fm0.txt
agrep -0 -c 'TGAGGGGTAACTGTATC' *.fastq > count/B16672_Fm0.txt
agrep -0 -c 'GCAGCGCAGTTACTTCT' *.fastq > count/B16673_Fm0.txt
agrep -0 -c 'TTGCTGGGTTCGTTTGA' *.fastq > count/B16674_Fm0.txt
agrep -0 -c 'AATAACCTGGAGCCAAC' *.fastq > count/B16675_Fm0.txt
agrep -0 -c 'TCGGCAATCATGTGGAG' *.fastq > count/B16676_Fm0.txt
agrep -0 -c 'GTCTCCTGAGGTTCACC' *.fastq > count/B16677_Fm0.txt
agrep -0 -c 'AGCCTCTATTGGCGTTT' *.fastq > count/B16678_Fm0.txt
agrep -0 -c 'ATCTCGCCAAAATCAAC' *.fastq > count/B16679_Fm0.txt
agrep -0 -c 'TCACTCCGTACACGCGT' *.fastq > count/B16680_Fm0.txt
agrep -0 -c 'CGTCCGTTTCGACGACT' *.fastq > count/B16681_Fm0.txt
agrep -0 -c 'TGGCTGGTAGACTCACC' *.fastq > count/B16682_Fm0.txt
agrep -0 -c 'TCGACAGACAGAAAGCC' *.fastq > count/B16684_Fm0.txt
agrep -0 -c 'TTACGGTCGTTTAACCA' *.fastq > count/B16686_Fm0.txt
agrep -0 -c 'AAGCCATAGGGCGGCAT' *.fastq > count/B16687_Fm0.txt
agrep -0 -c 'CGGGGAATTACGAAGAC' *.fastq > count/B16688_Fm0.txt
agrep -0 -c 'AAGTCACCTGAGGGGGA' *.fastq > count/B16689_Fm0.txt
agrep -0 -c 'CACATGTGGAGCATAGG' *.fastq > count/B16690_Fm0.txt
agrep -0 -c 'TTACAGCTTCCAACACG' *.fastq > count/B16691_Fm0.txt
agrep -0 -c 'GGCTTTGTCCCACATAA' *.fastq > count/B16692_Fm0.txt
agrep -0 -c 'GGGGAGGTTATTATCGG' *.fastq > count/B16694_Fm0.txt
agrep -0 -c 'GACCCATAATAGTGAAC' *.fastq > count/B16696_Fm0.txt
agrep -0 -c 'ACGTTTCGAAGCACATG' *.fastq > count/B16697_Fm0.txt
agrep -0 -c 'AGCTGGGGTGCTCTTTG' *.fastq > count/B16698_Fm0.txt
agrep -0 -c 'GGAGCTGACTGAGCTAT' *.fastq > count/B16699_Fm0.txt
agrep -0 -c 'AAGACGACACTCGGACA' *.fastq > count/B16701_Fm0.txt
agrep -0 -c 'TACTGACTCCAACATCT' *.fastq > count/B16702_Fm0.txt
agrep -0 -c 'TGGAAGCTAGGTTCGAC' *.fastq > count/B16703_Fm0.txt
agrep -0 -c 'ATACCGACATCTGAAGG' *.fastq > count/B16704_Fm0.txt
agrep -0 -c 'CACCGAAGGTACAGTGA' *.fastq > count/B16707_Fm0.txt
agrep -0 -c 'CAACATACTACAGACGG' *.fastq > count/B16708_Fm0.txt
agrep -0 -c 'TGATACCAACTCGTTGG' *.fastq > count/B16709_Fm0.txt
agrep -0 -c 'CTCCGGGAGATGAACAA' *.fastq > count/B16711_Fm0.txt
agrep -0 -c 'GCTGGTACTTACAAGGC' *.fastq > count/B16713_Fm0.txt
agrep -0 -c 'CATGCACTGTAAAAGAC' *.fastq > count/B16714_Fm0.txt
agrep -0 -c 'ACGTGTGAAGAATGGAT' *.fastq > count/B16715_Fm0.txt
agrep -0 -c 'TCGCACTCTGAAGGGTA' *.fastq > count/B16716_Fm0.txt
agrep -0 -c 'GATAGAGTTGATCAGAC' *.fastq > count/B16717_Fm0.txt
agrep -0 -c 'GTCATGTCGGCAGGTAT' *.fastq > count/B16718_Fm0.txt
agrep -0 -c 'TGACACGTACACCCTAG' *.fastq > count/B16719_Fm0.txt
agrep -0 -c 'CTGCAGTTAATGGGGGC' *.fastq > count/B16720_Fm0.txt
agrep -0 -c 'GTGGGGTTATAAAAAGG' *.fastq > count/B16721_Fm0.txt
agrep -0 -c 'AGCACACGACCATACAC' *.fastq > count/B16723_Fm0.txt
agrep -0 -c 'TGAATACGGGGTGAGAT' *.fastq > count/B16724_Fm0.txt
agrep -0 -c 'TAAAGACGGCGGAGAGC' *.fastq > count/B16725_Fm0.txt
agrep -0 -c 'CAACGCTCTGTCAGAGA' *.fastq > count/B16726_Fm0.txt
agrep -0 -c 'CAGACCTTTCGATTCAC' *.fastq > count/B16727_Fm0.txt
agrep -0 -c 'GCCCATCTCAGTAAAAG' *.fastq > count/B16728_Fm0.txt
agrep -0 -c 'GCTTAGGGTGCTGCACT' *.fastq > count/B16729_Fm0.txt
agrep -0 -c 'TACCTCTACGGCAAGGT' *.fastq > count/B16730_Fm0.txt
agrep -0 -c 'TAGGTTACCAATATGCG' *.fastq > count/B16731_Fm0.txt
agrep -0 -c 'CGGAGCTGTTCTTATAC' *.fastq > count/B16732_Fm0.txt
agrep -0 -c 'ACGCCAAGCGGAAATTG' *.fastq > count/B16733_Fm0.txt
agrep -0 -c 'TACTAGTGCACGACACA' *.fastq > count/B16734_Fm0.txt
agrep -0 -c 'CGGATGTCCCTAAGTGT' *.fastq > count/B16735_Fm0.txt
agrep -0 -c 'GGAACCTCTCAAATGAC' *.fastq > count/B16736_Fm0.txt
agrep -0 -c 'CTGCATGGTACGTCTAT' *.fastq > count/B16737_Fm0.txt
agrep -0 -c 'TACTCGCTTCGTATGAT' *.fastq > count/B16738_Fm0.txt
agrep -0 -c 'GGCTTTCCGGCGCTTTA' *.fastq > count/B16739_Fm0.txt
agrep -0 -c 'AGGTGGTATGGTCTGAG' *.fastq > count/B16742_Fm0.txt
agrep -0 -c 'GCGAGAACAGAATTAAG' *.fastq > count/B16743_Fm0.txt
agrep -0 -c 'TTCCAGGCGGTGATTTG' *.fastq > count/B16744_Fm0.txt
agrep -0 -c 'CCAGTCCATCTTCGACC' *.fastq > count/B16745_Fm0.txt
agrep -0 -c 'GTAGTCGCCAGTATTCA' *.fastq > count/B16747_Fm0.txt
agrep -0 -c 'TCGCGAGAGCAATGCGA' *.fastq > count/B16748_Fm0.txt
agrep -0 -c 'GCCGTGACTCATCTTCA' *.fastq > count/B16749_Fm0.txt
agrep -0 -c 'ACTCAGTTCCATTGGAG' *.fastq > count/B16750_Fm0.txt
agrep -0 -c 'ATGGTTCTTTGCAAGCG' *.fastq > count/B16752_Fm0.txt
agrep -0 -c 'TGCCTGATAGATGTGAA' *.fastq > count/B16753_Fm0.txt
agrep -0 -c 'CGAATGGTGTTTACTGG' *.fastq > count/B16754_Fm0.txt
agrep -0 -c 'AGGAGATATTAGCTTCG' *.fastq > count/B16755_Fm0.txt
agrep -0 -c 'TACTACCCAGTAACTCG' *.fastq > count/B16756_Fm0.txt
agrep -0 -c 'GAGTGATCAGGGGCTAA' *.fastq > count/B16757_Fm0.txt
agrep -0 -c 'CAAAGCCTACTTAAGCA' *.fastq > count/B16758_Fm0.txt
agrep -0 -c 'GTTTGGATAGACTCTGC' *.fastq > count/B16759_Fm0.txt
agrep -0 -c 'TCGTTGGCTGTTTTAGG' *.fastq > count/B16760_Fm0.txt
agrep -0 -c 'CCGTTGATCTTTACTGC' *.fastq > count/B16761_Fm0.txt
agrep -0 -c 'AACAAGCGCCCTCGAAT' *.fastq > count/B16762_Fm0.txt
agrep -0 -c 'GACGAGGCGCTAAGCAT' *.fastq > count/B16763_Fm0.txt
agrep -0 -c 'CGCTAGATATGAAACCT' *.fastq > count/B16764_Fm0.txt
agrep -0 -c 'TAGTGTACAAACCCCGA' *.fastq > count/B16765_Fm0.txt
agrep -0 -c 'TCGCTCACGTATATTCA' *.fastq > count/B16766_Fm0.txt
agrep -0 -c 'GGCCAATATGGACAATA' *.fastq > count/B16767_Fm0.txt
agrep -0 -c 'CCTCATTCTCAAAAGGC' *.fastq > count/B16768_Fm0.txt
agrep -0 -c 'GGCACCGAATTTGCGGT' *.fastq > count/B16769_Fm0.txt
agrep -0 -c 'TGCAGAGCAAAGCGTCG' *.fastq > count/B16770_Fm0.txt
agrep -0 -c 'CATCACGTGAGTCTCGG' *.fastq > count/B16771_Fm0.txt
agrep -0 -c 'GTAACCGTACAACTACG' *.fastq > count/B16772_Fm0.txt
agrep -0 -c 'ACGCGGTTTTTATATCG' *.fastq > count/B16774_Fm0.txt
agrep -0 -c 'GGCAAAAACGGTCTAAT' *.fastq > count/B16775_Fm0.txt
agrep -0 -c 'AATGACCTTTTGGAACC' *.fastq > count/B16777_Fm0.txt
agrep -0 -c 'ATACCTAGGGGTGGCCA' *.fastq > count/B16778_Fm0.txt
agrep -0 -c 'CAGGGTTCCGTGGTCAT' *.fastq > count/B16780_Fm0.txt
agrep -0 -c 'AAGGCTTGAGGAGTGGT' *.fastq > count/B16781_Fm0.txt
agrep -0 -c 'GTCACCGGGAGTTTAGG' *.fastq > count/B16782_Fm0.txt
agrep -0 -c 'GCCTTCAGTAAACCGCT' *.fastq > count/B16783_Fm0.txt
agrep -0 -c 'CGTGCAACGAGCAGTTA' *.fastq > count/B16784_Fm0.txt
agrep -0 -c 'CTGCCAGAGGTAAAGGC' *.fastq > count/B16785_Fm0.txt
agrep -0 -c 'TGACAGCCTCTAAGAAC' *.fastq > count/B16787_Fm0.txt
agrep -0 -c 'CGCCTTGTGTAGGCTTG' *.fastq > count/B16788_Fm0.txt
agrep -0 -c 'CATCGACTGGCTCAACT' *.fastq > count/B16789_Fm0.txt
agrep -0 -c 'TCATAGACTCGAGTGAC' *.fastq > count/B16790_Fm0.txt
agrep -0 -c 'ATCGTCGCATGGTTAAT' *.fastq > count/B16791_Fm0.txt
agrep -0 -c 'TACCTACCGACAACATA' *.fastq > count/B16792_Fm0.txt
agrep -0 -c 'GATATGTCCAGAGCTAA' *.fastq > count/B16793_Fm0.txt
agrep -0 -c 'TTCGCTTTGCAGTCAGC' *.fastq > count/B16795_Fm0.txt
agrep -0 -c 'CGAATAAACCGGCGAAG' *.fastq > count/B16797_Fm0.txt
agrep -0 -c 'TAAGGCCCTTCCTGGAG' *.fastq > count/B16798_Fm0.txt
agrep -0 -c 'GATAACGGCTTAGACTA' *.fastq > count/B16799_Fm0.txt
agrep -0 -c 'ATTCGACCCTTGCTAGA' *.fastq > count/B16800_Fm0.txt
agrep -0 -c 'GTTCATGCGTTCTGCAG' *.fastq > count/B16801_Fm0.txt
agrep -0 -c 'TCTTGAGAGATTCCCGG' *.fastq > count/B16802_Fm0.txt
agrep -0 -c 'GAGCCAATAAGGAACCC' *.fastq > count/B16803_Fm0.txt
agrep -0 -c 'CCGTACGTCAGTTTCCG' *.fastq > count/B16804_Fm0.txt
agrep -0 -c 'CGATACACAGTATTACG' *.fastq > count/B16805_Fm0.txt
agrep -0 -c 'GTGGCACTTCTTACTCC' *.fastq > count/B16807_Fm0.txt
agrep -0 -c 'GCAGTTTGCTACTCGTA' *.fastq > count/B16809_Fm0.txt
agrep -0 -c 'AATACGGCTCCATTCTA' *.fastq > count/B16810_Fm0.txt
agrep -0 -c 'AGATCTTTCCGCTCCTC' *.fastq > count/B16813_Fm0.txt
agrep -0 -c 'CGAAGGTAAGACTAGCG' *.fastq > count/B16814_Fm0.txt
agrep -0 -c 'TACCGTAGTAATCGGGT' *.fastq > count/B16815_Fm0.txt
agrep -0 -c 'GGTCAGTGTTTGTTAGT' *.fastq > count/B16816_Fm0.txt
agrep -0 -c 'GTTACCCTTCAGGTCAC' *.fastq > count/B16817_Fm0.txt
agrep -0 -c 'CAGATGGGAAGTTAGCG' *.fastq > count/B16818_Fm0.txt
agrep -0 -c 'GAGCGTTCTGTTGCTTG' *.fastq > count/B16819_Fm0.txt
agrep -0 -c 'CCGGGAATGTGTATATG' *.fastq > count/B16820_Fm0.txt
agrep -0 -c 'ATTTAGCGATCAGTACC' *.fastq > count/B16821_Fm0.txt
agrep -0 -c 'GTAGGATTACGAGGAAA' *.fastq > count/B16822_Fm0.txt
agrep -0 -c 'TTAGCCGCAAATGCTGC' *.fastq > count/B16823_Fm0.txt
agrep -0 -c 'GTACTCAGTTGCGAACC' *.fastq > count/B16825_Fm0.txt
agrep -0 -c 'GGTACTCCTGCTTTACT' *.fastq > count/B16826_Fm0.txt
agrep -0 -c 'TAGCTTTACGCAACCTT' *.fastq > count/B16827_Fm0.txt
agrep -0 -c 'GCATAGCATGGAATCAT' *.fastq > count/B16828_Fm0.txt
agrep -0 -c 'CGGAAAAGAAGTCGATC' *.fastq > count/B16829_Fm0.txt
agrep -0 -c 'CTATGAGAAGCCATTCG' *.fastq > count/B16832_Fm0.txt
agrep -0 -c 'GGTGCTGATCGGGATAT' *.fastq > count/B16833_Fm0.txt
agrep -0 -c 'GCCGGCCTTATTGGCAA' *.fastq > count/B16834_Fm0.txt
agrep -0 -c 'ACATTCACAACGTCGTA' *.fastq > count/B16835_Fm0.txt
agrep -0 -c 'AATCTCAGGTACCTCGC' *.fastq > count/B16836_Fm0.txt
agrep -0 -c 'CGCCATGAAGTCGTGTC' *.fastq > count/B16837_Fm0.txt
agrep -0 -c 'CTTGCGTGACTAATGAT' *.fastq > count/B16838_Fm0.txt
agrep -0 -c 'GCGGACAATATTAGGAT' *.fastq > count/B16840_Fm0.txt
agrep -0 -c 'AAGCTCCCCTTAAGGCG' *.fastq > count/B16842_Fm0.txt
agrep -0 -c 'CACTTAACATTGACGAC' *.fastq > count/B16843_Fm0.txt
agrep -0 -c 'GGAATTTAGGGTGAGGA' *.fastq > count/B16844_Fm0.txt
agrep -0 -c 'CATTCTCATAATGCCTG' *.fastq > count/B16845_Fm0.txt
agrep -0 -c 'GCGATCAACACCTAGGC' *.fastq > count/B16846_Fm0.txt
agrep -0 -c 'CGTATGTTGGTCTGATG' *.fastq > count/B16847_Fm0.txt
agrep -0 -c 'ACCATATCCGATGCCTG' *.fastq > count/B16848_Fm0.txt
agrep -0 -c 'CGTAAAAGGGTTCTGGA' *.fastq > count/B16849_Fm0.txt
agrep -0 -c 'ACCGCTGTTATCGGGCT' *.fastq > count/B16850_Fm0.txt
agrep -0 -c 'CCTGCCGAAGTTAAAGG' *.fastq > count/B16851_Fm0.txt
agrep -0 -c 'AAGATTTTCGTTGTGGG' *.fastq > count/B16853_Fm0.txt
agrep -0 -c 'TAGTTAAGCTGCCGTTG' *.fastq > count/B16854_Fm0.txt
agrep -0 -c 'AGGGATGTACCACAAGG' *.fastq > count/B16855_Fm0.txt
agrep -0 -c 'TGAAGATCAGGGGGGGA' *.fastq > count/B16856_Fm0.txt
agrep -0 -c 'TAACCAACGGGATTAAG' *.fastq > count/B16857_Fm0.txt
agrep -0 -c 'AGGCCTTTAGGACCGCA' *.fastq > count/B16858_Fm0.txt
agrep -0 -c 'AATCCGCCTGATATATG' *.fastq > count/B16859_Fm0.txt
agrep -0 -c 'TAAACGAGATAGGGAGT' *.fastq > count/B16862_Fm0.txt
agrep -0 -c 'CATTCCCGCTTTTGCGA' *.fastq > count/B16863_Fm0.txt
agrep -0 -c 'GCAAGTTCTCCCCACGT' *.fastq > count/B16864_Fm0.txt
agrep -0 -c 'ATCTGTTCAATGGGGAC' *.fastq > count/B16865_Fm0.txt
agrep -0 -c 'ACGCGGGATCGTGGATT' *.fastq > count/B16867_Fm0.txt
agrep -0 -c 'TGCCGCTTTCGTGTATC' *.fastq > count/B16869_Fm0.txt
agrep -0 -c 'GAGAGTGATAGTCGACT' *.fastq > count/B16870_Fm0.txt
agrep -0 -c 'TTAGATACGTGAGCGGC' *.fastq > count/B16871_Fm0.txt
agrep -0 -c 'CTAATGCGTGGTAGTAT' *.fastq > count/B16872_Fm0.txt
agrep -0 -c 'GAGGATAAACGGATACT' *.fastq > count/B16874_Fm0.txt
agrep -0 -c 'TTCCTAGACTCCGGTGG' *.fastq > count/B16875_Fm0.txt
agrep -0 -c 'GCGTATTGTTGGGCTAC' *.fastq > count/B16876_Fm0.txt
agrep -0 -c 'CTAGTGAATTCCGGGAG' *.fastq > count/B16877_Fm0.txt
agrep -0 -c 'GCCTCCACTAAGGCAAT' *.fastq > count/B16878_Fm0.txt
agrep -0 -c 'GAGATGGGTTTAGGGTA' *.fastq > count/B16879_Fm0.txt
agrep -0 -c 'TAAGCTTGTGCGCTCAA' *.fastq > count/B16880_Fm0.txt
agrep -0 -c 'TCGACTACTCTACAAAC' *.fastq > count/B16881_Fm0.txt
agrep -0 -c 'GTAAAGGCTCTACTCAG' *.fastq > count/B16882_Fm0.txt
agrep -0 -c 'TTGGAGCCAAGAGTGGG' *.fastq > count/B16883_Fm0.txt
agrep -0 -c 'GATCGGACCACAAAAAA' *.fastq > count/B16884_Fm0.txt
agrep -0 -c 'ACTCGTCTGTTAGCATT' *.fastq > count/B16885_Fm0.txt
agrep -0 -c 'TTAACTGCCAAGACACG' *.fastq > count/B16886_Fm0.txt
agrep -0 -c 'GTACAGGGTTCACGTCT' *.fastq > count/B16888_Fm0.txt
agrep -0 -c 'GCGGACCTTGAACACGT' *.fastq > count/B16889_Fm0.txt
agrep -0 -c 'GCAAAGTACCGTAATTG' *.fastq > count/B16891_Fm0.txt
agrep -0 -c 'TTCGTGCAACGGCAGAT' *.fastq > count/B16894_Fm0.txt
agrep -0 -c 'TCATCGGTTGCAATCCG' *.fastq > count/B16895_Fm0.txt
agrep -0 -c 'TGCATGACGGGTCACCA' *.fastq > count/B16896_Fm0.txt
agrep -0 -c 'GGAATCCCCCTTCGATT' *.fastq > count/B16897_Fm0.txt
agrep -0 -c 'TGAATCTCACCGTCGTT' *.fastq > count/B16898_Fm0.txt
agrep -0 -c 'TGTCAACCACGAACGGA' *.fastq > count/B16899_Fm0.txt
agrep -0 -c 'AACCTTTCCTTACGTGT' *.fastq > count/B16900_Fm0.txt
agrep -0 -c 'TGCTAAGGACAGGAGCT' *.fastq > count/B16902_Fm0.txt
agrep -0 -c 'TTCTGTGCTGCCTAATA' *.fastq > count/B16905_Fm0.txt
agrep -0 -c 'AACACGGAAGATCCGCT' *.fastq > count/B16906_Fm0.txt
agrep -0 -c 'ATTACAATCTAGACGGC' *.fastq > count/B16907_Fm0.txt
agrep -0 -c 'AAGCCATTGTGGCATAT' *.fastq > count/B16908_Fm0.txt
agrep -0 -c 'GGATTAGCGCCGAAAGT' *.fastq > count/B16909_Fm0.txt
agrep -0 -c 'TGAGATATATGTTCCGC' *.fastq > count/B16912_Fm0.txt
agrep -0 -c 'CCACGACAATAAAACGT' *.fastq > count/B16913_Fm0.txt
agrep -0 -c 'CTAACTGGCCCAATTAT' *.fastq > count/B16914_Fm0.txt
agrep -0 -c 'ATCGAGAAGATACAGCT' *.fastq > count/B16915_Fm0.txt
agrep -0 -c 'TGAGCGAAGACTACCGA' *.fastq > count/B16916_Fm0.txt
agrep -0 -c 'TAGCAGGAAGCCATCCG' *.fastq > count/B16917_Fm0.txt
agrep -0 -c 'TAAGTATAACGCCCTCG' *.fastq > count/B16919_Fm0.txt
agrep -0 -c 'CTAGTTCATGCGATTGT' *.fastq > count/B16920_Fm0.txt
agrep -0 -c 'CTAATTAGGCGAGGCGT' *.fastq > count/B16921_Fm0.txt
agrep -0 -c 'AAGCTACCTCTACCTAC' *.fastq > count/B16923_Fm0.txt
agrep -0 -c 'CATGTAGTTGCCCTCGC' *.fastq > count/B16924_Fm0.txt
agrep -0 -c 'CGAGTAACCGAAGGCAA' *.fastq > count/B16925_Fm0.txt
agrep -0 -c 'TGTTAGCCCACTTGTTT' *.fastq > count/B16926_Fm0.txt
agrep -0 -c 'TTACGTTTAACGGACTG' *.fastq > count/B16928_Fm0.txt
agrep -0 -c 'GACCGTCCAGATTCTAG' *.fastq > count/B16929_Fm0.txt
agrep -0 -c 'AATAGGTGGAAGCAGGT' *.fastq > count/B16930_Fm0.txt
agrep -0 -c 'TCGCGAACAACGCTTTG' *.fastq > count/B16931_Fm0.txt
agrep -0 -c 'AGTTGCATAGTTCGCGC' *.fastq > count/B16932_Fm0.txt
agrep -0 -c 'AGAGACGTGTCGAGCGA' *.fastq > count/B16933_Fm0.txt
agrep -0 -c 'CCGGAATCGCCTAAATA' *.fastq > count/B16934_Fm0.txt
agrep -0 -c 'ACGGAAGTTTCGGGATC' *.fastq > count/B16936_Fm0.txt
agrep -0 -c 'CACCACTGAGTGACAAT' *.fastq > count/B16937_Fm0.txt
agrep -0 -c 'GCCTGCTATAGCGATTT' *.fastq > count/B16938_Fm0.txt
agrep -0 -c 'GTCGTGTTCTCTTGGTC' *.fastq > count/B16939_Fm0.txt
agrep -0 -c 'TCGGAAAGTCTCTCAAC' *.fastq > count/B16940_Fm0.txt
agrep -0 -c 'AGTAGGGTACTACTTCC' *.fastq > count/B16941_Fm0.txt
agrep -0 -c 'CGTAAATGACGCGACAG' *.fastq > count/B16942_Fm0.txt
agrep -0 -c 'TGGAGCGCCAGATAGAT' *.fastq > count/B16944_Fm0.txt
agrep -0 -c 'CGCACGAAATAACTAGC' *.fastq > count/B16945_Fm0.txt
agrep -0 -c 'CTTATGTGTTGCTAGAC' *.fastq > count/B16946_Fm0.txt
agrep -0 -c 'TTAGCGTGATTGTCCAT' *.fastq > count/B16947_Fm0.txt
agrep -0 -c 'ACGCCAAGGAAGGCACT' *.fastq > count/B16949_Fm0.txt
agrep -0 -c 'GGACTCAGCCTTTGTTT' *.fastq > count/B16950_Fm0.txt
agrep -0 -c 'CCGTGTAACCTCCCACT' *.fastq > count/B16951_Fm0.txt
agrep -0 -c 'GTTCCTACCCCCATGAT' *.fastq > count/B16952_Fm0.txt
agrep -0 -c 'TTGAAGGCCCTAGCGTT' *.fastq > count/B16953_Fm0.txt
agrep -0 -c 'CACCCCCTCTTATTCAT' *.fastq > count/B16955_Fm0.txt
agrep -0 -c 'TCGGCACTCAGAGCAAA' *.fastq > count/B16956_Fm0.txt
agrep -0 -c 'TTCTCGCGGTTACTTCT' *.fastq > count/B16958_Fm0.txt
agrep -0 -c 'AATTCACCCTCGGCCAT' *.fastq > count/B16959_Fm0.txt
agrep -0 -c 'TCGGAACTCGATCGATT' *.fastq > count/B16960_Fm0.txt
agrep -0 -c 'TCAGGATACCGCCTTCA' *.fastq > count/B16961_Fm0.txt
agrep -0 -c 'ACGCAGCGTACTTCTTC' *.fastq > count/B16962_Fm0.txt
agrep -0 -c 'TCAAAGCGGGCTCTTCT' *.fastq > count/B16963_Fm0.txt
agrep -0 -c 'TCAGTCACAGCGTGTTT' *.fastq > count/B16964_Fm0.txt
agrep -0 -c 'TGCACTGCCGATTTCAA' *.fastq > count/B16965_Fm0.txt
agrep -0 -c 'ATGTAGGGCTAATCCCG' *.fastq > count/B16966_Fm0.txt
agrep -0 -c 'CTCGGTGCATTCAATTT' *.fastq > count/B16967_Fm0.txt
agrep -0 -c 'CACGCGTACAAGAGTTT' *.fastq > count/B16968_Fm0.txt
agrep -0 -c 'TTGATTGATCCCTGGTC' *.fastq > count/B16971_Fm0.txt
agrep -0 -c 'ATCCCACCTCCCGCAAT' *.fastq > count/B16972_Fm0.txt
agrep -0 -c 'GCCGACATAGACTGTCC' *.fastq > count/B16973_Fm0.txt
agrep -0 -c 'GATTACAACGGTAGATG' *.fastq > count/B16974_Fm0.txt
agrep -0 -c 'GGAGCGGTTACGTTGTC' *.fastq > count/B16975_Fm0.txt
agrep -0 -c 'CCGGAGAGCGTTTTATG' *.fastq > count/B16976_Fm0.txt
agrep -0 -c 'GGGCTGTACGGTATAGC' *.fastq > count/B16978_Fm0.txt
agrep -0 -c 'GCCTATACCATTTAGTC' *.fastq > count/B16979_Fm0.txt
agrep -0 -c 'ATAAACCTCGCCTTCCA' *.fastq > count/B16980_Fm0.txt
agrep -0 -c 'TAGTCTCTCACGCGTAA' *.fastq > count/B16982_Fm0.txt
agrep -0 -c 'TTCGACACGCATGTGGT' *.fastq > count/B16983_Fm0.txt
agrep -0 -c 'CTGCACGCCGTTTGTGA' *.fastq > count/B16985_Fm0.txt
agrep -0 -c 'GCCTTTGCAAAACGTCC' *.fastq > count/B16986_Fm0.txt
agrep -0 -c 'GCTCGCACTTCGTACTC' *.fastq > count/B16987_Fm0.txt
agrep -0 -c 'TGGAGTTTGGGTATCTC' *.fastq > count/B16988_Fm0.txt
agrep -0 -c 'AAGGGCGACTAGTGGAT' *.fastq > count/B16989_Fm0.txt
agrep -0 -c 'TGATCCACGGCAACACT' *.fastq > count/B16990_Fm0.txt
agrep -0 -c 'TAAAAGCCGTGTTCACC' *.fastq > count/B16991_Fm0.txt
agrep -0 -c 'CCGGTTACCTGATGACG' *.fastq > count/B16993_Fm0.txt
agrep -0 -c 'CGTCACATTCTGTGAGT' *.fastq > count/B16994_Fm0.txt
agrep -0 -c 'TCTACTAGCGGCATACG' *.fastq > count/B16995_Fm0.txt
agrep -0 -c 'GACAGGTTAGGATCAAT' *.fastq > count/B16996_Fm0.txt
agrep -0 -c 'TGCTTCGCAGTGTTTCC' *.fastq > count/B16998_Fm0.txt
agrep -0 -c 'TCGGGGAACATTAAGGA' *.fastq > count/B16999_Fm0.txt
agrep -0 -c 'ACTTTACTGGCAGATAG' *.fastq > count/B17000_Fm0.txt
agrep -0 -c 'GCAGAGCTGCTAATTTG' *.fastq > count/B17001_Fm0.txt
agrep -0 -c 'AACGACTCGGGTTGTAA' *.fastq > count/B17002_Fm0.txt
agrep -0 -c 'CCTCTGTACACGGCACT' *.fastq > count/B17003_Fm0.txt
agrep -0 -c 'CATATCGCAGCAGCTAG' *.fastq > count/B17005_Fm0.txt
agrep -0 -c 'CTAACTAAGGGTTCTTG' *.fastq > count/B17006_Fm0.txt
agrep -0 -c 'GTCGATTACCGTGTCCG' *.fastq > count/B17007_Fm0.txt
agrep -0 -c 'CCGATCTGGTTGCTAGA' *.fastq > count/B17008_Fm0.txt
agrep -0 -c 'AGACTATTCACGGTGCC' *.fastq > count/B17009_Fm0.txt
agrep -0 -c 'GGGCGACATAATATGCG' *.fastq > count/B17010_Fm0.txt
agrep -0 -c 'ATCGAAGCTACCAACGC' *.fastq > count/B17011_Fm0.txt
agrep -0 -c 'GCATTAGTGTCTATGGA' *.fastq > count/B17013_Fm0.txt
agrep -0 -c 'TTAGGAGACACACCAAG' *.fastq > count/B17014_Fm0.txt
agrep -0 -c 'AAGGCCGAAAATAAGGT' *.fastq > count/B17016_Fm0.txt
agrep -0 -c 'GCCGCTAGGGAAAGCAA' *.fastq > count/B17017_Fm0.txt
agrep -0 -c 'AACGGTCTTGCTAACCT' *.fastq > count/B17019_Fm0.txt
agrep -0 -c 'TTCTAGGTACCGTTGTA' *.fastq > count/B17020_Fm0.txt
agrep -0 -c 'AGTTACCCGCACACAGT' *.fastq > count/B17021_Fm0.txt
agrep -0 -c 'AGCTATTTGGTCCACGT' *.fastq > count/B17022_Fm0.txt
agrep -0 -c 'TCGCGGGATGTCTAGAT' *.fastq > count/B17024_Fm0.txt
agrep -0 -c 'GTAACATTACTTGGGCG' *.fastq > count/B17025_Fm0.txt
agrep -0 -c 'TCTAGGTCCAAGTGGCT' *.fastq > count/B17027_Fm0.txt
agrep -0 -c 'GGCGAAAGTTTTTCCTG' *.fastq > count/B17028_Fm0.txt
agrep -0 -c 'TGGAGGAGTACCGTTTC' *.fastq > count/B17029_Fm0.txt
agrep -0 -c 'CTATACCAAGGTACCTA' *.fastq > count/B17030_Fm0.txt
agrep -0 -c 'GGTATGGACCTGATCAT' *.fastq > count/B17031_Fm0.txt
agrep -0 -c 'TGGAGCGCATCTGATCG' *.fastq > count/B17032_Fm0.txt
agrep -0 -c 'TTGTATGGTCTACTCGG' *.fastq > count/B17033_Fm0.txt
agrep -0 -c 'GCGGTCGTCACTCTAAG' *.fastq > count/B17034_Fm0.txt
agrep -0 -c 'GTTCGCTGCACATTAGA' *.fastq > count/B17035_Fm0.txt
agrep -0 -c 'CCTATGAAACCCGTCTC' *.fastq > count/B17036_Fm0.txt
agrep -0 -c 'CTCACGATGTTGAGTAG' *.fastq > count/B17037_Fm0.txt
agrep -0 -c 'GCACACTTAATCAGGAC' *.fastq > count/B17038_Fm0.txt
agrep -0 -c 'GTCGTTTCCGTGTGCTG' *.fastq > count/B17039_Fm0.txt
agrep -0 -c 'AAGTCGAGGTAATACGG' *.fastq > count/B17040_Fm0.txt
agrep -0 -c 'GTTGAGCCGCAAGACTG' *.fastq > count/B17041_Fm0.txt
agrep -0 -c 'AATTTGATCGCGGAGCA' *.fastq > count/B17042_Fm0.txt
agrep -0 -c 'TCAGCTGACTGCACTGT' *.fastq > count/B17044_Fm0.txt
agrep -0 -c 'GTAGGCCCTTTAATCCA' *.fastq > count/B17047_Fm0.txt
agrep -0 -c 'TGGCCGAGTCTATAGTC' *.fastq > count/B17048_Fm0.txt
agrep -0 -c 'GGACGTGTGATATCGAT' *.fastq > count/B17049_Fm0.txt
agrep -0 -c 'GGAGAGGAATGTTGTGC' *.fastq > count/B17050_Fm0.txt
agrep -0 -c 'CAGATTCGAGCCTTTAG' *.fastq > count/B17052_Fm0.txt
agrep -0 -c 'AGAAGTTAAGCGCGATA' *.fastq > count/B17053_Fm0.txt
agrep -0 -c 'TGCGTTGAACGCTCTCG' *.fastq > count/B17054_Fm0.txt
agrep -0 -c 'ATCACTAATTTACGGGG' *.fastq > count/B17055_Fm0.txt
agrep -0 -c 'ACCCTGAGCATCGGACA' *.fastq > count/B17056_Fm0.txt
agrep -0 -c 'TCATCGTGGGATACTGG' *.fastq > count/B17057_Fm0.txt
agrep -0 -c 'CTACCTGTGTACGCGAA' *.fastq > count/B17058_Fm0.txt
agrep -0 -c 'CTCGGAAGTCCTCTGGA' *.fastq > count/B17060_Fm0.txt
agrep -0 -c 'CTAGATTCTTCTTCGCT' *.fastq > count/B17061_Fm0.txt
agrep -0 -c 'TCGAGCAGGGGACACTT' *.fastq > count/B17063_Fm0.txt
agrep -0 -c 'TCTCATACGACGTTGCG' *.fastq > count/B17065_Fm0.txt
agrep -0 -c 'ATGTAGGCTACGAGGAA' *.fastq > count/B17067_Fm0.txt
agrep -0 -c 'ACTTACGATGCATGGGG' *.fastq > count/B17068_Fm0.txt
agrep -0 -c 'ATGAGAAACGAGAGGCC' *.fastq > count/B17069_Fm0.txt
agrep -0 -c 'GCGCGGATAAATGTATT' *.fastq > count/B17070_Fm0.txt
agrep -0 -c 'TTGGATAGATTAGGCCT' *.fastq > count/B17071_Fm0.txt
agrep -0 -c 'CTTAGGGTGGCTATTTC' *.fastq > count/B17073_Fm0.txt
agrep -0 -c 'ACACGCGCAGTTTAAGA' *.fastq > count/B17074_Fm0.txt
agrep -0 -c 'CAACAGATTCCTTTAGG' *.fastq > count/B17075_Fm0.txt
agrep -0 -c 'GGAGGGACATCGAAGTC' *.fastq > count/B17076_Fm0.txt
agrep -0 -c 'TCACAAGAGCCACTGGT' *.fastq > count/B17077_Fm0.txt
agrep -0 -c 'TCTGTGATCCCATCCGT' *.fastq > count/B17079_Fm0.txt
agrep -0 -c 'CATCTCCTACTTCGCAC' *.fastq > count/B17080_Fm0.txt
agrep -0 -c 'CGTTCAAATAGGTCTGT' *.fastq > count/B17081_Fm0.txt
agrep -0 -c 'TCAAACGAGAGGTCGTG' *.fastq > count/B17084_Fm0.txt
agrep -0 -c 'CGGAAACAAGGCAACGT' *.fastq > count/B17085_Fm0.txt
agrep -0 -c 'GCGTTTCAGTCTGAGAG' *.fastq > count/B17086_Fm0.txt
agrep -0 -c 'GTGGAAAAATCAGCTGG' *.fastq > count/B17087_Fm0.txt
agrep -0 -c 'TATGATCAAGTGGCGCG' *.fastq > count/B17088_Fm0.txt
agrep -0 -c 'TTCGTCGCTAACACGAC' *.fastq > count/B17089_Fm0.txt
agrep -0 -c 'CTCGCGCCCTGATTTGT' *.fastq > count/B17090_Fm0.txt
agrep -0 -c 'TCGGCGCAGATTACGAT' *.fastq > count/B17091_Fm0.txt
agrep -0 -c 'CCGTTTGTGCCAGATGT' *.fastq > count/B17092_Fm0.txt
agrep -0 -c 'ACTTAGGCCTTGGTAAA' *.fastq > count/B17093_Fm0.txt
agrep -0 -c 'CAGGATCTAACGTTCTG' *.fastq > count/B17094_Fm0.txt
agrep -0 -c 'ACCACAGACGGAATGCA' *.fastq > count/B17096_Fm0.txt
agrep -0 -c 'TAGATGGACTGTATCCG' *.fastq > count/B17097_Fm0.txt
agrep -0 -c 'GTTTCATCTCTGTACGT' *.fastq > count/B17098_Fm0.txt
agrep -0 -c 'TAACGTGCCCTTGGCAA' *.fastq > count/B17099_Fm0.txt
agrep -0 -c 'TGTAGCACCCAACGCTG' *.fastq > count/B17101_Fm0.txt
agrep -0 -c 'GCACGGCTTCCTATTCG' *.fastq > count/B17102_Fm0.txt
agrep -0 -c 'ACATGCTAACCCACGAA' *.fastq > count/B17103_Fm0.txt
agrep -0 -c 'GTCCGTAGAATGCTTAA' *.fastq > count/B17104_Fm0.txt
agrep -0 -c 'GCATACACCAAGTACCG' *.fastq > count/B17105_Fm0.txt
agrep -0 -c 'TGGACATCCTGCTATAA' *.fastq > count/B17106_Fm0.txt
agrep -0 -c 'GTTACTAACATGGTGCT' *.fastq > count/B17108_Fm0.txt
agrep -0 -c 'TACCTCGTTATGACCAC' *.fastq > count/B17109_Fm0.txt
agrep -0 -c 'TGAGATAATTCGGAGAC' *.fastq > count/B17110_Fm0.txt
agrep -0 -c 'CCAGTTAAGTTTCTCGT' *.fastq > count/B17111_Fm0.txt
agrep -0 -c 'GTGCCAATACGGGACCA' *.fastq > count/B17112_Fm0.txt
agrep -0 -c 'TGAGAGTTTCCGCGACG' *.fastq > count/B17113_Fm0.txt
agrep -0 -c 'TACTGGACTCACACCCG' *.fastq > count/B17114_Fm0.txt
agrep -0 -c 'ACACCGGCTTACGACAG' *.fastq > count/B17115_Fm0.txt
agrep -0 -c 'AGGATGGTACGCAGTGT' *.fastq > count/B17116_Fm0.txt
agrep -0 -c 'AGAGTAAAGACCCGAGA' *.fastq > count/B17117_Fm0.txt
agrep -0 -c 'AAGACCTCGAAGTTGCG' *.fastq > count/B17121_Fm0.txt
agrep -0 -c 'CTTGATTTCTCCCCGCC' *.fastq > count/B17122_Fm0.txt
agrep -0 -c 'TCGCTGCTAGCTGGTAT' *.fastq > count/B17123_Fm0.txt
agrep -0 -c 'TTGCGTAGTTGCTTTTC' *.fastq > count/B17125_Fm0.txt
agrep -0 -c 'CGGACATGTTTACGGGT' *.fastq > count/B17127_Fm0.txt
agrep -0 -c 'GACGACGCGAAGAAACA' *.fastq > count/B17129_Fm0.txt
agrep -0 -c 'TGATACTGTCCGCTGGG' *.fastq > count/B17130_Fm0.txt
agrep -0 -c 'AAGCTGTCCGGCGCTTA' *.fastq > count/B17131_Fm0.txt
agrep -0 -c 'ATAACCTTCATGTCGGA' *.fastq > count/B17132_Fm0.txt
agrep -0 -c 'ACCTAATCTCACGCGTG' *.fastq > count/B17133_Fm0.txt
agrep -0 -c 'ATCGATCGCGGGGGAAT' *.fastq > count/B17134_Fm0.txt
agrep -0 -c 'GGCAATATACGTGCAAG' *.fastq > count/B17135_Fm0.txt
agrep -0 -c 'CCGGAAGTACGGGTGTA' *.fastq > count/B17136_Fm0.txt
agrep -0 -c 'GGAGCTCGTCGAGTTTA' *.fastq > count/B17137_Fm0.txt
agrep -0 -c 'CCAATTCCTATTGCTGG' *.fastq > count/B17139_Fm0.txt
agrep -0 -c 'CGTATGTCACGAGCTAC' *.fastq > count/B17140_Fm0.txt
agrep -0 -c 'GTTTAACTGGAAGGTCT' *.fastq > count/B17141_Fm0.txt
agrep -0 -c 'GCTGGATGGTACTTCCT' *.fastq > count/B17142_Fm0.txt
agrep -0 -c 'GCAACCCCCCATACTTA' *.fastq > count/B17143_Fm0.txt
agrep -0 -c 'GAGGGGAGGTCAAACGT' *.fastq > count/B17146_Fm0.txt
agrep -0 -c 'TTATAAGGGATCGACTC' *.fastq > count/B17147_Fm0.txt
agrep -0 -c 'TCGGTCGAGATATTGCC' *.fastq > count/B17148_Fm0.txt
agrep -0 -c 'TACACTACGCTACTGAT' *.fastq > count/B17150_Fm0.txt
agrep -0 -c 'CAGGCAATTGCCATTAC' *.fastq > count/B17151_Fm0.txt
agrep -0 -c 'AGTGGAGGCTTAATGGA' *.fastq > count/B17152_Fm0.txt
agrep -0 -c 'AGTTCGTGGGCAGCGAT' *.fastq > count/B17153_Fm0.txt
agrep -0 -c 'ACAGATAACATTGTGCC' *.fastq > count/B17156_Fm0.txt
agrep -0 -c 'TGCATCCCCCAGGTAAG' *.fastq > count/B17157_Fm0.txt
agrep -0 -c 'GCTTAATGCCGGAATTG' *.fastq > count/B17158_Fm0.txt
agrep -0 -c 'GCTTGTTGGTGCAGACT' *.fastq > count/B17159_Fm0.txt
agrep -0 -c 'AATGGGAAGCCGTTAAC' *.fastq > count/B17160_Fm0.txt
agrep -0 -c 'CGAGAGACATACATGTA' *.fastq > count/B17161_Fm0.txt
agrep -0 -c 'ACTCGGGATCGCTTAGG' *.fastq > count/B17162_Fm0.txt
agrep -0 -c 'AATCGATCACCCCCGTG' *.fastq > count/B17163_Fm0.txt
agrep -0 -c 'AGACCACATACACTCGC' *.fastq > count/B17164_Fm0.txt
agrep -0 -c 'CTAAACACTGACTGAAC' *.fastq > count/B17166_Fm0.txt
agrep -0 -c 'GGCCTTACCATTCTGAG' *.fastq > count/B17168_Fm0.txt
agrep -0 -c 'CCAAAGGATAAGACGCA' *.fastq > count/B17170_Fm0.txt
agrep -0 -c 'GAGTGTCGCTCCTTGTA' *.fastq > count/B17171_Fm0.txt
agrep -0 -c 'TATAGGCTGAAGCGAGT' *.fastq > count/B17172_Fm0.txt
agrep -0 -c 'TAGAACGACCTTGACGT' *.fastq > count/B17173_Fm0.txt
agrep -0 -c 'AGGAAAACTCGCTAACG' *.fastq > count/B17174_Fm0.txt
agrep -0 -c 'AGTTAATCGATACCCCG' *.fastq > count/B17175_Fm0.txt
agrep -0 -c 'AGCGGAGCTGTAACAAT' *.fastq > count/B17177_Fm0.txt
agrep -0 -c 'TGTCAAGCGGCTAACCG' *.fastq > count/B17178_Fm0.txt
agrep -0 -c 'AAGCGGATTCGAGACCG' *.fastq > count/B17179_Fm0.txt
agrep -0 -c 'GGTTAACACGCCCTAAC' *.fastq > count/B17180_Fm0.txt
agrep -0 -c 'CATAGTGTAGAACCGCT' *.fastq > count/B17181_Fm0.txt
agrep -0 -c 'GTCTACTCAAAGTTTCG' *.fastq > count/B17182_Fm0.txt
agrep -0 -c 'GATTTCGACGTATCCGT' *.fastq > count/B17183_Fm0.txt
agrep -0 -c 'GGCAATGGTAAATGGGC' *.fastq > count/B17184_Fm0.txt
agrep -0 -c 'CGGTCATCCTGAGGCTA' *.fastq > count/B17185_Fm0.txt
agrep -0 -c 'CCTATCCGCAATGCCCT' *.fastq > count/B17186_Fm0.txt
agrep -0 -c 'CCTACCCTACCTACGTC' *.fastq > count/B17187_Fm0.txt
agrep -0 -c 'TAGCTGGACCGTCCCAT' *.fastq > count/B17188_Fm0.txt
agrep -0 -c 'GGAAGCAGAACAGGTTA' *.fastq > count/B17189_Fm0.txt
agrep -0 -c 'AGGCCAGTTCGACAAAT' *.fastq > count/B17192_Fm0.txt
agrep -0 -c 'CGTTATATCCCTTCGAC' *.fastq > count/B17193_Fm0.txt
agrep -0 -c 'AGCTTAGTTCGGGAGGG' *.fastq > count/B17194_Fm0.txt
agrep -0 -c 'GCGAGCTAGGCCTATTA' *.fastq > count/B17195_Fm0.txt
agrep -0 -c 'ACCAGTGGAAGTTCTCC' *.fastq > count/B17196_Fm0.txt
agrep -0 -c 'AACAGCAACCCCTATAT' *.fastq > count/B17197_Fm0.txt
agrep -0 -c 'CTCGCTTTCCGCCTTAC' *.fastq > count/B17199_Fm0.txt
agrep -0 -c 'ACGGGGAAATGTTCCGT' *.fastq > count/B17200_Fm0.txt
agrep -0 -c 'CTAGGAACAGTACATGA' *.fastq > count/B17201_Fm0.txt
agrep -0 -c 'GGGTGTCACATAGTCCC' *.fastq > count/B17202_Fm0.txt
agrep -0 -c 'TTACAGATGGGGCCAAT' *.fastq > count/B17203_Fm0.txt
agrep -0 -c 'ACCCAAACTGGCCGAAT' *.fastq > count/B17205_Fm0.txt
agrep -0 -c 'AATGCTGTAGGGGAGCA' *.fastq > count/B17206_Fm0.txt
agrep -0 -c 'GCCCAGCGATGGAAATA' *.fastq > count/B17207_Fm0.txt
agrep -0 -c 'TAGATACATTGGCCCTC' *.fastq > count/B17208_Fm0.txt
agrep -0 -c 'GTATAGGATATAACGGC' *.fastq > count/B17209_Fm0.txt
agrep -0 -c 'GCCTCGTACGATCTTCA' *.fastq > count/B17211_Fm0.txt
agrep -0 -c 'TGACGTTCACAGGCTTG' *.fastq > count/B17212_Fm0.txt
agrep -0 -c 'TTATGTCGTGACAGCGA' *.fastq > count/B17213_Fm0.txt
agrep -0 -c 'GAGAAACATAGCGTCTG' *.fastq > count/B17214_Fm0.txt
agrep -0 -c 'GGTCTTCATCACTACTC' *.fastq > count/B17215_Fm0.txt
agrep -0 -c 'CCAAGGCTGCGAGTTCT' *.fastq > count/B17216_Fm0.txt
agrep -0 -c 'CGAACTTAGCCATGTGT' *.fastq > count/B17217_Fm0.txt
agrep -0 -c 'GCGCAATAGCTCTACAA' *.fastq > count/B17218_Fm0.txt
agrep -0 -c 'CGGAATTGGTTCTTCCA' *.fastq > count/B17220_Fm0.txt
agrep -0 -c 'GAGCGGGTCGAAAAAGC' *.fastq > count/B17221_Fm0.txt
agrep -0 -c 'GTGCATCAGCTTCGTAT' *.fastq > count/B17222_Fm0.txt
agrep -0 -c 'TCTCGGTGAAGAAGCTA' *.fastq > count/B17223_Fm0.txt
agrep -0 -c 'CTCAATTGGTTCGGGCG' *.fastq > count/B17224_Fm0.txt
agrep -0 -c 'TTCTGAGCCATAAGATC' *.fastq > count/B17226_Fm0.txt
agrep -0 -c 'CACTCGTAAGTCAGTCT' *.fastq > count/B17227_Fm0.txt
agrep -0 -c 'GATACTCGGTTAATGGC' *.fastq > count/B17228_Fm0.txt
agrep -0 -c 'TGAAGTAGAGGCCTTCT' *.fastq > count/B17229_Fm0.txt
agrep -0 -c 'TTCTGAACAATACCGGT' *.fastq > count/B17230_Fm0.txt
agrep -0 -c 'TCAGGCAAGGTCCTGAA' *.fastq > count/B17231_Fm0.txt
agrep -0 -c 'ACGACGTGAGACACCCT' *.fastq > count/B17232_Fm0.txt
agrep -0 -c 'CGTACGATCACAGTACC' *.fastq > count/B17235_Fm0.txt
agrep -0 -c 'TCGGCACACCTCTAGGA' *.fastq > count/B17236_Fm0.txt
agrep -0 -c 'CTCTCCACTAAAGGCTA' *.fastq > count/B17237_Fm0.txt
agrep -0 -c 'CGTCTATTAGTATGGAG' *.fastq > count/B17238_Fm0.txt
agrep -0 -c 'GGATTCACGTTTTCAGC' *.fastq > count/B17239_Fm0.txt
agrep -0 -c 'CTGTCGTATTCCTAGCT' *.fastq > count/B17240_Fm0.txt
agrep -0 -c 'ATTGCCGTTTCACCTTG' *.fastq > count/B17241_Fm0.txt
agrep -0 -c 'GTCCCCATAAACAGAGC' *.fastq > count/B17242_Fm0.txt
agrep -0 -c 'AGTCGATATAGCATCTG' *.fastq > count/B17245_Fm0.txt
agrep -0 -c 'AGATGATTGACGGGCTA' *.fastq > count/B17246_Fm0.txt
agrep -0 -c 'TCGCTACAGCCTTGCTT' *.fastq > count/B17247_Fm0.txt
agrep -0 -c 'CGATGGATAGTCAACCA' *.fastq > count/B17248_Fm0.txt
agrep -0 -c 'GTGGTACGGTTGTTCTG' *.fastq > count/B17250_Fm0.txt
agrep -0 -c 'GACTTGACGTTTCTGCT' *.fastq > count/B17251_Fm0.txt
agrep -0 -c 'AGTCTAAGTCCGAGCGG' *.fastq > count/B17252_Fm0.txt
agrep -0 -c 'CCTCCCTTATAACGGTG' *.fastq > count/B17253_Fm0.txt
agrep -0 -c 'ATTCGAACCTGTCAAAC' *.fastq > count/B17254_Fm0.txt
agrep -0 -c 'TATTGTGATGGCAACGT' *.fastq > count/B17255_Fm0.txt
agrep -0 -c 'ACGCTCATAGATCAGTC' *.fastq > count/B17256_Fm0.txt
agrep -0 -c 'GGGCTTCAACTCTTTTG' *.fastq > count/B17257_Fm0.txt
agrep -0 -c 'GCTAGGCCTAGAAAGGC' *.fastq > count/B17258_Fm0.txt
agrep -0 -c 'TTCGGAGCGTGACCACA' *.fastq > count/B17259_Fm0.txt
agrep -0 -c 'TATGTCCCCCTATAGCG' *.fastq > count/B17260_Fm0.txt
agrep -0 -c 'AGCTTGAGGAATACTCC' *.fastq > count/B17261_Fm0.txt
agrep -0 -c 'TGACACTCAGCCGTAGA' *.fastq > count/B17262_Fm0.txt
agrep -0 -c 'TAGAGTCCACGAAGCTC' *.fastq > count/B17263_Fm0.txt
agrep -0 -c 'CTTAACGGGGCCGAGAT' *.fastq > count/B17264_Fm0.txt
agrep -0 -c 'AGCGATGATGCGGTAGG' *.fastq > count/B17265_Fm0.txt
agrep -0 -c 'GGCGCCCATCCTTTATT' *.fastq > count/B17266_Fm0.txt
agrep -0 -c 'GTGGACAGTACTCGCCA' *.fastq > count/B17267_Fm0.txt
agrep -0 -c 'ATGACCGGTCTCCAAGT' *.fastq > count/B17268_Fm0.txt
agrep -0 -c 'GCTGGGCCAACTAATTC' *.fastq > count/B17270_Fm0.txt
agrep -0 -c 'CACAGACCGAACTGCTT' *.fastq > count/B17274_Fm0.txt
agrep -0 -c 'ACTTCAAGAGGTCGAAC' *.fastq > count/B17275_Fm0.txt
agrep -0 -c 'ACGTGTCATAGCCTTTG' *.fastq > count/B17276_Fm0.txt
agrep -0 -c 'TACTACGGACTGTGATG' *.fastq > count/B17277_Fm0.txt
agrep -0 -c 'CGGATGCTAACCATGGG' *.fastq > count/B17278_Fm0.txt
agrep -0 -c 'CTAAGCTCTCGGTAAAG' *.fastq > count/B17279_Fm0.txt
agrep -0 -c 'ACGCTAATCCGTTCCAG' *.fastq > count/B17280_Fm0.txt
agrep -0 -c 'CCTGACTCGTGATTGCC' *.fastq > count/B17281_Fm0.txt
agrep -0 -c 'CCTGACAATGCGTGGTC' *.fastq > count/B17282_Fm0.txt
agrep -0 -c 'GCCTCAACTTCAAAATG' *.fastq > count/B17283_Fm0.txt
agrep -0 -c 'GATCATCCGGGCACACA' *.fastq > count/B17284_Fm0.txt
agrep -0 -c 'ATCTTCCATGTCATCCC' *.fastq > count/B17285_Fm0.txt
agrep -0 -c 'CTAATATGTTGCACCCC' *.fastq > count/B17286_Fm0.txt
agrep -0 -c 'CTCGTTGATTACTAGCC' *.fastq > count/B17287_Fm0.txt
agrep -0 -c 'TGTGCACTACCGTATTA' *.fastq > count/B17288_Fm0.txt
agrep -0 -c 'CGAGTTGCGAGAACTTG' *.fastq > count/B17289_Fm0.txt
agrep -0 -c 'GTGCGGGTGCTATTCCT' *.fastq > count/B17290_Fm0.txt
agrep -0 -c 'TAAACCAGTGATCGGAA' *.fastq > count/B17291_Fm0.txt
agrep -0 -c 'ACAACACATCCACTCTA' *.fastq > count/B17293_Fm0.txt
agrep -0 -c 'GCTTCAACGTCTGGTGT' *.fastq > count/B17294_Fm0.txt
agrep -0 -c 'GAGACTGAATTCGCTGT' *.fastq > count/B17295_Fm0.txt
agrep -0 -c 'GATGTCAGATTTTCCAG' *.fastq > count/B17296_Fm0.txt
agrep -0 -c 'CGGTGGATTGCGCGTAT' *.fastq > count/B17298_Fm0.txt
agrep -0 -c 'GGCCATCTGATCTGACA' *.fastq > count/B17299_Fm0.txt
agrep -0 -c 'ATCGACCAATACCCCAA' *.fastq > count/B17300_Fm0.txt
agrep -0 -c 'CGTTAATGCGGCATCTC' *.fastq > count/B17301_Fm0.txt
agrep -0 -c 'TGAATCCGAGGTTTGCC' *.fastq > count/B17302_Fm0.txt
agrep -0 -c 'CCTGACTAGTCCTTTTA' *.fastq > count/B17303_Fm0.txt
agrep -0 -c 'GGCCACATACACCGCTT' *.fastq > count/B17304_Fm0.txt
agrep -0 -c 'GTAAGAGCTGATCATTC' *.fastq > count/B17305_Fm0.txt
agrep -0 -c 'GGAGAAACAACGCAGCC' *.fastq > count/B17306_Fm0.txt
agrep -0 -c 'AGTACCTATAATCACGG' *.fastq > count/B17307_Fm0.txt
agrep -0 -c 'TCATATTCGGACGCTCA' *.fastq > count/B17308_Fm0.txt
agrep -0 -c 'TACTGGTGTCCCATGAC' *.fastq > count/B17309_Fm0.txt
agrep -0 -c 'AGGGCTATTGGTGAAGG' *.fastq > count/B17310_Fm0.txt
agrep -0 -c 'CCATCCACTGTCCTTTG' *.fastq > count/B17311_Fm0.txt
agrep -0 -c 'CGCATTACCAATGCCGG' *.fastq > count/B17312_Fm0.txt
agrep -0 -c 'TGTGTGACGGCTGTTTA' *.fastq > count/B17313_Fm0.txt
agrep -0 -c 'TAGGTGTCCTTAAGGAC' *.fastq > count/B17315_Fm0.txt
agrep -0 -c 'CAAGCTGAAGCGGGATT' *.fastq > count/B17318_Fm0.txt
agrep -0 -c 'ATCTACATCCGCAAACC' *.fastq > count/B17320_Fm0.txt
agrep -0 -c 'GTGAACCAGGTTCAGAT' *.fastq > count/B17321_Fm0.txt
agrep -0 -c 'AATGTACACGTGCGTTA' *.fastq > count/B17322_Fm0.txt
agrep -0 -c 'ACGAGCGTGAGTACTGC' *.fastq > count/B17323_Fm0.txt
agrep -0 -c 'TAGCGGGTGGTTGCCAT' *.fastq > count/B17324_Fm0.txt
agrep -0 -c 'AGCGAGAGGACTAGAAG' *.fastq > count/B17326_Fm0.txt
agrep -0 -c 'ATGAAAGGTTTCTCGCA' *.fastq > count/B17327_Fm0.txt
agrep -0 -c 'TTCCAACGCACTGTGGC' *.fastq > count/B17328_Fm0.txt
agrep -0 -c 'CGATTACGGGTGACGTG' *.fastq > count/B17331_Fm0.txt
agrep -0 -c 'GAGGTGTGCGTTGTGAT' *.fastq > count/B17332_Fm0.txt
agrep -0 -c 'TCGAGTTCACGTCGCTT' *.fastq > count/B17333_Fm0.txt
agrep -0 -c 'GCCTACCATCATTCTAG' *.fastq > count/B17335_Fm0.txt
agrep -0 -c 'GCCGAGCTGATCATACC' *.fastq > count/B17338_Fm0.txt
agrep -0 -c 'AGATGGCACCATTTGAT' *.fastq > count/B17339_Fm0.txt
agrep -0 -c 'TAATAAGCTCAGGGATG' *.fastq > count/B17340_Fm0.txt
agrep -0 -c 'TCGGCACGTAATAAGCC' *.fastq > count/B17341_Fm0.txt
agrep -0 -c 'CAGCTAAGTACGGGCAA' *.fastq > count/B17343_Fm0.txt
agrep -0 -c 'CGCTGTGTGATCGCTAA' *.fastq > count/B17344_Fm0.txt
agrep -0 -c 'GGTGGAATCGGCAGTAA' *.fastq > count/B17345_Fm0.txt
agrep -0 -c 'GTGAGACCTTCGGTGTC' *.fastq > count/B17348_Fm0.txt
agrep -0 -c 'GGAGCTTGTACCACTGC' *.fastq > count/B17349_Fm0.txt
agrep -0 -c 'CGCTTATGTTAGACGCG' *.fastq > count/B17350_Fm0.txt
agrep -0 -c 'GGGACCTCGAGTTACGT' *.fastq > count/B17351_Fm0.txt
agrep -0 -c 'GTCGTAAATAGGAGTCG' *.fastq > count/B17353_Fm0.txt
agrep -0 -c 'GTGCGTGAACATCACGT' *.fastq > count/B17354_Fm0.txt
agrep -0 -c 'AGGCAGGACCATGGCTT' *.fastq > count/B17355_Fm0.txt
agrep -0 -c 'ACATTTGAGACGGAAAC' *.fastq > count/B17356_Fm0.txt
agrep -0 -c 'AAGGGCTTTCATTAGCG' *.fastq > count/B17357_Fm0.txt
agrep -0 -c 'CGTCCCTCTATGATTCG' *.fastq > count/B17358_Fm0.txt
agrep -0 -c 'CATCGGAATGCTGAAAT' *.fastq > count/B17359_Fm0.txt
agrep -0 -c 'CGTATATCTCGCAACAC' *.fastq > count/B17361_Fm0.txt
agrep -0 -c 'ATGGAGCTACCTTGTGT' *.fastq > count/B17362_Fm0.txt
agrep -0 -c 'GGCAAGGGAATCCCTTC' *.fastq > count/B17363_Fm0.txt
agrep -0 -c 'AATCAGATCGCAGCGAG' *.fastq > count/B17364_Fm0.txt
agrep -0 -c 'GGGTGATCTGTCCAGCT' *.fastq > count/B17365_Fm0.txt
agrep -0 -c 'TGTTCGCCCGAGTTGAT' *.fastq > count/B17366_Fm0.txt
agrep -0 -c 'CGATCGGGCTGATTCGA' *.fastq > count/B17367_Fm0.txt
agrep -0 -c 'AGGGCTAGTCTGCAAAC' *.fastq > count/B17368_Fm0.txt
agrep -0 -c 'GGGAAGTCGGGACTTAA' *.fastq > count/B17370_Fm0.txt
agrep -0 -c 'ATTAGCGTGATCGTCCC' *.fastq > count/B17371_Fm0.txt
agrep -0 -c 'TCGGCATCAATGAATGG' *.fastq > count/B17372_Fm0.txt
agrep -0 -c 'CCTCTTTGGTGGAGCTG' *.fastq > count/B17373_Fm0.txt
agrep -0 -c 'ACAACGCGACATCTTGT' *.fastq > count/B17374_Fm0.txt
agrep -0 -c 'CGTGTGCATCGGAAACA' *.fastq > count/B17375_Fm0.txt
agrep -0 -c 'TTAGATGTTCTATGCGC' *.fastq > count/B17376_Fm0.txt
agrep -0 -c 'ACCTGTGTGCGTTATAA' *.fastq > count/B17377_Fm0.txt
agrep -0 -c 'CAGCAGGGGGATAGTTC' *.fastq > count/B17379_Fm0.txt
agrep -0 -c 'GTCTATCTCTTCCGCCA' *.fastq > count/B17380_Fm0.txt
agrep -0 -c 'TGTACAGCATGGTCGCT' *.fastq > count/B17381_Fm0.txt
agrep -0 -c 'ATGTTTGACCAGGCATG' *.fastq > count/B17382_Fm0.txt
agrep -0 -c 'CAAGGGTAAGCGGATAA' *.fastq > count/B17383_Fm0.txt
agrep -0 -c 'GCGTAGAACAACTTCAC' *.fastq > count/B17384_Fm0.txt
agrep -0 -c 'AACTCTCAAGGCGTCTC' *.fastq > count/B17386_Fm0.txt
agrep -0 -c 'GACGCTGTAGAGTGGAG' *.fastq > count/B17387_Fm0.txt
agrep -0 -c 'GAGTCGACACACGGTTC' *.fastq > count/B17388_Fm0.txt
agrep -0 -c 'GCACAGGTTCATCCCGT' *.fastq > count/B17389_Fm0.txt
agrep -0 -c 'GGCTGACTCTCGTATTA' *.fastq > count/B17390_Fm0.txt
agrep -0 -c 'ACTCCTTGACGTGGCCA' *.fastq > count/B17392_Fm0.txt
agrep -0 -c 'GTTAAAGTGTCCGTGCC' *.fastq > count/B17393_Fm0.txt
agrep -0 -c 'TTGGACAGACAGGGTAG' *.fastq > count/B17394_Fm0.txt
agrep -0 -c 'CACCCACGTCTACGTAC' *.fastq > count/B17395_Fm0.txt
agrep -0 -c 'AGCTTATGCCGAAAATG' *.fastq > count/B17396_Fm0.txt
agrep -0 -c 'GGTGAACTGTACAGTAT' *.fastq > count/B17398_Fm0.txt
agrep -0 -c 'GTGGTATCGGTAAGCGA' *.fastq > count/B17399_Fm0.txt
agrep -0 -c 'ACTAATCTAACGGCGAG' *.fastq > count/B17400_Fm0.txt
agrep -0 -c 'CGTTGCCTCTACAGCCA' *.fastq > count/B17401_Fm0.txt
agrep -0 -c 'TGCCTCACATACATCGG' *.fastq > count/B17402_Fm0.txt
agrep -0 -c 'ACGGCATACTACTACCC' *.fastq > count/B17404_Fm0.txt
agrep -0 -c 'AAGTTGTTGGACACCCG' *.fastq > count/B17405_Fm0.txt
agrep -0 -c 'GGTCACACGTGTCGTAT' *.fastq > count/B17406_Fm0.txt
agrep -0 -c 'TGTTTCCTGAGTTGCGA' *.fastq > count/B17407_Fm0.txt
agrep -0 -c 'GCCCTTTGTAGAATCGC' *.fastq > count/B17408_Fm0.txt
agrep -0 -c 'TCTCATAGTAAGCCGGA' *.fastq > count/B17409_Fm0.txt
agrep -0 -c 'TATTCCGCTACTGGAAT' *.fastq > count/B17410_Fm0.txt
agrep -0 -c 'ACCCTAGGACTTTACTC' *.fastq > count/B17411_Fm0.txt
agrep -0 -c 'ATGGTTCGCTCAAGAGC' *.fastq > count/B17412_Fm0.txt
agrep -0 -c 'GGGTAAATAGCCGAGCT' *.fastq > count/B17413_Fm0.txt
agrep -0 -c 'CCTAGCTGAACGCCACA' *.fastq > count/B17414_Fm0.txt
agrep -0 -c 'ATATTGACAGTGTGCCC' *.fastq > count/B17415_Fm0.txt
agrep -0 -c 'CGAGTCAATACCTGGTC' *.fastq > count/B17416_Fm0.txt
agrep -0 -c 'CTGGAGCTACTCACTAC' *.fastq > count/B17417_Fm0.txt
agrep -0 -c 'AGGGGCTTATGATAGTT' *.fastq > count/B17418_Fm0.txt
agrep -0 -c 'CTGTGCAGCCTAGTAGA' *.fastq > count/B17419_Fm0.txt
agrep -0 -c 'ACTCGACTACAGCCCAT' *.fastq > count/B17421_Fm0.txt
agrep -0 -c 'GACATACTTCACATGAG' *.fastq > count/B17423_Fm0.txt
agrep -0 -c 'TCTCATGACGCCTGACA' *.fastq > count/B17424_Fm0.txt
agrep -0 -c 'AGTAGTAACAGAACCCG' *.fastq > count/B17425_Fm0.txt
agrep -0 -c 'GGACCGTATTAAACAGG' *.fastq > count/B17426_Fm0.txt
agrep -0 -c 'GTACTGGACTACTAGTT' *.fastq > count/B17427_Fm0.txt
agrep -0 -c 'CACGTCCTACCATTAGG' *.fastq > count/B17428_Fm0.txt
agrep -0 -c 'CGACCCACCAATTTTAT' *.fastq > count/B17430_Fm0.txt
agrep -0 -c 'TAGCTCTCGGATTCGGC' *.fastq > count/B17431_Fm0.txt
agrep -0 -c 'TAATACCCTAGGCCCCG' *.fastq > count/B17433_Fm0.txt
agrep -0 -c 'TTATATTGTACTCCCGG' *.fastq > count/B17434_Fm0.txt
agrep -0 -c 'TAGTGGACTAGGGTTTG' *.fastq > count/B17437_Fm0.txt
agrep -0 -c 'GTCATGCTTAGTTTCTC' *.fastq > count/B17438_Fm0.txt
agrep -0 -c 'CGAACTGGGCGTCTACA' *.fastq > count/B17439_Fm0.txt
agrep -0 -c 'ATCGAACATAGCGGGCC' *.fastq > count/B17441_Fm0.txt
agrep -0 -c 'GCTTACGGTTTAGCTTA' *.fastq > count/B17442_Fm0.txt
agrep -0 -c 'CGATCGATACGGATAAA' *.fastq > count/B17443_Fm0.txt
agrep -0 -c 'TTGTACCGGTCCTGTTG' *.fastq > count/B17444_Fm0.txt
agrep -0 -c 'TACACTCGCATCTCTAT' *.fastq > count/B17445_Fm0.txt
agrep -0 -c 'AGGGCGAGATACCACAA' *.fastq > count/B17446_Fm0.txt
agrep -0 -c 'CTCCGATAGTTGATGCA' *.fastq > count/B17447_Fm0.txt
agrep -0 -c 'ATTCTGCTAGTGCCATT' *.fastq > count/B17448_Fm0.txt
agrep -0 -c 'CTACCACGTGATTGGGC' *.fastq > count/B17450_Fm0.txt
agrep -0 -c 'CCTGTATAAGCTACGAT' *.fastq > count/B17451_Fm0.txt
agrep -0 -c 'TCGGGAGTTTTATAGAC' *.fastq > count/B17452_Fm0.txt
agrep -0 -c 'GTCTGTTGCCCAGCAGT' *.fastq > count/B17453_Fm0.txt
agrep -0 -c 'ACGAGACTAGATCAGAG' *.fastq > count/B17454_Fm0.txt
agrep -0 -c 'TCAAACTGATAACCCTC' *.fastq > count/B17455_Fm0.txt
agrep -0 -c 'TACAGAACGCGCATGTC' *.fastq > count/B17456_Fm0.txt
agrep -0 -c 'ACCTAACCCCTATAAAC' *.fastq > count/B17458_Fm0.txt
agrep -0 -c 'TGAGCATATAGGGTTGG' *.fastq > count/B17459_Fm0.txt
agrep -0 -c 'GGCAATAGAAACTTCAC' *.fastq > count/B17460_Fm0.txt
agrep -0 -c 'ACATCGCACATGTATCT' *.fastq > count/B17462_Fm0.txt
agrep -0 -c 'AACAGGGTAACCAACTT' *.fastq > count/B17465_Fm0.txt
agrep -0 -c 'TCGTAACACCCTCGCTT' *.fastq > count/B17466_Fm0.txt
agrep -0 -c 'TGCATATAGTCGGATGT' *.fastq > count/B17467_Fm0.txt
agrep -0 -c 'TAATAATCAACGCAGCC' *.fastq > count/B17469_Fm0.txt
agrep -0 -c 'CAGGATCTATCACATCG' *.fastq > count/B17470_Fm0.txt
agrep -0 -c 'CATTGACTAATGCTTCC' *.fastq > count/B17473_Fm0.txt
agrep -0 -c 'GTCGGCAGAGTTTTGGG' *.fastq > count/B17474_Fm0.txt
agrep -0 -c 'GATAACAGGCCGAGTTG' *.fastq > count/B17475_Fm0.txt
agrep -0 -c 'TGATACGCGTATGATTC' *.fastq > count/B17476_Fm0.txt
agrep -0 -c 'GTTTGCCAATTGCGACG' *.fastq > count/B17477_Fm0.txt
agrep -0 -c 'ACGCTTCGTATGGATTC' *.fastq > count/B17478_Fm0.txt
agrep -0 -c 'CTAATGGTCATGGCTAA' *.fastq > count/B17479_Fm0.txt
agrep -0 -c 'ATTCGGTCCCATCGGTA' *.fastq > count/B17480_Fm0.txt
agrep -0 -c 'TGCTCTCAAAACTCTTC' *.fastq > count/B17481_Fm0.txt
agrep -0 -c 'CTGGGTCCACTATACGG' *.fastq > count/B17482_Fm0.txt
agrep -0 -c 'GCCATACCGACGGTAAG' *.fastq > count/B17483_Fm0.txt
agrep -0 -c 'TGTAGGTATCGGTTTGG' *.fastq > count/B17486_Fm0.txt
agrep -0 -c 'CAGCCGTCCGTAGACAT' *.fastq > count/B17487_Fm0.txt
agrep -0 -c 'TGCGACAAGCAAGCGCA' *.fastq > count/B17488_Fm0.txt
agrep -0 -c 'TGACACGATTGTGCGGG' *.fastq > count/B17489_Fm0.txt
agrep -0 -c 'GTCACGCAACCGTCTAC' *.fastq > count/B17490_Fm0.txt
agrep -0 -c 'GATACGCGTTTTGTGAC' *.fastq > count/B17491_Fm0.txt
agrep -0 -c 'TATCTAGGCCGTTGGAC' *.fastq > count/B17492_Fm0.txt
agrep -0 -c 'TAGCCTGGAGACGAATG' *.fastq > count/B17494_Fm0.txt
agrep -0 -c 'AGACGTATCCTGACTAC' *.fastq > count/B17495_Fm0.txt
agrep -0 -c 'TGTAGGCAGATCGTAGT' *.fastq > count/B17496_Fm0.txt
agrep -0 -c 'GCCAAGATTCGCATCCC' *.fastq > count/B17497_Fm0.txt
agrep -0 -c 'TTGCACCAGCATAAGAG' *.fastq > count/B17498_Fm0.txt
agrep -0 -c 'TATGGCTACGGAGAGCA' *.fastq > count/B17499_Fm0.txt
agrep -0 -c 'GCCGAAGTGATCTTATT' *.fastq > count/B17500_Fm0.txt
agrep -0 -c 'CGCTATTCGTCTGTGTA' *.fastq > count/B17501_Fm0.txt
agrep -0 -c 'CCGATGGGTCGGTACAA' *.fastq > count/B17502_Fm0.txt
agrep -0 -c 'ATCGTTCACGCACGGGA' *.fastq > count/B17503_Fm0.txt
agrep -0 -c 'CCTTGTCTCTTGTCGCA' *.fastq > count/B17505_Fm0.txt
agrep -0 -c 'GAGTGGGTTACTACACG' *.fastq > count/B17506_Fm0.txt
agrep -0 -c 'TAGAGGCGAGCTAGTCC' *.fastq > count/B17507_Fm0.txt
agrep -0 -c 'TGTTCAACAGAATCGCT' *.fastq > count/B17508_Fm0.txt
agrep -0 -c 'GTATGGAATTGATCTGG' *.fastq > count/B17510_Fm0.txt
agrep -0 -c 'CGCGGCGTTTAAAGAGG' *.fastq > count/B17512_Fm0.txt
agrep -0 -c 'GGTCTAGTGTTGGCAGA' *.fastq > count/B17513_Fm0.txt
agrep -0 -c 'GGATTAATCGATTGGGG' *.fastq > count/B17514_Fm0.txt
agrep -0 -c 'CGCAGCTCCTAATCCGA' *.fastq > count/B17515_Fm0.txt
agrep -0 -c 'GTTGCAACGCATGTTGC' *.fastq > count/B17516_Fm0.txt
agrep -0 -c 'GATTAGTCCTGAACACG' *.fastq > count/B17517_Fm0.txt
agrep -0 -c 'ATCTGCGTCTAAGACAA' *.fastq > count/B17519_Fm0.txt
agrep -0 -c 'ATGTCTTCGGGAACCGG' *.fastq > count/B17520_Fm0.txt
agrep -0 -c 'AGATTCTTCAAACGCGC' *.fastq > count/B17523_Fm0.txt
agrep -0 -c 'TCTAAACCAATACTGGG' *.fastq > count/B17524_Fm0.txt
agrep -0 -c 'AACCGATAACACAGTAC' *.fastq > count/B17525_Fm0.txt
agrep -0 -c 'CTCCTTTGTGCCACCGT' *.fastq > count/B17526_Fm0.txt
agrep -0 -c 'CGCATGTGATCTGGAAG' *.fastq > count/B17527_Fm0.txt
agrep -0 -c 'CGAGTAACTCATGGCGA' *.fastq > count/B17529_Fm0.txt
agrep -0 -c 'CCGATTAAACCGCAGTA' *.fastq > count/B17530_Fm0.txt
agrep -0 -c 'AACAGGTCACTTCGACT' *.fastq > count/B17531_Fm0.txt
agrep -0 -c 'CCATACGATTAGGTGCT' *.fastq > count/B17532_Fm0.txt
agrep -0 -c 'TAGTTTCCGTTGCCTTA' *.fastq > count/B17533_Fm0.txt
agrep -0 -c 'AGCGTTACGATGTTATC' *.fastq > count/B17534_Fm0.txt
agrep -0 -c 'TGTCGGGAATCCTCGAC' *.fastq > count/B17536_Fm0.txt
agrep -0 -c 'AGTACGTTCCTATTGCC' *.fastq > count/B17537_Fm0.txt
agrep -0 -c 'AAGCCGATCAAATCTCC' *.fastq > count/B17539_Fm0.txt
agrep -0 -c 'TACCCTAGCCAACTCTA' *.fastq > count/B17540_Fm0.txt
agrep -0 -c 'CCATAAATCCTCGGACA' *.fastq > count/B17541_Fm0.txt
agrep -0 -c 'ATTCAAGCTGCTACCTG' *.fastq > count/B17542_Fm0.txt
agrep -0 -c 'ACTTATCCGATAGACAC' *.fastq > count/B17543_Fm0.txt
agrep -0 -c 'CAAGTTGTGGACCACGG' *.fastq > count/B17544_Fm0.txt
agrep -0 -c 'TCGTTTGATTGACGAAC' *.fastq > count/B17545_Fm0.txt
agrep -0 -c 'TGAAACGCTTCCTCGCA' *.fastq > count/B17546_Fm0.txt
agrep -0 -c 'GTTGTGCGTTCCAAGAT' *.fastq > count/B17547_Fm0.txt
agrep -0 -c 'AGGGTAATGTCCACTCA' *.fastq > count/B17548_Fm0.txt
agrep -0 -c 'CGCCGAAATTGTGATTA' *.fastq > count/B17549_Fm0.txt
agrep -0 -c 'GGAATGTTATAGGGTGG' *.fastq > count/B17550_Fm0.txt
agrep -0 -c 'CTGATTTGTATGTCGCT' *.fastq > count/B17552_Fm0.txt
agrep -0 -c 'GCATCGCTGTCTTAGTA' *.fastq > count/B17553_Fm0.txt
agrep -0 -c 'GGCAAAAGACGATCTCC' *.fastq > count/B17554_Fm0.txt
agrep -0 -c 'TCTAATGGCGTCGTAAT' *.fastq > count/B17555_Fm0.txt
agrep -0 -c 'TTCGACTGAAGTCATCA' *.fastq > count/B17556_Fm0.txt
agrep -0 -c 'AGCAGTATTGAGGTCAC' *.fastq > count/B17557_Fm0.txt
agrep -0 -c 'TGCTAAACTAAGACCGC' *.fastq > count/B17558_Fm0.txt
agrep -0 -c 'CAACTAGGACATAGTGA' *.fastq > count/B17559_Fm0.txt
agrep -0 -c 'CCTGTAGGCAAGTGGTC' *.fastq > count/B17560_Fm0.txt
agrep -0 -c 'GCGTCAACCAAGGCACT' *.fastq > count/B17561_Fm0.txt
agrep -0 -c 'GCGGCCCTGTGATACAA' *.fastq > count/B17562_Fm0.txt
agrep -0 -c 'GGCCCTGCGAAACTCAA' *.fastq > count/B17563_Fm0.txt
agrep -0 -c 'CACGTAGACACTGAGAT' *.fastq > count/B17564_Fm0.txt
agrep -0 -c 'TAAATGGGCAGGGCGAC' *.fastq > count/B17567_Fm0.txt
agrep -0 -c 'TATGCTTTACGTGCTGA' *.fastq > count/B17568_Fm0.txt
agrep -0 -c 'TCTTCCTTAGACGTCTC' *.fastq > count/B17569_Fm0.txt
agrep -0 -c 'GACCTAGTACCGACAGC' *.fastq > count/B17570_Fm0.txt
agrep -0 -c 'CTATTCTGGCCCGCATT' *.fastq > count/B17574_Fm0.txt
agrep -0 -c 'CGTTGAGTTTGTAAGAC' *.fastq > count/B17575_Fm0.txt
agrep -0 -c 'ACCTACGACACACGGTT' *.fastq > count/B17577_Fm0.txt
agrep -0 -c 'AAGTCATGACGGTGGGC' *.fastq > count/B17578_Fm0.txt
agrep -0 -c 'AGCTACTAGTTTAGGTG' *.fastq > count/B17579_Fm0.txt
agrep -0 -c 'CTGCCTTAAAGTATCGA' *.fastq > count/B17580_Fm0.txt
agrep -0 -c 'GCAACTCCGTTCTCAGA' *.fastq > count/B17582_Fm0.txt
agrep -0 -c 'CTGATTTAACGCACTTC' *.fastq > count/B17584_Fm0.txt
agrep -0 -c 'TTGCGCGAGTGCACCAA' *.fastq > count/B17585_Fm0.txt
agrep -0 -c 'ACGCGGAGTCCAAATAA' *.fastq > count/B17586_Fm0.txt
agrep -0 -c 'GCAAGAAAACGCCTTGC' *.fastq > count/B17588_Fm0.txt
agrep -0 -c 'TGAAATACGAGCGGCAC' *.fastq > count/B17589_Fm0.txt
agrep -0 -c 'CTTCGGCGTTGACACGA' *.fastq > count/B17590_Fm0.txt
agrep -0 -c 'GCTTCCTGACACTATAC' *.fastq > count/B17591_Fm0.txt
agrep -0 -c 'GGCATAACCGAATACCC' *.fastq > count/B17592_Fm0.txt
agrep -0 -c 'TAGCGTTCGAATTCGGC' *.fastq > count/B17594_Fm0.txt
agrep -0 -c 'CGGCGGCTACATGATTT' *.fastq > count/B17595_Fm0.txt
agrep -0 -c 'TATCCCGCGTAAAGCTA' *.fastq > count/B17596_Fm0.txt
agrep -0 -c 'TTGTTCCTGGCTCGAAG' *.fastq > count/B17597_Fm0.txt
agrep -0 -c 'AATTAGGTTGAACGCCC' *.fastq > count/B17598_Fm0.txt
agrep -0 -c 'GCAGGGTACTAGGAGAG' *.fastq > count/B17600_Fm0.txt
agrep -0 -c 'GACCTATTAAGCGGACT' *.fastq > count/B17601_Fm0.txt
agrep -0 -c 'AAGGTTGAAGCGGAACA' *.fastq > count/B17602_Fm0.txt
agrep -0 -c 'CCAACTGAAATGTGCGC' *.fastq > count/B17603_Fm0.txt
agrep -0 -c 'TGCGCGTACCAATACCA' *.fastq > count/B17604_Fm0.txt
agrep -0 -c 'CGCATGAGAGTATGAGC' *.fastq > count/B17606_Fm0.txt
agrep -0 -c 'GACTAGATGTCTACCAG' *.fastq > count/B17607_Fm0.txt
agrep -0 -c 'AGGCGAAGCAGCGAGAA' *.fastq > count/B17608_Fm0.txt
agrep -0 -c 'AATTGGGATACTGAGGG' *.fastq > count/B17609_Fm0.txt
agrep -0 -c 'CGACTGTCGGCGTGATA' *.fastq > count/B17611_Fm0.txt
agrep -0 -c 'CCATACTCCACGACGAT' *.fastq > count/B17612_Fm0.txt
agrep -0 -c 'GTCCCCGTCGAACAAAG' *.fastq > count/B17613_Fm0.txt
agrep -0 -c 'CTTGGTAATGTGGCTTT' *.fastq > count/B17614_Fm0.txt
agrep -0 -c 'CAGGCGACTCGATAGAT' *.fastq > count/B17615_Fm0.txt
agrep -0 -c 'GAGCGAACATTCCCACT' *.fastq > count/B17616_Fm0.txt
agrep -0 -c 'ACGCTACTCCCCCTACT' *.fastq > count/B17617_Fm0.txt
agrep -0 -c 'TTCGAATGAGTGGCACC' *.fastq > count/B17618_Fm0.txt
agrep -0 -c 'GTCGCCACATTAGGTTG' *.fastq > count/B17619_Fm0.txt
agrep -0 -c 'GTGAATTGCCGCTACGC' *.fastq > count/B17620_Fm0.txt
agrep -0 -c 'AGGATCCCTCGGCTTTA' *.fastq > count/B17621_Fm0.txt
agrep -0 -c 'AGGAAACCATAAGGCTT' *.fastq > count/B17622_Fm0.txt
agrep -0 -c 'TTGATGTGCGGCAAACA' *.fastq > count/B17623_Fm0.txt
agrep -0 -c 'TTGATCCCACGATTTGG' *.fastq > count/B17625_Fm0.txt
agrep -0 -c 'AGACTTCTGTAGGCGAC' *.fastq > count/B17626_Fm0.txt
agrep -0 -c 'GGACGATCTTGATTAGC' *.fastq > count/B17628_Fm0.txt
agrep -0 -c 'CCTATCTGATATGACTC' *.fastq > count/B17629_Fm0.txt
agrep -0 -c 'GATAAGCCACCATCCCG' *.fastq > count/B17630_Fm0.txt
agrep -0 -c 'ACCATATGGTCGAGTCC' *.fastq > count/B17631_Fm0.txt
agrep -0 -c 'ATCCAAGCGAGTGGAGC' *.fastq > count/B17632_Fm0.txt
agrep -0 -c 'GAGACAGGCTCTCCGAA' *.fastq > count/B17633_Fm0.txt
agrep -0 -c 'GTACGTCTAGCGTAATT' *.fastq > count/B17634_Fm0.txt
agrep -0 -c 'CGGATATTCCGGATGAA' *.fastq > count/B17635_Fm0.txt
agrep -0 -c 'TGCACCGCTGGAGTTTG' *.fastq > count/B17636_Fm0.txt
agrep -0 -c 'CTTCGTGATGTCGGTAG' *.fastq > count/B17637_Fm0.txt
agrep -0 -c 'CAAGCAATGGTCTCGTG' *.fastq > count/B17640_Fm0.txt
agrep -0 -c 'AATAGCTTCAGGGGCTA' *.fastq > count/B17641_Fm0.txt
agrep -0 -c 'TCACCAATGAAGGTCTA' *.fastq > count/B17642_Fm0.txt
agrep -0 -c 'CTCTTAATTAGGCTGCA' *.fastq > count/B17643_Fm0.txt
agrep -0 -c 'AGAGTAATGCAACCCTT' *.fastq > count/B17644_Fm0.txt
agrep -0 -c 'GAGATCAGTATAGGCGG' *.fastq > count/B17645_Fm0.txt
agrep -0 -c 'TTGGATCCACTCGTTAA' *.fastq > count/B17646_Fm0.txt
agrep -0 -c 'TGTCGCATAAGGCTAGG' *.fastq > count/B17647_Fm0.txt
agrep -0 -c 'ATGTTGCCAGCACCCCT' *.fastq > count/B17648_Fm0.txt
agrep -0 -c 'GACGACCTGTCATCTGT' *.fastq > count/B17649_Fm0.txt
agrep -0 -c 'GCATATCCGGAGGGTAT' *.fastq > count/B17650_Fm0.txt
agrep -0 -c 'CCGACTCCTCTCTAAAC' *.fastq > count/B17651_Fm0.txt
agrep -0 -c 'GACGAGTATCTGGTACG' *.fastq > count/B17652_Fm0.txt
agrep -0 -c 'CGGATATTCGACCATTA' *.fastq > count/B17653_Fm0.txt
agrep -0 -c 'GTCAGAAAGGAATCGAA' *.fastq > count/B17654_Fm0.txt
agrep -0 -c 'GTCAATCTACATGGTGC' *.fastq > count/B17655_Fm0.txt
agrep -0 -c 'GCGACTCTTGTTGCTAA' *.fastq > count/B17656_Fm0.txt
agrep -0 -c 'TCGGTTTGTGGTCGGTA' *.fastq > count/B17657_Fm0.txt
agrep -0 -c 'CATGCGTGCAACTAGCT' *.fastq > count/B17658_Fm0.txt
agrep -0 -c 'TGTCAGAGGCTACTAAG' *.fastq > count/B17659_Fm0.txt
agrep -0 -c 'GCGACATAGCAAGTGGG' *.fastq > count/B17660_Fm0.txt
agrep -0 -c 'GATGCGCTTCGGGTACA' *.fastq > count/B17661_Fm0.txt
agrep -0 -c 'CACGTACAGCTCGCATT' *.fastq > count/B17662_Fm0.txt
agrep -0 -c 'GTCCCGTAAGCGTGTGA' *.fastq > count/B17663_Fm0.txt
agrep -0 -c 'ACACGTGTCCCGCTACA' *.fastq > count/B17664_Fm0.txt
agrep -0 -c 'CAAATGGCGTTTAGTAC' *.fastq > count/B17667_Fm0.txt
agrep -0 -c 'AAGGCACTTTTACCTCC' *.fastq > count/B17668_Fm0.txt
agrep -0 -c 'CTCTGTCTACTATCAGA' *.fastq > count/B17669_Fm0.txt
agrep -0 -c 'TCGTTACCGAGATACTC' *.fastq > count/B17670_Fm0.txt
agrep -0 -c 'TACTACACGGTTCCTAC' *.fastq > count/B17671_Fm0.txt
agrep -0 -c 'GCGTCGATCCCATAGAC' *.fastq > count/B17672_Fm0.txt
agrep -0 -c 'AGTGATTGACCTATCGG' *.fastq > count/B17673_Fm0.txt
agrep -0 -c 'CTCGTCTTTCTCCGTAT' *.fastq > count/B17674_Fm0.txt
agrep -0 -c 'ATATGATGGTTAGGACC' *.fastq > count/B17675_Fm0.txt
agrep -0 -c 'TAATTCCGCTGTGCTTA' *.fastq > count/B17676_Fm0.txt
agrep -0 -c 'GGCGCAGCTCGATACAA' *.fastq > count/B17677_Fm0.txt
agrep -0 -c 'GCTCACTGGCGTACTAA' *.fastq > count/B17678_Fm0.txt
agrep -0 -c 'TTGCGTCCTTGGGCGAT' *.fastq > count/B17679_Fm0.txt
agrep -0 -c 'CGTATAAAAGGCCTAGC' *.fastq > count/B17680_Fm0.txt
agrep -0 -c 'ACGTACAAATACCCCTG' *.fastq > count/B17682_Fm0.txt
agrep -0 -c 'ATCGATTCGCGCTCGTC' *.fastq > count/B17683_Fm0.txt
agrep -0 -c 'GTGTCCCTTTTCCGGTA' *.fastq > count/B17684_Fm0.txt
agrep -0 -c 'CTGACCTCATTTAAGGG' *.fastq > count/B17686_Fm0.txt
agrep -0 -c 'TCTAAGTGCGTCACTAA' *.fastq > count/B17689_Fm0.txt
agrep -0 -c 'TCTGAAGTGGCGCATGC' *.fastq > count/B17690_Fm0.txt
agrep -0 -c 'GGCTTCAGATAAAGAAC' *.fastq > count/B17691_Fm0.txt
agrep -0 -c 'GCGATGTGCTGCGTCTA' *.fastq > count/B17692_Fm0.txt
agrep -0 -c 'CACGTAAAGAATCATGC' *.fastq > count/B17693_Fm0.txt
agrep -0 -c 'GATCCAGGTTGATGTGG' *.fastq > count/B17695_Fm0.txt
agrep -0 -c 'GCGCTCGAATTCGACTT' *.fastq > count/B17697_Fm0.txt
agrep -0 -c 'AGCGACCACTGATACAG' *.fastq > count/B17698_Fm0.txt
agrep -0 -c 'TGGCCGAGATTCGTAAA' *.fastq > count/B17699_Fm0.txt
agrep -0 -c 'GCCCCTACTTTGACAAG' *.fastq > count/B17700_Fm0.txt
agrep -0 -c 'CTCAACAAAGGTGCCCT' *.fastq > count/B17702_Fm0.txt
agrep -0 -c 'ACGTTATCTGTATGGTC' *.fastq > count/B17705_Fm0.txt
agrep -0 -c 'CCACAAAACGAAGTCGT' *.fastq > count/B17706_Fm0.txt
agrep -0 -c 'ACAGCTAGTCATCCCAA' *.fastq > count/B17707_Fm0.txt
agrep -0 -c 'GGGGGACTGAGTAGCTT' *.fastq > count/B17708_Fm0.txt
agrep -0 -c 'TCGGGTGTTGATTCTCG' *.fastq > count/B17709_Fm0.txt
agrep -0 -c 'CCTTCAGTCAACTACCT' *.fastq > count/B17710_Fm0.txt
agrep -0 -c 'GGTGCTTACATGAATTC' *.fastq > count/B17711_Fm0.txt
agrep -0 -c 'AGTAGAGGATACAATGG' *.fastq > count/B17712_Fm0.txt
agrep -0 -c 'CTCTCTTAAGTGCCGTG' *.fastq > count/B17713_Fm0.txt
agrep -0 -c 'TCTTCTATGTAGTCCAC' *.fastq > count/B17714_Fm0.txt
agrep -0 -c 'TTCCAGATGCTCCGTCT' *.fastq > count/B17715_Fm0.txt
agrep -0 -c 'GGAGATGACATTCGGAG' *.fastq > count/B17716_Fm0.txt
agrep -0 -c 'GCAGAATTGTACCTCCT' *.fastq > count/B17718_Fm0.txt
agrep -0 -c 'CCATGTCGTGAAATGTT' *.fastq > count/B17720_Fm0.txt
agrep -0 -c 'TGCTTACTCTTCAATGC' *.fastq > count/B17722_Fm0.txt
agrep -0 -c 'AACGGCAAACTAAGACC' *.fastq > count/B17723_Fm0.txt
agrep -0 -c 'TCATGCCTAGCCAGCAT' *.fastq > count/B17725_Fm0.txt
agrep -0 -c 'ACATTTCGCGTACACAC' *.fastq > count/B17726_Fm0.txt
agrep -0 -c 'CCACGCTTACGATGACC' *.fastq > count/B17728_Fm0.txt
agrep -0 -c 'TTCTTCTTTCGAGGAGA' *.fastq > count/B17729_Fm0.txt
agrep -0 -c 'GGGACTATGGCTAAAGA' *.fastq > count/B17730_Fm0.txt
agrep -0 -c 'CGATCTGACCTGAATCC' *.fastq > count/B17731_Fm0.txt
agrep -0 -c 'ACGACCTGCGTTGCAAT' *.fastq > count/B17732_Fm0.txt
agrep -0 -c 'ATATGCGAGAATGTTCG' *.fastq > count/B17737_Fm0.txt
agrep -0 -c 'TTCCTGATCGTCCTCCA' *.fastq > count/B17738_Fm0.txt
agrep -0 -c 'AGATCCGAAGTGCGATA' *.fastq > count/B17739_Fm0.txt
agrep -0 -c 'AATTTCGCGTTCAGCAT' *.fastq > count/B17740_Fm0.txt
agrep -0 -c 'TACCTATGACGCCCACA' *.fastq > count/B17742_Fm0.txt
agrep -0 -c 'GCTTCCTTACCTTATCG' *.fastq > count/B17743_Fm0.txt
agrep -0 -c 'AATCCTGGAGCGTGTAG' *.fastq > count/B17744_Fm0.txt
agrep -0 -c 'CGAAACTCCCCCAAAAC' *.fastq > count/B17745_Fm0.txt
agrep -0 -c 'AACTGATCCTGCGCGTG' *.fastq > count/B17746_Fm0.txt
agrep -0 -c 'AGTCCAACGAAGCGTCC' *.fastq > count/B17747_Fm0.txt
agrep -0 -c 'AGCTCTTAATACCGCGA' *.fastq > count/B17749_Fm0.txt
agrep -0 -c 'GGTGACGATAGGCTAGC' *.fastq > count/B17750_Fm0.txt
agrep -0 -c 'ACGTGTCTCGTTCTATT' *.fastq > count/B17752_Fm0.txt
agrep -0 -c 'TTGCGTAAAAGCGTCAC' *.fastq > count/B17753_Fm0.txt
agrep -0 -c 'AGCAAGCGTAGATTTTC' *.fastq > count/B17754_Fm0.txt
agrep -0 -c 'GGTCGGTCGTGATCAGA' *.fastq > count/B17755_Fm0.txt
agrep -0 -c 'CACTAGCGCACAGTGTT' *.fastq > count/B17756_Fm0.txt
agrep -0 -c 'GGCATAACTACAGTGGA' *.fastq > count/B17757_Fm0.txt
agrep -0 -c 'CGCCTTGCTTAGCATAG' *.fastq > count/B17758_Fm0.txt
agrep -0 -c 'ACCTTCTTGGTAGACGT' *.fastq > count/B17760_Fm0.txt
agrep -0 -c 'GCAATCGAAAGTGCAGT' *.fastq > count/B17761_Fm0.txt
agrep -0 -c 'CAGACGTGTTCAGTGCA' *.fastq > count/B17762_Fm0.txt
agrep -0 -c 'ATACCGGGGTTGACATA' *.fastq > count/B17763_Fm0.txt
agrep -0 -c 'TCAACCTTGGATACCTT' *.fastq > count/B17764_Fm0.txt
agrep -0 -c 'CGACTACCATAATCTCT' *.fastq > count/B17765_Fm0.txt
agrep -0 -c 'TACCTGGAAGTCTACCC' *.fastq > count/B17766_Fm0.txt
agrep -0 -c 'ACCGATGCACCAATAGT' *.fastq > count/B17767_Fm0.txt
agrep -0 -c 'CTGCTTTTCTACAAGCT' *.fastq > count/B17768_Fm0.txt
agrep -0 -c 'GTTGTCACCTTCGAACC' *.fastq > count/B17769_Fm0.txt
agrep -0 -c 'AGCGCGATTACCCTAAT' *.fastq > count/B17770_Fm0.txt
agrep -0 -c 'ACCGAATACAGCTATTC' *.fastq > count/B17771_Fm0.txt
agrep -0 -c 'AATGGCGAACGGGAAAT' *.fastq > count/B17772_Fm0.txt
agrep -0 -c 'CACTGGAATACACACGC' *.fastq > count/B17773_Fm0.txt
agrep -0 -c 'CCGTAAAATACCTCTGG' *.fastq > count/B17774_Fm0.txt
agrep -0 -c 'GCTAAACTTCGCACATC' *.fastq > count/B17775_Fm0.txt
agrep -0 -c 'ATGTTTGGGCGGAATGA' *.fastq > count/B17776_Fm0.txt
agrep -0 -c 'AGTAATGGCAATAGACC' *.fastq > count/B17777_Fm0.txt
agrep -0 -c 'GCGTAAATCATCTCAGA' *.fastq > count/B17779_Fm0.txt
agrep -0 -c 'TCTGCTTGTGATGCAAC' *.fastq > count/B17781_Fm0.txt
agrep -0 -c 'TGTCGGGCGTGATACTG' *.fastq > count/B17783_Fm0.txt
agrep -0 -c 'GATATCCGCAGAGGAAG' *.fastq > count/B17784_Fm0.txt
agrep -0 -c 'TCGAATCTTATCCCTAC' *.fastq > count/B17786_Fm0.txt
agrep -0 -c 'TGACATGTCCACCGCTG' *.fastq > count/B17789_Fm0.txt
agrep -0 -c 'TCGACGATATAGAATCC' *.fastq > count/B17790_Fm0.txt
agrep -0 -c 'GGTGCTGGAGAGTCGAA' *.fastq > count/B17792_Fm0.txt
agrep -0 -c 'GACCACGGGAATAGAGC' *.fastq > count/B17793_Fm0.txt
agrep -0 -c 'CCACATAACGGTTGGAA' *.fastq > count/B17794_Fm0.txt
agrep -0 -c 'CGGTTCCAAGAGATGGA' *.fastq > count/B17795_Fm0.txt
agrep -0 -c 'TCTGGGGTTATAGGGTC' *.fastq > count/B17796_Fm0.txt
agrep -0 -c 'CAGCGCGTATCTACCAG' *.fastq > count/B17797_Fm0.txt
agrep -0 -c 'TTGGCGATTCCGAATCG' *.fastq > count/B17798_Fm0.txt
agrep -0 -c 'AACGTGTGTCATCAGCG' *.fastq > count/B17799_Fm0.txt
agrep -0 -c 'CACCCCCTACTATGCTC' *.fastq > count/B17800_Fm0.txt
agrep -0 -c 'TACGGAGGTGTATCTGC' *.fastq > count/B17803_Fm0.txt
agrep -0 -c 'AGTACACCCCATGATGG' *.fastq > count/B17804_Fm0.txt
agrep -0 -c 'ATACGAAATGAAGCCAG' *.fastq > count/B17805_Fm0.txt
agrep -0 -c 'CTGCCTAGAATCGATAG' *.fastq > count/B17807_Fm0.txt
agrep -0 -c 'GACATCCTGTGAAGCCA' *.fastq > count/B17808_Fm0.txt
agrep -0 -c 'CGCACTTCCCATAAGCC' *.fastq > count/B17810_Fm0.txt
agrep -0 -c 'GGGAATTGGACACACCA' *.fastq > count/B17811_Fm0.txt
agrep -0 -c 'GGGAGACAAAACGGCCA' *.fastq > count/B17812_Fm0.txt
agrep -0 -c 'TTAAACGCCGGTCGGAG' *.fastq > count/B17813_Fm0.txt
agrep -0 -c 'AATACCTGCCGCCCCTT' *.fastq > count/B17814_Fm0.txt
agrep -0 -c 'CCGAACTATAGGCCAGA' *.fastq > count/B17815_Fm0.txt
agrep -0 -c 'CTGTCACGTAATCTAGA' *.fastq > count/B17816_Fm0.txt
agrep -0 -c 'TGATCGGATATGGGCCT' *.fastq > count/B17817_Fm0.txt
agrep -0 -c 'CTAGCACAATCGATCTC' *.fastq > count/B17818_Fm0.txt
agrep -0 -c 'AACCAGACACTGCCATG' *.fastq > count/B17819_Fm0.txt
agrep -0 -c 'TCTACCTTAAGTCCAGC' *.fastq > count/B17820_Fm0.txt
agrep -0 -c 'CAATAGTCGGCACATGT' *.fastq > count/B17821_Fm0.txt
agrep -0 -c 'CGACCCCTCACTGTGTT' *.fastq > count/B17822_Fm0.txt
agrep -0 -c 'GCTCAATATCCCAACCT' *.fastq > count/B17823_Fm0.txt
agrep -0 -c 'GGACCTGGCGTGCATAA' *.fastq > count/B17824_Fm0.txt
agrep -0 -c 'CTTAGTTCCTTCGCCCT' *.fastq > count/B17826_Fm0.txt
agrep -0 -c 'AAGTGTTCCGAAGCAAA' *.fastq > count/B17829_Fm0.txt
agrep -0 -c 'CCTTCGCTAGACCTAAG' *.fastq > count/B17830_Fm0.txt
agrep -0 -c 'CGTCGCAAAAGACCCAC' *.fastq > count/B17831_Fm0.txt
agrep -0 -c 'CAATTACTCCGAATGGA' *.fastq > count/B17832_Fm0.txt
agrep -0 -c 'ATGTCTCCCGGTTACGT' *.fastq > count/B17833_Fm0.txt
agrep -0 -c 'TTGTGTCGACTCTACAT' *.fastq > count/B17834_Fm0.txt
agrep -0 -c 'AATGGCCCGCTCTTAAC' *.fastq > count/B17835_Fm0.txt
agrep -0 -c 'ACAGCGGATAGTAGGCA' *.fastq > count/B17837_Fm0.txt
agrep -0 -c 'TCGTATCTAGCACGGAG' *.fastq > count/B17838_Fm0.txt
agrep -0 -c 'ATTACCGGTTGATGGAC' *.fastq > count/B17841_Fm0.txt
agrep -0 -c 'GGAGATTCTCGTAGTGT' *.fastq > count/B17842_Fm0.txt
agrep -0 -c 'CTAACTGAGCGTACTGC' *.fastq > count/B17843_Fm0.txt
agrep -0 -c 'CGTGTGGACGTTATCGT' *.fastq > count/B17844_Fm0.txt
agrep -0 -c 'AAGAAGAACCCGTGACT' *.fastq > count/B17846_Fm0.txt
agrep -0 -c 'ATGTCCTCAACGACTCA' *.fastq > count/B17847_Fm0.txt
agrep -0 -c 'CAAGGACCATCTACATA' *.fastq > count/B17848_Fm0.txt
agrep -0 -c 'ACAGAGAATAGCGGACC' *.fastq > count/B17851_Fm0.txt
agrep -0 -c 'GGATGCATGTGTACATC' *.fastq > count/B17852_Fm0.txt
agrep -0 -c 'GCGCATTGCTGTGTGTA' *.fastq > count/B17854_Fm0.txt
agrep -0 -c 'CCGTTGCGCAATTGTAT' *.fastq > count/B17855_Fm0.txt
agrep -0 -c 'TGTCGGTGCAACATTCG' *.fastq > count/B17856_Fm0.txt
agrep -0 -c 'TAGGTACTCGTACCAGT' *.fastq > count/B17857_Fm0.txt
agrep -0 -c 'TTATTTTCAGCGCTCGC' *.fastq > count/B17858_Fm0.txt
agrep -0 -c 'ATCGACCTCGCATTACC' *.fastq > count/B17859_Fm0.txt
agrep -0 -c 'CATGTTATACCATGTGG' *.fastq > count/B17860_Fm0.txt
agrep -0 -c 'CTTAAAACCTTGGGTCC' *.fastq > count/B17861_Fm0.txt
agrep -0 -c 'ACAGACGAAAGCGGCTT' *.fastq > count/B17862_Fm0.txt
agrep -0 -c 'ATTCCGGAGCTGCACGA' *.fastq > count/B17864_Fm0.txt
agrep -0 -c 'TCGGAGCTTATCGATAA' *.fastq > count/B17865_Fm0.txt
agrep -0 -c 'GGCGTCTGTAAATCTAC' *.fastq > count/B17866_Fm0.txt
agrep -0 -c 'GTTAACAAAACCGAGCA' *.fastq > count/B17867_Fm0.txt
agrep -0 -c 'CGTTCCTTTCGAACCTC' *.fastq > count/B17869_Fm0.txt
agrep -0 -c 'GCATACTAAGCTCAGTA' *.fastq > count/B17870_Fm0.txt
agrep -0 -c 'ATCACTAACGAGCCCTG' *.fastq > count/B17871_Fm0.txt
agrep -0 -c 'CTCTCAATAGGACAGCG' *.fastq > count/B17872_Fm0.txt
agrep -0 -c 'CTTGTGACCTGAAATTC' *.fastq > count/B17873_Fm0.txt
agrep -0 -c 'CCTCTGACCGGTTTGTC' *.fastq > count/B17874_Fm0.txt
agrep -0 -c 'GCCATTAAGCGAGGGCA' *.fastq > count/B17876_Fm0.txt
agrep -0 -c 'TGAGACCGTACGACCTG' *.fastq > count/B17877_Fm0.txt
agrep -0 -c 'ACTTAACCACAAACGCG' *.fastq > count/B17879_Fm0.txt
agrep -0 -c 'TCGTTACAGAGAGCCAG' *.fastq > count/B17881_Fm0.txt
agrep -0 -c 'GCCTACTATAAATGGGC' *.fastq > count/B17882_Fm0.txt
agrep -0 -c 'GCTACACGCTAGAGAGA' *.fastq > count/B17883_Fm0.txt
agrep -0 -c 'GGGCCGAAAGTTATAAT' *.fastq > count/B17884_Fm0.txt
agrep -0 -c 'CAATCTGGCATAGTGAA' *.fastq > count/B17886_Fm0.txt
agrep -0 -c 'TAACAGATGCATGAGCG' *.fastq > count/B17887_Fm0.txt
agrep -0 -c 'CCTTAGGACACCTTCAA' *.fastq > count/B17889_Fm0.txt
agrep -0 -c 'CCTTTTCACTTGCTGAA' *.fastq > count/B17890_Fm0.txt
agrep -0 -c 'CACTGATCTTACTGCGT' *.fastq > count/B17891_Fm0.txt
agrep -0 -c 'GGTTGCTTACTGGTTAG' *.fastq > count/B17892_Fm0.txt
agrep -0 -c 'GCATTGGGTGGTGGAGT' *.fastq > count/B17893_Fm0.txt
agrep -0 -c 'CTGAGCTACGGAATAAC' *.fastq > count/B17894_Fm0.txt
agrep -0 -c 'CACATCGGGTTTGGATT' *.fastq > count/B17895_Fm0.txt
agrep -0 -c 'CAACTTGATTCGGAACC' *.fastq > count/B17896_Fm0.txt
agrep -0 -c 'GTTAGAGGACGGTAATC' *.fastq > count/B17897_Fm0.txt
agrep -0 -c 'GCCTGTAGGACCTATCG' *.fastq > count/B17898_Fm0.txt
agrep -0 -c 'CGCGCGGATGTTACTAT' *.fastq > count/B17899_Fm0.txt
agrep -0 -c 'TGACGAGGCGTTTAGGT' *.fastq > count/B17900_Fm0.txt
agrep -0 -c 'GCGATTGGGGTTTTCAA' *.fastq > count/B17901_Fm0.txt
agrep -0 -c 'CATCGCAACTCTACCAA' *.fastq > count/B17902_Fm0.txt
agrep -0 -c 'GAGGACAAATATGTGGG' *.fastq > count/B17904_Fm0.txt
agrep -0 -c 'GACGTTCCAGTCGTTAC' *.fastq > count/B17905_Fm0.txt
agrep -0 -c 'TCGGCCTTTGGCCTGAA' *.fastq > count/B17906_Fm0.txt
agrep -0 -c 'ACTGCAACTTACTGGGC' *.fastq > count/B17907_Fm0.txt
agrep -0 -c 'CCTTACTAGATGACCGC' *.fastq > count/B17908_Fm0.txt
agrep -0 -c 'CACGTCGCATGTACTAT' *.fastq > count/B17909_Fm0.txt
agrep -0 -c 'GATCTAAGGAGCATCAG' *.fastq > count/B17910_Fm0.txt
agrep -0 -c 'CACAACTTTTCCCCGCC' *.fastq > count/B17911_Fm0.txt
agrep -0 -c 'ATTGCCCTTGCACTAGC' *.fastq > count/B17912_Fm0.txt
agrep -0 -c 'GCTGAGAAATGACGTCG' *.fastq > count/B17913_Fm0.txt
agrep -0 -c 'CTGCACTTCGTCTTGAA' *.fastq > count/B17914_Fm0.txt
agrep -0 -c 'AGATGCGTACAGGTGGG' *.fastq > count/B17915_Fm0.txt
agrep -0 -c 'TACTTTGGGGGGCACAT' *.fastq > count/B17916_Fm0.txt
agrep -0 -c 'AACAGACTGCCTATGTG' *.fastq > count/B17919_Fm0.txt
agrep -0 -c 'GGGAGTGTGAAAACTAA' *.fastq > count/B17920_Fm0.txt
agrep -0 -c 'TATCGCGAGCCAGCCTA' *.fastq > count/B17921_Fm0.txt
agrep -0 -c 'CCTCAAACAATAGACGA' *.fastq > count/B17923_Fm0.txt
agrep -0 -c 'GACGCAATTGAGTGAAC' *.fastq > count/B17925_Fm0.txt
agrep -0 -c 'AGACGATTACGGTTCAA' *.fastq > count/B17926_Fm0.txt
agrep -0 -c 'CGCAAACGTGAGTTTAG' *.fastq > count/B17928_Fm0.txt
agrep -0 -c 'AATTCGCTGCTGGGCGA' *.fastq > count/B17929_Fm0.txt
agrep -0 -c 'ATGTAACTATCAGCCGG' *.fastq > count/B17930_Fm0.txt
agrep -0 -c 'GCTTCGTGCCTAGTTTC' *.fastq > count/B17931_Fm0.txt
agrep -0 -c 'GCGACTGACATCATACT' *.fastq > count/B17932_Fm0.txt
agrep -0 -c 'TCAGTATCACTTCTCGA' *.fastq > count/B17933_Fm0.txt
agrep -0 -c 'CCACCAGCTAGGGAACT' *.fastq > count/B17934_Fm0.txt
agrep -0 -c 'CAACGTAACTCGATGCC' *.fastq > count/B17935_Fm0.txt
agrep -0 -c 'GTATCCCGCCGCTATAC' *.fastq > count/B17937_Fm0.txt
agrep -0 -c 'ACAGCTTGCTCCTTAAT' *.fastq > count/B17938_Fm0.txt
agrep -0 -c 'AGAGGAAAAGGCTTCGA' *.fastq > count/B17939_Fm0.txt
agrep -0 -c 'CTAGGCGCCAGAATATG' *.fastq > count/B17940_Fm0.txt
agrep -0 -c 'ATAAAAGCGAGAGCGGT' *.fastq > count/B17941_Fm0.txt
agrep -0 -c 'GGTGGGTCTTCAGCGAA' *.fastq > count/B17944_Fm0.txt
agrep -0 -c 'TCATGAACCCCGCGTTA' *.fastq > count/B17945_Fm0.txt
agrep -0 -c 'ACATGAAGTCGCCAATC' *.fastq > count/B17946_Fm0.txt
agrep -0 -c 'GCACGCGACCAGAAAGA' *.fastq > count/B17949_Fm0.txt
agrep -0 -c 'GTTGAATGGAGCGTTGT' *.fastq > count/B17950_Fm0.txt
agrep -0 -c 'ATGGTACTCAGATAGAG' *.fastq > count/B17951_Fm0.txt
agrep -0 -c 'GGTAACGGCTCGAGTTG' *.fastq > count/B17952_Fm0.txt
agrep -0 -c 'CACGCTTGCACGCTAGA' *.fastq > count/B17953_Fm0.txt
agrep -0 -c 'CAGAACCACATATGCGC' *.fastq > count/B17954_Fm0.txt
agrep -0 -c 'TGATAATGCGACTGCAG' *.fastq > count/B17955_Fm0.txt
agrep -0 -c 'AGGCTGCAATTCCAAAA' *.fastq > count/B17957_Fm0.txt
agrep -0 -c 'AGTTACACCTGATTTCG' *.fastq > count/B17960_Fm0.txt
agrep -0 -c 'GGGAGTGTTCGGTTGAC' *.fastq > count/B17961_Fm0.txt
agrep -0 -c 'AGTACCACGAGATGGCC' *.fastq > count/B17962_Fm0.txt
agrep -0 -c 'AATAGCCGTTTCGACGT' *.fastq > count/B17964_Fm0.txt
agrep -0 -c 'GCATCACTCTAATCACA' *.fastq > count/B17965_Fm0.txt
agrep -0 -c 'CAAAAGGCATGCTCCGT' *.fastq > count/B17967_Fm0.txt
agrep -0 -c 'GCTGGAAGCAGAATACG' *.fastq > count/B17968_Fm0.txt
agrep -0 -c 'TCGGACGTTCAAGGATG' *.fastq > count/B17970_Fm0.txt
agrep -0 -c 'CGTCCTAGCACTATATA' *.fastq > count/B17971_Fm0.txt
agrep -0 -c 'GAGCGCTCTCTTTGACT' *.fastq > count/B17972_Fm0.txt
agrep -0 -c 'TCTACCATACCGCCCTA' *.fastq > count/B17974_Fm0.txt
agrep -0 -c 'AATGCGGAGTGAGTCCT' *.fastq > count/B17975_Fm0.txt
agrep -0 -c 'TGTTCCATGAACCCGTC' *.fastq > count/B17978_Fm0.txt
agrep -0 -c 'CAGCGAATATTGGTTCT' *.fastq > count/B17979_Fm0.txt
agrep -0 -c 'ATACCTGGCGATTACCG' *.fastq > count/B17980_Fm0.txt
agrep -0 -c 'CTATCCTGCCGTTAACT' *.fastq > count/B17981_Fm0.txt
agrep -0 -c 'GATGTGGCCTCCTTGTA' *.fastq > count/B17983_Fm0.txt
agrep -0 -c 'CAGTCGCTAGCTTGGTA' *.fastq > count/B17984_Fm0.txt
agrep -0 -c 'GTGTATGCGGTTTAGGC' *.fastq > count/B17986_Fm0.txt
agrep -0 -c 'TCAGTGACATCATCCGG' *.fastq > count/B17987_Fm0.txt
agrep -0 -c 'GGCCTACACCCAGCTTA' *.fastq > count/B17988_Fm0.txt
agrep -0 -c 'GCCGTATTGATTCGAGA' *.fastq > count/B17989_Fm0.txt
agrep -0 -c 'GCGAGCTGAGCAGAAAC' *.fastq > count/B17990_Fm0.txt
agrep -0 -c 'TTCGCTGTGGGTATGTA' *.fastq > count/B17991_Fm0.txt
agrep -0 -c 'CGCCTGAATCTTAGTCG' *.fastq > count/B17992_Fm0.txt
agrep -0 -c 'GCTTACTAAATCAGAGC' *.fastq > count/B17994_Fm0.txt
agrep -0 -c 'GTAATAGCCTACACGCC' *.fastq > count/B17995_Fm0.txt
agrep -0 -c 'TGCGTATATACGCAGAG' *.fastq > count/B17997_Fm0.txt
agrep -0 -c 'AGTCGATACACGTACCC' *.fastq > count/B17998_Fm0.txt
agrep -0 -c 'GCTAGAACAGGGAACAG' *.fastq > count/B17999_Fm0.txt
agrep -0 -c 'CGGTGGTTGATTATGCG' *.fastq > count/B18001_Fm0.txt
agrep -0 -c 'ATTATTCGTGGATCCGT' *.fastq > count/B18003_Fm0.txt
agrep -0 -c 'AGCCGATACCGGAAACC' *.fastq > count/B18004_Fm0.txt
agrep -0 -c 'GTCAGTTAAGCATCAGG' *.fastq > count/B18005_Fm0.txt
agrep -0 -c 'ACTTAGACCTCCTTGGG' *.fastq > count/B18007_Fm0.txt
agrep -0 -c 'TAAAACGCCGTAGGTAG' *.fastq > count/B18008_Fm0.txt
agrep -0 -c 'ATTGCAGGTCACAGTAA' *.fastq > count/B18009_Fm0.txt
agrep -0 -c 'ACTTTCGGTCCTACCGC' *.fastq > count/B18011_Fm0.txt
agrep -0 -c 'TGTTGCCTCGATGCACG' *.fastq > count/B18012_Fm0.txt
agrep -0 -c 'CGTTGTAGGTGAACAGT' *.fastq > count/B18013_Fm0.txt
agrep -0 -c 'CCATTACTCCGGGTCGA' *.fastq > count/B18014_Fm0.txt
agrep -0 -c 'CCACCAACCGATGTCGT' *.fastq > count/B18015_Fm0.txt
agrep -0 -c 'AATTGAGGTTCCGCACC' *.fastq > count/B18016_Fm0.txt
agrep -0 -c 'TAGGACTAGGTAGTCGC' *.fastq > count/B18017_Fm0.txt
agrep -0 -c 'ACACGCAATTTATGGCG' *.fastq > count/B18018_Fm0.txt
agrep -0 -c 'CGTTCTAAGGCTCGTCC' *.fastq > count/B18019_Fm0.txt
agrep -0 -c 'CGTAGGGTAGGGCATTT' *.fastq > count/B18020_Fm0.txt
agrep -0 -c 'CAACCTTGGGAGTAGCA' *.fastq > count/B18021_Fm0.txt
agrep -0 -c 'ACCCTGCCTTCAATCGG' *.fastq > count/B18023_Fm0.txt
agrep -0 -c 'ACTAATCGTGTCACTGG' *.fastq > count/B18024_Fm0.txt
agrep -0 -c 'CGCCCCATGTTATAAGC' *.fastq > count/B18026_Fm0.txt
agrep -0 -c 'ATGCTCGATTCGCAGTA' *.fastq > count/B18027_Fm0.txt
agrep -0 -c 'TCTAGGAAGGCTTTTTG' *.fastq > count/B18028_Fm0.txt
agrep -0 -c 'AGATCTGATAGGCAGCG' *.fastq > count/B18029_Fm0.txt
agrep -0 -c 'ATGGAGCTTCCTTTCCC' *.fastq > count/B18030_Fm0.txt
agrep -0 -c 'TCGGTGATAAACGATCG' *.fastq > count/B18031_Fm0.txt
agrep -0 -c 'GCCCACTAGAGTTAGAC' *.fastq > count/B18032_Fm0.txt
agrep -0 -c 'TGTCAGGCTGCAAGCCT' *.fastq > count/B18033_Fm0.txt
agrep -0 -c 'TACGGCTCGTGCTACCA' *.fastq > count/B18034_Fm0.txt
agrep -0 -c 'CGTGTGTGGAACATGGC' *.fastq > count/B18035_Fm0.txt
agrep -0 -c 'CCACAGAGTGATCTATC' *.fastq > count/B18036_Fm0.txt
agrep -0 -c 'GGTCAATCAGAGAGCCC' *.fastq > count/B18037_Fm0.txt
agrep -0 -c 'AAGCAACCTTCATGAGT' *.fastq > count/B18038_Fm0.txt
agrep -0 -c 'AAGGTAGCTTCCTCGTT' *.fastq > count/B18040_Fm0.txt
agrep -0 -c 'GTACCGAGCGAAACTCC' *.fastq > count/B18042_Fm0.txt
agrep -0 -c 'AAGCGGTAAGCATCGGC' *.fastq > count/B18043_Fm0.txt
agrep -0 -c 'GCAAAGAACGAACGTCG' *.fastq > count/B18044_Fm0.txt
agrep -0 -c 'CCTAGCCGTGGTACATT' *.fastq > count/B18045_Fm0.txt
agrep -0 -c 'GTGCTAACGGATCGTAT' *.fastq > count/B18046_Fm0.txt
agrep -0 -c 'ATACACCGAGCAAACAT' *.fastq > count/B18047_Fm0.txt
agrep -0 -c 'CTTATCACCGCAACAGA' *.fastq > count/B18048_Fm0.txt
agrep -0 -c 'GGATTTAGATGCCATGT' *.fastq > count/B18049_Fm0.txt
agrep -0 -c 'ATTGATACGGTTCGCTC' *.fastq > count/B18050_Fm0.txt
agrep -0 -c 'TACGCCTCTATGCGATA' *.fastq > count/B18051_Fm0.txt
agrep -0 -c 'AGGTTTATCGCCAGGAG' *.fastq > count/B18052_Fm0.txt
agrep -0 -c 'ACCGCTGCGTAATTTCG' *.fastq > count/B18053_Fm0.txt
agrep -0 -c 'CGCTGCTGTTTACAAAT' *.fastq > count/B18054_Fm0.txt
agrep -0 -c 'AACTCCGTTTACGGCAC' *.fastq > count/B18056_Fm0.txt
agrep -0 -c 'GTTACGACAGTTACGGT' *.fastq > count/B18059_Fm0.txt
agrep -0 -c 'CGATCCTCCAGAATATG' *.fastq > count/B18060_Fm0.txt
agrep -0 -c 'TAAGTAAGGCACTTCTG' *.fastq > count/B18061_Fm0.txt
agrep -0 -c 'GATCAAGTTCGATGTGA' *.fastq > count/B18062_Fm0.txt
agrep -0 -c 'ACGCCGCGAGTGCATTT' *.fastq > count/B18063_Fm0.txt
agrep -0 -c 'ACGATTCGTAACATGTG' *.fastq > count/B18064_Fm0.txt
agrep -0 -c 'CCTTACTAGACCTCAGT' *.fastq > count/B18065_Fm0.txt
agrep -0 -c 'CCGGTCGATGGACAATG' *.fastq > count/B18066_Fm0.txt
agrep -0 -c 'TCAGTACAGACGTAGCA' *.fastq > count/B18067_Fm0.txt
agrep -0 -c 'TGACATCGTTGAGCGTC' *.fastq > count/B18068_Fm0.txt
agrep -0 -c 'ATTTCTAGTCTATCCCG' *.fastq > count/B18069_Fm0.txt
agrep -0 -c 'AGCCCTTTGAATGCTGC' *.fastq > count/B18071_Fm0.txt
agrep -0 -c 'GTACTCAATAGCCATAG' *.fastq > count/B18073_Fm0.txt
agrep -0 -c 'TGTTCCTGTGTACCTAC' *.fastq > count/B18074_Fm0.txt
agrep -0 -c 'ACCGACTCCGTTAATTC' *.fastq > count/B18075_Fm0.txt
agrep -0 -c 'TGCTCGCTCCTATTGCA' *.fastq > count/B18076_Fm0.txt
agrep -0 -c 'CTTCCAAATCGGTCTAG' *.fastq > count/B18078_Fm0.txt
agrep -0 -c 'GGCCTGTTTCTTCTGAG' *.fastq > count/B18079_Fm0.txt
agrep -0 -c 'CCTGCAACATTCGTACG' *.fastq > count/B18080_Fm0.txt
agrep -0 -c 'CCATGTTTTTGCGTGAA' *.fastq > count/B18081_Fm0.txt
agrep -0 -c 'CTCACCTGCGATATTAT' *.fastq > count/B18082_Fm0.txt
agrep -0 -c 'TCGGTGGACCCTTACCT' *.fastq > count/B18083_Fm0.txt
agrep -0 -c 'GTCGGGTGAAAACTTTA' *.fastq > count/B18084_Fm0.txt
agrep -0 -c 'GGTCACGATTCTACTCC' *.fastq > count/B18085_Fm0.txt
agrep -0 -c 'GCTGCATGAGGGATCCT' *.fastq > count/B18086_Fm0.txt
agrep -0 -c 'ATCGGCGCATCAGCTTT' *.fastq > count/B18087_Fm0.txt
agrep -0 -c 'CGAGACCATTTTTGGGG' *.fastq > count/B18088_Fm0.txt
agrep -0 -c 'CGGCACTTTGTTGGTGA' *.fastq > count/B18089_Fm0.txt
agrep -0 -c 'ATGGCCCTTAAGTATCC' *.fastq > count/B18090_Fm0.txt
agrep -0 -c 'GCCCCAAATAGCACACT' *.fastq > count/B18091_Fm0.txt
agrep -0 -c 'CGTCTTCTGATTAGCCT' *.fastq > count/B18092_Fm0.txt
agrep -0 -c 'CAAGGATACACAAATGC' *.fastq > count/B18093_Fm0.txt
agrep -0 -c 'TGTATAAGACACCAGCA' *.fastq > count/B18094_Fm0.txt
agrep -0 -c 'TACCGTTGGCAACGGTC' *.fastq > count/B18095_Fm0.txt
agrep -0 -c 'ATTAGGTTTTAAGGCGG' *.fastq > count/B18096_Fm0.txt
agrep -0 -c 'GCTAAGGCACGGCTTGT' *.fastq > count/B18097_Fm0.txt
agrep -0 -c 'CTAAAGGGGCGTGCGTT' *.fastq > count/B18098_Fm0.txt
agrep -0 -c 'ACTACCGGCATCAAGAG' *.fastq > count/B18099_Fm0.txt
agrep -0 -c 'AGGTTACGCTGTTGAGA' *.fastq > count/B18101_Fm0.txt
agrep -0 -c 'CTCAAGTACAGTAATCG' *.fastq > count/B18102_Fm0.txt
agrep -0 -c 'GTTTTTAAGACTGCCGG' *.fastq > count/B18103_Fm0.txt
agrep -0 -c 'TCAGGGTATACGAGCGG' *.fastq > count/B18104_Fm0.txt
agrep -0 -c 'AAGGAATAATCGGTAGC' *.fastq > count/B18106_Fm0.txt
agrep -0 -c 'CTCACGATACGGCTCCA' *.fastq > count/B18107_Fm0.txt
agrep -0 -c 'CCAGATTGCGATCGTCT' *.fastq > count/B18108_Fm0.txt
agrep -0 -c 'TACCGCACATAGGCGCT' *.fastq > count/B18110_Fm0.txt
agrep -0 -c 'CATGCCTTCATCATGGC' *.fastq > count/B18111_Fm0.txt
agrep -0 -c 'ATTTAAATCCCCAGCGT' *.fastq > count/B18112_Fm0.txt
agrep -0 -c 'CAGTCTTCGGCCGTATA' *.fastq > count/B18113_Fm0.txt
agrep -0 -c 'GGTCGACTCCGAATTCA' *.fastq > count/B18114_Fm0.txt
agrep -0 -c 'TAGTCGAGACTACGGTT' *.fastq > count/B18115_Fm0.txt
agrep -0 -c 'ACCCATCTAACTGGCTA' *.fastq > count/B18116_Fm0.txt
agrep -0 -c 'ACCCCCAGTGTGTCACT' *.fastq > count/B18117_Fm0.txt
agrep -0 -c 'TGTGGACCAGTCGATAC' *.fastq > count/B18118_Fm0.txt
agrep -0 -c 'GTGCTTCCACGTTAGGG' *.fastq > count/B18119_Fm0.txt
agrep -0 -c 'ATCGACGTCTAGTAGTT' *.fastq > count/B18120_Fm0.txt
agrep -0 -c 'TGCGAGAGCGGTCATAT' *.fastq > count/B18121_Fm0.txt
agrep -0 -c 'GATGGGTATTGAACACC' *.fastq > count/B18123_Fm0.txt
agrep -0 -c 'TAACCGAGCCTAATCAG' *.fastq > count/B18124_Fm0.txt
agrep -0 -c 'CGAAATTCGTGTTCTCC' *.fastq > count/B18125_Fm0.txt
agrep -0 -c 'GGAGCAGCAGTTCATGA' *.fastq > count/B18126_Fm0.txt
agrep -0 -c 'TGGCAAAATGTGTCGAC' *.fastq > count/B18127_Fm0.txt
agrep -0 -c 'TCTTCGTACAAAACGGC' *.fastq > count/B18128_Fm0.txt
agrep -0 -c 'TCGGATGATCTAATCCT' *.fastq > count/B18130_Fm0.txt
agrep -0 -c 'GCGGTCCATTCCTAGGA' *.fastq > count/B18131_Fm0.txt
agrep -0 -c 'GTGTGAAGGCTCGAACC' *.fastq > count/B18132_Fm0.txt
agrep -0 -c 'AGCGAGTGAGAACCGGT' *.fastq > count/B18133_Fm0.txt
agrep -0 -c 'GTGGTGCCTGTTTGGAT' *.fastq > count/B18134_Fm0.txt
agrep -0 -c 'CCGGTATGAATACGCAA' *.fastq > count/B18135_Fm0.txt
agrep -0 -c 'GAGCGGTTGGGATGTGT' *.fastq > count/B18136_Fm0.txt
agrep -0 -c 'CCAATCAGGCAGATGGT' *.fastq > count/B18137_Fm0.txt
agrep -0 -c 'TCGGCTGTCCACTCTTG' *.fastq > count/B18138_Fm0.txt
agrep -0 -c 'TAGTCTTAAGTACCGGG' *.fastq > count/B18140_Fm0.txt
agrep -0 -c 'CAGTGCTTTAGGACTTC' *.fastq > count/B18141_Fm0.txt
agrep -0 -c 'AGATTCGCCTAAATCAG' *.fastq > count/B18142_Fm0.txt
agrep -0 -c 'AATAGCTTGGTGCGGAC' *.fastq > count/B18143_Fm0.txt
agrep -0 -c 'CTAAATGGCTGGAGGTT' *.fastq > count/B18144_Fm0.txt
agrep -0 -c 'TAACTGTAGCTCGATGG' *.fastq > count/B18145_Fm0.txt
agrep -0 -c 'AGGGCACTCTTATGACT' *.fastq > count/B18146_Fm0.txt
agrep -0 -c 'ACAAGAGCGATGATTCT' *.fastq > count/B18148_Fm0.txt
agrep -0 -c 'GTCTTACGGGTTGATTA' *.fastq > count/B18149_Fm0.txt
agrep -0 -c 'GAGTCCTCACACGCGAT' *.fastq > count/B18150_Fm0.txt
agrep -0 -c 'GTTAAGCCATAACGGCG' *.fastq > count/B18151_Fm0.txt
agrep -0 -c 'ATAATGTAACGGCCCAA' *.fastq > count/B18152_Fm0.txt
agrep -0 -c 'CTTACCGACCCGAGTTG' *.fastq > count/B18153_Fm0.txt
agrep -0 -c 'TTGTGCACTCATTCTAC' *.fastq > count/B18156_Fm0.txt
agrep -0 -c 'GACTAACCGGGTAAAAA' *.fastq > count/B18157_Fm0.txt
agrep -0 -c 'GTCAAAACGCCACCATT' *.fastq > count/B18158_Fm0.txt
agrep -0 -c 'GAGTAGTTTACTCGTCT' *.fastq > count/B18159_Fm0.txt
agrep -0 -c 'AGCCCGTAGTATCTCTA' *.fastq > count/B18160_Fm0.txt
agrep -0 -c 'TACGCGATGGCTCGTAA' *.fastq > count/B18161_Fm0.txt
agrep -0 -c 'TAGGGGCAGCACTATGA' *.fastq > count/B18163_Fm0.txt
agrep -0 -c 'GGTCACATAATACCGGA' *.fastq > count/B18168_Fm0.txt
agrep -0 -c 'CTAGTTGGGCTAGACGG' *.fastq > count/B18171_Fm0.txt
agrep -0 -c 'CATATCCCGAGTTGCAG' *.fastq > count/B18172_Fm0.txt
agrep -0 -c 'ACTGAAACCAATTGCAG' *.fastq > count/B18173_Fm0.txt
agrep -0 -c 'TAAGTCCGAGTAGGGGC' *.fastq > count/B18174_Fm0.txt
agrep -0 -c 'GTGATCAAAGTGTCAAG' *.fastq > count/B18175_Fm0.txt
agrep -0 -c 'CCTTTAAAGCGTGGCTG' *.fastq > count/B18176_Fm0.txt
agrep -0 -c 'ATAACAGCTGGAGAGCA' *.fastq > count/B18178_Fm0.txt
agrep -0 -c 'TGCTTCGACCGACCGTA' *.fastq > count/B18181_Fm0.txt
agrep -0 -c 'AGGTCCCCATCCACCAA' *.fastq > count/B18182_Fm0.txt
agrep -0 -c 'GCGATCGTTGCTTTAAA' *.fastq > count/B18183_Fm0.txt
agrep -0 -c 'GTTGCTAGGATAAAGAC' *.fastq > count/B18184_Fm0.txt
agrep -0 -c 'GAGAACGACCATGCATC' *.fastq > count/B18185_Fm0.txt
agrep -0 -c 'TGCTATAGGTACAGCAG' *.fastq > count/B18186_Fm0.txt
agrep -0 -c 'TGACTCCCGCGAATCTT' *.fastq > count/B18188_Fm0.txt
agrep -0 -c 'AAGAGTTAACGGGCGTA' *.fastq > count/B18189_Fm0.txt
agrep -0 -c 'TGCTAGAGGTGAATCAA' *.fastq > count/B18190_Fm0.txt
agrep -0 -c 'TAAACCGGTTTTAGGGG' *.fastq > count/B18191_Fm0.txt
agrep -0 -c 'CCAAGTTACTCAGACGT' *.fastq > count/B18192_Fm0.txt
agrep -0 -c 'GCACAGATAGAGGGCAG' *.fastq > count/B18193_Fm0.txt
agrep -0 -c 'TCGATTAGGTAGGGTGT' *.fastq > count/B18194_Fm0.txt
agrep -0 -c 'GAGGACGACCACTTCTC' *.fastq > count/B18195_Fm0.txt
agrep -0 -c 'CCACAATCGTTATTCGC' *.fastq > count/B18196_Fm0.txt
agrep -0 -c 'CAATGAGACCGATCAAG' *.fastq > count/B18197_Fm0.txt
agrep -0 -c 'GGTCTGTTTAGATTGGG' *.fastq > count/B18198_Fm0.txt
agrep -0 -c 'CTGGTAATATAGTACGC' *.fastq > count/B18199_Fm0.txt
agrep -0 -c 'AACTACGAGGTTGTAGC' *.fastq > count/B18200_Fm0.txt
agrep -0 -c 'GGTACTGCTGAGTAGGG' *.fastq > count/B18201_Fm0.txt
agrep -0 -c 'CGATAAGCAACCATCCG' *.fastq > count/B18202_Fm0.txt
agrep -0 -c 'AGTTAGTGACCATACGA' *.fastq > count/B18205_Fm0.txt
agrep -0 -c 'GTAATGCGCGGCAGATC' *.fastq > count/B18206_Fm0.txt
agrep -0 -c 'GACGAGCATGCAGACCA' *.fastq > count/B18207_Fm0.txt
agrep -0 -c 'TTCTAAGTCTCGAATGG' *.fastq > count/B18208_Fm0.txt
agrep -0 -c 'TTGCCGGACTGCGGTAA' *.fastq > count/B18209_Fm0.txt
agrep -0 -c 'TAAGTCAGCACCAAGCA' *.fastq > count/B18210_Fm0.txt
agrep -0 -c 'TGTATCACAGACTCGCA' *.fastq > count/B18211_Fm0.txt
agrep -0 -c 'ACGGACCTATGTGCAGT' *.fastq > count/B18213_Fm0.txt
agrep -0 -c 'TAGATGCCTTCCGCTAG' *.fastq > count/B18217_Fm0.txt
agrep -0 -c 'TAAGTGAATCTGCTCTG' *.fastq > count/B18218_Fm0.txt
agrep -0 -c 'TGAAAAAAGCAGCGGAT' *.fastq > count/B18219_Fm0.txt
agrep -0 -c 'TAGAATGCGAGGGGTTA' *.fastq > count/B18220_Fm0.txt
agrep -0 -c 'AATTTGCAGTCAGCGTC' *.fastq > count/B18221_Fm0.txt
agrep -0 -c 'GAGGGCATGGGTGTTAC' *.fastq > count/B18222_Fm0.txt
agrep -0 -c 'TTAAGGATCCTGTTCGT' *.fastq > count/B18224_Fm0.txt
agrep -0 -c 'ATGACCGATCTGGAAAC' *.fastq > count/B18226_Fm0.txt
agrep -0 -c 'GGAAGCATCCCCCACTT' *.fastq > count/B18227_Fm0.txt
agrep -0 -c 'ACAATCCCAATCACGAC' *.fastq > count/B18228_Fm0.txt
agrep -0 -c 'GACGAACCATTTAGAAC' *.fastq > count/B18229_Fm0.txt
agrep -0 -c 'ACGCTTTGATGACGCAG' *.fastq > count/B18230_Fm0.txt
agrep -0 -c 'GTCGACGTTTATGACTA' *.fastq > count/B18231_Fm0.txt
agrep -0 -c 'AGACTCGATGTTCGAAA' *.fastq > count/B18232_Fm0.txt
agrep -0 -c 'ACTGCTTTGCGTGTGCT' *.fastq > count/B18234_Fm0.txt
agrep -0 -c 'CGCTGAATTCTTGATGC' *.fastq > count/B18235_Fm0.txt
agrep -0 -c 'ATCGTATTGTGTGCAGT' *.fastq > count/B18236_Fm0.txt
agrep -0 -c 'TACTGCGTCCAGGCTTT' *.fastq > count/B18237_Fm0.txt
agrep -0 -c 'AGTAGCACAGTTAAAGG' *.fastq > count/B18238_Fm0.txt
agrep -0 -c 'GGTATTCGCCGTTCCTC' *.fastq > count/B18239_Fm0.txt
agrep -0 -c 'CGCTACATCGGTAGTTT' *.fastq > count/B18240_Fm0.txt
agrep -0 -c 'GTTCCTACTTACAGCCG' *.fastq > count/B18241_Fm0.txt
agrep -0 -c 'AACGGTCAGATTAGAGG' *.fastq > count/B18242_Fm0.txt
agrep -0 -c 'GTCCGTTACAGCCGTGA' *.fastq > count/B4_Rm0.txt
agrep -0 -c 'CCGGTATAGCGAACTCG' *.fastq > count/B5_Rm0.txt
agrep -0 -c 'ATTTCGGACCTCGTGTA' *.fastq > count/B7_Rm0.txt
agrep -0 -c 'CTCTGGGGTATGTATAG' *.fastq > count/B10_Rm0.txt
agrep -0 -c 'GATCACACTATTGGTGT' *.fastq > count/B11_Rm0.txt
agrep -0 -c 'AGGTGTGCAGCAGCCAT' *.fastq > count/B14_Rm0.txt
agrep -0 -c 'GATATCATTCGGGACTT' *.fastq > count/B15_Rm0.txt
agrep -0 -c 'ACGGCCTCATAGACACG' *.fastq > count/B16_Rm0.txt
agrep -0 -c 'GAAGAGCGCGTGGAATC' *.fastq > count/B17_Rm0.txt
agrep -0 -c 'CTAGAATGCTGGGACCT' *.fastq > count/B18_Rm0.txt
agrep -0 -c 'TTGGGTACGTATCATAC' *.fastq > count/B19_Rm0.txt
agrep -0 -c 'TAACTTAACCTTGCGCA' *.fastq > count/B21_Rm0.txt
agrep -0 -c 'CGTCGAGAAAGTGGATA' *.fastq > count/B22_Rm0.txt
agrep -0 -c 'CTTTATTTAAGGGGCGG' *.fastq > count/B23_Rm0.txt
agrep -0 -c 'CCGACATGGATCTAAGC' *.fastq > count/B24_Rm0.txt
agrep -0 -c 'ACTACAACCCTGACTTG' *.fastq > count/B25_Rm0.txt
agrep -0 -c 'TCAGATTGTGAGTGGAC' *.fastq > count/B26_Rm0.txt
agrep -0 -c 'GCGCACTTAAGACAACG' *.fastq > count/B27_Rm0.txt
agrep -0 -c 'AGCCTATAGTAATCCTG' *.fastq > count/B29_Rm0.txt
agrep -0 -c 'TTGCCAGCACAAGTACT' *.fastq > count/B30_Rm0.txt
agrep -0 -c 'GCAAACCGTTACAAACA' *.fastq > count/B33_Rm0.txt
agrep -0 -c 'GGGTGCCATGCATATGT' *.fastq > count/B34_Rm0.txt
agrep -0 -c 'GACCTACTGCCGCAGAT' *.fastq > count/B35_Rm0.txt
agrep -0 -c 'AATACCTGCCACGTGTC' *.fastq > count/B36_Rm0.txt
agrep -0 -c 'ACCTAACGTACGGTCGA' *.fastq > count/B37_Rm0.txt
agrep -0 -c 'CCGTCTATCTCATATAC' *.fastq > count/B39_Rm0.txt
agrep -0 -c 'TCACGCGGTAAAAGTCA' *.fastq > count/B40_Rm0.txt
agrep -0 -c 'ATTCGGCGGGAGTATTG' *.fastq > count/B42_Rm0.txt
agrep -0 -c 'ACTAGAGCATAGAGATC' *.fastq > count/B44_Rm0.txt
agrep -0 -c 'TCAGGCTGGGTACTATG' *.fastq > count/B45_Rm0.txt
agrep -0 -c 'CTAGCCGTCTAGGTGTA' *.fastq > count/B46_Rm0.txt
agrep -0 -c 'TTCCGATACGATACTAC' *.fastq > count/B48_Rm0.txt
agrep -0 -c 'TGGCTATCCGGTCGCAA' *.fastq > count/B49_Rm0.txt
agrep -0 -c 'GTGGCAGTGCCCGATTA' *.fastq > count/B50_Rm0.txt
agrep -0 -c 'TACGAATAGCGTGAGTG' *.fastq > count/B51_Rm0.txt
agrep -0 -c 'TTAGACACCCGGCGGTA' *.fastq > count/B52_Rm0.txt
agrep -0 -c 'TGACGCTAATATCCAAG' *.fastq > count/B53_Rm0.txt
agrep -0 -c 'CAATGTATCGACGTTTG' *.fastq > count/B54_Rm0.txt
agrep -0 -c 'TTGTACGCTTGTCCTTA' *.fastq > count/B55_Rm0.txt
agrep -0 -c 'GCGTGAGCATTCGATCT' *.fastq > count/B56_Rm0.txt
agrep -0 -c 'TGTGTGTTCGAACGCTG' *.fastq > count/B57_Rm0.txt
agrep -0 -c 'TCTGGTTTGCCCGTCTA' *.fastq > count/B58_Rm0.txt
agrep -0 -c 'GCGATGGTGCCGCTATA' *.fastq > count/B60_Rm0.txt
agrep -0 -c 'AGGTCCTGTCATTATGA' *.fastq > count/B61_Rm0.txt
agrep -0 -c 'CCTGTAGAATTGTGCGG' *.fastq > count/B62_Rm0.txt
agrep -0 -c 'CCAAACCGCCCTTAGAG' *.fastq > count/B63_Rm0.txt
agrep -0 -c 'CTCGTTAATCTCCTCTT' *.fastq > count/B64_Rm0.txt
agrep -0 -c 'GGGAACTAAGGATTTCG' *.fastq > count/B65_Rm0.txt
agrep -0 -c 'CGAGTGGGTTTATGGTC' *.fastq > count/B66_Rm0.txt
agrep -0 -c 'TATGCTTGACAACTACC' *.fastq > count/B67_Rm0.txt
agrep -0 -c 'GTCGACTGAATACGTCC' *.fastq > count/B68_Rm0.txt
agrep -0 -c 'ACCGGGAGAGTAAGGAG' *.fastq > count/B69_Rm0.txt
agrep -0 -c 'GCGAATAGGGAATTGAA' *.fastq > count/B71_Rm0.txt
agrep -0 -c 'GTTGTGGGAACAGTCAG' *.fastq > count/B72_Rm0.txt
agrep -0 -c 'GGTACTACGCTGTGATC' *.fastq > count/B73_Rm0.txt
agrep -0 -c 'TCCGCTCATACAACACA' *.fastq > count/B75_Rm0.txt
agrep -0 -c 'ATAATATTTGCCGCTCG' *.fastq > count/B76_Rm0.txt
agrep -0 -c 'AGTCCTCTCTTCGCGGT' *.fastq > count/B77_Rm0.txt
agrep -0 -c 'GACTTTACGCCCTGTGA' *.fastq > count/B78_Rm0.txt
agrep -0 -c 'GTTTGGGAAACTAAGGT' *.fastq > count/B79_Rm0.txt
agrep -0 -c 'GGGAACAAATCCCCGTA' *.fastq > count/B80_Rm0.txt
agrep -0 -c 'CTTGACGCGAAAGACCG' *.fastq > count/B81_Rm0.txt
agrep -0 -c 'AAGGCTAACTACATGGC' *.fastq > count/B82_Rm0.txt
agrep -0 -c 'TGAGGTTCGAGGCTGTC' *.fastq > count/B83_Rm0.txt
agrep -0 -c 'GTTTGCAGCCAGATCAA' *.fastq > count/B84_Rm0.txt
agrep -0 -c 'CCATCAAAGGTAGACCT' *.fastq > count/B85_Rm0.txt
agrep -0 -c 'GTTGTCAACTGATATCC' *.fastq > count/B87_Rm0.txt
agrep -0 -c 'AACTGGTTGCGAAGTTG' *.fastq > count/B88_Rm0.txt
agrep -0 -c 'TAAGGCACGCTACGGTG' *.fastq > count/B89_Rm0.txt
agrep -0 -c 'CTCCGGGTGGAAAAGAA' *.fastq > count/B90_Rm0.txt
agrep -0 -c 'TAACCAATGTGAAAGCC' *.fastq > count/B91_Rm0.txt
agrep -0 -c 'ACTCTGCCACTTTTACC' *.fastq > count/B92_Rm0.txt
agrep -0 -c 'GCCAGTAATGTGTCGTG' *.fastq > count/B93_Rm0.txt
agrep -0 -c 'ATGTAGGGTGTACTTGT' *.fastq > count/B94_Rm0.txt
agrep -0 -c 'TCCCCACGACACTACAA' *.fastq > count/B95_Rm0.txt
agrep -0 -c 'TGTAGATAGGCGTACTT' *.fastq > count/B96_Rm0.txt
agrep -0 -c 'AATCTGTCCCGGCCAAG' *.fastq > count/B97_Rm0.txt
agrep -0 -c 'TGTAAGCTCAGGGCTGG' *.fastq > count/B98_Rm0.txt
agrep -0 -c 'TGAGCTTTGCGAAGACT' *.fastq > count/B99_Rm0.txt
agrep -0 -c 'GTAAAATATGGCCCGCT' *.fastq > count/B100_Rm0.txt
agrep -0 -c 'TGACGGAACCAGCCTTA' *.fastq > count/B103_Rm0.txt
agrep -0 -c 'GGGGGACGGAAGATAGT' *.fastq > count/B104_Rm0.txt
agrep -0 -c 'GCCAACTGCGAATTCTC' *.fastq > count/B105_Rm0.txt
agrep -0 -c 'GGTAATCGATTTGCTGT' *.fastq > count/B106_Rm0.txt
agrep -0 -c 'CATCAGCTATTGGTGTA' *.fastq > count/B107_Rm0.txt
agrep -0 -c 'CTCGTGAGACTTGGAAT' *.fastq > count/B108_Rm0.txt
agrep -0 -c 'GCTCACAACAGCGGATG' *.fastq > count/B109_Rm0.txt
agrep -0 -c 'GATCAGACCATGCGCTC' *.fastq > count/B110_Rm0.txt
agrep -0 -c 'ATAAGAACGAGGTCCCG' *.fastq > count/B112_Rm0.txt
agrep -0 -c 'TACAGAAACCCGTCGAC' *.fastq > count/B113_Rm0.txt
agrep -0 -c 'GAGCGGGGTTCATTCAA' *.fastq > count/B114_Rm0.txt
agrep -0 -c 'TTGCGTACGTCCCATGA' *.fastq > count/B115_Rm0.txt
agrep -0 -c 'TCAAGGCCGATTCTTAT' *.fastq > count/B116_Rm0.txt
agrep -0 -c 'CACACTGTATCGTCTCG' *.fastq > count/B117_Rm0.txt
agrep -0 -c 'TTGACTCTCTAGTTTGC' *.fastq > count/B118_Rm0.txt
agrep -0 -c 'TTGACTCGTCCGAAGTC' *.fastq > count/B120_Rm0.txt
agrep -0 -c 'AATATTGAGGCTGTGTC' *.fastq > count/B121_Rm0.txt
agrep -0 -c 'CAAAACCGAAACCCACG' *.fastq > count/B122_Rm0.txt
agrep -0 -c 'CATTGATCGACGGGTCT' *.fastq > count/B123_Rm0.txt
agrep -0 -c 'TCCGGATACTTCCTGAC' *.fastq > count/B124_Rm0.txt
agrep -0 -c 'CCTTTGCGAGCCTACAT' *.fastq > count/B125_Rm0.txt
agrep -0 -c 'GCATTTTTAGCCACCGC' *.fastq > count/B126_Rm0.txt
agrep -0 -c 'TACAAGTTTGGTACACC' *.fastq > count/B128_Rm0.txt
agrep -0 -c 'GTGAAAATCCACCAGGC' *.fastq > count/B129_Rm0.txt
agrep -0 -c 'CGTGTGATTCTTCCTAT' *.fastq > count/B131_Rm0.txt
agrep -0 -c 'CGAATACCGAGATATGT' *.fastq > count/B5446_Rm0.txt
agrep -0 -c 'GTTCCCTCGGTTATACT' *.fastq > count/B8570_Rm0.txt
agrep -0 -c 'GCACTGGAGTAGTTCGC' *.fastq > count/B269_Rm0.txt
agrep -0 -c 'CTAAGTAGTCGTAGCTT' *.fastq > count/B1313_Rm0.txt
agrep -0 -c 'CGGTCTACGTAATCCAC' *.fastq > count/B160_Rm0.txt
agrep -0 -c 'CAATTAACTGTGGTGAC' *.fastq > count/B167_Rm0.txt
agrep -0 -c 'TTGCAGTGTCCAGATGA' *.fastq > count/B259_Rm0.txt
agrep -0 -c 'CGAATATGTGCACCGGC' *.fastq > count/B305_Rm0.txt
agrep -0 -c 'TTCCTGTCGTATAGGAT' *.fastq > count/B306_Rm0.txt
agrep -0 -c 'GACAAGCGATTTATGAC' *.fastq > count/B374_Rm0.txt
agrep -0 -c 'GTGACAACGATGGTCGG' *.fastq > count/B4161_Rm0.txt
agrep -0 -c 'ATAGGAAGTGCCCGTAA' *.fastq > count/B5277_Rm0.txt
agrep -0 -c 'ACAATGACCAGATGGAC' *.fastq > count/B5328_Rm0.txt
agrep -0 -c 'CAGGAGCCTTCATACTG' *.fastq > count/B5744_Rm0.txt
agrep -0 -c 'AATGCGGGACGTACGAG' *.fastq > count/B7238_Rm0.txt
agrep -0 -c 'TCAAAACGGGGAGTATG' *.fastq > count/B7310_Rm0.txt
agrep -0 -c 'ATACCGTTCGAGCAGGT' *.fastq > count/B8804_Rm0.txt
agrep -0 -c 'GCATCAGTCTCTTCTTA' *.fastq > count/B8863_Rm0.txt
agrep -0 -c 'ACACAATACGTCCATGG' *.fastq > count/B9338_Rm0.txt
agrep -0 -c 'TAACGTGAGTGGGATAG' *.fastq > count/B9783_Rm0.txt
agrep -0 -c 'CGTATGAGAAGACCTGC' *.fastq > count/B9788_Rm0.txt
agrep -0 -c 'ACGCTCACTCCGTTAGC' *.fastq > count/B1058_Rm0.txt
agrep -0 -c 'ACAAGCAGATTTCTGCC' *.fastq > count/B1065_Rm0.txt
agrep -0 -c 'AGTTAGATACGCGGGCC' *.fastq > count/B132_Rm0.txt
agrep -0 -c 'TGTCTCGCGCTAAGCCA' *.fastq > count/B133_Rm0.txt
agrep -0 -c 'CCTCGTTGCCTAGTATT' *.fastq > count/B134_Rm0.txt
agrep -0 -c 'GCGTAGATGTGAAACAC' *.fastq > count/B137_Rm0.txt
agrep -0 -c 'ACCCGCATTGAGACTGC' *.fastq > count/B139_Rm0.txt
agrep -0 -c 'TCTCCTTTCCGCTGGTA' *.fastq > count/B141_Rm0.txt
agrep -0 -c 'CCGACTACGCATCTGTA' *.fastq > count/B142_Rm0.txt
agrep -0 -c 'CGAGCAGACATATTGGT' *.fastq > count/B144_Rm0.txt
agrep -0 -c 'AAGATCGACCACCGATT' *.fastq > count/B146_Rm0.txt
agrep -0 -c 'GCCCTGCTCGATATTCT' *.fastq > count/B148_Rm0.txt
agrep -0 -c 'CGTCTGGAGCGAACTAC' *.fastq > count/B149_Rm0.txt
agrep -0 -c 'TAGACCCCGAAGGTCAT' *.fastq > count/B150_Rm0.txt
agrep -0 -c 'TCGTTGACATATTCGAC' *.fastq > count/B151_Rm0.txt
agrep -0 -c 'TCGTAGCTCCATAATGT' *.fastq > count/B152_Rm0.txt
agrep -0 -c 'TTGCGTCGTAGTCGGAG' *.fastq > count/B153_Rm0.txt
agrep -0 -c 'CAGGCTATGTGTAAACC' *.fastq > count/B155_Rm0.txt
agrep -0 -c 'AATCCACAGGGTAGGGC' *.fastq > count/B156_Rm0.txt
agrep -0 -c 'TATTTGCCGTACCTACC' *.fastq > count/B159_Rm0.txt
agrep -0 -c 'GTCGGGTATGGACTTTG' *.fastq > count/B161_Rm0.txt
agrep -0 -c 'AGGAACGACGACCAAAC' *.fastq > count/B162_Rm0.txt
agrep -0 -c 'GGCGTCCAAGTTTCTCG' *.fastq > count/B163_Rm0.txt
agrep -0 -c 'AGGAGATAGTACCTACA' *.fastq > count/B164_Rm0.txt
agrep -0 -c 'AACCGTCATGTGTGACC' *.fastq > count/B165_Rm0.txt
agrep -0 -c 'TGTCTAGTTTTACGACG' *.fastq > count/B166_Rm0.txt
agrep -0 -c 'CTCTGAATTCTTGCATG' *.fastq > count/B168_Rm0.txt
agrep -0 -c 'AAAGCTCGGGGATATTA' *.fastq > count/B169_Rm0.txt
agrep -0 -c 'GATTGTCCAGTGCTTCG' *.fastq > count/B170_Rm0.txt
agrep -0 -c 'AACGTGTTCGATGCTAA' *.fastq > count/B171_Rm0.txt
agrep -0 -c 'TGCATGAAGTCGCTCGA' *.fastq > count/B172_Rm0.txt
agrep -0 -c 'GAATGGCCAAAGGCCAA' *.fastq > count/B173_Rm0.txt
agrep -0 -c 'GAACACATCACTCGCGT' *.fastq > count/B174_Rm0.txt
agrep -0 -c 'TGAATTCTGAGCTCACT' *.fastq > count/B175_Rm0.txt
agrep -0 -c 'GGGACCGGTTTAAGAAC' *.fastq > count/B176_Rm0.txt
agrep -0 -c 'AAGAGTGCTTCGGGATG' *.fastq > count/B177_Rm0.txt
agrep -0 -c 'TTCGAAGTTTGGGTCAA' *.fastq > count/B179_Rm0.txt
agrep -0 -c 'TGTCGTGTTTCATCAGA' *.fastq > count/B180_Rm0.txt
agrep -0 -c 'ATCCCTACATGTACTGC' *.fastq > count/B183_Rm0.txt
agrep -0 -c 'TAAGTGGCCTAATCCGT' *.fastq > count/B184_Rm0.txt
agrep -0 -c 'GAACGTGAAGGTTTAAC' *.fastq > count/B185_Rm0.txt
agrep -0 -c 'CAAAGAGCTTTACGGTA' *.fastq > count/B186_Rm0.txt
agrep -0 -c 'AGGTTGTGTTCCGGCCA' *.fastq > count/B187_Rm0.txt
agrep -0 -c 'ATCTAGGTTGCTGGGGC' *.fastq > count/B188_Rm0.txt
agrep -0 -c 'GATCCGCTACTGCATAC' *.fastq > count/B189_Rm0.txt
agrep -0 -c 'GAGACTTCGTTGTACAC' *.fastq > count/B190_Rm0.txt
agrep -0 -c 'TTTCGAATCAGAGTCCC' *.fastq > count/B191_Rm0.txt
agrep -0 -c 'CAGTCGACCCCAGTGTT' *.fastq > count/B192_Rm0.txt
agrep -0 -c 'CAGTGTTTTCGTTATGG' *.fastq > count/B194_Rm0.txt
agrep -0 -c 'AACGACCAGTCTTACGA' *.fastq > count/B195_Rm0.txt
agrep -0 -c 'TTTCTAAGCCGCACCAT' *.fastq > count/B196_Rm0.txt
agrep -0 -c 'GGTGTTAGTGGGTTTGA' *.fastq > count/B197_Rm0.txt
agrep -0 -c 'GCGAGGGCATTTGTGTT' *.fastq > count/B198_Rm0.txt
agrep -0 -c 'AAGTGATTGAGCCACAT' *.fastq > count/B199_Rm0.txt
agrep -0 -c 'ATGTTGCACGTCCTGCA' *.fastq > count/B200_Rm0.txt
agrep -0 -c 'AATCAGCTTGTTGCGTA' *.fastq > count/B201_Rm0.txt
agrep -0 -c 'ACTTCCACGTTTGCCCT' *.fastq > count/B202_Rm0.txt
agrep -0 -c 'GCGGGTACGACGTTGTT' *.fastq > count/B205_Rm0.txt
agrep -0 -c 'GACTGGTACTGGTGAAC' *.fastq > count/B206_Rm0.txt
agrep -0 -c 'AAATGGTGAGCCCGCGA' *.fastq > count/B207_Rm0.txt
agrep -0 -c 'GGTCATTTTACTACGAC' *.fastq > count/B208_Rm0.txt
agrep -0 -c 'GGTACACGACTCTTGTG' *.fastq > count/B209_Rm0.txt
agrep -0 -c 'CGCAACGTGTAGAGGCT' *.fastq > count/B210_Rm0.txt
agrep -0 -c 'TTTACCCGTGGTGTAGA' *.fastq > count/B211_Rm0.txt
agrep -0 -c 'TCAACGAATGCTTGCTT' *.fastq > count/B213_Rm0.txt
agrep -0 -c 'GCGTGTCCTATGGAGTT' *.fastq > count/B214_Rm0.txt
agrep -0 -c 'TATGTGTCGTGTCTTGT' *.fastq > count/B215_Rm0.txt
agrep -0 -c 'GTGTTCGGTACTAACGC' *.fastq > count/B216_Rm0.txt
agrep -0 -c 'TTTGTGCCAAAGGAGCT' *.fastq > count/B217_Rm0.txt
agrep -0 -c 'TGTTTTCGCTCGTAGTG' *.fastq > count/B219_Rm0.txt
agrep -0 -c 'GACCAAATCTTCAGCAA' *.fastq > count/B220_Rm0.txt
agrep -0 -c 'AAAGGGGGGTCTCTTAT' *.fastq > count/B221_Rm0.txt
agrep -0 -c 'TCGGGCAAAGTTATGAG' *.fastq > count/B222_Rm0.txt
agrep -0 -c 'TAACACTACGGCTGTTA' *.fastq > count/B223_Rm0.txt
agrep -0 -c 'GATCTGCCAGCACGTCT' *.fastq > count/B224_Rm0.txt
agrep -0 -c 'AGAGTCCTAACACCAAC' *.fastq > count/B225_Rm0.txt
agrep -0 -c 'AGTCATTGGGATAAGCG' *.fastq > count/B226_Rm0.txt
agrep -0 -c 'GGTGTTCCCCCAGATGA' *.fastq > count/B227_Rm0.txt
agrep -0 -c 'TCCAGATATCCGATTCG' *.fastq > count/B228_Rm0.txt
agrep -0 -c 'TCGGGTACTAGAGGAGG' *.fastq > count/B229_Rm0.txt
agrep -0 -c 'ATCGCCTGGTAACTGTA' *.fastq > count/B230_Rm0.txt
agrep -0 -c 'ATGGTTCTATGGGCCAG' *.fastq > count/B231_Rm0.txt
agrep -0 -c 'TGGTAAAAGTAAAGCCG' *.fastq > count/B233_Rm0.txt
agrep -0 -c 'AAGTGAATGCGACATTG' *.fastq > count/B234_Rm0.txt
agrep -0 -c 'GCCTGATATACGTTGAC' *.fastq > count/B235_Rm0.txt
agrep -0 -c 'GATTTGGAGTTAGCGAC' *.fastq > count/B236_Rm0.txt
agrep -0 -c 'CTGCATGTTAAACCACC' *.fastq > count/B238_Rm0.txt
agrep -0 -c 'TGTTCGCCTATGTTTCA' *.fastq > count/B239_Rm0.txt
agrep -0 -c 'CGTTCGATAGAGGATAA' *.fastq > count/B240_Rm0.txt
agrep -0 -c 'GTTGCTGGACACTGATA' *.fastq > count/B241_Rm0.txt
agrep -0 -c 'GGGCAGATGTCGACGAA' *.fastq > count/B242_Rm0.txt
agrep -0 -c 'GTTCGTCAAGTGGCTCC' *.fastq > count/B243_Rm0.txt
agrep -0 -c 'GATGGCAGCAATGCTTA' *.fastq > count/B244_Rm0.txt
agrep -0 -c 'ATTAGAGGGAACTAAGC' *.fastq > count/B245_Rm0.txt
agrep -0 -c 'AGATACACAGAACCACG' *.fastq > count/B247_Rm0.txt
agrep -0 -c 'TCACGCCAACGCAACAC' *.fastq > count/B248_Rm0.txt
agrep -0 -c 'CGGTTACGCGCAACCTT' *.fastq > count/B249_Rm0.txt
agrep -0 -c 'TTACTAAAGTGGAACGC' *.fastq > count/B251_Rm0.txt
agrep -0 -c 'GTTCGTACCCTTTCATG' *.fastq > count/B252_Rm0.txt
agrep -0 -c 'ATACCCCCGACCTCACA' *.fastq > count/B253_Rm0.txt
agrep -0 -c 'TGCGGTGACTTAAACTT' *.fastq > count/B254_Rm0.txt
agrep -0 -c 'TAAGCATCTGTCGGGAG' *.fastq > count/B255_Rm0.txt
agrep -0 -c 'AATCGTGGTTACGATCA' *.fastq > count/B257_Rm0.txt
agrep -0 -c 'GTCATCACGACACTCCC' *.fastq > count/B258_Rm0.txt
agrep -0 -c 'TCGGACTTCGCAGATAT' *.fastq > count/B260_Rm0.txt
agrep -0 -c 'ATTTCATCTGTGACCGG' *.fastq > count/B261_Rm0.txt
agrep -0 -c 'TTTCCGTGGGTCATTCG' *.fastq > count/B262_Rm0.txt
agrep -0 -c 'TCAAACGGGGTTAAGAC' *.fastq > count/B263_Rm0.txt
agrep -0 -c 'GTATGGGGTGACCTGAT' *.fastq > count/B264_Rm0.txt
agrep -0 -c 'TACACCTGACAGCTCTC' *.fastq > count/B267_Rm0.txt
agrep -0 -c 'CTGACAGTAACCCTTAC' *.fastq > count/B268_Rm0.txt
agrep -0 -c 'TACCAATCCGATGGACA' *.fastq > count/B270_Rm0.txt
agrep -0 -c 'TTGGTTTGCCGGTTCTG' *.fastq > count/B271_Rm0.txt
agrep -0 -c 'CCAATGTATGTGCTCCC' *.fastq > count/B273_Rm0.txt
agrep -0 -c 'GCACAGACCAAACTTCC' *.fastq > count/B274_Rm0.txt
agrep -0 -c 'ACTGGGCGTTTCGAGCT' *.fastq > count/B276_Rm0.txt
agrep -0 -c 'CACTCGCTACCACTTGG' *.fastq > count/B277_Rm0.txt
agrep -0 -c 'TCTGTGGAAACTTACGC' *.fastq > count/B278_Rm0.txt
agrep -0 -c 'CCATCCGGATAAGAGTC' *.fastq > count/B279_Rm0.txt
agrep -0 -c 'GACATCCACGTGGTAAT' *.fastq > count/B281_Rm0.txt
agrep -0 -c 'ACACTATCCCATCCACG' *.fastq > count/B282_Rm0.txt
agrep -0 -c 'ACACGCCACCTGTGTAT' *.fastq > count/B283_Rm0.txt
agrep -0 -c 'GCCCGGTCTTCACCTAT' *.fastq > count/B284_Rm0.txt
agrep -0 -c 'GTACACAAACCGTTACT' *.fastq > count/B286_Rm0.txt
agrep -0 -c 'GATGACTGACGAGGTCT' *.fastq > count/B288_Rm0.txt
agrep -0 -c 'CTCCAAGTACGCATCTA' *.fastq > count/B289_Rm0.txt
agrep -0 -c 'CTAGGCGGAATTGGGAT' *.fastq > count/B290_Rm0.txt
agrep -0 -c 'TTCATCTGACCCGAGCA' *.fastq > count/B291_Rm0.txt
agrep -0 -c 'TTCCAGCGAAGAAAGCT' *.fastq > count/B293_Rm0.txt
agrep -0 -c 'AACCCCGAGTTGACCCT' *.fastq > count/B294_Rm0.txt
agrep -0 -c 'AGCTAGCCTAAGACCGC' *.fastq > count/B295_Rm0.txt
agrep -0 -c 'TTGAGCTCTTCTTCACA' *.fastq > count/B296_Rm0.txt
agrep -0 -c 'TTATCGAGCCTGATTTG' *.fastq > count/B297_Rm0.txt
agrep -0 -c 'TTTGAGGGACATGGCTG' *.fastq > count/B299_Rm0.txt
agrep -0 -c 'TGGGCATCTACCCGTGT' *.fastq > count/B300_Rm0.txt
agrep -0 -c 'ACTACGAGTCGATTCTT' *.fastq > count/B301_Rm0.txt
agrep -0 -c 'AATCCCACGATGAATAG' *.fastq > count/B302_Rm0.txt
agrep -0 -c 'AGATGACTGATTGCCTA' *.fastq > count/B303_Rm0.txt
agrep -0 -c 'CCCTTAATAGCGTCCGA' *.fastq > count/B304_Rm0.txt
agrep -0 -c 'TGAATCTATCGGTTGCC' *.fastq > count/B307_Rm0.txt
agrep -0 -c 'CCTCCTAACCGTTTGAA' *.fastq > count/B309_Rm0.txt
agrep -0 -c 'GTATACCTACTGAGGGT' *.fastq > count/B311_Rm0.txt
agrep -0 -c 'AAACGATGACCCGATAC' *.fastq > count/B312_Rm0.txt
agrep -0 -c 'CTACGTACTCTCGACGC' *.fastq > count/B313_Rm0.txt
agrep -0 -c 'CTTTATCCCGATTGAGG' *.fastq > count/B314_Rm0.txt
agrep -0 -c 'CGAGCACACTACAGGTA' *.fastq > count/B315_Rm0.txt
agrep -0 -c 'AGAATTCTCTGTCGCGG' *.fastq > count/B316_Rm0.txt
agrep -0 -c 'ATCAGTGCCGTCACCTG' *.fastq > count/B317_Rm0.txt
agrep -0 -c 'TAAGTCACCACAGATGC' *.fastq > count/B318_Rm0.txt
agrep -0 -c 'ATCGGAGCGCAGTGACT' *.fastq > count/B322_Rm0.txt
agrep -0 -c 'GTCGGGCAGCACAAAAC' *.fastq > count/B323_Rm0.txt
agrep -0 -c 'ACCCTACGGCATATGTA' *.fastq > count/B324_Rm0.txt
agrep -0 -c 'TTCCCTTACGACCAACA' *.fastq > count/B325_Rm0.txt
agrep -0 -c 'GCGCCAAAATATGGGTT' *.fastq > count/B327_Rm0.txt
agrep -0 -c 'CTGGAACTACGATCACT' *.fastq > count/B329_Rm0.txt
agrep -0 -c 'ACAATCTGTCTTGTGCT' *.fastq > count/B331_Rm0.txt
agrep -0 -c 'TAGAGCATTCACCACCT' *.fastq > count/B332_Rm0.txt
agrep -0 -c 'TTCGAAGGGTAAGCGGC' *.fastq > count/B333_Rm0.txt
agrep -0 -c 'CCCGGCTTATCCGTGTT' *.fastq > count/B335_Rm0.txt
agrep -0 -c 'CGGTACGCCTTTAGTGA' *.fastq > count/B336_Rm0.txt
agrep -0 -c 'TACTTCCTAGGTCCGCC' *.fastq > count/B337_Rm0.txt
agrep -0 -c 'AGGACTCGTGTCTGTAA' *.fastq > count/B338_Rm0.txt
agrep -0 -c 'GCAGTCCTGGTATACGC' *.fastq > count/B340_Rm0.txt
agrep -0 -c 'CTTGTGGGGCCACTTTA' *.fastq > count/B341_Rm0.txt
agrep -0 -c 'CGGGCAACTTGGGTAGT' *.fastq > count/B342_Rm0.txt
agrep -0 -c 'TGTGCATCAGCACGTAA' *.fastq > count/B344_Rm0.txt
agrep -0 -c 'CCTACCTAGTACGATGC' *.fastq > count/B346_Rm0.txt
agrep -0 -c 'TGGCGCTACCTTTGGAG' *.fastq > count/B347_Rm0.txt
agrep -0 -c 'AGCCGGACCCACGAATT' *.fastq > count/B349_Rm0.txt
agrep -0 -c 'GTCCCTAATTTAGACGC' *.fastq > count/B350_Rm0.txt
agrep -0 -c 'GATGCCTCGTCTACATT' *.fastq > count/B351_Rm0.txt
agrep -0 -c 'GGTAACATGGTGACCTG' *.fastq > count/B353_Rm0.txt
agrep -0 -c 'AGGGCTCCTCTCTAACA' *.fastq > count/B354_Rm0.txt
agrep -0 -c 'CTGCAGCAGAGACTAAC' *.fastq > count/B355_Rm0.txt
agrep -0 -c 'GTGAGTAATCACTCCTT' *.fastq > count/B357_Rm0.txt
agrep -0 -c 'AGATACACGTCCTCTAT' *.fastq > count/B358_Rm0.txt
agrep -0 -c 'GTAAGGAGGACCCGATT' *.fastq > count/B360_Rm0.txt
agrep -0 -c 'ACGCGCTCCAATAGCTT' *.fastq > count/B361_Rm0.txt
agrep -0 -c 'ATTTATGCCGGATGTCA' *.fastq > count/B362_Rm0.txt
agrep -0 -c 'CGTGACTATCAGACTCC' *.fastq > count/B363_Rm0.txt
agrep -0 -c 'GGCCGTTCGTCGTGTAA' *.fastq > count/B364_Rm0.txt
agrep -0 -c 'CTTTAGAATTGGAGGCG' *.fastq > count/B365_Rm0.txt
agrep -0 -c 'GAGCATTTGATTACGCA' *.fastq > count/B366_Rm0.txt
agrep -0 -c 'TACGTGCATCTCGTTCT' *.fastq > count/B367_Rm0.txt
agrep -0 -c 'AGGCCGGAAACATTACA' *.fastq > count/B369_Rm0.txt
agrep -0 -c 'GAGACGCTTCGGCTGTT' *.fastq > count/B370_Rm0.txt
agrep -0 -c 'CCGACATGAGAAGACAT' *.fastq > count/B372_Rm0.txt
agrep -0 -c 'ATTAGACCGTCGTAAGA' *.fastq > count/B375_Rm0.txt
agrep -0 -c 'TAGATGAGGCTTCTGTA' *.fastq > count/B376_Rm0.txt
agrep -0 -c 'ACATAGGAACTCCACCC' *.fastq > count/B377_Rm0.txt
agrep -0 -c 'CAAAGCGAACTTACGCA' *.fastq > count/B378_Rm0.txt
agrep -0 -c 'CAATGATTCGACAACAG' *.fastq > count/B379_Rm0.txt
agrep -0 -c 'GTCCGTTCTATGGTGTT' *.fastq > count/B381_Rm0.txt
agrep -0 -c 'TCGAAAGGCGGTATGCC' *.fastq > count/B382_Rm0.txt
agrep -0 -c 'AGTCGCGGTAATTCCAT' *.fastq > count/B383_Rm0.txt
agrep -0 -c 'GATCTCGTTCTATACGC' *.fastq > count/B384_Rm0.txt
agrep -0 -c 'CATTTGGAGGTAGGCGT' *.fastq > count/B385_Rm0.txt
agrep -0 -c 'GAGCAGCTTGACAGATG' *.fastq > count/B386_Rm0.txt
agrep -0 -c 'ACAGCTAGAGCCAGCTT' *.fastq > count/B387_Rm0.txt
agrep -0 -c 'TGGTTACCTTGGGGTGC' *.fastq > count/B388_Rm0.txt
agrep -0 -c 'AGCGACATCACAACCTC' *.fastq > count/B389_Rm0.txt
agrep -0 -c 'TGTGGGTTAATGAATCG' *.fastq > count/B390_Rm0.txt
agrep -0 -c 'ATCGTCCAGTCTTTCAT' *.fastq > count/B392_Rm0.txt
agrep -0 -c 'GAAAACCTGAATGCGCC' *.fastq > count/B393_Rm0.txt
agrep -0 -c 'TAGTCGGGGCTTAGCGT' *.fastq > count/B394_Rm0.txt
agrep -0 -c 'GCCACTGTACATAGCAC' *.fastq > count/B395_Rm0.txt
agrep -0 -c 'AGTCGAAGCGGGACATA' *.fastq > count/B396_Rm0.txt
agrep -0 -c 'GCCCCAATTAAACTGTC' *.fastq > count/B397_Rm0.txt
agrep -0 -c 'CCTTGGACTTATATAGC' *.fastq > count/B398_Rm0.txt
agrep -0 -c 'GGTCTTTTGTGTACGTC' *.fastq > count/B399_Rm0.txt
agrep -0 -c 'CCGAACTTATTCCATGT' *.fastq > count/B400_Rm0.txt
agrep -0 -c 'GATGATGAGTTCACCGA' *.fastq > count/B401_Rm0.txt
agrep -0 -c 'TTCTCGAGCGACACTCC' *.fastq > count/B402_Rm0.txt
agrep -0 -c 'AACTGCGCTTCTACTAT' *.fastq > count/B403_Rm0.txt
agrep -0 -c 'GATATCGGTGAGAGATG' *.fastq > count/B404_Rm0.txt
agrep -0 -c 'GCCCCCTATGTACCCTA' *.fastq > count/B405_Rm0.txt
agrep -0 -c 'GCGCCCTTCATGACATG' *.fastq > count/B407_Rm0.txt
agrep -0 -c 'TGGCGAAGATATGTCAG' *.fastq > count/B408_Rm0.txt
agrep -0 -c 'ACTCAGCAAGCATTGCC' *.fastq > count/B409_Rm0.txt
agrep -0 -c 'GGCTGTAGGTCTGAAAT' *.fastq > count/B411_Rm0.txt
agrep -0 -c 'TTCATACGCGCTAGCAC' *.fastq > count/B412_Rm0.txt
agrep -0 -c 'TCTGTAGTCAACGGCAG' *.fastq > count/B413_Rm0.txt
agrep -0 -c 'TTGATTATAGGGCGCGT' *.fastq > count/B414_Rm0.txt
agrep -0 -c 'TCGCTGGCGTAGTTATG' *.fastq > count/B416_Rm0.txt
agrep -0 -c 'AGGGGCGAAATAGAGTC' *.fastq > count/B417_Rm0.txt
agrep -0 -c 'CACTCGGTCCTATCTAA' *.fastq > count/B418_Rm0.txt
agrep -0 -c 'GACTCTAACGTTGCGTT' *.fastq > count/B419_Rm0.txt
agrep -0 -c 'GAATATTCGCCACACTG' *.fastq > count/B420_Rm0.txt
agrep -0 -c 'ACCATGACAAGGCTCTC' *.fastq > count/B421_Rm0.txt
agrep -0 -c 'CCTGTCCAACGGATCAT' *.fastq > count/B422_Rm0.txt
agrep -0 -c 'CGATTTTGGGAATTGGC' *.fastq > count/B424_Rm0.txt
agrep -0 -c 'GATGAAGGGACCACTTG' *.fastq > count/B429_Rm0.txt
agrep -0 -c 'CGTATTCTGAGATACTG' *.fastq > count/B430_Rm0.txt
agrep -0 -c 'ACCTGGATTTTCGAGGT' *.fastq > count/B431_Rm0.txt
agrep -0 -c 'GGAAAATCTCCCCCGAC' *.fastq > count/B432_Rm0.txt
agrep -0 -c 'TAGCGAAAATCGTTTGC' *.fastq > count/B433_Rm0.txt
agrep -0 -c 'ACGACACGAAGGATCAT' *.fastq > count/B434_Rm0.txt
agrep -0 -c 'CGAAGCTACTAGTTCGG' *.fastq > count/B435_Rm0.txt
agrep -0 -c 'TGAGAGGCGCACATTCA' *.fastq > count/B436_Rm0.txt
agrep -0 -c 'GCGACAGCATGACCACA' *.fastq > count/B437_Rm0.txt
agrep -0 -c 'ATTGGTACCTTACCGGC' *.fastq > count/B438_Rm0.txt
agrep -0 -c 'GTCGCGAACAATGCTGG' *.fastq > count/B439_Rm0.txt
agrep -0 -c 'TCAGCGCGATATCTCTT' *.fastq > count/B440_Rm0.txt
agrep -0 -c 'ATACTTTCGCCGTCCTC' *.fastq > count/B441_Rm0.txt
agrep -0 -c 'CTCCACGTGGCTCTCAT' *.fastq > count/B442_Rm0.txt
agrep -0 -c 'AGCAAGTGCCGCCTGTA' *.fastq > count/B443_Rm0.txt
agrep -0 -c 'ACAGTGCTAAGGTGCAT' *.fastq > count/B444_Rm0.txt
agrep -0 -c 'CATGGTCTTACAACCTA' *.fastq > count/B445_Rm0.txt
agrep -0 -c 'AGGAGCAAACACGCCGA' *.fastq > count/B446_Rm0.txt
agrep -0 -c 'TATCGCTGTCCCGTTAG' *.fastq > count/B447_Rm0.txt
agrep -0 -c 'CTGGTGGTGTTGCGTAT' *.fastq > count/B448_Rm0.txt
agrep -0 -c 'CTCCGGCCTTTGATATC' *.fastq > count/B449_Rm0.txt
agrep -0 -c 'AATCGCCCTGTACAGTG' *.fastq > count/B450_Rm0.txt
agrep -0 -c 'GAGTTCGGACTGTAGTA' *.fastq > count/B451_Rm0.txt
agrep -0 -c 'TTCACGGCAATGCAGCT' *.fastq > count/B452_Rm0.txt
agrep -0 -c 'CTTGCCGATCCAACGCA' *.fastq > count/B453_Rm0.txt
agrep -0 -c 'TTGCTCTATCCTGCGGT' *.fastq > count/B454_Rm0.txt
agrep -0 -c 'CCTCTCGACTAGGAGGT' *.fastq > count/B455_Rm0.txt
agrep -0 -c 'ACTGCTTCGGTACTGTG' *.fastq > count/B456_Rm0.txt
agrep -0 -c 'AGTCGCAACTCAAGCGA' *.fastq > count/B457_Rm0.txt
agrep -0 -c 'CACACCTTGGACGAGAT' *.fastq > count/B458_Rm0.txt
agrep -0 -c 'TAAACCGGGTGGGGTGA' *.fastq > count/B459_Rm0.txt
agrep -0 -c 'TGCGTGGTTTAGGCTTA' *.fastq > count/B460_Rm0.txt
agrep -0 -c 'TGTGGGGTCCAACTGGT' *.fastq > count/B461_Rm0.txt
agrep -0 -c 'ATTGGAAGAGTGGATAC' *.fastq > count/B462_Rm0.txt
agrep -0 -c 'CGCCCTCAAAAGTAGCA' *.fastq > count/B463_Rm0.txt
agrep -0 -c 'TTTGGGTGAGACAATAC' *.fastq > count/B464_Rm0.txt
agrep -0 -c 'AGTTGGTGTCGAGCAGG' *.fastq > count/B465_Rm0.txt
agrep -0 -c 'TTCCGACACAAATTCGA' *.fastq > count/B467_Rm0.txt
agrep -0 -c 'ATCTATGAGGGAGTGCG' *.fastq > count/B468_Rm0.txt
agrep -0 -c 'ACTTCGAACCGGTTGTA' *.fastq > count/B469_Rm0.txt
agrep -0 -c 'ACATCACCCTCTGTTCC' *.fastq > count/B471_Rm0.txt
agrep -0 -c 'TTCGAACGACGAAGCAC' *.fastq > count/B472_Rm0.txt
agrep -0 -c 'TAGCCAGCCATGATCGT' *.fastq > count/B473_Rm0.txt
agrep -0 -c 'TCTCACTGAACCTAGTC' *.fastq > count/B474_Rm0.txt
agrep -0 -c 'CCTGACGACGGGTTGAT' *.fastq > count/B475_Rm0.txt
agrep -0 -c 'AACAGCTTCCAGTCCCG' *.fastq > count/B476_Rm0.txt
agrep -0 -c 'CGTCACGAGATTCATCT' *.fastq > count/B477_Rm0.txt
agrep -0 -c 'CTGGTCAACAGTGAATC' *.fastq > count/B478_Rm0.txt
agrep -0 -c 'AACATGCTTAGGCGCGC' *.fastq > count/B479_Rm0.txt
agrep -0 -c 'GCTTTACAGTTCGCTAA' *.fastq > count/B482_Rm0.txt
agrep -0 -c 'AGCTTCCTCCGGTAATT' *.fastq > count/B483_Rm0.txt
agrep -0 -c 'GTCTCTTCTGATAGCAT' *.fastq > count/B484_Rm0.txt
agrep -0 -c 'GTTGGTGCATACGGGAT' *.fastq > count/B485_Rm0.txt
agrep -0 -c 'CCCGTATCTTGAACAAC' *.fastq > count/B486_Rm0.txt
agrep -0 -c 'TCTAGTAGAACCACCCC' *.fastq > count/B487_Rm0.txt
agrep -0 -c 'GTATGCTACAGGCTCAC' *.fastq > count/B488_Rm0.txt
agrep -0 -c 'AGCAGAGGTTGCCTAGC' *.fastq > count/B489_Rm0.txt
agrep -0 -c 'CGAAACAGCGCCAGAAG' *.fastq > count/B490_Rm0.txt
agrep -0 -c 'TCCGACCTAAGTTTGAT' *.fastq > count/B491_Rm0.txt
agrep -0 -c 'TTAACGTTTGTCCCGAA' *.fastq > count/B492_Rm0.txt
agrep -0 -c 'GCCAGGATGTTCCTACT' *.fastq > count/B493_Rm0.txt
agrep -0 -c 'AAGGCCATAACTTCTAG' *.fastq > count/B494_Rm0.txt
agrep -0 -c 'AAGTAACTACAGACTCG' *.fastq > count/B495_Rm0.txt
agrep -0 -c 'AACTCCTTAGCGTTAAG' *.fastq > count/B496_Rm0.txt
agrep -0 -c 'CAGACCCGTGAAACTGG' *.fastq > count/B497_Rm0.txt
agrep -0 -c 'TAACACTGTGGCGTTGC' *.fastq > count/B498_Rm0.txt
agrep -0 -c 'GTCAAGAATGCTCGGCA' *.fastq > count/B499_Rm0.txt
agrep -0 -c 'CTCAAGTACCCTAGAGA' *.fastq > count/B500_Rm0.txt
agrep -0 -c 'GGTGAGTGACGAATGTG' *.fastq > count/B501_Rm0.txt
agrep -0 -c 'GTCAATGAGCATCTAAC' *.fastq > count/B502_Rm0.txt
agrep -0 -c 'GGAATCCTATTGCGATC' *.fastq > count/B504_Rm0.txt
agrep -0 -c 'CCCTTGTGCACAAGATA' *.fastq > count/B505_Rm0.txt
agrep -0 -c 'TTTCCAACAGACTCAGG' *.fastq > count/B506_Rm0.txt
agrep -0 -c 'ACTTGACGCGCAGCAAC' *.fastq > count/B507_Rm0.txt
agrep -0 -c 'AGAAGACTTTAGTGTGG' *.fastq > count/B508_Rm0.txt
agrep -0 -c 'ACTTCCCTATAACCGTG' *.fastq > count/B510_Rm0.txt
agrep -0 -c 'GTAGCCTCGGCACTTAA' *.fastq > count/B511_Rm0.txt
agrep -0 -c 'AGCGAATGCAGTCGGCT' *.fastq > count/B512_Rm0.txt
agrep -0 -c 'AGCAAGTGCACGGTAAC' *.fastq > count/B513_Rm0.txt
agrep -0 -c 'TCATCGCCGCTCAAGTA' *.fastq > count/B514_Rm0.txt
agrep -0 -c 'AGGTTCTCACCAATCGG' *.fastq > count/B515_Rm0.txt
agrep -0 -c 'ACGACGGACCATATAGT' *.fastq > count/B517_Rm0.txt
agrep -0 -c 'AAATTTCGCCGAAGGAT' *.fastq > count/B518_Rm0.txt
agrep -0 -c 'AGTGTTTAACTTCGAGC' *.fastq > count/B519_Rm0.txt
agrep -0 -c 'TTGCGGGAATCTGGATC' *.fastq > count/B520_Rm0.txt
agrep -0 -c 'TAAATTTCTGATGGGGC' *.fastq > count/B521_Rm0.txt
agrep -0 -c 'ATTATAAGCCGTAGGAG' *.fastq > count/B522_Rm0.txt
agrep -0 -c 'TCTTCTGTCCACCGAGC' *.fastq > count/B523_Rm0.txt
agrep -0 -c 'GTACACATACCCAAGTC' *.fastq > count/B524_Rm0.txt
agrep -0 -c 'CGTATGCGGTATCATGG' *.fastq > count/B525_Rm0.txt
agrep -0 -c 'ATCCGATTCTCCGCGCA' *.fastq > count/B526_Rm0.txt
agrep -0 -c 'TACAGAGGAACCCTCGT' *.fastq > count/B527_Rm0.txt
agrep -0 -c 'CAGTCCTCGATCTGATC' *.fastq > count/B528_Rm0.txt
agrep -0 -c 'TTAATGCCGCTTCGGCT' *.fastq > count/B529_Rm0.txt
agrep -0 -c 'ATCCAATGAGCGACCGT' *.fastq > count/B530_Rm0.txt
agrep -0 -c 'GTGCCACTTTCCGTCTT' *.fastq > count/B533_Rm0.txt
agrep -0 -c 'AATGTGGCCAGCCCTAA' *.fastq > count/B534_Rm0.txt
agrep -0 -c 'CCCCTCAACCTAGTGAC' *.fastq > count/B537_Rm0.txt
agrep -0 -c 'TAGCAGGGATGCAAGTC' *.fastq > count/B538_Rm0.txt
agrep -0 -c 'CGAATAAAGTTCTCCGG' *.fastq > count/B539_Rm0.txt
agrep -0 -c 'CGACTGCCAACTATAAC' *.fastq > count/B540_Rm0.txt
agrep -0 -c 'GTTACAGCGTATTTGGC' *.fastq > count/B541_Rm0.txt
agrep -0 -c 'CACCTTTGATTTGTAGG' *.fastq > count/B543_Rm0.txt
agrep -0 -c 'GCAAACGAGTCCTACAA' *.fastq > count/B544_Rm0.txt
agrep -0 -c 'GAATAGTGTTACGACGC' *.fastq > count/B545_Rm0.txt
agrep -0 -c 'CCGAACTCAACCGGTTG' *.fastq > count/B546_Rm0.txt
agrep -0 -c 'TACGGAATTCGTCCATG' *.fastq > count/B547_Rm0.txt
agrep -0 -c 'TTTTCGACGCATACACA' *.fastq > count/B548_Rm0.txt
agrep -0 -c 'ATTTGTTGACGCAGGTG' *.fastq > count/B549_Rm0.txt
agrep -0 -c 'ACTTAGCTCCACCGGAT' *.fastq > count/B550_Rm0.txt
agrep -0 -c 'CCTCCAACCGCAAGGTA' *.fastq > count/B553_Rm0.txt
agrep -0 -c 'GCAGCGACAGTATGCTT' *.fastq > count/B554_Rm0.txt
agrep -0 -c 'CGCGTACATTCGTCGTG' *.fastq > count/B556_Rm0.txt
agrep -0 -c 'GTACGGACTGGATACTG' *.fastq > count/B557_Rm0.txt
agrep -0 -c 'ATGCGCAAGTGACTCCG' *.fastq > count/B558_Rm0.txt
agrep -0 -c 'TCGAGTTCTTGCTACAC' *.fastq > count/B559_Rm0.txt
agrep -0 -c 'AGGTCGCTTTTGCACTC' *.fastq > count/B560_Rm0.txt
agrep -0 -c 'ACGCTCCCTGTGTTGAA' *.fastq > count/B561_Rm0.txt
agrep -0 -c 'TCTGCCTTGGGGCTTAG' *.fastq > count/B563_Rm0.txt
agrep -0 -c 'GATTCCGCCTAGTACTA' *.fastq > count/B564_Rm0.txt
agrep -0 -c 'AAAGGAGCACCACACCG' *.fastq > count/B565_Rm0.txt
agrep -0 -c 'TCTAACACCTCCCTAAT' *.fastq > count/B567_Rm0.txt
agrep -0 -c 'CCAAGCGTGGCGTAAAT' *.fastq > count/B568_Rm0.txt
agrep -0 -c 'AAATAGGACCTGCCACC' *.fastq > count/B569_Rm0.txt
agrep -0 -c 'CTTTATGGCTTGAACGC' *.fastq > count/B570_Rm0.txt
agrep -0 -c 'CGATGCCCCTCTTAATC' *.fastq > count/B571_Rm0.txt
agrep -0 -c 'CCGGATTTAGCAGTCAC' *.fastq > count/B572_Rm0.txt
agrep -0 -c 'TCGTATCTTGACGGGAC' *.fastq > count/B573_Rm0.txt
agrep -0 -c 'GCTTTCGGAAGTTCATG' *.fastq > count/B574_Rm0.txt
agrep -0 -c 'ATCTGCTCTTCTAGCGT' *.fastq > count/B575_Rm0.txt
agrep -0 -c 'TTCCGTGATGTAGAAGC' *.fastq > count/B576_Rm0.txt
agrep -0 -c 'CTGGTGATCATCTAACA' *.fastq > count/B577_Rm0.txt
agrep -0 -c 'TGCGGGAGCGATTAAGT' *.fastq > count/B579_Rm0.txt
agrep -0 -c 'CAAAGATGCCCGTTAAT' *.fastq > count/B580_Rm0.txt
agrep -0 -c 'TATGATGGATTATCCGG' *.fastq > count/B581_Rm0.txt
agrep -0 -c 'AGGACAACGGCATCTTA' *.fastq > count/B582_Rm0.txt
agrep -0 -c 'CCCATGGGTTACAGATA' *.fastq > count/B583_Rm0.txt
agrep -0 -c 'GGTAGGTGGGAATTTGG' *.fastq > count/B584_Rm0.txt
agrep -0 -c 'ACTGTGGGTCTTCTTTA' *.fastq > count/B586_Rm0.txt
agrep -0 -c 'GCTTGGTTTAACCTCCT' *.fastq > count/B587_Rm0.txt
agrep -0 -c 'GGTTATTCACAAACTGG' *.fastq > count/B588_Rm0.txt
agrep -0 -c 'AACGCCATCGTAGGACA' *.fastq > count/B591_Rm0.txt
agrep -0 -c 'GAGACTTAGGCCAGCCA' *.fastq > count/B592_Rm0.txt
agrep -0 -c 'CGCCAATAGGTGAAGTT' *.fastq > count/B593_Rm0.txt
agrep -0 -c 'TGCCACTAAGACTGGAA' *.fastq > count/B595_Rm0.txt
agrep -0 -c 'CAGATGACACACTCGCC' *.fastq > count/B596_Rm0.txt
agrep -0 -c 'TGATGGCTTTCAGCGCT' *.fastq > count/B597_Rm0.txt
agrep -0 -c 'GCGTTGCTAATCCCTTA' *.fastq > count/B598_Rm0.txt
agrep -0 -c 'GTATGGACCCTTACTCA' *.fastq > count/B599_Rm0.txt
agrep -0 -c 'CTCTGGTTCTCGGTAGT' *.fastq > count/B600_Rm0.txt
agrep -0 -c 'GAGATCTTTCACATGCC' *.fastq > count/B601_Rm0.txt
agrep -0 -c 'CGCGTGCTCCCTGAAAT' *.fastq > count/B602_Rm0.txt
agrep -0 -c 'AGTTGTGCCTTTGGAAT' *.fastq > count/B603_Rm0.txt
agrep -0 -c 'GAATGATCCCGTACAGC' *.fastq > count/B604_Rm0.txt
agrep -0 -c 'GCCCTCAAAAGAGAGAT' *.fastq > count/B605_Rm0.txt
agrep -0 -c 'CCTCCGGAAATTTCGAT' *.fastq > count/B606_Rm0.txt
agrep -0 -c 'ATGAGTGCTAGGTAGAC' *.fastq > count/B607_Rm0.txt
agrep -0 -c 'ATACATCTGCGACTTAG' *.fastq > count/B608_Rm0.txt
agrep -0 -c 'CTAGCATTTATCGTCAG' *.fastq > count/B609_Rm0.txt
agrep -0 -c 'TTAGGGTAGTAGGTGAA' *.fastq > count/B610_Rm0.txt
agrep -0 -c 'TGGTAGCACTTAGAAGG' *.fastq > count/B611_Rm0.txt
agrep -0 -c 'CTGGTTGGTAATGTATC' *.fastq > count/B614_Rm0.txt
agrep -0 -c 'ATCGTCAGGGATCGCAG' *.fastq > count/B615_Rm0.txt
agrep -0 -c 'GCAATGCGTAATAGTGT' *.fastq > count/B616_Rm0.txt
agrep -0 -c 'AAACACGCTATTACCGC' *.fastq > count/B617_Rm0.txt
agrep -0 -c 'ACACCTATGCGGTCGTG' *.fastq > count/B618_Rm0.txt
agrep -0 -c 'AGCCCGTCGATCAAGAG' *.fastq > count/B619_Rm0.txt
agrep -0 -c 'CTGTGATCTACCCAACT' *.fastq > count/B620_Rm0.txt
agrep -0 -c 'TTGACGAATCCTACATG' *.fastq > count/B621_Rm0.txt
agrep -0 -c 'AATTCGAGACACAGCGA' *.fastq > count/B622_Rm0.txt
agrep -0 -c 'GCGTTCGTGTTACCCAT' *.fastq > count/B623_Rm0.txt
agrep -0 -c 'AGAGGCCGTAGGTTCTA' *.fastq > count/B626_Rm0.txt
agrep -0 -c 'CATGGTCTCCTCACGAG' *.fastq > count/B627_Rm0.txt
agrep -0 -c 'CAAAGTCATATGACCCT' *.fastq > count/B628_Rm0.txt
agrep -0 -c 'ACGTTCTTGCTTTAGTG' *.fastq > count/B629_Rm0.txt
agrep -0 -c 'TGACTCGCACCACGATG' *.fastq > count/B632_Rm0.txt
agrep -0 -c 'TGCAATCACAGTCCAAC' *.fastq > count/B633_Rm0.txt
agrep -0 -c 'AGTGTGCGCAGTATCCG' *.fastq > count/B634_Rm0.txt
agrep -0 -c 'ATTCCAGGAAACGAACA' *.fastq > count/B636_Rm0.txt
agrep -0 -c 'TGCTCGTCAACATGTGG' *.fastq > count/B637_Rm0.txt
agrep -0 -c 'AAAATCCTACGTTCCTC' *.fastq > count/B638_Rm0.txt
agrep -0 -c 'CCAAAGCGATTCGGATC' *.fastq > count/B639_Rm0.txt
agrep -0 -c 'CATCGTACCACACGCCA' *.fastq > count/B640_Rm0.txt
agrep -0 -c 'AAAGCGGTAGGTGTTGG' *.fastq > count/B642_Rm0.txt
agrep -0 -c 'CTGCGAAAACAACCCCG' *.fastq > count/B645_Rm0.txt
agrep -0 -c 'CTCCTCTTCAATGAATG' *.fastq > count/B647_Rm0.txt
agrep -0 -c 'TTACGCGCGTCAGCAAT' *.fastq > count/B648_Rm0.txt
agrep -0 -c 'GGCGGATATGACTAGAG' *.fastq > count/B649_Rm0.txt
agrep -0 -c 'CTCCGTTATACTACTAG' *.fastq > count/B650_Rm0.txt
agrep -0 -c 'GACGCCCAATTATTTCA' *.fastq > count/B651_Rm0.txt
agrep -0 -c 'AAAACGCACCTAGTACC' *.fastq > count/B652_Rm0.txt
agrep -0 -c 'ATTGGCGAGAGCTTGTT' *.fastq > count/B653_Rm0.txt
agrep -0 -c 'AGAACCGACCCTTTCGC' *.fastq > count/B655_Rm0.txt
agrep -0 -c 'GTGGTATCGCATATTCC' *.fastq > count/B657_Rm0.txt
agrep -0 -c 'AAGCTTCGAGTCTCGTT' *.fastq > count/B658_Rm0.txt
agrep -0 -c 'TAGAGGCGACGTAGAGC' *.fastq > count/B659_Rm0.txt
agrep -0 -c 'CGGTGAGAGTGATAACC' *.fastq > count/B661_Rm0.txt
agrep -0 -c 'CGCTTGGGTCTTAAGTG' *.fastq > count/B663_Rm0.txt
agrep -0 -c 'GTTAGGACATGCCGCGA' *.fastq > count/B664_Rm0.txt
agrep -0 -c 'CCTCGTGTAACTGGTTA' *.fastq > count/B666_Rm0.txt
agrep -0 -c 'CCTATCATGTAGCTTCT' *.fastq > count/B667_Rm0.txt
agrep -0 -c 'GACGACGAGGCTAGTCA' *.fastq > count/B669_Rm0.txt
agrep -0 -c 'CTCGTGTTCACGACTCA' *.fastq > count/B670_Rm0.txt
agrep -0 -c 'GTAACTATTCAGTGCAG' *.fastq > count/B671_Rm0.txt
agrep -0 -c 'TCGACAAGGCGCAAATT' *.fastq > count/B672_Rm0.txt
agrep -0 -c 'CTGGAGCACAGCGAATA' *.fastq > count/B673_Rm0.txt
agrep -0 -c 'TCGTACCCAGATTAGTC' *.fastq > count/B674_Rm0.txt
agrep -0 -c 'GCGTCTAGGTAGTACTG' *.fastq > count/B675_Rm0.txt
agrep -0 -c 'AACATTCTGCGAGTCAG' *.fastq > count/B676_Rm0.txt
agrep -0 -c 'AACATTGCGTGTGTACC' *.fastq > count/B677_Rm0.txt
agrep -0 -c 'CCGTAGAGTTGTACACT' *.fastq > count/B678_Rm0.txt
agrep -0 -c 'GACTCGGTCTGAATGGC' *.fastq > count/B679_Rm0.txt
agrep -0 -c 'CTATAGCACTGAGTTCA' *.fastq > count/B680_Rm0.txt
agrep -0 -c 'CCCTGCAGTAGGATGAT' *.fastq > count/B682_Rm0.txt
agrep -0 -c 'CAACCAGTTGAGTTCGG' *.fastq > count/B683_Rm0.txt
agrep -0 -c 'GATCGTCTCACGCCATG' *.fastq > count/B686_Rm0.txt
agrep -0 -c 'TAATTACGATCGCCGCC' *.fastq > count/B687_Rm0.txt
agrep -0 -c 'CCCCAAGTGCAGCACTT' *.fastq > count/B688_Rm0.txt
agrep -0 -c 'CGGGCGTCGGTCAAATA' *.fastq > count/B689_Rm0.txt
agrep -0 -c 'GCTTATCAGGGAATTGA' *.fastq > count/B690_Rm0.txt
agrep -0 -c 'GTACCTCCTGTTTGCAA' *.fastq > count/B691_Rm0.txt
agrep -0 -c 'TCGCGGATTGGACGAAG' *.fastq > count/B692_Rm0.txt
agrep -0 -c 'ATAATTACTCACGGTGG' *.fastq > count/B693_Rm0.txt
agrep -0 -c 'CCTGAGCTACTCGTTCC' *.fastq > count/B694_Rm0.txt
agrep -0 -c 'AACCTACTTATCGGCAT' *.fastq > count/B695_Rm0.txt
agrep -0 -c 'TCGTGATGTGTCAGTGT' *.fastq > count/B696_Rm0.txt
agrep -0 -c 'TGAACCTATCGATCGTG' *.fastq > count/B698_Rm0.txt
agrep -0 -c 'CACTCCAAAGCTTGAAC' *.fastq > count/B699_Rm0.txt
agrep -0 -c 'CTAGTACACAGCGAGTG' *.fastq > count/B701_Rm0.txt
agrep -0 -c 'ACAGTGTATTCCGTAGC' *.fastq > count/B702_Rm0.txt
agrep -0 -c 'AGGTTATCGTTCGTTTG' *.fastq > count/B704_Rm0.txt
agrep -0 -c 'GACTTCTACCTTAGAGC' *.fastq > count/B705_Rm0.txt
agrep -0 -c 'ACACATCATGCTACCTA' *.fastq > count/B706_Rm0.txt
agrep -0 -c 'ATGTTTCGACGATAAGC' *.fastq > count/B707_Rm0.txt
agrep -0 -c 'ACCAGGGTAGTACGCAT' *.fastq > count/B708_Rm0.txt
agrep -0 -c 'GGCCCGTGAATCGACTT' *.fastq > count/B709_Rm0.txt
agrep -0 -c 'TATCCATATAAGCGCGC' *.fastq > count/B710_Rm0.txt
agrep -0 -c 'TCACGGTGTTTGACCTT' *.fastq > count/B711_Rm0.txt
agrep -0 -c 'TGATCTGACGTATAGAC' *.fastq > count/B712_Rm0.txt
agrep -0 -c 'TTACACCTGGGTCTGGC' *.fastq > count/B715_Rm0.txt
agrep -0 -c 'TTGCTCGCATCGCGATC' *.fastq > count/B717_Rm0.txt
agrep -0 -c 'AGGGATCTAGACATTCA' *.fastq > count/B718_Rm0.txt
agrep -0 -c 'TAACGATAGACCCTCCT' *.fastq > count/B719_Rm0.txt
agrep -0 -c 'GTCCTGTTGCCTGTAGG' *.fastq > count/B720_Rm0.txt
agrep -0 -c 'CGATGGAAATAGCACTA' *.fastq > count/B721_Rm0.txt
agrep -0 -c 'ATCAGTCAACCGGAAGA' *.fastq > count/B722_Rm0.txt
agrep -0 -c 'ATAGAGTCCGTTCGGCG' *.fastq > count/B723_Rm0.txt
agrep -0 -c 'CGGACCTAACTTCCTCT' *.fastq > count/B724_Rm0.txt
agrep -0 -c 'ATTGGTCTGGCGGATAT' *.fastq > count/B725_Rm0.txt
agrep -0 -c 'AAGACAGTCGAGAACTT' *.fastq > count/B726_Rm0.txt
agrep -0 -c 'TGTATCCGTCGAAGCAG' *.fastq > count/B727_Rm0.txt
agrep -0 -c 'ACAAATGAGTACCGTAC' *.fastq > count/B728_Rm0.txt
agrep -0 -c 'TCACCGACGAGAGCTAC' *.fastq > count/B729_Rm0.txt
agrep -0 -c 'TGAGAGTAAACCCGGCG' *.fastq > count/B730_Rm0.txt
agrep -0 -c 'AGGAAGCTGTATAGCTT' *.fastq > count/B731_Rm0.txt
agrep -0 -c 'GCAAGGCCTCACAGTTA' *.fastq > count/B732_Rm0.txt
agrep -0 -c 'CAACGCTGTAGTTTTGA' *.fastq > count/B733_Rm0.txt
agrep -0 -c 'GTATCAATCGAGCCACC' *.fastq > count/B734_Rm0.txt
agrep -0 -c 'CTAGCGTCGGTGGTATT' *.fastq > count/B735_Rm0.txt
agrep -0 -c 'ACTACGAACAGGAGACC' *.fastq > count/B736_Rm0.txt
agrep -0 -c 'GGGCGCGATACAAAAGT' *.fastq > count/B737_Rm0.txt
agrep -0 -c 'CCACTTGGCATAAAGGT' *.fastq > count/B738_Rm0.txt
agrep -0 -c 'ACTGTGTGCTGTAACCC' *.fastq > count/B739_Rm0.txt
agrep -0 -c 'CAGACGAATCCTAGCCA' *.fastq > count/B740_Rm0.txt
agrep -0 -c 'GTTGGCATTTGACTGAC' *.fastq > count/B741_Rm0.txt
agrep -0 -c 'ATTGATAAGACAGCTGC' *.fastq > count/B742_Rm0.txt
agrep -0 -c 'CAGAACTTGCTTTTGAG' *.fastq > count/B743_Rm0.txt
agrep -0 -c 'GAACATCCGCTTGAGCG' *.fastq > count/B744_Rm0.txt
agrep -0 -c 'AGCATCCTCGTTAACAC' *.fastq > count/B745_Rm0.txt
agrep -0 -c 'ACACTACGGGCAGGTAC' *.fastq > count/B746_Rm0.txt
agrep -0 -c 'TGCTGTTTCCTATCAGT' *.fastq > count/B747_Rm0.txt
agrep -0 -c 'GGCGCTGTACTGGTAAT' *.fastq > count/B748_Rm0.txt
agrep -0 -c 'GCCTTGACGTAGAGCGT' *.fastq > count/B749_Rm0.txt
agrep -0 -c 'TATCGGGGGCATACCAA' *.fastq > count/B750_Rm0.txt
agrep -0 -c 'AGCGTGAGGCACGTAGA' *.fastq > count/B752_Rm0.txt
agrep -0 -c 'ACTTTGGCCCAGCTCCA' *.fastq > count/B753_Rm0.txt
agrep -0 -c 'TTGTCTACGCGGAGAAC' *.fastq > count/B754_Rm0.txt
agrep -0 -c 'ACATCCCCGGCAACGAT' *.fastq > count/B755_Rm0.txt
agrep -0 -c 'GTGAGCAGCTTTGACGT' *.fastq > count/B756_Rm0.txt
agrep -0 -c 'TACGGTAACCACCGAAT' *.fastq > count/B758_Rm0.txt
agrep -0 -c 'TACTTTACAGTGCCTAC' *.fastq > count/B759_Rm0.txt
agrep -0 -c 'CCTGTCGTCGATTAGCC' *.fastq > count/B760_Rm0.txt
agrep -0 -c 'GAGGGAGAGTTACGTGC' *.fastq > count/B761_Rm0.txt
agrep -0 -c 'CAGCGCGAGGAGTTTTA' *.fastq > count/B762_Rm0.txt
agrep -0 -c 'GTTGCCGAGATTTTCGC' *.fastq > count/B763_Rm0.txt
agrep -0 -c 'GTAAAGGCAATCGTCCC' *.fastq > count/B765_Rm0.txt
agrep -0 -c 'GGTAGGAAGGAAGTATC' *.fastq > count/B767_Rm0.txt
agrep -0 -c 'TTACTAGCACGGCGGCT' *.fastq > count/B768_Rm0.txt
agrep -0 -c 'AGCCCGCAGAATCGGAA' *.fastq > count/B769_Rm0.txt
agrep -0 -c 'GGGCTGCAATGTGAGCA' *.fastq > count/B770_Rm0.txt
agrep -0 -c 'CGTAGGACTTATTTCCA' *.fastq > count/B771_Rm0.txt
agrep -0 -c 'GCGTGATTCTTGCGAAT' *.fastq > count/B772_Rm0.txt
agrep -0 -c 'GGGGTAGTGTTTATCGT' *.fastq > count/B773_Rm0.txt
agrep -0 -c 'ATGAAGTACTCGAGAGT' *.fastq > count/B774_Rm0.txt
agrep -0 -c 'ATAGGTAATGCGGGCCT' *.fastq > count/B775_Rm0.txt
agrep -0 -c 'TGACCAGTCCTCGCAAG' *.fastq > count/B776_Rm0.txt
agrep -0 -c 'AGTAATCCCGGCTCTAA' *.fastq > count/B777_Rm0.txt
agrep -0 -c 'CTTACGGACCGACGGAA' *.fastq > count/B778_Rm0.txt
agrep -0 -c 'CTAGCGAGGATACTTGG' *.fastq > count/B779_Rm0.txt
agrep -0 -c 'AAGGAGTCCCGAGCCAT' *.fastq > count/B781_Rm0.txt
agrep -0 -c 'AGCACTATAAGATCCAG' *.fastq > count/B782_Rm0.txt
agrep -0 -c 'GTGAGAGGTCAAGATCG' *.fastq > count/B783_Rm0.txt
agrep -0 -c 'CTTCGGGGTCATCGCTA' *.fastq > count/B784_Rm0.txt
agrep -0 -c 'AGCATGGCTTGGAATTG' *.fastq > count/B785_Rm0.txt
agrep -0 -c 'ATCGCCAGGCCGATAAC' *.fastq > count/B787_Rm0.txt
agrep -0 -c 'TCCGTGGGTCGGATGTT' *.fastq > count/B788_Rm0.txt
agrep -0 -c 'TTACGCTGGTGCGGATG' *.fastq > count/B789_Rm0.txt
agrep -0 -c 'ATGTGACACGTCCTAAC' *.fastq > count/B790_Rm0.txt
agrep -0 -c 'AATGCCCTTTAGTGAGT' *.fastq > count/B791_Rm0.txt
agrep -0 -c 'ATCCGCATTACGTCCAT' *.fastq > count/B792_Rm0.txt
agrep -0 -c 'GCCTAGGCTTAACAGAC' *.fastq > count/B793_Rm0.txt
agrep -0 -c 'AACGTGCAAGCACCCAG' *.fastq > count/B795_Rm0.txt
agrep -0 -c 'CAGCGGGTGTTCGAACT' *.fastq > count/B800_Rm0.txt
agrep -0 -c 'GTCCTAATCCCTCCCTA' *.fastq > count/B801_Rm0.txt
agrep -0 -c 'CCGTTTGCCTTGACTAA' *.fastq > count/B802_Rm0.txt
agrep -0 -c 'CACCTCGACTAGTGAGG' *.fastq > count/B804_Rm0.txt
agrep -0 -c 'ACTCTCATATGGCCATA' *.fastq > count/B806_Rm0.txt
agrep -0 -c 'TGAAACGAACAGGAGTC' *.fastq > count/B807_Rm0.txt
agrep -0 -c 'GTTCCTAGAACGAAGAC' *.fastq > count/B808_Rm0.txt
agrep -0 -c 'CGATACATCGGTTGCAA' *.fastq > count/B809_Rm0.txt
agrep -0 -c 'AGCGTCTGAAACACACC' *.fastq > count/B812_Rm0.txt
agrep -0 -c 'GTGCACGGATTAAGAGT' *.fastq > count/B813_Rm0.txt
agrep -0 -c 'ATCGTTACCTGCAGGTG' *.fastq > count/B814_Rm0.txt
agrep -0 -c 'ACGCAGATTCCAAGAGG' *.fastq > count/B815_Rm0.txt
agrep -0 -c 'ACGATTTGCGATGATCA' *.fastq > count/B816_Rm0.txt
agrep -0 -c 'CATACGCTGGCCAATAA' *.fastq > count/B817_Rm0.txt
agrep -0 -c 'ATTGCGAGGCGTCTTTG' *.fastq > count/B818_Rm0.txt
agrep -0 -c 'TCGAGCTATCGCAAACC' *.fastq > count/B819_Rm0.txt
agrep -0 -c 'CATGTAGAAACGAGTGT' *.fastq > count/B821_Rm0.txt
agrep -0 -c 'TTCGCTAGCCAACTAGT' *.fastq > count/B822_Rm0.txt
agrep -0 -c 'AGAGCCCCATCGAGTCA' *.fastq > count/B823_Rm0.txt
agrep -0 -c 'GAACCCGAATTGAACTT' *.fastq > count/B824_Rm0.txt
agrep -0 -c 'AGCAACTCCACAAAAAC' *.fastq > count/B825_Rm0.txt
agrep -0 -c 'CAATACCAAGGATCAGG' *.fastq > count/B826_Rm0.txt
agrep -0 -c 'GAAGCGGTGGCTTCACA' *.fastq > count/B828_Rm0.txt
agrep -0 -c 'AGAACCGACCACACTAT' *.fastq > count/B829_Rm0.txt
agrep -0 -c 'ACGGCGACGGTTGTCTT' *.fastq > count/B830_Rm0.txt
agrep -0 -c 'CATTACGTACTCCGTGG' *.fastq > count/B832_Rm0.txt
agrep -0 -c 'TCAGTGTTACGCATTGA' *.fastq > count/B833_Rm0.txt
agrep -0 -c 'TAGCACATGACGCAGCT' *.fastq > count/B834_Rm0.txt
agrep -0 -c 'CATAGCTACCTGGGTCA' *.fastq > count/B836_Rm0.txt
agrep -0 -c 'TCGTATTAGTCAGGGCT' *.fastq > count/B837_Rm0.txt
agrep -0 -c 'ATGGGTACTGGTGATCA' *.fastq > count/B838_Rm0.txt
agrep -0 -c 'CATGCTCTGCCCTTATG' *.fastq > count/B839_Rm0.txt
agrep -0 -c 'TCCTTCGGCCTCTTGCT' *.fastq > count/B840_Rm0.txt
agrep -0 -c 'CTTATCTTCGACCCCTC' *.fastq > count/B841_Rm0.txt
agrep -0 -c 'TTCTGCACTGCTCGTCT' *.fastq > count/B842_Rm0.txt
agrep -0 -c 'AAGTTCTACCACTGGAC' *.fastq > count/B843_Rm0.txt
agrep -0 -c 'TACTATGCCACCATGTC' *.fastq > count/B846_Rm0.txt
agrep -0 -c 'TTGATCCCTGTCGTGTC' *.fastq > count/B848_Rm0.txt
agrep -0 -c 'GCTAGATGGCGCCTACA' *.fastq > count/B850_Rm0.txt
agrep -0 -c 'GATTAACTTCTCACCGC' *.fastq > count/B852_Rm0.txt
agrep -0 -c 'TTATACCCAGCGCTGCG' *.fastq > count/B853_Rm0.txt
agrep -0 -c 'CTAGATCGTGTTCGATG' *.fastq > count/B854_Rm0.txt
agrep -0 -c 'ACTGAGCAACATACAAC' *.fastq > count/B855_Rm0.txt
agrep -0 -c 'CGTCTGTCGTCGATGGT' *.fastq > count/B856_Rm0.txt
agrep -0 -c 'GGTGGCGTTTCTGTTTA' *.fastq > count/B857_Rm0.txt
agrep -0 -c 'AGCGCTATTGATCTATC' *.fastq > count/B858_Rm0.txt
agrep -0 -c 'TTCATGAGCACCACGAC' *.fastq > count/B859_Rm0.txt
agrep -0 -c 'CTCCATAGTTGGAAGCA' *.fastq > count/B860_Rm0.txt
agrep -0 -c 'CTGTAAGAAGGAAACGA' *.fastq > count/B861_Rm0.txt
agrep -0 -c 'AGTTCGCAGGTACTACG' *.fastq > count/B862_Rm0.txt
agrep -0 -c 'TTTCCATGGGGGGTCAA' *.fastq > count/B863_Rm0.txt
agrep -0 -c 'ACTTAACGGAGCGTCTG' *.fastq > count/B864_Rm0.txt
agrep -0 -c 'TAAGATAGTCGGACCCC' *.fastq > count/B865_Rm0.txt
agrep -0 -c 'AACTTGTCTCTTCCAGA' *.fastq > count/B866_Rm0.txt
agrep -0 -c 'TGGACGAAGCTTATTCT' *.fastq > count/B867_Rm0.txt
agrep -0 -c 'CCACTATGCTTAGGGAC' *.fastq > count/B868_Rm0.txt
agrep -0 -c 'ACGTAGTTTGTGGCTTG' *.fastq > count/B869_Rm0.txt
agrep -0 -c 'ATCCCTAGCGCTTGAAC' *.fastq > count/B870_Rm0.txt
agrep -0 -c 'TACCGGTGGGCAAGTCT' *.fastq > count/B871_Rm0.txt
agrep -0 -c 'GGTATAAACCGCCCGCA' *.fastq > count/B872_Rm0.txt
agrep -0 -c 'AGCGCGTAGTATAATAG' *.fastq > count/B873_Rm0.txt
agrep -0 -c 'GCGGGCTAAAGAGTTGG' *.fastq > count/B875_Rm0.txt
agrep -0 -c 'TGCCGGAGTGACTTTCT' *.fastq > count/B877_Rm0.txt
agrep -0 -c 'GGCTAATGCTGGTTACT' *.fastq > count/B880_Rm0.txt
agrep -0 -c 'TTCCTGCTCTCGACGTA' *.fastq > count/B881_Rm0.txt
agrep -0 -c 'GGGCGATTTTGGAAACT' *.fastq > count/B882_Rm0.txt
agrep -0 -c 'CTGTACTGACAGTCCGA' *.fastq > count/B883_Rm0.txt
agrep -0 -c 'GACAGACGGTAGTGGAC' *.fastq > count/B884_Rm0.txt
agrep -0 -c 'CTACCTGCAGTATATCG' *.fastq > count/B885_Rm0.txt
agrep -0 -c 'ATATTTAGGCTAGCGCA' *.fastq > count/B886_Rm0.txt
agrep -0 -c 'CCAGCGTGAAGTTGTCG' *.fastq > count/B887_Rm0.txt
agrep -0 -c 'AAACTGACGAAGTACGA' *.fastq > count/B888_Rm0.txt
agrep -0 -c 'TCATCGCGGCCGTAATG' *.fastq > count/B889_Rm0.txt
agrep -0 -c 'TTCAACCAGGCAAGCAG' *.fastq > count/B890_Rm0.txt
agrep -0 -c 'GTCGATCCGCTGAGATT' *.fastq > count/B891_Rm0.txt
agrep -0 -c 'GTGCTGTGGCTGTAACG' *.fastq > count/B892_Rm0.txt
agrep -0 -c 'CGCCGTCCCTAGATTAA' *.fastq > count/B893_Rm0.txt
agrep -0 -c 'TACATGGCGATATACTG' *.fastq > count/B894_Rm0.txt
agrep -0 -c 'CAAACGTGAAGGGTCGC' *.fastq > count/B895_Rm0.txt
agrep -0 -c 'GTGGGCATTGAACAGTT' *.fastq > count/B896_Rm0.txt
agrep -0 -c 'TTGAATGCCGACCCCTA' *.fastq > count/B897_Rm0.txt
agrep -0 -c 'CGGACTGAGCCTTTTGC' *.fastq > count/B898_Rm0.txt
agrep -0 -c 'GGCAGCGATACTACGAT' *.fastq > count/B899_Rm0.txt
agrep -0 -c 'ACTGTCGGCACGTATTA' *.fastq > count/B900_Rm0.txt
agrep -0 -c 'ATACCGGCGATATCACG' *.fastq > count/B901_Rm0.txt
agrep -0 -c 'TAACCCTGCAACTTGCA' *.fastq > count/B902_Rm0.txt
agrep -0 -c 'GAAGAACTATTTGGGCT' *.fastq > count/B903_Rm0.txt
agrep -0 -c 'AGCCAATTTCTGCCAGG' *.fastq > count/B905_Rm0.txt
agrep -0 -c 'AGTTAGAACCGGGTAAC' *.fastq > count/B906_Rm0.txt
agrep -0 -c 'CTGTGGTGTTCAGTTGC' *.fastq > count/B907_Rm0.txt
agrep -0 -c 'AAAGCGCTCTCTCCTGA' *.fastq > count/B908_Rm0.txt
agrep -0 -c 'GACGCTCTTAACACGCA' *.fastq > count/B909_Rm0.txt
agrep -0 -c 'GCGGCAACGTTGCTATC' *.fastq > count/B910_Rm0.txt
agrep -0 -c 'ACCGGCCCAAAGGTAGA' *.fastq > count/B911_Rm0.txt
agrep -0 -c 'GGGCCCATCAAGTGAAT' *.fastq > count/B912_Rm0.txt
agrep -0 -c 'CAGGCCAAACGTACAGA' *.fastq > count/B913_Rm0.txt
agrep -0 -c 'CTCTTTCTCCGAATTCC' *.fastq > count/B915_Rm0.txt
agrep -0 -c 'TAGCTTCGTGTCTTCCA' *.fastq > count/B916_Rm0.txt
agrep -0 -c 'CTCTTTGTATCGTATCG' *.fastq > count/B918_Rm0.txt
agrep -0 -c 'AGGAGATTGACGGGGAG' *.fastq > count/B919_Rm0.txt
agrep -0 -c 'GCGTAATAAGCCTGGTA' *.fastq > count/B920_Rm0.txt
agrep -0 -c 'TAGCTGGACTAAGCGTC' *.fastq > count/B921_Rm0.txt
agrep -0 -c 'CGAAGTTATGTGAGACT' *.fastq > count/B922_Rm0.txt
agrep -0 -c 'AGGCATAAATCCTCCAA' *.fastq > count/B923_Rm0.txt
agrep -0 -c 'GTAGTACCCTCTATAAC' *.fastq > count/B924_Rm0.txt
agrep -0 -c 'TCGCGATATACGGCCAT' *.fastq > count/B925_Rm0.txt
agrep -0 -c 'ACCAATCCAGTCCAGAT' *.fastq > count/B926_Rm0.txt
agrep -0 -c 'TTAAACAAGGTGCGCCC' *.fastq > count/B927_Rm0.txt
agrep -0 -c 'ACTGAAGTATACGCGTC' *.fastq > count/B928_Rm0.txt
agrep -0 -c 'AATAAGTTACCTCCAGC' *.fastq > count/B929_Rm0.txt
agrep -0 -c 'ACTACACGCCGTAGCGA' *.fastq > count/B930_Rm0.txt
agrep -0 -c 'TCAAAGTCACGCCCACA' *.fastq > count/B932_Rm0.txt
agrep -0 -c 'AACACAAACAACTGGGT' *.fastq > count/B933_Rm0.txt
agrep -0 -c 'TTACCTACTAGGATGCG' *.fastq > count/B934_Rm0.txt
agrep -0 -c 'GAACGGTTGAGATAGTT' *.fastq > count/B935_Rm0.txt
agrep -0 -c 'GCATTTGTCTCCAAGCG' *.fastq > count/B936_Rm0.txt
agrep -0 -c 'TATGCGCCATTTGGAAG' *.fastq > count/B938_Rm0.txt
agrep -0 -c 'GTCTCCGTCAGTTACTC' *.fastq > count/B939_Rm0.txt
agrep -0 -c 'CTCCAATTTGGCGCAAT' *.fastq > count/B941_Rm0.txt
agrep -0 -c 'TTCAAGGTGTTTGCGCA' *.fastq > count/B942_Rm0.txt
agrep -0 -c 'GGCTGTTCTCTCTATAT' *.fastq > count/B943_Rm0.txt
agrep -0 -c 'CGGGCTTATCCTTCATA' *.fastq > count/B945_Rm0.txt
agrep -0 -c 'ACTGGAACCGTGCATGG' *.fastq > count/B947_Rm0.txt
agrep -0 -c 'GGGGTTGGAGCATAGTA' *.fastq > count/B948_Rm0.txt
agrep -0 -c 'CTTAAAACCCATGGGAT' *.fastq > count/B949_Rm0.txt
agrep -0 -c 'TCGTCGCTATTGCTATC' *.fastq > count/B950_Rm0.txt
agrep -0 -c 'TTCGTTTTGTGTTTGCG' *.fastq > count/B951_Rm0.txt
agrep -0 -c 'CTAACTACATGAGCAGG' *.fastq > count/B952_Rm0.txt
agrep -0 -c 'GACGCATGCACTAAACG' *.fastq > count/B953_Rm0.txt
agrep -0 -c 'GTACCCAGCTACGTCCA' *.fastq > count/B954_Rm0.txt
agrep -0 -c 'GGTGAAAGATAGTCCTT' *.fastq > count/B955_Rm0.txt
agrep -0 -c 'GATCGTACCAAGCTATC' *.fastq > count/B956_Rm0.txt
agrep -0 -c 'AATGCAAACATATCCGC' *.fastq > count/B957_Rm0.txt
agrep -0 -c 'CGCGTGATCTTTGGATT' *.fastq > count/B958_Rm0.txt
agrep -0 -c 'GCCTCTAACTTGTGCCT' *.fastq > count/B960_Rm0.txt
agrep -0 -c 'CGCGATATGGGTTCCTC' *.fastq > count/B961_Rm0.txt
agrep -0 -c 'TATTCCGCGTGATGTCC' *.fastq > count/B962_Rm0.txt
agrep -0 -c 'TCACAGATTGGACTAAC' *.fastq > count/B963_Rm0.txt
agrep -0 -c 'CTGGTTCTTTCGTCAGC' *.fastq > count/B964_Rm0.txt
agrep -0 -c 'GTCAAACTTACCTGGGT' *.fastq > count/B965_Rm0.txt
agrep -0 -c 'CAGCCCTTAAATTACCC' *.fastq > count/B966_Rm0.txt
agrep -0 -c 'TAGTACGCTCCCGGTAG' *.fastq > count/B969_Rm0.txt
agrep -0 -c 'TCATCCCGGCCTTGTCT' *.fastq > count/B971_Rm0.txt
agrep -0 -c 'GCTAGAAGATTCTTCAC' *.fastq > count/B972_Rm0.txt
agrep -0 -c 'GTCGTCAACAATGACGC' *.fastq > count/B973_Rm0.txt
agrep -0 -c 'CTTATGACACGTTACAG' *.fastq > count/B974_Rm0.txt
agrep -0 -c 'GATGAGTAGCGCGTATC' *.fastq > count/B976_Rm0.txt
agrep -0 -c 'TTAGCCGAAGTTGTAGT' *.fastq > count/B977_Rm0.txt
agrep -0 -c 'CAGTATTGCGGTCTAGG' *.fastq > count/B979_Rm0.txt
agrep -0 -c 'GTGATGCTTACCACAGC' *.fastq > count/B982_Rm0.txt
agrep -0 -c 'TCATAGCAAAACCCAGA' *.fastq > count/B983_Rm0.txt
agrep -0 -c 'GCGTGACATTGCTGAGT' *.fastq > count/B985_Rm0.txt
agrep -0 -c 'TGAGTTGGGTCAGTTAG' *.fastq > count/B986_Rm0.txt
agrep -0 -c 'GGGCAGTTTAAACGGAA' *.fastq > count/B987_Rm0.txt
agrep -0 -c 'TAAAGCACCGTTACCGA' *.fastq > count/B988_Rm0.txt
agrep -0 -c 'CCCATCTTTTATGGTCT' *.fastq > count/B990_Rm0.txt
agrep -0 -c 'CTCTCACATCGAACATT' *.fastq > count/B991_Rm0.txt
agrep -0 -c 'TTGGTTCTCCTTACGTT' *.fastq > count/B992_Rm0.txt
agrep -0 -c 'TTTTGACAGAGCACTGG' *.fastq > count/B993_Rm0.txt
agrep -0 -c 'AAGATTCGCGCTGAACC' *.fastq > count/B994_Rm0.txt
agrep -0 -c 'AACGTCTTTCAGGAGAG' *.fastq > count/B995_Rm0.txt
agrep -0 -c 'GGGTAAGGGACCATAAC' *.fastq > count/B996_Rm0.txt
agrep -0 -c 'GTGCTTCACACTCCAAC' *.fastq > count/B997_Rm0.txt
agrep -0 -c 'TGTTGGTCCGAAGCAGA' *.fastq > count/B998_Rm0.txt
agrep -0 -c 'AAAACAGCCCGCCAACT' *.fastq > count/B999_Rm0.txt
agrep -0 -c 'AGCAGTCATAAAAGCAG' *.fastq > count/B1000_Rm0.txt
agrep -0 -c 'ATCAACCCGTTAGGCCG' *.fastq > count/B1001_Rm0.txt
agrep -0 -c 'CAACGGCCTTCTCTATT' *.fastq > count/B1002_Rm0.txt
agrep -0 -c 'GTTGTGTCCCTTGTTTG' *.fastq > count/B1003_Rm0.txt
agrep -0 -c 'AACGTTCTGTGCAGAAG' *.fastq > count/B1004_Rm0.txt
agrep -0 -c 'GGAAACGGTCGGTTAAG' *.fastq > count/B1005_Rm0.txt
agrep -0 -c 'CCAGTCTTAGCTAGGCA' *.fastq > count/B1006_Rm0.txt
agrep -0 -c 'CCATAACAGAGCCCGAG' *.fastq > count/B1007_Rm0.txt
agrep -0 -c 'AACACATATATGGGAGC' *.fastq > count/B1010_Rm0.txt
agrep -0 -c 'TGTCGACGATCTTAGGC' *.fastq > count/B1012_Rm0.txt
agrep -0 -c 'GTTCATTACTCAAGGTG' *.fastq > count/B1013_Rm0.txt
agrep -0 -c 'GCGTTACGGCGGATAGT' *.fastq > count/B1014_Rm0.txt
agrep -0 -c 'TATTCCGGACCAGGGCT' *.fastq > count/B1015_Rm0.txt
agrep -0 -c 'AAAAAGCGAGCAACCAT' *.fastq > count/B1016_Rm0.txt
agrep -0 -c 'CAGAGTTCAAATACGAG' *.fastq > count/B1017_Rm0.txt
agrep -0 -c 'TCATGATCGTAGGATTG' *.fastq > count/B1018_Rm0.txt
agrep -0 -c 'TCTGTTTGACACAGTTG' *.fastq > count/B1019_Rm0.txt
agrep -0 -c 'CTGTAGTGCACGGTCTT' *.fastq > count/B1020_Rm0.txt
agrep -0 -c 'TATGGTGGACCCAAGCG' *.fastq > count/B1023_Rm0.txt
agrep -0 -c 'CCTGAGCTTGATCCAGT' *.fastq > count/B1024_Rm0.txt
agrep -0 -c 'CTTGTCGGTGCACATAT' *.fastq > count/B1025_Rm0.txt
agrep -0 -c 'ATCGAACTGGACGACTA' *.fastq > count/B1026_Rm0.txt
agrep -0 -c 'CAAGCGAAAAGACCGAA' *.fastq > count/B1027_Rm0.txt
agrep -0 -c 'AAGGGACTTGGTTTGAG' *.fastq > count/B1028_Rm0.txt
agrep -0 -c 'GTCTTCGATACGTAGTG' *.fastq > count/B1029_Rm0.txt
agrep -0 -c 'GTCATCCCTCTATACAC' *.fastq > count/B1032_Rm0.txt
agrep -0 -c 'AACGGCTGGAGTAGGAC' *.fastq > count/B1033_Rm0.txt
agrep -0 -c 'TACTCTTGCGCACGAAG' *.fastq > count/B1034_Rm0.txt
agrep -0 -c 'TGGTCTACTGATGCTTG' *.fastq > count/B1035_Rm0.txt
agrep -0 -c 'AATCTGCTTCGTTCACA' *.fastq > count/B1036_Rm0.txt
agrep -0 -c 'TTGCAAACGAGGACGAT' *.fastq > count/B1037_Rm0.txt
agrep -0 -c 'CGCCAATGTCGTCAGTG' *.fastq > count/B1038_Rm0.txt
agrep -0 -c 'CCCCATGTTATTAGGTG' *.fastq > count/B1039_Rm0.txt
agrep -0 -c 'GTTGGGCGTTAACAACT' *.fastq > count/B1040_Rm0.txt
agrep -0 -c 'TCCATGGATCGCTAGCA' *.fastq > count/B1041_Rm0.txt
agrep -0 -c 'CATATATACTCGGCACG' *.fastq > count/B1042_Rm0.txt
agrep -0 -c 'TCATCTAGAGCGAAACG' *.fastq > count/B1045_Rm0.txt
agrep -0 -c 'CCTGACTGTGTAGTATT' *.fastq > count/B1046_Rm0.txt
agrep -0 -c 'AAATTGCGTGGAAGGCC' *.fastq > count/B1047_Rm0.txt
agrep -0 -c 'AAGAACACGACTACGTC' *.fastq > count/B1048_Rm0.txt
agrep -0 -c 'CCCGTTTGATAGTGCAC' *.fastq > count/B1049_Rm0.txt
agrep -0 -c 'CCCCAGTCATGTTCAGG' *.fastq > count/B1050_Rm0.txt
agrep -0 -c 'AGCACAATTACTGGTGA' *.fastq > count/B1051_Rm0.txt
agrep -0 -c 'ATCGATCTATATTGGCG' *.fastq > count/B1052_Rm0.txt
agrep -0 -c 'CTCGTGATTAGCCTCAC' *.fastq > count/B1054_Rm0.txt
agrep -0 -c 'GCGAACCTCCTCAACTG' *.fastq > count/B1056_Rm0.txt
agrep -0 -c 'ACATAGTTAGCGACGGT' *.fastq > count/B1057_Rm0.txt
agrep -0 -c 'GCCGTCCTGTGTATGTC' *.fastq > count/B1059_Rm0.txt
agrep -0 -c 'TTGCGGCTAGATATGTA' *.fastq > count/B1061_Rm0.txt
agrep -0 -c 'TTGCGGACTGGCTTCCA' *.fastq > count/B1062_Rm0.txt
agrep -0 -c 'TTTGCGGGAGTAGTATG' *.fastq > count/B1063_Rm0.txt
agrep -0 -c 'GCGCATAAGAGAGTAGT' *.fastq > count/B1066_Rm0.txt
agrep -0 -c 'AGCTTGACATTCGTTGT' *.fastq > count/B1067_Rm0.txt
agrep -0 -c 'GCAACCTTCCTGTACGG' *.fastq > count/B1068_Rm0.txt
agrep -0 -c 'CTTATAGGACTCCTGGC' *.fastq > count/B1069_Rm0.txt
agrep -0 -c 'AAGCACCATGGAACAAT' *.fastq > count/B1070_Rm0.txt
agrep -0 -c 'GCTAACCCATCGTTGCA' *.fastq > count/B1071_Rm0.txt
agrep -0 -c 'ACTGTCATATCGGGAAC' *.fastq > count/B1072_Rm0.txt
agrep -0 -c 'TACCTTCTGGATACCAT' *.fastq > count/B1074_Rm0.txt
agrep -0 -c 'AAATTTGTTTCCGCGGT' *.fastq > count/B1075_Rm0.txt
agrep -0 -c 'AGGTGTAGACATATGCC' *.fastq > count/B1076_Rm0.txt
agrep -0 -c 'GAGCATGATTTAGGCGA' *.fastq > count/B1078_Rm0.txt
agrep -0 -c 'AAATGGTTCGGTTGGTC' *.fastq > count/B1080_Rm0.txt
agrep -0 -c 'TAGAGACGCCAATGGCC' *.fastq > count/B1082_Rm0.txt
agrep -0 -c 'GATCATAGGTCCTTTAC' *.fastq > count/B1083_Rm0.txt
agrep -0 -c 'ATAGAGATGCCCTCGGT' *.fastq > count/B1084_Rm0.txt
agrep -0 -c 'AGAATTCTCCTCGTCAA' *.fastq > count/B1086_Rm0.txt
agrep -0 -c 'TTCGAATACGCCACAGC' *.fastq > count/B1087_Rm0.txt
agrep -0 -c 'TACCTGTCTTGGCGTCA' *.fastq > count/B1088_Rm0.txt
agrep -0 -c 'GAACTGGCGGCTCAGTA' *.fastq > count/B1089_Rm0.txt
agrep -0 -c 'ATACAAACGGACACGCA' *.fastq > count/B1090_Rm0.txt
agrep -0 -c 'GTCTTTGCGATTACCCT' *.fastq > count/B1092_Rm0.txt
agrep -0 -c 'AAGGCCGCATATTCGTG' *.fastq > count/B1093_Rm0.txt
agrep -0 -c 'TCGATCATGCCATGTAA' *.fastq > count/B1094_Rm0.txt
agrep -0 -c 'GGAGAGGTTCAACTACG' *.fastq > count/B1095_Rm0.txt
agrep -0 -c 'ACAGCGCCGGTCTAATA' *.fastq > count/B1097_Rm0.txt
agrep -0 -c 'CAGAATCGAACGAGCGC' *.fastq > count/B1098_Rm0.txt
agrep -0 -c 'ATGGTTTCCGCCATAAT' *.fastq > count/B1099_Rm0.txt
agrep -0 -c 'CGTCGTCATACAGCCAG' *.fastq > count/B1102_Rm0.txt
agrep -0 -c 'GAGTACTGACTATGATG' *.fastq > count/B1103_Rm0.txt
agrep -0 -c 'GACGTTGCTCTATTGTT' *.fastq > count/B1104_Rm0.txt
agrep -0 -c 'CGCGGAGGGGAAAATTA' *.fastq > count/B1105_Rm0.txt
agrep -0 -c 'CTTCCCTGAATACTCCA' *.fastq > count/B1106_Rm0.txt
agrep -0 -c 'TGCATAGCGCAGGGGTT' *.fastq > count/B1107_Rm0.txt
agrep -0 -c 'CACCCATAGCCTTCTCC' *.fastq > count/B1109_Rm0.txt
agrep -0 -c 'ATTCCGCGCCCTGCATA' *.fastq > count/B1111_Rm0.txt
agrep -0 -c 'GTGGGTCATAATTGCCG' *.fastq > count/B1112_Rm0.txt
agrep -0 -c 'GCGTAATGAAACATGGC' *.fastq > count/B1113_Rm0.txt
agrep -0 -c 'CAGATGATTTGGGCACT' *.fastq > count/B1114_Rm0.txt
agrep -0 -c 'GCACCCCTGATAGTGCA' *.fastq > count/B1116_Rm0.txt
agrep -0 -c 'AAATTAGTGGCTGTCCT' *.fastq > count/B1121_Rm0.txt
agrep -0 -c 'AGTCCTAGGCGGCCTAA' *.fastq > count/B1122_Rm0.txt
agrep -0 -c 'AGCGTAATATCTGTTCC' *.fastq > count/B1123_Rm0.txt
agrep -0 -c 'GTTTCGGGGGTAAACAG' *.fastq > count/B1124_Rm0.txt
agrep -0 -c 'TTTGAACGGAGTCGCTA' *.fastq > count/B1125_Rm0.txt
agrep -0 -c 'CGTAGATGTTCTCACAA' *.fastq > count/B1126_Rm0.txt
agrep -0 -c 'TTGTCTTACCGACTCGA' *.fastq > count/B1127_Rm0.txt
agrep -0 -c 'TCAAGTAGCGATGGCAC' *.fastq > count/B1129_Rm0.txt
agrep -0 -c 'TCAACGGTTCGCGTCCA' *.fastq > count/B1130_Rm0.txt
agrep -0 -c 'GTGTAACAGCCGTTATC' *.fastq > count/B1131_Rm0.txt
agrep -0 -c 'TTCTATGGAACCTAGCG' *.fastq > count/B1132_Rm0.txt
agrep -0 -c 'AACGAACCTGAGGGCTG' *.fastq > count/B1135_Rm0.txt
agrep -0 -c 'CCCAGTCGACCCTATAT' *.fastq > count/B1137_Rm0.txt
agrep -0 -c 'CACAGATCGCTCACGCA' *.fastq > count/B1138_Rm0.txt
agrep -0 -c 'ATGTTGTGATTAACCGG' *.fastq > count/B1139_Rm0.txt
agrep -0 -c 'GGAAGCCGATCTTATGG' *.fastq > count/B1140_Rm0.txt
agrep -0 -c 'CATCGCGACAATGGTAA' *.fastq > count/B1143_Rm0.txt
agrep -0 -c 'ATGTGAGACGGGAAATA' *.fastq > count/B1145_Rm0.txt
agrep -0 -c 'AGCAAAGGGGGTGAACT' *.fastq > count/B1146_Rm0.txt
agrep -0 -c 'CTTCAGGGGCATACGAT' *.fastq > count/B1148_Rm0.txt
agrep -0 -c 'AAAGGCCCTCTATGGCC' *.fastq > count/B1149_Rm0.txt
agrep -0 -c 'CGAACCGAGGACTGCTA' *.fastq > count/B1150_Rm0.txt
agrep -0 -c 'TAAGCCCCGTAATAGAT' *.fastq > count/B1151_Rm0.txt
agrep -0 -c 'GCTTGACTTAAGCTTCT' *.fastq > count/B1152_Rm0.txt
agrep -0 -c 'AGTCAGCATAAAGTCGC' *.fastq > count/B1153_Rm0.txt
agrep -0 -c 'GGCCTTCGTCCTTAGCT' *.fastq > count/B1154_Rm0.txt
agrep -0 -c 'ACGAACTGAACACCTAG' *.fastq > count/B1155_Rm0.txt
agrep -0 -c 'TTTTCGAGCCCTACGTG' *.fastq > count/B1156_Rm0.txt
agrep -0 -c 'GTCGCTATAGTCTGTAT' *.fastq > count/B1158_Rm0.txt
agrep -0 -c 'TCTAACCCTACCGGGAG' *.fastq > count/B1159_Rm0.txt
agrep -0 -c 'GGCCCTCGTATGTATTA' *.fastq > count/B1160_Rm0.txt
agrep -0 -c 'ATAACCATCGTCTACGA' *.fastq > count/B1161_Rm0.txt
agrep -0 -c 'GAGGATAATGGAAGTTG' *.fastq > count/B1162_Rm0.txt
agrep -0 -c 'ACCACTATGAACATCTG' *.fastq > count/B1163_Rm0.txt
agrep -0 -c 'ATGGGCAGTCATGTCTC' *.fastq > count/B1164_Rm0.txt
agrep -0 -c 'GTTTGGATGTCCCCCGT' *.fastq > count/B1165_Rm0.txt
agrep -0 -c 'GCAACAGCCATCATGCT' *.fastq > count/B1167_Rm0.txt
agrep -0 -c 'AGGCGCGTCTACATGGT' *.fastq > count/B1168_Rm0.txt
agrep -0 -c 'GACAAGATCACGCTAAC' *.fastq > count/B1169_Rm0.txt
agrep -0 -c 'CTTCCCATAGTTCGTAG' *.fastq > count/B1170_Rm0.txt
agrep -0 -c 'TCAAGGGCAGTTTAGTA' *.fastq > count/B1171_Rm0.txt
agrep -0 -c 'TTTAGGCGTTCAGAGAG' *.fastq > count/B1172_Rm0.txt
agrep -0 -c 'TTAAGAATCGCTGTGGC' *.fastq > count/B1174_Rm0.txt
agrep -0 -c 'AGATCACGACTAGACGC' *.fastq > count/B1175_Rm0.txt
agrep -0 -c 'ATTGTGGTTCTCTTGAC' *.fastq > count/B1176_Rm0.txt
agrep -0 -c 'CAAACTGCGTGCCGTCT' *.fastq > count/B1177_Rm0.txt
agrep -0 -c 'AATGCTTGACATCCGCG' *.fastq > count/B1178_Rm0.txt
agrep -0 -c 'CGCGAGATTTATGGTCC' *.fastq > count/B1180_Rm0.txt
agrep -0 -c 'GTAGGGGAGGAGCACTT' *.fastq > count/B1181_Rm0.txt
agrep -0 -c 'GTAAGGGATAGGAGATG' *.fastq > count/B1183_Rm0.txt
agrep -0 -c 'GGTAAGCTTGAATCATG' *.fastq > count/B1184_Rm0.txt
agrep -0 -c 'CCTCTCGTACGCTGATA' *.fastq > count/B1185_Rm0.txt
agrep -0 -c 'GCCGTATCGGCTCTATG' *.fastq > count/B1187_Rm0.txt
agrep -0 -c 'CGCTAACCAAGGCTCGA' *.fastq > count/B1188_Rm0.txt
agrep -0 -c 'CACAGCCGGATAGACTG' *.fastq > count/B1189_Rm0.txt
agrep -0 -c 'TGCGGACACGACTGACT' *.fastq > count/B1190_Rm0.txt
agrep -0 -c 'CTGGCACTGAATAATGG' *.fastq > count/B1192_Rm0.txt
agrep -0 -c 'TCTGTTCCCACAAGCCG' *.fastq > count/B1193_Rm0.txt
agrep -0 -c 'ACCTTAGCAAAGCACCG' *.fastq > count/B1195_Rm0.txt
agrep -0 -c 'TTTCAACCGCCCCTATC' *.fastq > count/B1198_Rm0.txt
agrep -0 -c 'TCACCCAGGAACGATTG' *.fastq > count/B1199_Rm0.txt
agrep -0 -c 'CTGTTGCGACAGAACGT' *.fastq > count/B1203_Rm0.txt
agrep -0 -c 'CTTCCCGTGTTCTAATC' *.fastq > count/B1204_Rm0.txt
agrep -0 -c 'GTATTCTGGATCGCAGC' *.fastq > count/B1206_Rm0.txt
agrep -0 -c 'TCACAGGTCGCTAGGTG' *.fastq > count/B1207_Rm0.txt
agrep -0 -c 'GGCACACTGTATGAACA' *.fastq > count/B1208_Rm0.txt
agrep -0 -c 'TAATGGCGGAGGTTAAG' *.fastq > count/B1211_Rm0.txt
agrep -0 -c 'GGCCGTAATAAAGGAAT' *.fastq > count/B1212_Rm0.txt
agrep -0 -c 'TCATTCAGGTCGTGTCA' *.fastq > count/B1213_Rm0.txt
agrep -0 -c 'TGCCGATTTTACAACGT' *.fastq > count/B1214_Rm0.txt
agrep -0 -c 'AAGAGGTATACTCGGCG' *.fastq > count/B1216_Rm0.txt
agrep -0 -c 'GGTTTCTAGCTCGTATC' *.fastq > count/B1217_Rm0.txt
agrep -0 -c 'CAGGACCGTCTTGTAAC' *.fastq > count/B1218_Rm0.txt
agrep -0 -c 'TTATGGCGTAGACGATT' *.fastq > count/B1219_Rm0.txt
agrep -0 -c 'CACATTCACCACGTCAT' *.fastq > count/B1222_Rm0.txt
agrep -0 -c 'ACGTCTGCATTTGTCCT' *.fastq > count/B1223_Rm0.txt
agrep -0 -c 'GAGGATAGTCTTCCACG' *.fastq > count/B1224_Rm0.txt
agrep -0 -c 'ATGATTCGAGAGAGAGT' *.fastq > count/B1225_Rm0.txt
agrep -0 -c 'GCTTCGGTATAGCTTAG' *.fastq > count/B1226_Rm0.txt
agrep -0 -c 'AGTCTGTGCCCTCAGAT' *.fastq > count/B1227_Rm0.txt
agrep -0 -c 'GAGTACTGACACTTGTT' *.fastq > count/B1231_Rm0.txt
agrep -0 -c 'CCCATATGCTCTTCGCT' *.fastq > count/B1232_Rm0.txt
agrep -0 -c 'TGTTCGGCGTATGCCCT' *.fastq > count/B1233_Rm0.txt
agrep -0 -c 'GTATGCGACTGAATACT' *.fastq > count/B1234_Rm0.txt
agrep -0 -c 'ACAACTTGACACATAGG' *.fastq > count/B1235_Rm0.txt
agrep -0 -c 'AAGAGAGGTCGCTTATT' *.fastq > count/B1237_Rm0.txt
agrep -0 -c 'AGACGTACAACGAGCTG' *.fastq > count/B1238_Rm0.txt
agrep -0 -c 'TAAGGAGATTCGTTGGC' *.fastq > count/B1239_Rm0.txt
agrep -0 -c 'CCATCCCTGTGCCGTTA' *.fastq > count/B1240_Rm0.txt
agrep -0 -c 'ACACAGTATGGTCGCAT' *.fastq > count/B1241_Rm0.txt
agrep -0 -c 'CAGGTACTCAATCCCGT' *.fastq > count/B1243_Rm0.txt
agrep -0 -c 'TAGGACTCCCCCCAGAT' *.fastq > count/B1244_Rm0.txt
agrep -0 -c 'CTTCTACGTGAGATCCC' *.fastq > count/B1245_Rm0.txt
agrep -0 -c 'ATGCGCAGGCTCCGATT' *.fastq > count/B1246_Rm0.txt
agrep -0 -c 'GTCGATCGCTAAGGTGC' *.fastq > count/B1247_Rm0.txt
agrep -0 -c 'TATCAGTTCGTAACCGA' *.fastq > count/B1248_Rm0.txt
agrep -0 -c 'GTTCCACGAGTTGAAGC' *.fastq > count/B1250_Rm0.txt
agrep -0 -c 'AGGGAACTTAGCACTTA' *.fastq > count/B1251_Rm0.txt
agrep -0 -c 'CTCCCAGTTTTGACCAT' *.fastq > count/B1252_Rm0.txt
agrep -0 -c 'GCGACTCAGTGACGGAA' *.fastq > count/B1253_Rm0.txt
agrep -0 -c 'TCCGATCCTATATGAGG' *.fastq > count/B1254_Rm0.txt
agrep -0 -c 'GGTGAGTCAACCACTAT' *.fastq > count/B1255_Rm0.txt
agrep -0 -c 'ACTCGCAGAAGTTCCTG' *.fastq > count/B1256_Rm0.txt
agrep -0 -c 'TTATGCCAGAAACCGTC' *.fastq > count/B1257_Rm0.txt
agrep -0 -c 'GCTACGTACCACAAGTG' *.fastq > count/B1258_Rm0.txt
agrep -0 -c 'GTTGATCGGCGACTTTA' *.fastq > count/B1259_Rm0.txt
agrep -0 -c 'TCCATTTCAAATCGGAG' *.fastq > count/B1260_Rm0.txt
agrep -0 -c 'CTAACTCCCATGCAGTG' *.fastq > count/B1261_Rm0.txt
agrep -0 -c 'TAAGCGATTGCATCTGT' *.fastq > count/B1263_Rm0.txt
agrep -0 -c 'CCTGAACTTCTACCCCC' *.fastq > count/B1264_Rm0.txt
agrep -0 -c 'AATGGCACATATCTGAC' *.fastq > count/B1266_Rm0.txt
agrep -0 -c 'CATGCTGGCCTATCACC' *.fastq > count/B1267_Rm0.txt
agrep -0 -c 'ACGGACCGGAACAGAGT' *.fastq > count/B1268_Rm0.txt
agrep -0 -c 'ATGGTCAACGGTGAGTG' *.fastq > count/B1270_Rm0.txt
agrep -0 -c 'CTTACGTCCCAACATCA' *.fastq > count/B1272_Rm0.txt
agrep -0 -c 'AAACCACTGCATTACCG' *.fastq > count/B1273_Rm0.txt
agrep -0 -c 'TGATATAGGTTTGCTCG' *.fastq > count/B1274_Rm0.txt
agrep -0 -c 'GTGAACGAGCGTACTAG' *.fastq > count/B1275_Rm0.txt
agrep -0 -c 'CGTAAATGCTGTAGTTG' *.fastq > count/B1277_Rm0.txt
agrep -0 -c 'GGTCACTCTTGGTGATA' *.fastq > count/B1278_Rm0.txt
agrep -0 -c 'TTCGGAATTTTACCCAC' *.fastq > count/B1280_Rm0.txt
agrep -0 -c 'CATAATCTCCCCTCGCA' *.fastq > count/B1281_Rm0.txt
agrep -0 -c 'TCTATCGTCAAGTTCCT' *.fastq > count/B1283_Rm0.txt
agrep -0 -c 'TGCATCCAATTCCAACA' *.fastq > count/B1284_Rm0.txt
agrep -0 -c 'GATATGCATCTCGTGTA' *.fastq > count/B1285_Rm0.txt
agrep -0 -c 'TGTAACTCGAGTATCTC' *.fastq > count/B1286_Rm0.txt
agrep -0 -c 'TTGACCTGGTTAGTCGC' *.fastq > count/B1287_Rm0.txt
agrep -0 -c 'GGAGGATGGGGTAGATA' *.fastq > count/B1288_Rm0.txt
agrep -0 -c 'ACCGAACAAGCCAAGAG' *.fastq > count/B1289_Rm0.txt
agrep -0 -c 'TAAAGGGGTGACAACGC' *.fastq > count/B1290_Rm0.txt
agrep -0 -c 'ACTAATGCGTTATCCAG' *.fastq > count/B1291_Rm0.txt
agrep -0 -c 'AGGTGGAATGCACGGTA' *.fastq > count/B1292_Rm0.txt
agrep -0 -c 'TGTGTCATGACGAGGAG' *.fastq > count/B1293_Rm0.txt
agrep -0 -c 'AGATTCGGCCTGTTCAA' *.fastq > count/B1294_Rm0.txt
agrep -0 -c 'AGGTAACGGGCTTTTAA' *.fastq > count/B1295_Rm0.txt
agrep -0 -c 'CGCCCTGAAGTAGACAA' *.fastq > count/B1296_Rm0.txt
agrep -0 -c 'AACCCTACGATATAACG' *.fastq > count/B1297_Rm0.txt
agrep -0 -c 'TAGCCACGTGAACGCAG' *.fastq > count/B1298_Rm0.txt
agrep -0 -c 'GTAAGTATGCCCTAACC' *.fastq > count/B1299_Rm0.txt
agrep -0 -c 'CCGTATCAAATTGTAGG' *.fastq > count/B1300_Rm0.txt
agrep -0 -c 'TGGCTTTGGGTTATCCT' *.fastq > count/B1301_Rm0.txt
agrep -0 -c 'TCTGGCGGGAATCTGCA' *.fastq > count/B1302_Rm0.txt
agrep -0 -c 'TTCTGAGACGACTCATC' *.fastq > count/B1303_Rm0.txt
agrep -0 -c 'CTGCAAAAACAGGCTAG' *.fastq > count/B1305_Rm0.txt
agrep -0 -c 'AGTGGACAATGACACGA' *.fastq > count/B1306_Rm0.txt
agrep -0 -c 'GAGTAATGAGATGTCGC' *.fastq > count/B1307_Rm0.txt
agrep -0 -c 'AGTGTGTGCCCTATCAC' *.fastq > count/B1308_Rm0.txt
agrep -0 -c 'TGACTCGATCTCTCTAC' *.fastq > count/B1309_Rm0.txt
agrep -0 -c 'GGGTCGACTTATATCGT' *.fastq > count/B1310_Rm0.txt
agrep -0 -c 'TGCCTTTCGAATGTGTG' *.fastq > count/B1311_Rm0.txt
agrep -0 -c 'GCTATTCGAATGGGTCA' *.fastq > count/B1312_Rm0.txt
agrep -0 -c 'TAGTTACACTTTCCCGT' *.fastq > count/B1314_Rm0.txt
agrep -0 -c 'ACCAACTGCTCCCTAGC' *.fastq > count/B1315_Rm0.txt
agrep -0 -c 'AAGTTCAACATACGCTG' *.fastq > count/B1316_Rm0.txt
agrep -0 -c 'GCCGAGCGATTATCTTA' *.fastq > count/B1317_Rm0.txt
agrep -0 -c 'CTGTACAATCCGATAGT' *.fastq > count/B1319_Rm0.txt
agrep -0 -c 'TGGGAGCCGTGCAAATA' *.fastq > count/B1321_Rm0.txt
agrep -0 -c 'CTCGAACAGACGTATAA' *.fastq > count/B1322_Rm0.txt
agrep -0 -c 'GGGGGACATGAGGATTG' *.fastq > count/B1323_Rm0.txt
agrep -0 -c 'GGCCTTCAGCACCACTT' *.fastq > count/B1324_Rm0.txt
agrep -0 -c 'CCCCCATGAGGACACAT' *.fastq > count/B1325_Rm0.txt
agrep -0 -c 'CCTCTATGCGGGATGCA' *.fastq > count/B1326_Rm0.txt
agrep -0 -c 'ACGCTGGTCCAGCGTAT' *.fastq > count/B1327_Rm0.txt
agrep -0 -c 'ACGTCTATATGCTTGCG' *.fastq > count/B1328_Rm0.txt
agrep -0 -c 'TCCTGGGCGCTTAGATT' *.fastq > count/B1329_Rm0.txt
agrep -0 -c 'GGAACCAAGTTAAAGCA' *.fastq > count/B1330_Rm0.txt
agrep -0 -c 'CCGCGTTTAAAGAGACG' *.fastq > count/B1332_Rm0.txt
agrep -0 -c 'TTTAGGATTGGCGATGT' *.fastq > count/B1333_Rm0.txt
agrep -0 -c 'TCGTTGTCGTATTACAG' *.fastq > count/B1336_Rm0.txt
agrep -0 -c 'GTTGTGATTCGGGTACA' *.fastq > count/B1338_Rm0.txt
agrep -0 -c 'TATCAACCGGACTACTT' *.fastq > count/B1339_Rm0.txt
agrep -0 -c 'GAGGCTGCTTGATCGGT' *.fastq > count/B1340_Rm0.txt
agrep -0 -c 'GATATAGACGATCGTTG' *.fastq > count/B1342_Rm0.txt
agrep -0 -c 'AGGGTTAAGTGGCTGGT' *.fastq > count/B1343_Rm0.txt
agrep -0 -c 'GTTCTTGATTCTGTGCG' *.fastq > count/B1344_Rm0.txt
agrep -0 -c 'AAAGGGGGCTAATCTAA' *.fastq > count/B1345_Rm0.txt
agrep -0 -c 'CGAGTTTTCCCCACATA' *.fastq > count/B1346_Rm0.txt
agrep -0 -c 'GTCAAAGTCGAATGTCA' *.fastq > count/B1347_Rm0.txt
agrep -0 -c 'CGAGTAGGAGTTGAGAG' *.fastq > count/B1348_Rm0.txt
agrep -0 -c 'ATAGACCTGTGATAGGT' *.fastq > count/B1349_Rm0.txt
agrep -0 -c 'ATAAACGCACCGAGCAT' *.fastq > count/B1350_Rm0.txt
agrep -0 -c 'ATGTCCAGTTCGCGACC' *.fastq > count/B1351_Rm0.txt
agrep -0 -c 'CTGAAGTTAACGTCCCT' *.fastq > count/B1352_Rm0.txt
agrep -0 -c 'ACTGGGCCTAATCGCTT' *.fastq > count/B1353_Rm0.txt
agrep -0 -c 'GGAGGCCATGATTTGTA' *.fastq > count/B1355_Rm0.txt
agrep -0 -c 'CCACGATATAGTTTGCG' *.fastq > count/B1357_Rm0.txt
agrep -0 -c 'ATTCTACTCAGCGGCCA' *.fastq > count/B1358_Rm0.txt
agrep -0 -c 'CAGCTTAACCCTGTGTG' *.fastq > count/B1359_Rm0.txt
agrep -0 -c 'GGCCTGCTATAAGGAGG' *.fastq > count/B1361_Rm0.txt
agrep -0 -c 'TGTCTGATCCGCCACTA' *.fastq > count/B1362_Rm0.txt
agrep -0 -c 'CGTATCCCCGTATTACG' *.fastq > count/B1363_Rm0.txt
agrep -0 -c 'CCATAAGAACATGCCGT' *.fastq > count/B1365_Rm0.txt
agrep -0 -c 'CAGTTTCTGACGTGCCT' *.fastq > count/B1366_Rm0.txt
agrep -0 -c 'GAGTCGCAATCTCAGCG' *.fastq > count/B1367_Rm0.txt
agrep -0 -c 'CACTCTGTCCTCGTCGA' *.fastq > count/B1368_Rm0.txt
agrep -0 -c 'CTCAAAAGTGATAACCG' *.fastq > count/B1369_Rm0.txt
agrep -0 -c 'ATCAGCTCCTTGGTCCT' *.fastq > count/B1370_Rm0.txt
agrep -0 -c 'TATATCCCCAGACACTA' *.fastq > count/B1371_Rm0.txt
agrep -0 -c 'CGTGTTAGGTTGTATCG' *.fastq > count/B1374_Rm0.txt
agrep -0 -c 'TTCGATTCGTAACTCAC' *.fastq > count/B1375_Rm0.txt
agrep -0 -c 'GTTTATCAGCGGAGAAC' *.fastq > count/B1378_Rm0.txt
agrep -0 -c 'CTAGACACCACGAGATG' *.fastq > count/B1380_Rm0.txt
agrep -0 -c 'TTTAGCAGCTCAGGGTC' *.fastq > count/B1381_Rm0.txt
agrep -0 -c 'TGAGCAGTTCATTGCGC' *.fastq > count/B1383_Rm0.txt
agrep -0 -c 'AATCTACCGCCTACAGA' *.fastq > count/B1384_Rm0.txt
agrep -0 -c 'ATGCTTCGTCCCTCTTG' *.fastq > count/B1385_Rm0.txt
agrep -0 -c 'TCGTAACGGATCGCGTG' *.fastq > count/B1386_Rm0.txt
agrep -0 -c 'GCCATAAGACTTCCTAT' *.fastq > count/B1387_Rm0.txt
agrep -0 -c 'TGGAACTTTATAGGCCC' *.fastq > count/B1388_Rm0.txt
agrep -0 -c 'TTTAAGTTACCCTCCAC' *.fastq > count/B1389_Rm0.txt
agrep -0 -c 'GGTGAGGTGTCTCAGAC' *.fastq > count/B1391_Rm0.txt
agrep -0 -c 'ATTGCGAGCTTACTGCC' *.fastq > count/B1392_Rm0.txt
agrep -0 -c 'CATAAGGCACCGGGTAC' *.fastq > count/B1393_Rm0.txt
agrep -0 -c 'CAGCAGCGATGGAATGC' *.fastq > count/B1394_Rm0.txt
agrep -0 -c 'AGCCTTCGTGCCAAACT' *.fastq > count/B1395_Rm0.txt
agrep -0 -c 'GATCATGCGACCGTGAC' *.fastq > count/B1397_Rm0.txt
agrep -0 -c 'GTGTCCGACCACTCAGA' *.fastq > count/B1398_Rm0.txt
agrep -0 -c 'TTCAAAACTATGGGTCC' *.fastq > count/B1399_Rm0.txt
agrep -0 -c 'GGTTGGTTGCCCTTTTA' *.fastq > count/B1400_Rm0.txt
agrep -0 -c 'GCAAACTAGGTGGATTG' *.fastq > count/B1401_Rm0.txt
agrep -0 -c 'TGGCAACTGTGTAGCAG' *.fastq > count/B1402_Rm0.txt
agrep -0 -c 'GTAGACTCCACCTCTAT' *.fastq > count/B1403_Rm0.txt
agrep -0 -c 'ATTTCGGAGAGTAATGC' *.fastq > count/B1404_Rm0.txt
agrep -0 -c 'GCAATTGTCCCTAAACG' *.fastq > count/B1405_Rm0.txt
agrep -0 -c 'TCCGCTTAGGACAGCGA' *.fastq > count/B1406_Rm0.txt
agrep -0 -c 'CTGTTGTGCCCTCTTAG' *.fastq > count/B1407_Rm0.txt
agrep -0 -c 'GGCATAGGGCGTTTAGG' *.fastq > count/B1408_Rm0.txt
agrep -0 -c 'CCTACAGATCACCAGCT' *.fastq > count/B1409_Rm0.txt
agrep -0 -c 'CCGGAATCCTGACTTCG' *.fastq > count/B1410_Rm0.txt
agrep -0 -c 'ATTAATGAGGGACCTTG' *.fastq > count/B1412_Rm0.txt
agrep -0 -c 'ATGAGGTATTGCGCGTA' *.fastq > count/B1413_Rm0.txt
agrep -0 -c 'GCATCTCTTAGGCTACT' *.fastq > count/B1414_Rm0.txt
agrep -0 -c 'GAAAGGTATGCGCTGCA' *.fastq > count/B1415_Rm0.txt
agrep -0 -c 'ATAGTACCCGTCGAGCT' *.fastq > count/B1416_Rm0.txt
agrep -0 -c 'CAATTACCGGCGTTAAT' *.fastq > count/B1417_Rm0.txt
agrep -0 -c 'GATAGCAGCGACCCTAC' *.fastq > count/B1418_Rm0.txt
agrep -0 -c 'AACGCTTCCCTGGATGA' *.fastq > count/B1419_Rm0.txt
agrep -0 -c 'CCATGATCCGGTACTCC' *.fastq > count/B1420_Rm0.txt
agrep -0 -c 'CCATAAATTTCCACCGT' *.fastq > count/B1422_Rm0.txt
agrep -0 -c 'AAGGGACACTAATGCGA' *.fastq > count/B1423_Rm0.txt
agrep -0 -c 'CGTATTCGCAGAACTTG' *.fastq > count/B1424_Rm0.txt
agrep -0 -c 'TCGTAGTTGCGGCTACC' *.fastq > count/B1425_Rm0.txt
agrep -0 -c 'CCGGGGGAATTAGAACT' *.fastq > count/B1427_Rm0.txt
agrep -0 -c 'AACAGGCTACCTACGTC' *.fastq > count/B1429_Rm0.txt
agrep -0 -c 'GATTACATACCCTTGCT' *.fastq > count/B1430_Rm0.txt
agrep -0 -c 'GCCCAGCTCTTTTAGCC' *.fastq > count/B1431_Rm0.txt
agrep -0 -c 'GGTCAGTACATTCGACT' *.fastq > count/B1433_Rm0.txt
agrep -0 -c 'CGGCTACTTTCTCAATC' *.fastq > count/B1435_Rm0.txt
agrep -0 -c 'GATGGGATAGTTGGCAA' *.fastq > count/B1436_Rm0.txt
agrep -0 -c 'CGGTCTATTGCTGGCGA' *.fastq > count/B1437_Rm0.txt
agrep -0 -c 'GCACACTGAAACAGGAC' *.fastq > count/B1439_Rm0.txt
agrep -0 -c 'CAACCGTCTGACGACAC' *.fastq > count/B1440_Rm0.txt
agrep -0 -c 'CAGGAACCAGTTGACAA' *.fastq > count/B1441_Rm0.txt
agrep -0 -c 'GCTTAGGAACGACATAC' *.fastq > count/B1442_Rm0.txt
agrep -0 -c 'GCTAGCAATCCCAACCC' *.fastq > count/B1443_Rm0.txt
agrep -0 -c 'GCTGCACGGAAGATTGC' *.fastq > count/B1444_Rm0.txt
agrep -0 -c 'AGCGAAATCCCTATTCG' *.fastq > count/B1445_Rm0.txt
agrep -0 -c 'TGAGGGCCGATGCTTAG' *.fastq > count/B1446_Rm0.txt
agrep -0 -c 'CGCCACCAATATCGATG' *.fastq > count/B1447_Rm0.txt
agrep -0 -c 'CACGGCGCTATGAATCG' *.fastq > count/B1448_Rm0.txt
agrep -0 -c 'CACATAACCATACTCCT' *.fastq > count/B1449_Rm0.txt
agrep -0 -c 'TCATGTAACGCCGTAAG' *.fastq > count/B1450_Rm0.txt
agrep -0 -c 'TGGGCGGGAATAGAGAC' *.fastq > count/B1451_Rm0.txt
agrep -0 -c 'GTCCCACCAAGCGTAAT' *.fastq > count/B1452_Rm0.txt
agrep -0 -c 'GTGTGCCGAAGTCGGAA' *.fastq > count/B1453_Rm0.txt
agrep -0 -c 'ACGAACTACCCATTAGT' *.fastq > count/B1454_Rm0.txt
agrep -0 -c 'GGCCCCGAAAGTTCTAG' *.fastq > count/B1455_Rm0.txt
agrep -0 -c 'CAATTGGAGGGCAGTCC' *.fastq > count/B1457_Rm0.txt
agrep -0 -c 'CACAAGATCAAATCCGA' *.fastq > count/B1458_Rm0.txt
agrep -0 -c 'TGCGTTAATGGACAGTA' *.fastq > count/B1459_Rm0.txt
agrep -0 -c 'TAGCACCAGCATTGGAT' *.fastq > count/B1461_Rm0.txt
agrep -0 -c 'GTACAGGGCTCGAGTAG' *.fastq > count/B1463_Rm0.txt
agrep -0 -c 'AAGAGCGAGACAGTACT' *.fastq > count/B1464_Rm0.txt
agrep -0 -c 'GACCGAAGATATACGGC' *.fastq > count/B1465_Rm0.txt
agrep -0 -c 'GCAAACAGGGATTTCAC' *.fastq > count/B1468_Rm0.txt
agrep -0 -c 'TATGTGCCGATACAGGC' *.fastq > count/B1470_Rm0.txt
agrep -0 -c 'TCGCTTCTCGTTACGGC' *.fastq > count/B1471_Rm0.txt
agrep -0 -c 'ATTGGCTTTACCCATGT' *.fastq > count/B1472_Rm0.txt
agrep -0 -c 'AGAGTATGATGCAGTAC' *.fastq > count/B1473_Rm0.txt
agrep -0 -c 'CGGGTAGTCTAGGTTCC' *.fastq > count/B1474_Rm0.txt
agrep -0 -c 'TGTCTGTCGAAGGGAGA' *.fastq > count/B1475_Rm0.txt
agrep -0 -c 'CAAACGTCCAAGATTCG' *.fastq > count/B1476_Rm0.txt
agrep -0 -c 'GGTCGATCTCTCCGACT' *.fastq > count/B1477_Rm0.txt
agrep -0 -c 'TGCTTCCACGAGGCTAT' *.fastq > count/B1479_Rm0.txt
agrep -0 -c 'CCCGGCTAATCACACAG' *.fastq > count/B1480_Rm0.txt
agrep -0 -c 'GCGATTCAAAGAGTTTG' *.fastq > count/B1481_Rm0.txt
agrep -0 -c 'TTACGGAGGTAACTTCT' *.fastq > count/B1483_Rm0.txt
agrep -0 -c 'CTAGATCGTAACGCCTG' *.fastq > count/B1484_Rm0.txt
agrep -0 -c 'GTTCAAGGTATGATCCC' *.fastq > count/B1485_Rm0.txt
agrep -0 -c 'CCCTTCCAAGCTAGATG' *.fastq > count/B1486_Rm0.txt
agrep -0 -c 'CAGCGCTCTCATTCGCA' *.fastq > count/B1487_Rm0.txt
agrep -0 -c 'CTTGATCTGGTCACCTT' *.fastq > count/B1488_Rm0.txt
agrep -0 -c 'GCTCCACAATTACCAAG' *.fastq > count/B1489_Rm0.txt
agrep -0 -c 'GTAACGACGTCCAAACA' *.fastq > count/B1491_Rm0.txt
agrep -0 -c 'AAGCCATAGCGGTTCTG' *.fastq > count/B1492_Rm0.txt
agrep -0 -c 'CTTGAACAACCCGGAGG' *.fastq > count/B1494_Rm0.txt
agrep -0 -c 'GATTTGGAGTAACCGCG' *.fastq > count/B1495_Rm0.txt
agrep -0 -c 'TACAATCCGTACATCCC' *.fastq > count/B1496_Rm0.txt
agrep -0 -c 'ACGTAGTAGTACTATGC' *.fastq > count/B1497_Rm0.txt
agrep -0 -c 'TACGCCAGCCACAAATA' *.fastq > count/B1498_Rm0.txt
agrep -0 -c 'CAGAATGTACCGCGTCG' *.fastq > count/B1500_Rm0.txt
agrep -0 -c 'GGCTTGCTACGTGCAGA' *.fastq > count/B1501_Rm0.txt
agrep -0 -c 'AGGAGCGTCGAAGAACG' *.fastq > count/B1502_Rm0.txt
agrep -0 -c 'CATCCCACATAGCCAGT' *.fastq > count/B1503_Rm0.txt
agrep -0 -c 'AGTGGCGTAGTTACCGA' *.fastq > count/B1504_Rm0.txt
agrep -0 -c 'TCGGACTCTACTGCAAT' *.fastq > count/B1505_Rm0.txt
agrep -0 -c 'GCATCAACACGTGAAGT' *.fastq > count/B1506_Rm0.txt
agrep -0 -c 'AAACAAACCCGGATCAA' *.fastq > count/B1507_Rm0.txt
agrep -0 -c 'ACTTCCATAAGGCTCGT' *.fastq > count/B1509_Rm0.txt
agrep -0 -c 'GTTGTGCCTTCATTACA' *.fastq > count/B1511_Rm0.txt
agrep -0 -c 'AGGCCAAACGGGGTTAT' *.fastq > count/B1512_Rm0.txt
agrep -0 -c 'GCGGCATCGGCATATGA' *.fastq > count/B1513_Rm0.txt
agrep -0 -c 'AGAATTGCTCGAAGCAA' *.fastq > count/B1514_Rm0.txt
agrep -0 -c 'GACTAACCACCATCAGG' *.fastq > count/B1515_Rm0.txt
agrep -0 -c 'TAGAAGGTAATACCCCG' *.fastq > count/B1516_Rm0.txt
agrep -0 -c 'AATGTGTTTAGCTCGAG' *.fastq > count/B1517_Rm0.txt
agrep -0 -c 'AACGAACCGTGTAAGCA' *.fastq > count/B1518_Rm0.txt
agrep -0 -c 'GAAACGCTCCGATCCGT' *.fastq > count/B1519_Rm0.txt
agrep -0 -c 'AGTATGTAATCGGCGCA' *.fastq > count/B1521_Rm0.txt
agrep -0 -c 'CAGCTACCGTTTTGAGG' *.fastq > count/B1522_Rm0.txt
agrep -0 -c 'CCATGGTAGTCGCAATC' *.fastq > count/B1523_Rm0.txt
agrep -0 -c 'TTATTGGTGGCCTTCGG' *.fastq > count/B1524_Rm0.txt
agrep -0 -c 'TGGGGAGCGTAGACTTA' *.fastq > count/B1525_Rm0.txt
agrep -0 -c 'GGTTCTTGCTTCAGAAC' *.fastq > count/B1526_Rm0.txt
agrep -0 -c 'GATCGCCGGATTTTGAA' *.fastq > count/B1527_Rm0.txt
agrep -0 -c 'GCCGTCGAGGTTTATAT' *.fastq > count/B1528_Rm0.txt
agrep -0 -c 'ATGGGGGTTAGTAGTGA' *.fastq > count/B1529_Rm0.txt
agrep -0 -c 'AGGCGAAAGTTGGATAT' *.fastq > count/B1530_Rm0.txt
agrep -0 -c 'GTTGAAAGCTTACGGAA' *.fastq > count/B1531_Rm0.txt
agrep -0 -c 'ACTGCATACAGAGTCAA' *.fastq > count/B1532_Rm0.txt
agrep -0 -c 'ACGCCGGTCATCTCTCA' *.fastq > count/B1535_Rm0.txt
agrep -0 -c 'AGTGTGGCCGGTTCATT' *.fastq > count/B1536_Rm0.txt
agrep -0 -c 'GAAACAGTCGGTTATCT' *.fastq > count/B1538_Rm0.txt
agrep -0 -c 'TGCGACGCTAACTCCAC' *.fastq > count/B1540_Rm0.txt
agrep -0 -c 'CTCCTACACTTTTGCTA' *.fastq > count/B1541_Rm0.txt
agrep -0 -c 'GCCTGTCCAGGTAAACA' *.fastq > count/B1542_Rm0.txt
agrep -0 -c 'ACAGGTTCCGGGAGACA' *.fastq > count/B1544_Rm0.txt
agrep -0 -c 'TTTTGAGCCCGTGCACG' *.fastq > count/B1545_Rm0.txt
agrep -0 -c 'TGAACGCGCTATTGGCC' *.fastq > count/B1546_Rm0.txt
agrep -0 -c 'GGGTACTGTCAGGAAAC' *.fastq > count/B1547_Rm0.txt
agrep -0 -c 'TGCGCGTAGAAAGAAAT' *.fastq > count/B1548_Rm0.txt
agrep -0 -c 'TAATTCGGGTTCAGGCC' *.fastq > count/B1549_Rm0.txt
agrep -0 -c 'AGAAGCTGATTCAGTGT' *.fastq > count/B1550_Rm0.txt
agrep -0 -c 'TTTGCTGGCCGGAATCC' *.fastq > count/B1551_Rm0.txt
agrep -0 -c 'AGGGGTTGAGCAATTAG' *.fastq > count/B1552_Rm0.txt
agrep -0 -c 'TGGCGCTCTAAATCGGC' *.fastq > count/B1553_Rm0.txt
agrep -0 -c 'CAAGACCCTCCAAGTGT' *.fastq > count/B1554_Rm0.txt
agrep -0 -c 'AAAGATATTCGGTGGTC' *.fastq > count/B1555_Rm0.txt
agrep -0 -c 'GCATGCGATCTCTACTG' *.fastq > count/B1556_Rm0.txt
agrep -0 -c 'ATACATACCTCTCCGTT' *.fastq > count/B1557_Rm0.txt
agrep -0 -c 'GATCCCGATCCAATATC' *.fastq > count/B1558_Rm0.txt
agrep -0 -c 'CTCCTGCTGTGAAATGG' *.fastq > count/B1559_Rm0.txt
agrep -0 -c 'GTGATGCCATGTCGGAA' *.fastq > count/B1561_Rm0.txt
agrep -0 -c 'CATATGGGGAATTGTCC' *.fastq > count/B1562_Rm0.txt
agrep -0 -c 'GCATGGGTATTCCGTCA' *.fastq > count/B1563_Rm0.txt
agrep -0 -c 'CTTCGTGCACGGTTTGA' *.fastq > count/B1564_Rm0.txt
agrep -0 -c 'AACCGTGTCCGAAGTAG' *.fastq > count/B1565_Rm0.txt
agrep -0 -c 'ATCGAGCTAGAGAGTGA' *.fastq > count/B1566_Rm0.txt
agrep -0 -c 'AAGGGGGCCAGATGCTT' *.fastq > count/B1567_Rm0.txt
agrep -0 -c 'ACCCGGTCGCATTTACC' *.fastq > count/B1568_Rm0.txt
agrep -0 -c 'GCACTACTAGCACTGGC' *.fastq > count/B1569_Rm0.txt
agrep -0 -c 'TTGCGCGTTTTCACTAC' *.fastq > count/B1570_Rm0.txt
agrep -0 -c 'AGGGATTTTGGCCGAGC' *.fastq > count/B1571_Rm0.txt
agrep -0 -c 'AATGGTAAGAGCGAAAC' *.fastq > count/B1572_Rm0.txt
agrep -0 -c 'AACACCCCTTTACTGCG' *.fastq > count/B1573_Rm0.txt
agrep -0 -c 'GTACCCCACCTCATACG' *.fastq > count/B1574_Rm0.txt
agrep -0 -c 'GGCAAGCATGACATGCA' *.fastq > count/B1575_Rm0.txt
agrep -0 -c 'GGGAATCGAATCGTGAA' *.fastq > count/B1576_Rm0.txt
agrep -0 -c 'TAACAGCTTGGGTTGAT' *.fastq > count/B1577_Rm0.txt
agrep -0 -c 'ACACAGTTCACGTGCAT' *.fastq > count/B1580_Rm0.txt
agrep -0 -c 'CGTGATATCTAGTGCCG' *.fastq > count/B1582_Rm0.txt
agrep -0 -c 'GTTCGCAGTGCATTTTG' *.fastq > count/B1584_Rm0.txt
agrep -0 -c 'AGAATCTTATCCCGTGG' *.fastq > count/B1585_Rm0.txt
agrep -0 -c 'ACATTCATCCTGACATC' *.fastq > count/B1586_Rm0.txt
agrep -0 -c 'GGGTTCGGTAAGATGCA' *.fastq > count/B1587_Rm0.txt
agrep -0 -c 'GGAACTGGCCAGAAGTT' *.fastq > count/B1588_Rm0.txt
agrep -0 -c 'ACTGCCCTGTTCGTAGC' *.fastq > count/B1589_Rm0.txt
agrep -0 -c 'CTGGACACCTACCAACT' *.fastq > count/B1590_Rm0.txt
agrep -0 -c 'AACGCCACCCTTATTGT' *.fastq > count/B1592_Rm0.txt
agrep -0 -c 'TTTCCACACGACATTGC' *.fastq > count/B1593_Rm0.txt
agrep -0 -c 'CATTCAGTACAGCGGAA' *.fastq > count/B1594_Rm0.txt
agrep -0 -c 'GGGCGGTAGCGGTTTAT' *.fastq > count/B1595_Rm0.txt
agrep -0 -c 'TACTCGGGAGGACAGTC' *.fastq > count/B1596_Rm0.txt
agrep -0 -c 'CTAGTGTTTACGTTGTG' *.fastq > count/B1597_Rm0.txt
agrep -0 -c 'GCTGCTACGTCGATGCT' *.fastq > count/B1598_Rm0.txt
agrep -0 -c 'GGTATCGTACTCGATCC' *.fastq > count/B1599_Rm0.txt
agrep -0 -c 'TTACGCGGACTTAACGC' *.fastq > count/B1600_Rm0.txt
agrep -0 -c 'TGATCCCATACTGTTGT' *.fastq > count/B1602_Rm0.txt
agrep -0 -c 'CTTCGCGGCGAATTCGT' *.fastq > count/B1603_Rm0.txt
agrep -0 -c 'TGCAAGATGCAGTTCAT' *.fastq > count/B1605_Rm0.txt
agrep -0 -c 'TCACACGGCCACTGGAT' *.fastq > count/B1606_Rm0.txt
agrep -0 -c 'GCGTTATGAGGGTACTA' *.fastq > count/B1607_Rm0.txt
agrep -0 -c 'CGCTTAGCGCACTGAGT' *.fastq > count/B1608_Rm0.txt
agrep -0 -c 'GATAGTTAGGGAATACC' *.fastq > count/B1609_Rm0.txt
agrep -0 -c 'AGCTGGCGTGAACATCC' *.fastq > count/B1610_Rm0.txt
agrep -0 -c 'ACCCTTCTTGACCACCT' *.fastq > count/B1611_Rm0.txt
agrep -0 -c 'AGATCGTTGCGCCTGAG' *.fastq > count/B1612_Rm0.txt
agrep -0 -c 'TCTTGTTCACCACGGCC' *.fastq > count/B1613_Rm0.txt
agrep -0 -c 'GAGAATTCATGATGGCA' *.fastq > count/B1615_Rm0.txt
agrep -0 -c 'GTAAGCAGGAGGATAGA' *.fastq > count/B1616_Rm0.txt
agrep -0 -c 'CGGCATAACGTCAATCC' *.fastq > count/B1617_Rm0.txt
agrep -0 -c 'GAGATCCCGTGATAAAC' *.fastq > count/B1618_Rm0.txt
agrep -0 -c 'TATGAAATTACGCGGGC' *.fastq > count/B1619_Rm0.txt
agrep -0 -c 'TGCCTGTCTTGACGACT' *.fastq > count/B1620_Rm0.txt
agrep -0 -c 'CCCTCATCCGATAACAA' *.fastq > count/B1621_Rm0.txt
agrep -0 -c 'TTCGATACTCTCTGCAA' *.fastq > count/B1622_Rm0.txt
agrep -0 -c 'GACAGAGCTCAAGTAGC' *.fastq > count/B1625_Rm0.txt
agrep -0 -c 'CAATGGTCGATACAAGG' *.fastq > count/B1626_Rm0.txt
agrep -0 -c 'GCCAGGTCATGTGTAGA' *.fastq > count/B1627_Rm0.txt
agrep -0 -c 'CGCCTAAATGTGGCCCT' *.fastq > count/B1628_Rm0.txt
agrep -0 -c 'CCTTTCATACGGGGTGA' *.fastq > count/B1629_Rm0.txt
agrep -0 -c 'GAAGAGAACACCCACTT' *.fastq > count/B1630_Rm0.txt
agrep -0 -c 'CTCGAAAGGGCCAGTCT' *.fastq > count/B1631_Rm0.txt
agrep -0 -c 'TCCCCTCATCGTTGGAC' *.fastq > count/B1632_Rm0.txt
agrep -0 -c 'ATTTTCGCCTTATGACG' *.fastq > count/B1633_Rm0.txt
agrep -0 -c 'AGTCTCTCTCAGACACG' *.fastq > count/B1634_Rm0.txt
agrep -0 -c 'GCAAGACCCCAGACAAT' *.fastq > count/B1635_Rm0.txt
agrep -0 -c 'GTGGAATCTGGCGAAGG' *.fastq > count/B1636_Rm0.txt
agrep -0 -c 'GTTTTTGTGGTATACGG' *.fastq > count/B1637_Rm0.txt
agrep -0 -c 'TCGTGACGGATACAGGT' *.fastq > count/B1638_Rm0.txt
agrep -0 -c 'CTTTTATCCACGCAGAT' *.fastq > count/B1639_Rm0.txt
agrep -0 -c 'CTTCGCAAAAGTGCCTT' *.fastq > count/B1640_Rm0.txt
agrep -0 -c 'TCGAATGGGCGTTAGTA' *.fastq > count/B1641_Rm0.txt
agrep -0 -c 'TTGAATCCGGATCCTCG' *.fastq > count/B1642_Rm0.txt
agrep -0 -c 'CCGAAGGCCGCCAAAAT' *.fastq > count/B1643_Rm0.txt
agrep -0 -c 'AGGCCCAGAAATGCGCA' *.fastq > count/B1644_Rm0.txt
agrep -0 -c 'GTAACCAGGTCTTAGAG' *.fastq > count/B1645_Rm0.txt
agrep -0 -c 'CCAGTGAAACTTGGCGG' *.fastq > count/B1646_Rm0.txt
agrep -0 -c 'AGGGACATTATCCGGAA' *.fastq > count/B1648_Rm0.txt
agrep -0 -c 'TCGCCATCAGGGATTGG' *.fastq > count/B1649_Rm0.txt
agrep -0 -c 'TCGGTTGCCCTAGCATG' *.fastq > count/B1650_Rm0.txt
agrep -0 -c 'TTCTGTGACGTGGAATA' *.fastq > count/B1651_Rm0.txt
agrep -0 -c 'CTCTCGAAAGATCCAGC' *.fastq > count/B1652_Rm0.txt
agrep -0 -c 'GTCGACCATACATAGAT' *.fastq > count/B1653_Rm0.txt
agrep -0 -c 'TGCAAAGTACCTGATCG' *.fastq > count/B1655_Rm0.txt
agrep -0 -c 'ATTAGCAATACGAGTGG' *.fastq > count/B1656_Rm0.txt
agrep -0 -c 'GCGGCTACTGGTGATTA' *.fastq > count/B1657_Rm0.txt
agrep -0 -c 'CCTCACTGTGAGGACCT' *.fastq > count/B1658_Rm0.txt
agrep -0 -c 'TCGGACGCGTTTGTGTT' *.fastq > count/B1659_Rm0.txt
agrep -0 -c 'TCCCGCGATGCATACCT' *.fastq > count/B1660_Rm0.txt
agrep -0 -c 'TGGCGCCATATCTCGTG' *.fastq > count/B1662_Rm0.txt
agrep -0 -c 'AACTCCTGGCTTGCAAC' *.fastq > count/B1663_Rm0.txt
agrep -0 -c 'CGACTACTGCTTCAATT' *.fastq > count/B1664_Rm0.txt
agrep -0 -c 'TCGATTTTAGGCAATCC' *.fastq > count/B1665_Rm0.txt
agrep -0 -c 'GTGCATTGAGACCCCAA' *.fastq > count/B1666_Rm0.txt
agrep -0 -c 'AACAAACGTTGGGAGCC' *.fastq > count/B1667_Rm0.txt
agrep -0 -c 'ACTACATGTCAGGTTAC' *.fastq > count/B1668_Rm0.txt
agrep -0 -c 'AGAACCTTCCGGGATCA' *.fastq > count/B1669_Rm0.txt
agrep -0 -c 'TGGTTTTAGGCTTTTGC' *.fastq > count/B1670_Rm0.txt
agrep -0 -c 'TCCACAGGCGGTTGGTA' *.fastq > count/B1671_Rm0.txt
agrep -0 -c 'GAGAGACTGATTCCGCA' *.fastq > count/B1672_Rm0.txt
agrep -0 -c 'CGCACTTCTAGGAGGTC' *.fastq > count/B1673_Rm0.txt
agrep -0 -c 'GGATATACTACAGTAGC' *.fastq > count/B1674_Rm0.txt
agrep -0 -c 'ACACTGGAGACCGCGTT' *.fastq > count/B1675_Rm0.txt
agrep -0 -c 'AACGGCGTAACAATTAC' *.fastq > count/B1676_Rm0.txt
agrep -0 -c 'ACCTAACAGCACGCCTA' *.fastq > count/B1677_Rm0.txt
agrep -0 -c 'GTACAGGCATCTAATCC' *.fastq > count/B1678_Rm0.txt
agrep -0 -c 'GCTTCTTCTGTCCGAAG' *.fastq > count/B1679_Rm0.txt
agrep -0 -c 'TGAACTCGCAAGGACGT' *.fastq > count/B1680_Rm0.txt
agrep -0 -c 'CGCCGCACAAGTCACTA' *.fastq > count/B1681_Rm0.txt
agrep -0 -c 'CGCTATCTATAGAACAG' *.fastq > count/B1682_Rm0.txt
agrep -0 -c 'ATAGCTGGTCGTTAGTT' *.fastq > count/B1683_Rm0.txt
agrep -0 -c 'AGCGCATATCTGCCGCT' *.fastq > count/B1684_Rm0.txt
agrep -0 -c 'TTAGACTACCCACGTGA' *.fastq > count/B1685_Rm0.txt
agrep -0 -c 'GGGTTATACCAGGTCAT' *.fastq > count/B1686_Rm0.txt
agrep -0 -c 'CCTAGCCGATAGTTAGT' *.fastq > count/B1687_Rm0.txt
agrep -0 -c 'CCAACAAAAGTTCTCGC' *.fastq > count/B1688_Rm0.txt
agrep -0 -c 'ATATCCCGTGCGGTCTA' *.fastq > count/B1689_Rm0.txt
agrep -0 -c 'ACTGACAGTGAGCCCAC' *.fastq > count/B1690_Rm0.txt
agrep -0 -c 'CCGGACCTCATCGTATT' *.fastq > count/B1691_Rm0.txt
agrep -0 -c 'AGCCCGCTAGAAGATGG' *.fastq > count/B1692_Rm0.txt
agrep -0 -c 'ACACGCCAGGGACAATT' *.fastq > count/B1694_Rm0.txt
agrep -0 -c 'GACGCAAATAGGTCCAT' *.fastq > count/B1695_Rm0.txt
agrep -0 -c 'TGATCTTCACCCCACAC' *.fastq > count/B1697_Rm0.txt
agrep -0 -c 'GGCCGAGGCATAGTATG' *.fastq > count/B1698_Rm0.txt
agrep -0 -c 'CTTTTGGCATATGAGCG' *.fastq > count/B1699_Rm0.txt
agrep -0 -c 'TTAATGGGTCACAATGC' *.fastq > count/B1700_Rm0.txt
agrep -0 -c 'GTACCCGATTGTTCAAG' *.fastq > count/B1701_Rm0.txt
agrep -0 -c 'ACGCTTTGAATATGCGC' *.fastq > count/B1702_Rm0.txt
agrep -0 -c 'TTTCGGAAAGATGTCGA' *.fastq > count/B1703_Rm0.txt
agrep -0 -c 'TTGCGGAGCATAGGATA' *.fastq > count/B1704_Rm0.txt
agrep -0 -c 'GTACTGCGCATTGCACA' *.fastq > count/B1705_Rm0.txt
agrep -0 -c 'ATGATAGCGTGTCGATA' *.fastq > count/B1707_Rm0.txt
agrep -0 -c 'GTCTCGCTGCACTTTAG' *.fastq > count/B1708_Rm0.txt
agrep -0 -c 'ACTGAGAGTAGGGCATC' *.fastq > count/B1710_Rm0.txt
agrep -0 -c 'GCGGGTTGTTAACATGT' *.fastq > count/B1711_Rm0.txt
agrep -0 -c 'TGTAAAGGAGTTAAGCG' *.fastq > count/B1712_Rm0.txt
agrep -0 -c 'ACCGTGCTCTGTTGTCT' *.fastq > count/B1714_Rm0.txt
agrep -0 -c 'GACCTTAGAACTTGCTG' *.fastq > count/B1715_Rm0.txt
agrep -0 -c 'GAAGAATCACCCAGGCC' *.fastq > count/B1718_Rm0.txt
agrep -0 -c 'GTGATTGGATTTCCCTG' *.fastq > count/B1719_Rm0.txt
agrep -0 -c 'GCCACCCTACCGATTCT' *.fastq > count/B1720_Rm0.txt
agrep -0 -c 'GTGCAATTTACATCCAG' *.fastq > count/B1721_Rm0.txt
agrep -0 -c 'AAGGACCGCTCGCGATA' *.fastq > count/B1722_Rm0.txt
agrep -0 -c 'CGTAATGGCCCTTGGGT' *.fastq > count/B1723_Rm0.txt
agrep -0 -c 'CACCGCCGATGTTTAAC' *.fastq > count/B1724_Rm0.txt
agrep -0 -c 'GTATACCGGCGTTCTCT' *.fastq > count/B1725_Rm0.txt
agrep -0 -c 'GACATTTGTACGTGCGG' *.fastq > count/B1726_Rm0.txt
agrep -0 -c 'GTGACGGACTCAGTTTA' *.fastq > count/B1728_Rm0.txt
agrep -0 -c 'TAAGACCAGAGTCGTTA' *.fastq > count/B1729_Rm0.txt
agrep -0 -c 'AAGACCCATCGAATTAC' *.fastq > count/B1730_Rm0.txt
agrep -0 -c 'TAAAACGGGAGTAGCGA' *.fastq > count/B1731_Rm0.txt
agrep -0 -c 'CCGAAGCCGAGGTTTAT' *.fastq > count/B1732_Rm0.txt
agrep -0 -c 'TCATGCGCGATGCAGTC' *.fastq > count/B1733_Rm0.txt
agrep -0 -c 'TTTAGAGATCGCACTAC' *.fastq > count/B1734_Rm0.txt
agrep -0 -c 'GACCCGATGAGATCGTA' *.fastq > count/B1735_Rm0.txt
agrep -0 -c 'TGTTTCGACCTCGGCTG' *.fastq > count/B1736_Rm0.txt
agrep -0 -c 'CGCGATAGAGACATGGC' *.fastq > count/B1737_Rm0.txt
agrep -0 -c 'GAGTACCAGGTTCGGGT' *.fastq > count/B1738_Rm0.txt
agrep -0 -c 'GGGTGAGATTGGAGTGC' *.fastq > count/B1739_Rm0.txt
agrep -0 -c 'CAGAAGATTTCCCTGAG' *.fastq > count/B1740_Rm0.txt
agrep -0 -c 'TTTCGGTTCACTATTCC' *.fastq > count/B1741_Rm0.txt
agrep -0 -c 'CTCTAAACTTGCCGGGT' *.fastq > count/B1743_Rm0.txt
agrep -0 -c 'AAACAGTTGACCGCTCT' *.fastq > count/B1744_Rm0.txt
agrep -0 -c 'CGCGAATATAAATTCGG' *.fastq > count/B1747_Rm0.txt
agrep -0 -c 'GCGTATAGTTCTGGACT' *.fastq > count/B1748_Rm0.txt
agrep -0 -c 'GTACTCCTCCCCATATG' *.fastq > count/B1749_Rm0.txt
agrep -0 -c 'AGCTAAGGCCTCGTAAC' *.fastq > count/B1750_Rm0.txt
agrep -0 -c 'GGAATGTAACGTAGGAA' *.fastq > count/B1751_Rm0.txt
agrep -0 -c 'GCCCTAGTTATTCGGTC' *.fastq > count/B1752_Rm0.txt
agrep -0 -c 'ATAGCTCATTGTACAGC' *.fastq > count/B1754_Rm0.txt
agrep -0 -c 'CTCGTACTCTGACCTTA' *.fastq > count/B1756_Rm0.txt
agrep -0 -c 'AGCTCGCTGGTCTGTAG' *.fastq > count/B1757_Rm0.txt
agrep -0 -c 'CAGAATGCGTGATCAAG' *.fastq > count/B1758_Rm0.txt
agrep -0 -c 'AGGAAAACGAACGGAGC' *.fastq > count/B1759_Rm0.txt
agrep -0 -c 'TAATTGCGTCGGGTGCG' *.fastq > count/B1760_Rm0.txt
agrep -0 -c 'CTTCACAAAGTGGATAG' *.fastq > count/B1762_Rm0.txt
agrep -0 -c 'CGCTATTGCTATCTGCA' *.fastq > count/B1763_Rm0.txt
agrep -0 -c 'GGCAGATACAGCCTAGG' *.fastq > count/B1766_Rm0.txt
agrep -0 -c 'CTAAGAGTTGAGCCTGA' *.fastq > count/B1767_Rm0.txt
agrep -0 -c 'GAACTTTCGGGGCATCG' *.fastq > count/B1768_Rm0.txt
agrep -0 -c 'CACGTTTACAGCACCGT' *.fastq > count/B1769_Rm0.txt
agrep -0 -c 'GCCTTCACGTATGGATA' *.fastq > count/B1770_Rm0.txt
agrep -0 -c 'AAGAGACGACCGTTTCT' *.fastq > count/B1771_Rm0.txt
agrep -0 -c 'CTAAACACGTTGCCACC' *.fastq > count/B1772_Rm0.txt
agrep -0 -c 'TCCCAAAGGACACAAGA' *.fastq > count/B1773_Rm0.txt
agrep -0 -c 'ACAACCCCTGAGTAAGT' *.fastq > count/B1774_Rm0.txt
agrep -0 -c 'CGACAGACGACGCAGTA' *.fastq > count/B1775_Rm0.txt
agrep -0 -c 'CCTCGCTCACTTGTCTG' *.fastq > count/B1777_Rm0.txt
agrep -0 -c 'ACCGTTGAGCCGGTGTA' *.fastq > count/B1778_Rm0.txt
agrep -0 -c 'AATACGGAACAGGCATT' *.fastq > count/B1779_Rm0.txt
agrep -0 -c 'ACCAGATCCGCTGCTAA' *.fastq > count/B1780_Rm0.txt
agrep -0 -c 'GCGATTAACCTATACAG' *.fastq > count/B1781_Rm0.txt
agrep -0 -c 'CCATTACTCACTACCCC' *.fastq > count/B1782_Rm0.txt
agrep -0 -c 'TAAGCCAGACTTATAGG' *.fastq > count/B1783_Rm0.txt
agrep -0 -c 'CGGAAACTCCTAGTGCA' *.fastq > count/B1784_Rm0.txt
agrep -0 -c 'TTACTCTGTTTCCCAAC' *.fastq > count/B1785_Rm0.txt
agrep -0 -c 'TCACGTAGGCGAACGTG' *.fastq > count/B1786_Rm0.txt
agrep -0 -c 'AATACCATCGCCTCTGT' *.fastq > count/B1787_Rm0.txt
agrep -0 -c 'GCCTTCGAATGGCGGAT' *.fastq > count/B1789_Rm0.txt
agrep -0 -c 'ATAGTCGCCGGTGTTGA' *.fastq > count/B1790_Rm0.txt
agrep -0 -c 'CATCACAATAGAGCAGG' *.fastq > count/B1791_Rm0.txt
agrep -0 -c 'AACATCTTAACGGCGAT' *.fastq > count/B1792_Rm0.txt
agrep -0 -c 'AACGTCAACGATGGGTC' *.fastq > count/B1794_Rm0.txt
agrep -0 -c 'GTTCGAATGTAACACCG' *.fastq > count/B1795_Rm0.txt
agrep -0 -c 'GGGCGGGTAACTTTTGG' *.fastq > count/B1798_Rm0.txt
agrep -0 -c 'TATTCGTGCTCCTCGCA' *.fastq > count/B1799_Rm0.txt
agrep -0 -c 'TAGCGAGCTCAGTGTTA' *.fastq > count/B1801_Rm0.txt
agrep -0 -c 'GACATACTTACGTAGAC' *.fastq > count/B1802_Rm0.txt
agrep -0 -c 'CCGCTTATCCAAACAGG' *.fastq > count/B1803_Rm0.txt
agrep -0 -c 'TAACGCCGGGTAACGAA' *.fastq > count/B1804_Rm0.txt
agrep -0 -c 'GAAAGCCACTTAGGCCA' *.fastq > count/B1806_Rm0.txt
agrep -0 -c 'AGCGGAGGACGTTCCAT' *.fastq > count/B1807_Rm0.txt
agrep -0 -c 'TTCACAGATTCGCTGAG' *.fastq > count/B1808_Rm0.txt
agrep -0 -c 'ACATACGTTACGGGCAT' *.fastq > count/B1809_Rm0.txt
agrep -0 -c 'CGTATTCCGTCTACTGT' *.fastq > count/B1810_Rm0.txt
agrep -0 -c 'GAAGACCCTGACTACAG' *.fastq > count/B1811_Rm0.txt
agrep -0 -c 'TTATTAGGGGACTGGGC' *.fastq > count/B1812_Rm0.txt
agrep -0 -c 'GGGAACAAATCAGCCCT' *.fastq > count/B1813_Rm0.txt
agrep -0 -c 'GGTTACTCGCCTAATAA' *.fastq > count/B1814_Rm0.txt
agrep -0 -c 'GTTCGTACTCTCGGTCC' *.fastq > count/B1815_Rm0.txt
agrep -0 -c 'CACTCGTCACCTACTGT' *.fastq > count/B1816_Rm0.txt
agrep -0 -c 'ATTAGAAGCGACTCTAC' *.fastq > count/B1817_Rm0.txt
agrep -0 -c 'AACTCGTAATCTCGGCA' *.fastq > count/B1818_Rm0.txt
agrep -0 -c 'ATACCGAGACACGTTAG' *.fastq > count/B1819_Rm0.txt
agrep -0 -c 'TATCGAGTGCTGGTAGC' *.fastq > count/B1820_Rm0.txt
agrep -0 -c 'GGCTTAGCCACGACGAT' *.fastq > count/B1821_Rm0.txt
agrep -0 -c 'ATAGGACGCTGCTCACG' *.fastq > count/B1822_Rm0.txt
agrep -0 -c 'GTTTTGTAGCGGGAGTT' *.fastq > count/B1823_Rm0.txt
agrep -0 -c 'ACGGCGTATAAGATCAG' *.fastq > count/B1824_Rm0.txt
agrep -0 -c 'TGTTCTTACGAACACCT' *.fastq > count/B1825_Rm0.txt
agrep -0 -c 'AAGTAATCTTCGTTGCC' *.fastq > count/B1826_Rm0.txt
agrep -0 -c 'CTAAGTGGTTGACATGG' *.fastq > count/B1827_Rm0.txt
agrep -0 -c 'CGCAATGATGGCATTCA' *.fastq > count/B1828_Rm0.txt
agrep -0 -c 'ACGTCTACCGGTAATGA' *.fastq > count/B1830_Rm0.txt
agrep -0 -c 'ACTGAGAGTACGTAGAA' *.fastq > count/B1831_Rm0.txt
agrep -0 -c 'CAGGGGTAATAACAGGT' *.fastq > count/B1832_Rm0.txt
agrep -0 -c 'GGGAAATAGTCCCAGAC' *.fastq > count/B1833_Rm0.txt
agrep -0 -c 'TCCCCTCCAAACGAGCT' *.fastq > count/B1834_Rm0.txt
agrep -0 -c 'CGGCCAAAGACGGTTTA' *.fastq > count/B1835_Rm0.txt
agrep -0 -c 'CTTTCCTAACCGCTCGG' *.fastq > count/B1837_Rm0.txt
agrep -0 -c 'TTTGCGACAGTAGGAAT' *.fastq > count/B1838_Rm0.txt
agrep -0 -c 'ACAAAATTTGAGTCGGC' *.fastq > count/B1839_Rm0.txt
agrep -0 -c 'TTCTCTGGTCTTGAGCT' *.fastq > count/B1840_Rm0.txt
agrep -0 -c 'GTGCCTCCCCCAGAATT' *.fastq > count/B1841_Rm0.txt
agrep -0 -c 'TCTGTGGAGACGTCATA' *.fastq > count/B1842_Rm0.txt
agrep -0 -c 'AAGATATGGACGGAAGT' *.fastq > count/B1843_Rm0.txt
agrep -0 -c 'TCCGTGAGAGGGATTTA' *.fastq > count/B1844_Rm0.txt
agrep -0 -c 'CCGGGTGTCATCAGATA' *.fastq > count/B1845_Rm0.txt
agrep -0 -c 'GCAGTTCGTAAGTAGAA' *.fastq > count/B1846_Rm0.txt
agrep -0 -c 'CGTGTTTGGTCGGCAAC' *.fastq > count/B1847_Rm0.txt
agrep -0 -c 'GCGTAAACGTGTTGCCT' *.fastq > count/B1848_Rm0.txt
agrep -0 -c 'ATAGGCAATCGGGCCCT' *.fastq > count/B1850_Rm0.txt
agrep -0 -c 'GTCATGAATAGGCCAAG' *.fastq > count/B1851_Rm0.txt
agrep -0 -c 'CCCTTACCGAGGTTAGA' *.fastq > count/B1853_Rm0.txt
agrep -0 -c 'CTTTTCGGAAACCCTAA' *.fastq > count/B1854_Rm0.txt
agrep -0 -c 'CGTCACGGAATATCAAG' *.fastq > count/B1855_Rm0.txt
agrep -0 -c 'CGTCGATAGCATGCTGT' *.fastq > count/B1856_Rm0.txt
agrep -0 -c 'ATAGGCAGAGGATAGTA' *.fastq > count/B1857_Rm0.txt
agrep -0 -c 'CGATTACGGATATACAC' *.fastq > count/B1858_Rm0.txt
agrep -0 -c 'GTGGACTTAACTCAATG' *.fastq > count/B1859_Rm0.txt
agrep -0 -c 'ATTGGGCGCACTCCAGA' *.fastq > count/B1860_Rm0.txt
agrep -0 -c 'TGCAGATCCAATCCCGA' *.fastq > count/B1862_Rm0.txt
agrep -0 -c 'GGCCTCAATTACCCCTA' *.fastq > count/B1863_Rm0.txt
agrep -0 -c 'ATACGACCCTTCTCGTA' *.fastq > count/B1864_Rm0.txt
agrep -0 -c 'AAGGGCCCAAATGTGAG' *.fastq > count/B1865_Rm0.txt
agrep -0 -c 'CGCCTTCTTTACCCACC' *.fastq > count/B1867_Rm0.txt
agrep -0 -c 'ACGCTTACGAGCGTCGA' *.fastq > count/B1868_Rm0.txt
agrep -0 -c 'GTGTATTACGACGCGCC' *.fastq > count/B1869_Rm0.txt
agrep -0 -c 'CGCCACCACAAGTCAAG' *.fastq > count/B1871_Rm0.txt
agrep -0 -c 'AGTCATCCCGTAATGTA' *.fastq > count/B1873_Rm0.txt
agrep -0 -c 'TGCAAATCGGTCGAATC' *.fastq > count/B1874_Rm0.txt
agrep -0 -c 'GTAGACCTGTTCGTTTA' *.fastq > count/B1875_Rm0.txt
agrep -0 -c 'GGGCTTAACTCCCAGCT' *.fastq > count/B1876_Rm0.txt
agrep -0 -c 'GAATAACCGGCGGTTGC' *.fastq > count/B1878_Rm0.txt
agrep -0 -c 'CTATGTCCCAAACGTCA' *.fastq > count/B1879_Rm0.txt
agrep -0 -c 'ATTTTTCTTCCGCAGCC' *.fastq > count/B1881_Rm0.txt
agrep -0 -c 'CGTGTTGGATGTGGTAG' *.fastq > count/B1882_Rm0.txt
agrep -0 -c 'TAGCTACCCTTTTAGCG' *.fastq > count/B1883_Rm0.txt
agrep -0 -c 'TTTGTGTAGTACGATCC' *.fastq > count/B1884_Rm0.txt
agrep -0 -c 'TACACAAACGATCGTCT' *.fastq > count/B1885_Rm0.txt
agrep -0 -c 'GATCGCTACTACTTCAA' *.fastq > count/B1886_Rm0.txt
agrep -0 -c 'GCGCATGGGTGTACTCA' *.fastq > count/B1887_Rm0.txt
agrep -0 -c 'ATCATAAGGGGCCCAGG' *.fastq > count/B1888_Rm0.txt
agrep -0 -c 'GACGGTCAAAAAGCGCC' *.fastq > count/B1889_Rm0.txt
agrep -0 -c 'CCGATTACAATTCTCTG' *.fastq > count/B1890_Rm0.txt
agrep -0 -c 'ATCTACCCAGGCGGTCT' *.fastq > count/B1891_Rm0.txt
agrep -0 -c 'TACAGTCAGATGGGAGA' *.fastq > count/B1892_Rm0.txt
agrep -0 -c 'TGCAGGCTTATTCGATA' *.fastq > count/B1893_Rm0.txt
agrep -0 -c 'CGAGAACTGAGCTTCCT' *.fastq > count/B1894_Rm0.txt
agrep -0 -c 'ATTAAACCAGATTCCGG' *.fastq > count/B1895_Rm0.txt
agrep -0 -c 'GCCGTAAGACTCACGTG' *.fastq > count/B1896_Rm0.txt
agrep -0 -c 'AGATTTCGCCAAGCTTA' *.fastq > count/B1897_Rm0.txt
agrep -0 -c 'CTTAGTATAGCCGTTGC' *.fastq > count/B1898_Rm0.txt
agrep -0 -c 'TGAATAGCATAGTGTGC' *.fastq > count/B1900_Rm0.txt
agrep -0 -c 'CAGCCTAAATGATGGCG' *.fastq > count/B1901_Rm0.txt
agrep -0 -c 'AGCGTCACGCTTATAAC' *.fastq > count/B1903_Rm0.txt
agrep -0 -c 'GAGTCAGCGTGTCTCCA' *.fastq > count/B1904_Rm0.txt
agrep -0 -c 'ACGGAAGTGGTAGTGTC' *.fastq > count/B1905_Rm0.txt
agrep -0 -c 'AGTTTACTACCGTGGCG' *.fastq > count/B1906_Rm0.txt
agrep -0 -c 'GACTTTATGATAGGTCG' *.fastq > count/B1907_Rm0.txt
agrep -0 -c 'CACCCTTTTGACTCCGG' *.fastq > count/B1908_Rm0.txt
agrep -0 -c 'TCAAGTCCGCTCCTCTT' *.fastq > count/B1910_Rm0.txt
agrep -0 -c 'CAATGACAGACCGAAGT' *.fastq > count/B1911_Rm0.txt
agrep -0 -c 'ACAAGACTGTCTTACCG' *.fastq > count/B1912_Rm0.txt
agrep -0 -c 'TATCCAATCTGCGGGAG' *.fastq > count/B1913_Rm0.txt
agrep -0 -c 'AAATTACTATCCGCGAC' *.fastq > count/B1914_Rm0.txt
agrep -0 -c 'ACGTAAGCCGTCATATC' *.fastq > count/B1915_Rm0.txt
agrep -0 -c 'TAGCTCGTGCCGCATTG' *.fastq > count/B1916_Rm0.txt
agrep -0 -c 'CTATGGAGAGATGGTAA' *.fastq > count/B1917_Rm0.txt
agrep -0 -c 'GAGTCTCTACCGTTGTG' *.fastq > count/B1918_Rm0.txt
agrep -0 -c 'TCCCGTCGACTACGATG' *.fastq > count/B1919_Rm0.txt
agrep -0 -c 'TCAGACCTAGGCATAGA' *.fastq > count/B1920_Rm0.txt
agrep -0 -c 'ATCTATGCTCCGCCAGT' *.fastq > count/B1921_Rm0.txt
agrep -0 -c 'ACAAATTCCGTGGACAT' *.fastq > count/B1923_Rm0.txt
agrep -0 -c 'TCTAGTTCGGCCATCTT' *.fastq > count/B1924_Rm0.txt
agrep -0 -c 'TCACGTGCTTGGGTGTC' *.fastq > count/B1926_Rm0.txt
agrep -0 -c 'TCCTTGTCCCGATCCTT' *.fastq > count/B1927_Rm0.txt
agrep -0 -c 'GGCGTGTTTGATTGAGA' *.fastq > count/B1928_Rm0.txt
agrep -0 -c 'GGCTCCTCTAAACGCGT' *.fastq > count/B1929_Rm0.txt
agrep -0 -c 'GTACTCGCGAGGACTGT' *.fastq > count/B1930_Rm0.txt
agrep -0 -c 'AATGCGTTATTTGCACG' *.fastq > count/B1933_Rm0.txt
agrep -0 -c 'TGCGTAAGACAACATTG' *.fastq > count/B1935_Rm0.txt
agrep -0 -c 'TCCTAAACCAATTGGTG' *.fastq > count/B1936_Rm0.txt
agrep -0 -c 'AACGATGTACGCCATAC' *.fastq > count/B1938_Rm0.txt
agrep -0 -c 'TACCTGCTGCTTAGCGC' *.fastq > count/B1939_Rm0.txt
agrep -0 -c 'CGCCTTTTTCTTAGGTC' *.fastq > count/B1941_Rm0.txt
agrep -0 -c 'AGAAACCGTCGACAAAT' *.fastq > count/B1942_Rm0.txt
agrep -0 -c 'AATTGACGCGTTGAGGC' *.fastq > count/B1943_Rm0.txt
agrep -0 -c 'TAATCTACGGCCAGACG' *.fastq > count/B1944_Rm0.txt
agrep -0 -c 'TAGACTCATGCCGACGG' *.fastq > count/B1945_Rm0.txt
agrep -0 -c 'AGTTCGTGGCCAAAGTG' *.fastq > count/B1947_Rm0.txt
agrep -0 -c 'GGACATGCTATGAACGG' *.fastq > count/B1948_Rm0.txt
agrep -0 -c 'GCGCCGTCAATTTACGT' *.fastq > count/B1949_Rm0.txt
agrep -0 -c 'CGACCAGAATTGTGAAC' *.fastq > count/B1950_Rm0.txt
agrep -0 -c 'GCCACCATAGACTTACG' *.fastq > count/B1952_Rm0.txt
agrep -0 -c 'GCCGTTCGCGTATATTA' *.fastq > count/B1953_Rm0.txt
agrep -0 -c 'GAAAAGACATACCGGGT' *.fastq > count/B1956_Rm0.txt
agrep -0 -c 'AATGGGTGATAGCTAAG' *.fastq > count/B1957_Rm0.txt
agrep -0 -c 'TACCTCTTAGTTTGCGT' *.fastq > count/B1958_Rm0.txt
agrep -0 -c 'AACAGGACCTGATGCAT' *.fastq > count/B1960_Rm0.txt
agrep -0 -c 'TGCATGCTCATTGTTGT' *.fastq > count/B1961_Rm0.txt
agrep -0 -c 'TTATGACAGCACGCGTG' *.fastq > count/B1962_Rm0.txt
agrep -0 -c 'GTGTTGCGTAGGAGCTC' *.fastq > count/B1963_Rm0.txt
agrep -0 -c 'AGACGTGGCATATTACG' *.fastq > count/B1964_Rm0.txt
agrep -0 -c 'CGAGGAATAGATATCTC' *.fastq > count/B1965_Rm0.txt
agrep -0 -c 'TTCTTCGAGGCCATACA' *.fastq > count/B1967_Rm0.txt
agrep -0 -c 'GCGACGTTATAAAGAGC' *.fastq > count/B1968_Rm0.txt
agrep -0 -c 'GCCTCTGCATACGATAG' *.fastq > count/B1971_Rm0.txt
agrep -0 -c 'CGGTACAAGATATTCAG' *.fastq > count/B1972_Rm0.txt
agrep -0 -c 'TAGCAGCTCTTTATGCC' *.fastq > count/B1973_Rm0.txt
agrep -0 -c 'TTCCGGCAGGTTATCCA' *.fastq > count/B1974_Rm0.txt
agrep -0 -c 'CCACTTCACGATGGAAT' *.fastq > count/B1975_Rm0.txt
agrep -0 -c 'CTACAGCCGAAAGGAAT' *.fastq > count/B1977_Rm0.txt
agrep -0 -c 'GGGTATAATCACCCGTC' *.fastq > count/B1978_Rm0.txt
agrep -0 -c 'CTTAGCGCTAGGAACTT' *.fastq > count/B1979_Rm0.txt
agrep -0 -c 'AAACTATCCGGATGGCA' *.fastq > count/B1980_Rm0.txt
agrep -0 -c 'GCGATTCATTGCGGCTG' *.fastq > count/B1982_Rm0.txt
agrep -0 -c 'CGTGATCGCTATTTCAC' *.fastq > count/B1983_Rm0.txt
agrep -0 -c 'CATCAGGCATTACCGCT' *.fastq > count/B1984_Rm0.txt
agrep -0 -c 'GGCGATTCTGCAACGAC' *.fastq > count/B1985_Rm0.txt
agrep -0 -c 'CAAGGATGCTTTCCTCG' *.fastq > count/B1986_Rm0.txt
agrep -0 -c 'GTACTAATTTGCCTGCA' *.fastq > count/B1987_Rm0.txt
agrep -0 -c 'GAATTGGTCTAGTGCAC' *.fastq > count/B1988_Rm0.txt
agrep -0 -c 'AACGGGCGAGAGATATT' *.fastq > count/B1989_Rm0.txt
agrep -0 -c 'TCGGTATAACTAGTCCG' *.fastq > count/B1990_Rm0.txt
agrep -0 -c 'TGTCTGCAATGCTATTG' *.fastq > count/B1992_Rm0.txt
agrep -0 -c 'TCACGAAAGGGGATCTT' *.fastq > count/B1993_Rm0.txt
agrep -0 -c 'CACCGCATAACTCCTCA' *.fastq > count/B1994_Rm0.txt
agrep -0 -c 'TTAGTAGGGGATCGGTG' *.fastq > count/B1995_Rm0.txt
agrep -0 -c 'CCTGATCGAAACGAACG' *.fastq > count/B1996_Rm0.txt
agrep -0 -c 'CAAATGCCGGGCAGTTA' *.fastq > count/B1997_Rm0.txt
agrep -0 -c 'CCACCGACGCATGTGTA' *.fastq > count/B1998_Rm0.txt
agrep -0 -c 'CCGCTTCTACTTTGACG' *.fastq > count/B2000_Rm0.txt
agrep -0 -c 'CTACCTATGGCCGATCT' *.fastq > count/B2001_Rm0.txt
agrep -0 -c 'GTATACTCACTCCAAGA' *.fastq > count/B2002_Rm0.txt
agrep -0 -c 'AAAGAGCCTGTAGAAGC' *.fastq > count/B2004_Rm0.txt
agrep -0 -c 'CTCGTAGCGTGCTTGAC' *.fastq > count/B2005_Rm0.txt
agrep -0 -c 'TCACCATCACATACACG' *.fastq > count/B2006_Rm0.txt
agrep -0 -c 'GCTTCAAGCGGTATCCA' *.fastq > count/B2008_Rm0.txt
agrep -0 -c 'GCATATCGAGCCGAGCT' *.fastq > count/B2009_Rm0.txt
agrep -0 -c 'GAGGGTTGGGCTCCATT' *.fastq > count/B2011_Rm0.txt
agrep -0 -c 'GGACGCGATGGTAAGAC' *.fastq > count/B2012_Rm0.txt
agrep -0 -c 'TCTGACCATGAGCCGCT' *.fastq > count/B2014_Rm0.txt
agrep -0 -c 'CCCAGAGTAGAGTAGTC' *.fastq > count/B2016_Rm0.txt
agrep -0 -c 'AACCAGTTTCTGCGCTT' *.fastq > count/B2017_Rm0.txt
agrep -0 -c 'ACGCTTCGCACTATGTC' *.fastq > count/B2019_Rm0.txt
agrep -0 -c 'AACTTGGCGGCAACTGG' *.fastq > count/B2020_Rm0.txt
agrep -0 -c 'AGTGCTAAGCCTAATAC' *.fastq > count/B2022_Rm0.txt
agrep -0 -c 'TTGGGAGGTTCAACGGC' *.fastq > count/B2023_Rm0.txt
agrep -0 -c 'GTCCCGTGTTATCTCAC' *.fastq > count/B2024_Rm0.txt
agrep -0 -c 'TATATTCCCGGTTGGTT' *.fastq > count/B2026_Rm0.txt
agrep -0 -c 'GAGTTCAACCAGGGCTG' *.fastq > count/B2027_Rm0.txt
agrep -0 -c 'GTCGAAGCCATAGCACG' *.fastq > count/B2028_Rm0.txt
agrep -0 -c 'TCTCCCGAGTGTAGACT' *.fastq > count/B2029_Rm0.txt
agrep -0 -c 'TAAACCCCAGTCACAAT' *.fastq > count/B2030_Rm0.txt
agrep -0 -c 'GTTCGACGGTCAGAGGT' *.fastq > count/B2031_Rm0.txt
agrep -0 -c 'CTGGTAAAACGTCGTCA' *.fastq > count/B2032_Rm0.txt
agrep -0 -c 'TCTCGCGCCGTACATTA' *.fastq > count/B2033_Rm0.txt
agrep -0 -c 'TATCGTGGTTGGGCGCA' *.fastq > count/B2034_Rm0.txt
agrep -0 -c 'TAGCCCTCTAGTGATAA' *.fastq > count/B2036_Rm0.txt
agrep -0 -c 'AATCGAAGTCATCCGTG' *.fastq > count/B2037_Rm0.txt
agrep -0 -c 'TGAAGGCAAGGATCTCG' *.fastq > count/B2038_Rm0.txt
agrep -0 -c 'TGCGGACAAACACAAGG' *.fastq > count/B2039_Rm0.txt
agrep -0 -c 'CTACACGAATAACAACG' *.fastq > count/B2040_Rm0.txt
agrep -0 -c 'GAGCTTAGACCGCAGCA' *.fastq > count/B2041_Rm0.txt
agrep -0 -c 'TGCTAAGGCTCACCCTA' *.fastq > count/B2042_Rm0.txt
agrep -0 -c 'TAGAGAGATTCGGTACG' *.fastq > count/B2043_Rm0.txt
agrep -0 -c 'TGCAGTTACCGCACAAG' *.fastq > count/B2044_Rm0.txt
agrep -0 -c 'CCCAGACGGTTTGAAGA' *.fastq > count/B2045_Rm0.txt
agrep -0 -c 'GCTACGGCTATCACCTG' *.fastq > count/B2046_Rm0.txt
agrep -0 -c 'ATCGAGCATGTGCGCTA' *.fastq > count/B2049_Rm0.txt
agrep -0 -c 'GACAGGACGCCTATCAT' *.fastq > count/B2050_Rm0.txt
agrep -0 -c 'GGGAGAATATCGTAACT' *.fastq > count/B2051_Rm0.txt
agrep -0 -c 'ACCCAATTCAAAAGAGG' *.fastq > count/B2052_Rm0.txt
agrep -0 -c 'CTCTAGGCAACTAAGCG' *.fastq > count/B2053_Rm0.txt
agrep -0 -c 'TGGATCTCTAAGCGGTC' *.fastq > count/B2054_Rm0.txt
agrep -0 -c 'CACAGCTGCTGTGTAAT' *.fastq > count/B2055_Rm0.txt
agrep -0 -c 'TTCTTCCGGAATGTACC' *.fastq > count/B2056_Rm0.txt
agrep -0 -c 'TCTTGCATCCTCGGTAC' *.fastq > count/B2057_Rm0.txt
agrep -0 -c 'GATCCTTGGCGGATGAA' *.fastq > count/B2058_Rm0.txt
agrep -0 -c 'CGACGGAAGTGTAATGG' *.fastq > count/B2059_Rm0.txt
agrep -0 -c 'ACTGTACGCGTAACATT' *.fastq > count/B2060_Rm0.txt
agrep -0 -c 'ATCTTCGCCTAATCTCT' *.fastq > count/B2061_Rm0.txt
agrep -0 -c 'CGCCGCAGGTAAGCTAA' *.fastq > count/B2064_Rm0.txt
agrep -0 -c 'AAATCAGATAGTACCGC' *.fastq > count/B2067_Rm0.txt
agrep -0 -c 'AAGTATGGCTCTACGCG' *.fastq > count/B2068_Rm0.txt
agrep -0 -c 'CGCATTAGCTTGAAGAA' *.fastq > count/B2069_Rm0.txt
agrep -0 -c 'GAAGTTGAACTCCATTG' *.fastq > count/B2070_Rm0.txt
agrep -0 -c 'TTCAACGCAATACTACG' *.fastq > count/B2071_Rm0.txt
agrep -0 -c 'TCGTGACGTCAGTGACA' *.fastq > count/B2074_Rm0.txt
agrep -0 -c 'TGCGGAGTGTCGATAGG' *.fastq > count/B2076_Rm0.txt
agrep -0 -c 'ACCTCTTACCCTCAAGA' *.fastq > count/B2077_Rm0.txt
agrep -0 -c 'TAATCGGGGCAGGCAGA' *.fastq > count/B2078_Rm0.txt
agrep -0 -c 'CCTACGCTCACTGAGCA' *.fastq > count/B2079_Rm0.txt
agrep -0 -c 'ATGCGGCTGGCAGCTAT' *.fastq > count/B2080_Rm0.txt
agrep -0 -c 'TTCGTCTCGTTTGGGTC' *.fastq > count/B2081_Rm0.txt
agrep -0 -c 'AACTGCATCTACTCCTT' *.fastq > count/B2084_Rm0.txt
agrep -0 -c 'GATTCCAGCGCGGGTTA' *.fastq > count/B2085_Rm0.txt
agrep -0 -c 'AACGCGTCGAATAGGAA' *.fastq > count/B2087_Rm0.txt
agrep -0 -c 'ACAGGGTATGGCCCTCA' *.fastq > count/B2088_Rm0.txt
agrep -0 -c 'CCGGTAATAACCGGAGT' *.fastq > count/B2089_Rm0.txt
agrep -0 -c 'ACGCTGGGGCACTATCA' *.fastq > count/B2090_Rm0.txt
agrep -0 -c 'TACGCTTTAATGCGGAC' *.fastq > count/B2091_Rm0.txt
agrep -0 -c 'TACTCAAGGGACAACGT' *.fastq > count/B2092_Rm0.txt
agrep -0 -c 'AGAAGTGCTAACACCCG' *.fastq > count/B2093_Rm0.txt
agrep -0 -c 'TCGACGTGCATAGTCGA' *.fastq > count/B2094_Rm0.txt
agrep -0 -c 'GCGAAGCCGTTTGAGAC' *.fastq > count/B2095_Rm0.txt
agrep -0 -c 'CGCGACGCTTTGTGAAT' *.fastq > count/B2096_Rm0.txt
agrep -0 -c 'AAAGCGGTCGGGATCAA' *.fastq > count/B2097_Rm0.txt
agrep -0 -c 'CGAGGGGGCTTGATTTG' *.fastq > count/B2098_Rm0.txt
agrep -0 -c 'CGTGCTCTACCCTATGA' *.fastq > count/B2099_Rm0.txt
agrep -0 -c 'AATCTGAAAAACCGGTC' *.fastq > count/B2100_Rm0.txt
agrep -0 -c 'CTACAACTTTGAAGGTG' *.fastq > count/B2101_Rm0.txt
agrep -0 -c 'TGCCCTATCCCTCTGTG' *.fastq > count/B2103_Rm0.txt
agrep -0 -c 'GTAGGTCCGTTGCGTAG' *.fastq > count/B2104_Rm0.txt
agrep -0 -c 'GAAGGCCCTTTCAGTTA' *.fastq > count/B2105_Rm0.txt
agrep -0 -c 'GATTCTCGTATAGCAGA' *.fastq > count/B2106_Rm0.txt
agrep -0 -c 'CGAACGACTGAGACGCT' *.fastq > count/B2107_Rm0.txt
agrep -0 -c 'GCTTCCCAATATAGCGC' *.fastq > count/B2108_Rm0.txt
agrep -0 -c 'GGCGGTTCTAGCTTCTC' *.fastq > count/B2109_Rm0.txt
agrep -0 -c 'CAACAAAGCGCTCTAAC' *.fastq > count/B2110_Rm0.txt
agrep -0 -c 'GAATCAGTCGCCATTGC' *.fastq > count/B2111_Rm0.txt
agrep -0 -c 'CAAGACCACATACTTCA' *.fastq > count/B2112_Rm0.txt
agrep -0 -c 'GTCTCTTGACGCCTATA' *.fastq > count/B2114_Rm0.txt
agrep -0 -c 'GACCCCATAACCTACTC' *.fastq > count/B2116_Rm0.txt
agrep -0 -c 'CGCAAAACTATGGGAGG' *.fastq > count/B2118_Rm0.txt
agrep -0 -c 'CTGACGAGCATAGACTC' *.fastq > count/B2119_Rm0.txt
agrep -0 -c 'CGATGAGCAAAACGCTT' *.fastq > count/B2120_Rm0.txt
agrep -0 -c 'TATCATGATCCGGCACG' *.fastq > count/B2121_Rm0.txt
agrep -0 -c 'TGAATCGCGCCAGTCTA' *.fastq > count/B2122_Rm0.txt
agrep -0 -c 'AGGCTGTGAGGGATACG' *.fastq > count/B2124_Rm0.txt
agrep -0 -c 'TTAGCAGTGACCTGGTC' *.fastq > count/B2125_Rm0.txt
agrep -0 -c 'AAATAGGGTCCCCCGGT' *.fastq > count/B2126_Rm0.txt
agrep -0 -c 'CGTCCATTAGGCACATC' *.fastq > count/B2127_Rm0.txt
agrep -0 -c 'GCTACCCTAAGGCTCGT' *.fastq > count/B2128_Rm0.txt
agrep -0 -c 'GTTGCACGCTACAGACT' *.fastq > count/B2129_Rm0.txt
agrep -0 -c 'CTGAGTGCGTTTTTGTA' *.fastq > count/B2130_Rm0.txt
agrep -0 -c 'AGAAAGACGCTAGTACG' *.fastq > count/B2131_Rm0.txt
agrep -0 -c 'GAGATGGTACGCACCAA' *.fastq > count/B2132_Rm0.txt
agrep -0 -c 'GAAGTCCTCGTTCGAGA' *.fastq > count/B2135_Rm0.txt
agrep -0 -c 'ATTGATTTCGTGTGCGT' *.fastq > count/B2137_Rm0.txt
agrep -0 -c 'AGCATAACCGCGTTTAT' *.fastq > count/B2138_Rm0.txt
agrep -0 -c 'TAGTCACACGGTCCCTA' *.fastq > count/B2139_Rm0.txt
agrep -0 -c 'CACGTAGTAAACACCGA' *.fastq > count/B2140_Rm0.txt
agrep -0 -c 'ATAGCGCACATGGTTTA' *.fastq > count/B2141_Rm0.txt
agrep -0 -c 'AGTACGGGCATACGTAT' *.fastq > count/B2142_Rm0.txt
agrep -0 -c 'TGTTAGGGGCGAGGCAT' *.fastq > count/B2144_Rm0.txt
agrep -0 -c 'CCAACTTACACTTGGTA' *.fastq > count/B2145_Rm0.txt
agrep -0 -c 'CAGTTGACCGCTTACAA' *.fastq > count/B2146_Rm0.txt
agrep -0 -c 'TGGTATCTGCAGCGCTG' *.fastq > count/B2148_Rm0.txt
agrep -0 -c 'TAGCGGCAGAATCCTAA' *.fastq > count/B2149_Rm0.txt
agrep -0 -c 'CGACTTAAGAACCTCAT' *.fastq > count/B2150_Rm0.txt
agrep -0 -c 'CTAGCCTAGGAGGATGT' *.fastq > count/B2151_Rm0.txt
agrep -0 -c 'CCATAGGCATAGTATGC' *.fastq > count/B2152_Rm0.txt
agrep -0 -c 'CGGGTGAATTGAGTGAA' *.fastq > count/B2153_Rm0.txt
agrep -0 -c 'CGTTCAACGGAGATGTG' *.fastq > count/B2154_Rm0.txt
agrep -0 -c 'CTACGAGAATTAGGTAC' *.fastq > count/B2155_Rm0.txt
agrep -0 -c 'CGCAATTTGATACAGCG' *.fastq > count/B2157_Rm0.txt
agrep -0 -c 'GGTACAGTCGCTGTCGT' *.fastq > count/B2158_Rm0.txt
agrep -0 -c 'AAAGTTGACGGCCAATG' *.fastq > count/B2159_Rm0.txt
agrep -0 -c 'GGCGATGAAATGGTGAC' *.fastq > count/B2160_Rm0.txt
agrep -0 -c 'TATAGCTACCGACCTCT' *.fastq > count/B2161_Rm0.txt
agrep -0 -c 'CCCGCGGGATTTACTAA' *.fastq > count/B2162_Rm0.txt
agrep -0 -c 'GACTTCGGACGCGTAAT' *.fastq > count/B2163_Rm0.txt
agrep -0 -c 'TTAAGCAATAATGCCGG' *.fastq > count/B2164_Rm0.txt
agrep -0 -c 'TAAGGGGTCAGCTCCAA' *.fastq > count/B2165_Rm0.txt
agrep -0 -c 'TTGGGGACCTTATGTAA' *.fastq > count/B2166_Rm0.txt
agrep -0 -c 'ATCCGTTAACGACATCG' *.fastq > count/B2167_Rm0.txt
agrep -0 -c 'AATGGGCTCGGCCATTA' *.fastq > count/B2170_Rm0.txt
agrep -0 -c 'TTTCGATTACAGTGCGC' *.fastq > count/B2171_Rm0.txt
agrep -0 -c 'AACGGGGTGGAAGTCTG' *.fastq > count/B2172_Rm0.txt
agrep -0 -c 'CTAGCCCGGACTATTAA' *.fastq > count/B2173_Rm0.txt
agrep -0 -c 'CGCTCTAACGCGTCATG' *.fastq > count/B2174_Rm0.txt
agrep -0 -c 'TACCCAGCCAGCTTAGG' *.fastq > count/B2175_Rm0.txt
agrep -0 -c 'ATCCAACTCATGAACGA' *.fastq > count/B2176_Rm0.txt
agrep -0 -c 'TGACCTGGTGAAACCTC' *.fastq > count/B2177_Rm0.txt
agrep -0 -c 'CGTAGGTCATTTTGCTG' *.fastq > count/B2179_Rm0.txt
agrep -0 -c 'ACTCCGCATAGAGTGTT' *.fastq > count/B2180_Rm0.txt
agrep -0 -c 'TGACACTCGAGAGTCCT' *.fastq > count/B2181_Rm0.txt
agrep -0 -c 'AGCGTTTCATTCACAGG' *.fastq > count/B2182_Rm0.txt
agrep -0 -c 'GGTGGAGAATAACGCAT' *.fastq > count/B2183_Rm0.txt
agrep -0 -c 'CATGAGCGCCTTATTGT' *.fastq > count/B2184_Rm0.txt
agrep -0 -c 'AGGGTAGTCAATACCAA' *.fastq > count/B2185_Rm0.txt
agrep -0 -c 'TATTGTGCCGAGGTTAC' *.fastq > count/B2186_Rm0.txt
agrep -0 -c 'GGGAAGGTAGTGGCCAT' *.fastq > count/B2187_Rm0.txt
agrep -0 -c 'GAATCCCATCGTCCTAT' *.fastq > count/B2188_Rm0.txt
agrep -0 -c 'TGATACGATTGTGCGCT' *.fastq > count/B2189_Rm0.txt
agrep -0 -c 'AAAATAACTGCTGCCGA' *.fastq > count/B2190_Rm0.txt
agrep -0 -c 'GGTTCTAGGATGGCTGC' *.fastq > count/B2192_Rm0.txt
agrep -0 -c 'GTCTACGTCCTACTTTA' *.fastq > count/B2194_Rm0.txt
agrep -0 -c 'TCCGTCTACTATATCGG' *.fastq > count/B2195_Rm0.txt
agrep -0 -c 'CAGACTTGGGTATCAGT' *.fastq > count/B2196_Rm0.txt
agrep -0 -c 'CTCGGTAATCGTGCTAA' *.fastq > count/B2197_Rm0.txt
agrep -0 -c 'TCACAATGCGCCAAGCT' *.fastq > count/B2198_Rm0.txt
agrep -0 -c 'AATCCATCGTCCCTTCT' *.fastq > count/B2200_Rm0.txt
agrep -0 -c 'TGGACTTACTTTGCCGT' *.fastq > count/B2201_Rm0.txt
agrep -0 -c 'GCACGAATTATCGTGAT' *.fastq > count/B2202_Rm0.txt
agrep -0 -c 'GGACCGTTTACAGTTAT' *.fastq > count/B2203_Rm0.txt
agrep -0 -c 'AGCGTTATAGGTCACGA' *.fastq > count/B2204_Rm0.txt
agrep -0 -c 'GGGCGCAGTAAAGCATT' *.fastq > count/B2205_Rm0.txt
agrep -0 -c 'AGCTCACTGCAGAGCGT' *.fastq > count/B2206_Rm0.txt
agrep -0 -c 'GCGGTCCAGTTTCTTGG' *.fastq > count/B2207_Rm0.txt
agrep -0 -c 'TTGGTTCAACCGGAATC' *.fastq > count/B2208_Rm0.txt
agrep -0 -c 'GGTGATACGGGCATCGA' *.fastq > count/B2209_Rm0.txt
agrep -0 -c 'TTGAGGAGCATGTATTG' *.fastq > count/B2210_Rm0.txt
agrep -0 -c 'AAGAATCCCCGCATGAT' *.fastq > count/B2211_Rm0.txt
agrep -0 -c 'GAGAGTATATCGATGGT' *.fastq > count/B2212_Rm0.txt
agrep -0 -c 'TGCGCTAGTCCTTCCAA' *.fastq > count/B2213_Rm0.txt
agrep -0 -c 'AACAGGAATGTCGCCAC' *.fastq > count/B2214_Rm0.txt
agrep -0 -c 'CCACACAGTAAGTCCCG' *.fastq > count/B2215_Rm0.txt
agrep -0 -c 'ATCTACACGCGGGTACG' *.fastq > count/B2217_Rm0.txt
agrep -0 -c 'TTGCGCTTTAGCTTCTA' *.fastq > count/B2218_Rm0.txt
agrep -0 -c 'GGAATAAAGTTCCCCGA' *.fastq > count/B2219_Rm0.txt
agrep -0 -c 'ATCTTAAAGAACCGGAG' *.fastq > count/B2220_Rm0.txt
agrep -0 -c 'TGATCTGTGAGCGTGAC' *.fastq > count/B2221_Rm0.txt
agrep -0 -c 'TCGACAACATGGTCCGT' *.fastq > count/B2222_Rm0.txt
agrep -0 -c 'GTGCGTCTGAAGAGTGG' *.fastq > count/B2223_Rm0.txt
agrep -0 -c 'AATCGTGGGTCACTGTG' *.fastq > count/B2225_Rm0.txt
agrep -0 -c 'GCAACCATAAGCTGTCG' *.fastq > count/B2227_Rm0.txt
agrep -0 -c 'CTAGGATAATGCGAGTA' *.fastq > count/B2228_Rm0.txt
agrep -0 -c 'AGACCAAGTTATTTGGC' *.fastq > count/B2229_Rm0.txt
agrep -0 -c 'TTGACCAATAGTGTTGC' *.fastq > count/B2230_Rm0.txt
agrep -0 -c 'GGTGGCTAAGGAGCACA' *.fastq > count/B2231_Rm0.txt
agrep -0 -c 'TAGGTCCAGGTCTTTGT' *.fastq > count/B2233_Rm0.txt
agrep -0 -c 'ATCTGGCGTAGCAAACC' *.fastq > count/B2234_Rm0.txt
agrep -0 -c 'ACACAGATGGATTCACT' *.fastq > count/B2235_Rm0.txt
agrep -0 -c 'AATGTACCATCGCGGTT' *.fastq > count/B2236_Rm0.txt
agrep -0 -c 'TTTTGATGCAGCCAGTA' *.fastq > count/B2237_Rm0.txt
agrep -0 -c 'CATTGGTCGCCAAATCG' *.fastq > count/B2238_Rm0.txt
agrep -0 -c 'CACTTTGTGTCAATCTC' *.fastq > count/B2239_Rm0.txt
agrep -0 -c 'TTGTTCTCGGTACCCCG' *.fastq > count/B2240_Rm0.txt
agrep -0 -c 'GATTGCTTGATTCACAC' *.fastq > count/B2241_Rm0.txt
agrep -0 -c 'TAGCCCCTTAAAACTAC' *.fastq > count/B2242_Rm0.txt
agrep -0 -c 'CGAGGTGCCAAAGTTGG' *.fastq > count/B2243_Rm0.txt
agrep -0 -c 'GAACGATCGGTAGGGTA' *.fastq > count/B2244_Rm0.txt
agrep -0 -c 'AATATTCCCGGTTCGAG' *.fastq > count/B2245_Rm0.txt
agrep -0 -c 'GTTGCTGTCGACACGAA' *.fastq > count/B2246_Rm0.txt
agrep -0 -c 'TGTGGCTAAGTGATCGC' *.fastq > count/B2247_Rm0.txt
agrep -0 -c 'ACCGACCCGTCCTAACT' *.fastq > count/B2248_Rm0.txt
agrep -0 -c 'TTGCAGCACCTCCGTAG' *.fastq > count/B2249_Rm0.txt
agrep -0 -c 'TCTAATCCTGACTATCG' *.fastq > count/B2250_Rm0.txt
agrep -0 -c 'TAGGGCGTGTGAATTTG' *.fastq > count/B2251_Rm0.txt
agrep -0 -c 'CACTAGCAGAGCCGTAC' *.fastq > count/B2252_Rm0.txt
agrep -0 -c 'TATCGAAGCTATCAGAC' *.fastq > count/B2254_Rm0.txt
agrep -0 -c 'ATTGTGCAACTTTGGCA' *.fastq > count/B2256_Rm0.txt
agrep -0 -c 'GAGTGATGATAGTCATG' *.fastq > count/B2258_Rm0.txt
agrep -0 -c 'CTATGCCACAAACCGTA' *.fastq > count/B2260_Rm0.txt
agrep -0 -c 'CACGAAGGCCTAACAAT' *.fastq > count/B2261_Rm0.txt
agrep -0 -c 'CTAAACCGTTAAACCTG' *.fastq > count/B2262_Rm0.txt
agrep -0 -c 'TAACAGTTTTTCACGCG' *.fastq > count/B2263_Rm0.txt
agrep -0 -c 'TACCACCAGTCCTCCTT' *.fastq > count/B2264_Rm0.txt
agrep -0 -c 'AACTAGCATAGGAAGAC' *.fastq > count/B2265_Rm0.txt
agrep -0 -c 'ACGACACGAATACCCGA' *.fastq > count/B2266_Rm0.txt
agrep -0 -c 'GACCGTAGATCGATTCA' *.fastq > count/B2267_Rm0.txt
agrep -0 -c 'CACACAGTCATAAGGCG' *.fastq > count/B2268_Rm0.txt
agrep -0 -c 'CTTGCCCCCCATCAGAA' *.fastq > count/B2269_Rm0.txt
agrep -0 -c 'TAAGCGCCAGCTCATAG' *.fastq > count/B2270_Rm0.txt
agrep -0 -c 'GCCTTTCCCGCAGACAT' *.fastq > count/B2272_Rm0.txt
agrep -0 -c 'ATCTGATCCGGTGGCTA' *.fastq > count/B2273_Rm0.txt
agrep -0 -c 'GAGAGTCCCACAATTTA' *.fastq > count/B2274_Rm0.txt
agrep -0 -c 'TCAGGATGCGATACGTT' *.fastq > count/B2275_Rm0.txt
agrep -0 -c 'AACAGGTCCCCAACATC' *.fastq > count/B2277_Rm0.txt
agrep -0 -c 'CATGCATCCGCGTACAT' *.fastq > count/B2278_Rm0.txt
agrep -0 -c 'TTAGGCACCAGGACTCC' *.fastq > count/B2279_Rm0.txt
agrep -0 -c 'CAGGCGTCTATTTAACG' *.fastq > count/B2280_Rm0.txt
agrep -0 -c 'TCTACGGTAGCCAATCA' *.fastq > count/B2281_Rm0.txt
agrep -0 -c 'ATGTAATGGTCACGCGA' *.fastq > count/B2282_Rm0.txt
agrep -0 -c 'GGGTTTGCCTATCTCCT' *.fastq > count/B2283_Rm0.txt
agrep -0 -c 'AGCGAGATAAGTCCTAG' *.fastq > count/B2284_Rm0.txt
agrep -0 -c 'TTTCGATGACCATCTCT' *.fastq > count/B2286_Rm0.txt
agrep -0 -c 'AATTGAACGATCTCAGG' *.fastq > count/B2287_Rm0.txt
agrep -0 -c 'TGGGTCTCATGGGTGAA' *.fastq > count/B2288_Rm0.txt
agrep -0 -c 'AGTGTAAAAGCTTTGCG' *.fastq > count/B2289_Rm0.txt
agrep -0 -c 'TGAACGGATAAGCTCCT' *.fastq > count/B2290_Rm0.txt
agrep -0 -c 'TAAGCGGACTCACGATC' *.fastq > count/B2291_Rm0.txt
agrep -0 -c 'TCATCCGCTCTTCTTAA' *.fastq > count/B2293_Rm0.txt
agrep -0 -c 'TACCCGGCTTTTCACTA' *.fastq > count/B2294_Rm0.txt
agrep -0 -c 'CTAGGTTACATATAGGC' *.fastq > count/B2295_Rm0.txt
agrep -0 -c 'TGTTACGGACGGAACTC' *.fastq > count/B2296_Rm0.txt
agrep -0 -c 'CTCTGTGTATCAACTGA' *.fastq > count/B2297_Rm0.txt
agrep -0 -c 'GAGATAGGAAACGGTCA' *.fastq > count/B2298_Rm0.txt
agrep -0 -c 'CCAATAGCAGAACTTCG' *.fastq > count/B2299_Rm0.txt
agrep -0 -c 'TGTCCTCATGTTCGTCT' *.fastq > count/B2300_Rm0.txt
agrep -0 -c 'GACCTGTTAGTTGTGAC' *.fastq > count/B2303_Rm0.txt
agrep -0 -c 'CCGGTAACAAGCATTCA' *.fastq > count/B2304_Rm0.txt
agrep -0 -c 'CGGGTCGTATGACTCAA' *.fastq > count/B2305_Rm0.txt
agrep -0 -c 'GCATAGATCAAACAGGC' *.fastq > count/B2306_Rm0.txt
agrep -0 -c 'TTATTAATCCGCTCCGG' *.fastq > count/B2307_Rm0.txt
agrep -0 -c 'GACCATACGCGGAATAG' *.fastq > count/B2308_Rm0.txt
agrep -0 -c 'CACCCCGGAGGGTATAT' *.fastq > count/B2309_Rm0.txt
agrep -0 -c 'TGTTTGGGCTAAGTGCG' *.fastq > count/B2310_Rm0.txt
agrep -0 -c 'ATGCAAAACTTGGTCCA' *.fastq > count/B2311_Rm0.txt
agrep -0 -c 'AACCCGCTGTATCACAG' *.fastq > count/B2312_Rm0.txt
agrep -0 -c 'CTAAAGCCGTTCCACGT' *.fastq > count/B2313_Rm0.txt
agrep -0 -c 'ATCAATCGCGTCAACTA' *.fastq > count/B2314_Rm0.txt
agrep -0 -c 'CGTGATTTCTTGCGGTC' *.fastq > count/B2315_Rm0.txt
agrep -0 -c 'ATCCGCCCAATCCCTGT' *.fastq > count/B2316_Rm0.txt
agrep -0 -c 'TAGGCCCGTATTCTTAT' *.fastq > count/B2317_Rm0.txt
agrep -0 -c 'ACTGCCCTCTGTTTGCG' *.fastq > count/B2318_Rm0.txt
agrep -0 -c 'CAGGTTATCTAACCAAG' *.fastq > count/B2319_Rm0.txt
agrep -0 -c 'CCACTTCCCGACTGAAG' *.fastq > count/B2320_Rm0.txt
agrep -0 -c 'GGGCAATACCCAAGTAC' *.fastq > count/B2321_Rm0.txt
agrep -0 -c 'CCAGTGCCAGAATCTAT' *.fastq > count/B2322_Rm0.txt
agrep -0 -c 'GATGAGGTTACGTCATT' *.fastq > count/B2323_Rm0.txt
agrep -0 -c 'GTACTCCCCCAATTCAT' *.fastq > count/B2324_Rm0.txt
agrep -0 -c 'CACCACCAGCCAAACCT' *.fastq > count/B2325_Rm0.txt
agrep -0 -c 'AGGTACTAGGGCTGCAC' *.fastq > count/B2326_Rm0.txt
agrep -0 -c 'CGGTTGGTCGGCAATAC' *.fastq > count/B2327_Rm0.txt
agrep -0 -c 'GAGCAGTTATGATCCCG' *.fastq > count/B2328_Rm0.txt
agrep -0 -c 'CCTAGCTCATATGCGCT' *.fastq > count/B2329_Rm0.txt
agrep -0 -c 'TGACTATCGCCAAATCA' *.fastq > count/B2330_Rm0.txt
agrep -0 -c 'CACGCTTGTGGGCTACT' *.fastq > count/B2331_Rm0.txt
agrep -0 -c 'AAGCTCGGACCTCAAAC' *.fastq > count/B2332_Rm0.txt
agrep -0 -c 'GGGTTGGGAAATTGCGC' *.fastq > count/B2333_Rm0.txt
agrep -0 -c 'CACTACAAGTTGGATAC' *.fastq > count/B2335_Rm0.txt
agrep -0 -c 'TATCCCAAACGACGACT' *.fastq > count/B2336_Rm0.txt
agrep -0 -c 'AGAACTGTGGTTGAGTT' *.fastq > count/B2337_Rm0.txt
agrep -0 -c 'ACCGTAACGCGGTCACT' *.fastq > count/B2340_Rm0.txt
agrep -0 -c 'AGCTTCATGCCCGCGTT' *.fastq > count/B2341_Rm0.txt
agrep -0 -c 'TCGAAGGGGCAGTCATT' *.fastq > count/B2342_Rm0.txt
agrep -0 -c 'GGTAACGGCTATTGGAA' *.fastq > count/B2343_Rm0.txt
agrep -0 -c 'AAAGGCCGTCAGTTCTG' *.fastq > count/B2345_Rm0.txt
agrep -0 -c 'TATTCGTCTACAGGAAG' *.fastq > count/B2346_Rm0.txt
agrep -0 -c 'GATAACTGCGGCTTGAG' *.fastq > count/B2347_Rm0.txt
agrep -0 -c 'TCGCTAGTCTCTATATC' *.fastq > count/B2348_Rm0.txt
agrep -0 -c 'GTGGGTGCGAAACAGTT' *.fastq > count/B2349_Rm0.txt
agrep -0 -c 'CTGGCTTCGTGACCAAG' *.fastq > count/B2350_Rm0.txt
agrep -0 -c 'ATCGCGAAACAAAGGCT' *.fastq > count/B2351_Rm0.txt
agrep -0 -c 'GATATACTCACTGTCAC' *.fastq > count/B2352_Rm0.txt
agrep -0 -c 'GCACGCTCTAATCTGTA' *.fastq > count/B2353_Rm0.txt
agrep -0 -c 'GGGGATCCATAACTGCT' *.fastq > count/B2354_Rm0.txt
agrep -0 -c 'ACGATCTGCATACGGCG' *.fastq > count/B2355_Rm0.txt
agrep -0 -c 'AAAGGTCCCAACACCCG' *.fastq > count/B2356_Rm0.txt
agrep -0 -c 'GATGCATGCGATAGGGT' *.fastq > count/B2357_Rm0.txt
agrep -0 -c 'AATGTCCGCGTTAGTCA' *.fastq > count/B2359_Rm0.txt
agrep -0 -c 'TTTGGGACTGTTTGCGG' *.fastq > count/B2360_Rm0.txt
agrep -0 -c 'AACCGTTATCTCATCGA' *.fastq > count/B2361_Rm0.txt
agrep -0 -c 'GTATGGATCGTGCTACT' *.fastq > count/B2362_Rm0.txt
agrep -0 -c 'ACTGGCGCCTAGGTAAC' *.fastq > count/B2363_Rm0.txt
agrep -0 -c 'TTTCGGTTAGGGATTGT' *.fastq > count/B2364_Rm0.txt
agrep -0 -c 'GAGTCCATCGCACAATC' *.fastq > count/B2366_Rm0.txt
agrep -0 -c 'GATGTCGACTCCTATAA' *.fastq > count/B2368_Rm0.txt
agrep -0 -c 'GCAATGCTTACGGGACC' *.fastq > count/B2369_Rm0.txt
agrep -0 -c 'TGGCCTTCCGCGAAACT' *.fastq > count/B2370_Rm0.txt
agrep -0 -c 'AGGCCCCCAGATCTTGA' *.fastq > count/B2371_Rm0.txt
agrep -0 -c 'CCCAGTGACGCTTTTCA' *.fastq > count/B2372_Rm0.txt
agrep -0 -c 'GTCTGTTCCTTCCGAGG' *.fastq > count/B2374_Rm0.txt
agrep -0 -c 'GGCAAGAAGATTTCGGT' *.fastq > count/B2375_Rm0.txt
agrep -0 -c 'GCGCTATAAAGTGTACT' *.fastq > count/B2377_Rm0.txt
agrep -0 -c 'AGCGCACTATGCTTCTC' *.fastq > count/B2378_Rm0.txt
agrep -0 -c 'ATTCGCTCGGTGAACTG' *.fastq > count/B2379_Rm0.txt
agrep -0 -c 'GGTTTTGCAGAGACCGA' *.fastq > count/B2380_Rm0.txt
agrep -0 -c 'TCTGAACTAGATCCCTG' *.fastq > count/B2382_Rm0.txt
agrep -0 -c 'CTACCAACCTTTCAAGT' *.fastq > count/B2383_Rm0.txt
agrep -0 -c 'TCGGCTGTACAAGGTGG' *.fastq > count/B2384_Rm0.txt
agrep -0 -c 'TAAGACTGGTGCCCTCA' *.fastq > count/B2385_Rm0.txt
agrep -0 -c 'CTCTACCCCGCATTTCA' *.fastq > count/B2386_Rm0.txt
agrep -0 -c 'GCTTCCACCTGAGAACA' *.fastq > count/B2388_Rm0.txt
agrep -0 -c 'TGGAGTATAGGGTCGCT' *.fastq > count/B2389_Rm0.txt
agrep -0 -c 'AGACTAGAATGGGCCCT' *.fastq > count/B2390_Rm0.txt
agrep -0 -c 'AAATATGTAGGAGGGCA' *.fastq > count/B2392_Rm0.txt
agrep -0 -c 'GGTATGGTTGAAAAGTG' *.fastq > count/B2393_Rm0.txt
agrep -0 -c 'CGATGTATGCGTTCCAC' *.fastq > count/B2395_Rm0.txt
agrep -0 -c 'AGGGATGCGACTTACAT' *.fastq > count/B2397_Rm0.txt
agrep -0 -c 'GAGATCGTAAGGTGCGT' *.fastq > count/B2398_Rm0.txt
agrep -0 -c 'AGGGCGATATACCCAGA' *.fastq > count/B2399_Rm0.txt
agrep -0 -c 'AGCACAGTCTACCATAC' *.fastq > count/B2400_Rm0.txt
agrep -0 -c 'ATAATATCGCGAGGTGC' *.fastq > count/B2402_Rm0.txt
agrep -0 -c 'TTGCCATAAAAACCCCC' *.fastq > count/B2403_Rm0.txt
agrep -0 -c 'CTTTAGTCAGGCTCGCG' *.fastq > count/B2404_Rm0.txt
agrep -0 -c 'GTTGCTGTCTAAATCGA' *.fastq > count/B2405_Rm0.txt
agrep -0 -c 'CCTACCTACATTACCAT' *.fastq > count/B2406_Rm0.txt
agrep -0 -c 'AATGGTATTCACTGGTG' *.fastq > count/B2407_Rm0.txt
agrep -0 -c 'TAGCGGGCATCAATCGC' *.fastq > count/B2408_Rm0.txt
agrep -0 -c 'ACTTAGACTCCCAACTA' *.fastq > count/B2410_Rm0.txt
agrep -0 -c 'GTACTTTTACGTACGGC' *.fastq > count/B2411_Rm0.txt
agrep -0 -c 'GGAATTGTGTCCCCTTG' *.fastq > count/B2412_Rm0.txt
agrep -0 -c 'CGGGCATATTTGATCGT' *.fastq > count/B2413_Rm0.txt
agrep -0 -c 'ATGTCGATTGACACCAG' *.fastq > count/B2414_Rm0.txt
agrep -0 -c 'GTATACGCAAGTTCGAG' *.fastq > count/B2415_Rm0.txt
agrep -0 -c 'CCCTTGACAAAATTAGG' *.fastq > count/B2416_Rm0.txt
agrep -0 -c 'ACGGATAAAGTCGCTAC' *.fastq > count/B2417_Rm0.txt
agrep -0 -c 'GGGCAAGACTCGTAGTT' *.fastq > count/B2418_Rm0.txt
agrep -0 -c 'TACGTAGGCCATAAGCA' *.fastq > count/B2420_Rm0.txt
agrep -0 -c 'CGAGCATTACTCTTACA' *.fastq > count/B2421_Rm0.txt
agrep -0 -c 'GCTGGAAGATAGGACTG' *.fastq > count/B2422_Rm0.txt
agrep -0 -c 'GATGGTCATACTGCGCC' *.fastq > count/B2423_Rm0.txt
agrep -0 -c 'CTGTTCTCCAAGACCCG' *.fastq > count/B2424_Rm0.txt
agrep -0 -c 'CCGGGGATCGTTTATCA' *.fastq > count/B2425_Rm0.txt
agrep -0 -c 'CGTAATCAGTTGGGTAT' *.fastq > count/B2426_Rm0.txt
agrep -0 -c 'TGTAGCTATTATGTGCG' *.fastq > count/B2427_Rm0.txt
agrep -0 -c 'CGTTTACCTCGGGGCTT' *.fastq > count/B2428_Rm0.txt
agrep -0 -c 'TAGTACGATGGGTCAAC' *.fastq > count/B2429_Rm0.txt
agrep -0 -c 'TGGATCCGTTATGTCAC' *.fastq > count/B2430_Rm0.txt
agrep -0 -c 'CGCAAGTTCGAAAACAC' *.fastq > count/B2431_Rm0.txt
agrep -0 -c 'CGTCACCCACTATTTGG' *.fastq > count/B2432_Rm0.txt
agrep -0 -c 'TATAGACAGGGAAAGAG' *.fastq > count/B2433_Rm0.txt
agrep -0 -c 'CTTTGCTGAAACGGGGT' *.fastq > count/B2434_Rm0.txt
agrep -0 -c 'GCTCTCATCCTCATGAC' *.fastq > count/B2436_Rm0.txt
agrep -0 -c 'AGGGCGGAACTAATGAT' *.fastq > count/B2437_Rm0.txt
agrep -0 -c 'CAGCACGCTTCGAAACT' *.fastq > count/B2438_Rm0.txt
agrep -0 -c 'AAAAGGGGATGACTGAC' *.fastq > count/B2439_Rm0.txt
agrep -0 -c 'CGGATTCTACGTTCGCC' *.fastq > count/B2440_Rm0.txt
agrep -0 -c 'TATAGACCTAGCCTGTC' *.fastq > count/B2441_Rm0.txt
agrep -0 -c 'GGGATTGCAACGGAGTC' *.fastq > count/B2442_Rm0.txt
agrep -0 -c 'TATAACTAGGCGGCTTA' *.fastq > count/B2443_Rm0.txt
agrep -0 -c 'TCTGTAGAGGCGTGGAA' *.fastq > count/B2445_Rm0.txt
agrep -0 -c 'ACATATTCCTAGCCACG' *.fastq > count/B2446_Rm0.txt
agrep -0 -c 'TGTGACACGACCCTATG' *.fastq > count/B2447_Rm0.txt
agrep -0 -c 'TGCACGCTGATTATACA' *.fastq > count/B2448_Rm0.txt
agrep -0 -c 'CCTCCAGAAGTAGTTAG' *.fastq > count/B2449_Rm0.txt
agrep -0 -c 'TGACAAGCGAGACGTAC' *.fastq > count/B2450_Rm0.txt
agrep -0 -c 'CCAGCCAGTATGATTAT' *.fastq > count/B2452_Rm0.txt
agrep -0 -c 'CGGAGTTTCACCCTGCA' *.fastq > count/B2454_Rm0.txt
agrep -0 -c 'GAGCCATATTCAACCTG' *.fastq > count/B2455_Rm0.txt
agrep -0 -c 'TGCAAAATGCCCTACGG' *.fastq > count/B2456_Rm0.txt
agrep -0 -c 'TAACTAGCAGGGGTAAG' *.fastq > count/B2458_Rm0.txt
agrep -0 -c 'GGCAATACGGTTGTTTG' *.fastq > count/B2460_Rm0.txt
agrep -0 -c 'GCTATGTGTGTGGTTAA' *.fastq > count/B2461_Rm0.txt
agrep -0 -c 'AAAAACACCCGTCACCC' *.fastq > count/B2462_Rm0.txt
agrep -0 -c 'ATGTGAAGTCGGGGTAA' *.fastq > count/B2463_Rm0.txt
agrep -0 -c 'CAGTTTTCCTGTTCCGC' *.fastq > count/B2466_Rm0.txt
agrep -0 -c 'TCCACGCGCTCTCTTAG' *.fastq > count/B2467_Rm0.txt
agrep -0 -c 'TCTCAGCATAACACCAT' *.fastq > count/B2469_Rm0.txt
agrep -0 -c 'CACTCTCTGAGGCTAGT' *.fastq > count/B2470_Rm0.txt
agrep -0 -c 'TCGCTTACCAAGAAGCC' *.fastq > count/B2471_Rm0.txt
agrep -0 -c 'AAGTCTGACTAGGCTTA' *.fastq > count/B2472_Rm0.txt
agrep -0 -c 'TGGGCGACACGTGTTCT' *.fastq > count/B2473_Rm0.txt
agrep -0 -c 'TTCTGCTATGCGGCAAG' *.fastq > count/B2474_Rm0.txt
agrep -0 -c 'TGGTAGTCCCAGTAGAA' *.fastq > count/B2476_Rm0.txt
agrep -0 -c 'ACCTTGTCACCAACTCG' *.fastq > count/B2477_Rm0.txt
agrep -0 -c 'GTAGGAGAATTCGGAGA' *.fastq > count/B2478_Rm0.txt
agrep -0 -c 'AAAGTACTGAGGCGGCG' *.fastq > count/B2479_Rm0.txt
agrep -0 -c 'AACGTCACCGAGTGCTC' *.fastq > count/B2480_Rm0.txt
agrep -0 -c 'ACGTCCGTCAATCTACC' *.fastq > count/B2481_Rm0.txt
agrep -0 -c 'GAGTAACTAGTCGCGAT' *.fastq > count/B2482_Rm0.txt
agrep -0 -c 'CATCAGAGGAGGTAGTT' *.fastq > count/B2483_Rm0.txt
agrep -0 -c 'AGCCTAAACTCTCGGAT' *.fastq > count/B2484_Rm0.txt
agrep -0 -c 'ATGGACTACTACGGATG' *.fastq > count/B2485_Rm0.txt
agrep -0 -c 'AACTCTATGTAAGGGTG' *.fastq > count/B2486_Rm0.txt
agrep -0 -c 'CTTCTCGAGAAGTAGCG' *.fastq > count/B2487_Rm0.txt
agrep -0 -c 'TGCAATCCTATGCACGT' *.fastq > count/B2488_Rm0.txt
agrep -0 -c 'CTAGAAAGTTCGGCCAT' *.fastq > count/B2489_Rm0.txt
agrep -0 -c 'GTCAAGCGCAAAAGCTT' *.fastq > count/B2490_Rm0.txt
agrep -0 -c 'GGGCTGAAGCTACTGAT' *.fastq > count/B2491_Rm0.txt
agrep -0 -c 'CTCGCGTATGTAGATAT' *.fastq > count/B2492_Rm0.txt
agrep -0 -c 'CAATATACTGGGTGGCA' *.fastq > count/B2493_Rm0.txt
agrep -0 -c 'AAATCAACCCCCGAGCC' *.fastq > count/B2494_Rm0.txt
agrep -0 -c 'GTCTTATGCTGAGGATG' *.fastq > count/B2495_Rm0.txt
agrep -0 -c 'AGTCTCATAACTTCCGC' *.fastq > count/B2496_Rm0.txt
agrep -0 -c 'TAGGAAGATGCGAAAGA' *.fastq > count/B2497_Rm0.txt
agrep -0 -c 'AGTGGGCGGATTCTTAT' *.fastq > count/B2498_Rm0.txt
agrep -0 -c 'CTAGCTGCTGCTGGTAC' *.fastq > count/B2500_Rm0.txt
agrep -0 -c 'GAAGACGCAGAGGTTCC' *.fastq > count/B2501_Rm0.txt
agrep -0 -c 'AAGACCAGGGCCGTACT' *.fastq > count/B2502_Rm0.txt
agrep -0 -c 'AGACTTCCATACTCATC' *.fastq > count/B2503_Rm0.txt
agrep -0 -c 'GCAGTCAACTGATCCAT' *.fastq > count/B2504_Rm0.txt
agrep -0 -c 'CCGTCATCCCACAATAA' *.fastq > count/B2505_Rm0.txt
agrep -0 -c 'CTTCGTGCCACCATCCT' *.fastq > count/B2506_Rm0.txt
agrep -0 -c 'GGAACTCTCCGTACGAA' *.fastq > count/B2507_Rm0.txt
agrep -0 -c 'GCCAATGACTAAGTCAT' *.fastq > count/B2508_Rm0.txt
agrep -0 -c 'TACTATCGAAGCTCTCT' *.fastq > count/B2509_Rm0.txt
agrep -0 -c 'TAGGTCGTCACGGCCAT' *.fastq > count/B2513_Rm0.txt
agrep -0 -c 'TTTGCAACCGCTGATTA' *.fastq > count/B2514_Rm0.txt
agrep -0 -c 'AATCCTCAAGCTCTTAC' *.fastq > count/B2515_Rm0.txt
agrep -0 -c 'TCCAGCATTTCAATGGT' *.fastq > count/B2516_Rm0.txt
agrep -0 -c 'ACCGGTGTGATTAAGAA' *.fastq > count/B2517_Rm0.txt
agrep -0 -c 'GGGTGCCTTTAAGTCTT' *.fastq > count/B2518_Rm0.txt
agrep -0 -c 'TCTTTCCCGGCTGGAAT' *.fastq > count/B2519_Rm0.txt
agrep -0 -c 'CAACTGTGGGTGAAGAA' *.fastq > count/B2520_Rm0.txt
agrep -0 -c 'AGTCGGCAGGTCGAGTT' *.fastq > count/B2521_Rm0.txt
agrep -0 -c 'TGGATCGGAGAAGCCGA' *.fastq > count/B2522_Rm0.txt
agrep -0 -c 'GGGCGCTGCTGGATTAA' *.fastq > count/B2523_Rm0.txt
agrep -0 -c 'GTATTCGTGTCTTCCGG' *.fastq > count/B2524_Rm0.txt
agrep -0 -c 'AACCGCAGTATACCGTT' *.fastq > count/B2525_Rm0.txt
agrep -0 -c 'CGTGTTGGTCCATCGGT' *.fastq > count/B2526_Rm0.txt
agrep -0 -c 'GCCTTCTTGGGCATTCG' *.fastq > count/B2528_Rm0.txt
agrep -0 -c 'AGGCTTGAGTTATTCCA' *.fastq > count/B2529_Rm0.txt
agrep -0 -c 'TCCGATTGCAGTTGTTA' *.fastq > count/B2530_Rm0.txt
agrep -0 -c 'TGCATCTGCTGCCCGAT' *.fastq > count/B2531_Rm0.txt
agrep -0 -c 'TCGCTGTCAAATATCGG' *.fastq > count/B2532_Rm0.txt
agrep -0 -c 'TGTAGCGTATTCAGACT' *.fastq > count/B2533_Rm0.txt
agrep -0 -c 'TTGGCGTTAAAAGGTGC' *.fastq > count/B2534_Rm0.txt
agrep -0 -c 'TACTCCAGACAAGCACC' *.fastq > count/B2535_Rm0.txt
agrep -0 -c 'CTACGTCCCAAAGCCAA' *.fastq > count/B2537_Rm0.txt
agrep -0 -c 'AGATTACGACCCGTTGT' *.fastq > count/B2538_Rm0.txt
agrep -0 -c 'CCGTCGCCAAAACGTAC' *.fastq > count/B2539_Rm0.txt
agrep -0 -c 'GGAAGTCCCGTTGTATA' *.fastq > count/B2540_Rm0.txt
agrep -0 -c 'CAATGGGAATTGGGCCG' *.fastq > count/B2541_Rm0.txt
agrep -0 -c 'GGTAACGAGTTCGTTTA' *.fastq > count/B2543_Rm0.txt
agrep -0 -c 'CGTCGTTCTCAAGGAAC' *.fastq > count/B2544_Rm0.txt
agrep -0 -c 'CGACGACTTAGGGATGT' *.fastq > count/B2545_Rm0.txt
agrep -0 -c 'GGATTGCGGGGAGTCAT' *.fastq > count/B2546_Rm0.txt
agrep -0 -c 'CGAACACCATCGGAGCA' *.fastq > count/B2547_Rm0.txt
agrep -0 -c 'GGTAAACTCGACCTTAA' *.fastq > count/B2551_Rm0.txt
agrep -0 -c 'CAGCCGGTGATATCTTA' *.fastq > count/B2552_Rm0.txt
agrep -0 -c 'AGTTAGACGCGGCAGTG' *.fastq > count/B2553_Rm0.txt
agrep -0 -c 'GTCAATATTAGTCGGTC' *.fastq > count/B2554_Rm0.txt
agrep -0 -c 'ACCAGGTAAGTTTCAGG' *.fastq > count/B2555_Rm0.txt
agrep -0 -c 'ACAAATAGGGCTCCAGC' *.fastq > count/B2556_Rm0.txt
agrep -0 -c 'TTGTGGCTCGAGCCTCA' *.fastq > count/B2557_Rm0.txt
agrep -0 -c 'GATTGGACACCTCCCAC' *.fastq > count/B2559_Rm0.txt
agrep -0 -c 'AGCAGACGTATTTCTCA' *.fastq > count/B2560_Rm0.txt
agrep -0 -c 'TCTCGTTTTCGTTTACG' *.fastq > count/B2561_Rm0.txt
agrep -0 -c 'ACAGATTACGGGAAAGA' *.fastq > count/B2562_Rm0.txt
agrep -0 -c 'GACCATGATTCGGCTCT' *.fastq > count/B2563_Rm0.txt
agrep -0 -c 'ATTACTCCGAAGCTGGC' *.fastq > count/B2564_Rm0.txt
agrep -0 -c 'GCACCGACCTAGGCTAA' *.fastq > count/B2565_Rm0.txt
agrep -0 -c 'TACCACCGCAGAACCAC' *.fastq > count/B2566_Rm0.txt
agrep -0 -c 'AATCACGGTGCGCATAT' *.fastq > count/B2567_Rm0.txt
agrep -0 -c 'GTATGACATGCCGAGCC' *.fastq > count/B2568_Rm0.txt
agrep -0 -c 'GACATCCTAGTCGGTTA' *.fastq > count/B2569_Rm0.txt
agrep -0 -c 'AGTTACCACTGTACGTG' *.fastq > count/B2571_Rm0.txt
agrep -0 -c 'CAAATAGCAGAAACGCA' *.fastq > count/B2572_Rm0.txt
agrep -0 -c 'CGTAACGGGATTATGTG' *.fastq > count/B2573_Rm0.txt
agrep -0 -c 'GGGTTCCGGTGATATGG' *.fastq > count/B2574_Rm0.txt
agrep -0 -c 'TTTGTCTGCACTAGGCA' *.fastq > count/B2575_Rm0.txt
agrep -0 -c 'AACGCCTCGTTTAGAAC' *.fastq > count/B2576_Rm0.txt
agrep -0 -c 'CGTGCCAAGGCGAGATT' *.fastq > count/B2577_Rm0.txt
agrep -0 -c 'AGCAGGAGTTACGATCA' *.fastq > count/B2580_Rm0.txt
agrep -0 -c 'GTCCGATTGCAACGAAG' *.fastq > count/B2581_Rm0.txt
agrep -0 -c 'AAGGAGTGGACTAGGTA' *.fastq > count/B2582_Rm0.txt
agrep -0 -c 'CTTATTCGCGAGTTCGG' *.fastq > count/B2583_Rm0.txt
agrep -0 -c 'ACCGCTGTCGATGGTTG' *.fastq > count/B2584_Rm0.txt
agrep -0 -c 'TATGACTCGACGTCTCG' *.fastq > count/B2585_Rm0.txt
agrep -0 -c 'TCGAGTGCTGGCGAACT' *.fastq > count/B2586_Rm0.txt
agrep -0 -c 'TTTTGATTCTGCACGCG' *.fastq > count/B2587_Rm0.txt
agrep -0 -c 'GGTCTCTAAACGTGTAT' *.fastq > count/B2588_Rm0.txt
agrep -0 -c 'GTGATGCAACGAATCAA' *.fastq > count/B2589_Rm0.txt
agrep -0 -c 'CGCAAATCGGCGGAATT' *.fastq > count/B2590_Rm0.txt
agrep -0 -c 'CTTTAAAACTGGTGCGC' *.fastq > count/B2593_Rm0.txt
agrep -0 -c 'CAGTCCTTAGTTAGTAG' *.fastq > count/B2594_Rm0.txt
agrep -0 -c 'GTGGGATGTCAGTGTCA' *.fastq > count/B2595_Rm0.txt
agrep -0 -c 'ACCAACTCTCGAGTCTG' *.fastq > count/B2596_Rm0.txt
agrep -0 -c 'CACACGTTGTTGTATCG' *.fastq > count/B2597_Rm0.txt
agrep -0 -c 'GTTCTCTAGCACAATGC' *.fastq > count/B2598_Rm0.txt
agrep -0 -c 'CTTTGCAACTCCGGTGG' *.fastq > count/B2599_Rm0.txt
agrep -0 -c 'CCGATGTAGTTGCTACA' *.fastq > count/B2600_Rm0.txt
agrep -0 -c 'TCGGTACGCCTTCACTT' *.fastq > count/B2601_Rm0.txt
agrep -0 -c 'CCCCCCTATAAATATCG' *.fastq > count/B2602_Rm0.txt
agrep -0 -c 'CAACGAAGGCTCGTGCA' *.fastq > count/B2603_Rm0.txt
agrep -0 -c 'GCAGCGAGTAATCAATC' *.fastq > count/B2604_Rm0.txt
agrep -0 -c 'CCAGGCTTGATCCTGAC' *.fastq > count/B2605_Rm0.txt
agrep -0 -c 'ACTGTCCGTAATCGCTC' *.fastq > count/B2606_Rm0.txt
agrep -0 -c 'GATGCCTCAAACATCTG' *.fastq > count/B2607_Rm0.txt
agrep -0 -c 'TGGTGGATCGTTAAGGC' *.fastq > count/B2609_Rm0.txt
agrep -0 -c 'CGATCATTCCGAACGTG' *.fastq > count/B2610_Rm0.txt
agrep -0 -c 'CGTCTAACTAGTAACGC' *.fastq > count/B2614_Rm0.txt
agrep -0 -c 'TCCGGTTACAAGTCTGT' *.fastq > count/B2615_Rm0.txt
agrep -0 -c 'CATTAGGCCGCAAAGCC' *.fastq > count/B2616_Rm0.txt
agrep -0 -c 'AGCACAGCAGACGATCA' *.fastq > count/B2617_Rm0.txt
agrep -0 -c 'CCGGGAATTAATTGAAG' *.fastq > count/B2618_Rm0.txt
agrep -0 -c 'CATAACTACGGCTTCAC' *.fastq > count/B2619_Rm0.txt
agrep -0 -c 'GGTCATTATGCAGAGTC' *.fastq > count/B2620_Rm0.txt
agrep -0 -c 'CCGATTTATCCTAGACG' *.fastq > count/B2621_Rm0.txt
agrep -0 -c 'CCGACGACAGCATCTAT' *.fastq > count/B2622_Rm0.txt
agrep -0 -c 'TTTAGCGAAACGGTCAG' *.fastq > count/B2623_Rm0.txt
agrep -0 -c 'CGCTATACGCTCCGTAC' *.fastq > count/B2624_Rm0.txt
agrep -0 -c 'CTATCGCGAACTTCACA' *.fastq > count/B2625_Rm0.txt
agrep -0 -c 'GCAGAAGTCGACGCCTT' *.fastq > count/B2626_Rm0.txt
agrep -0 -c 'CTCGTACTCTATGGCGG' *.fastq > count/B2627_Rm0.txt
agrep -0 -c 'GTCGCATCAAGAGCACG' *.fastq > count/B2628_Rm0.txt
agrep -0 -c 'GGGCGATAATAGATAGC' *.fastq > count/B2629_Rm0.txt
agrep -0 -c 'ATCCAGCAGAAACGGCC' *.fastq > count/B2630_Rm0.txt
agrep -0 -c 'CGTCCTCAGTTAGTCAA' *.fastq > count/B2631_Rm0.txt
agrep -0 -c 'ACTTGAAGTACCCGGCC' *.fastq > count/B2633_Rm0.txt
agrep -0 -c 'GGTGAACTTTCTCGGCT' *.fastq > count/B2634_Rm0.txt
agrep -0 -c 'CCAACCCCATTCAGCGA' *.fastq > count/B2635_Rm0.txt
agrep -0 -c 'TCGGTAGGAGAAAAGAG' *.fastq > count/B2636_Rm0.txt
agrep -0 -c 'GGGAGGCTTTATCAGAT' *.fastq > count/B2637_Rm0.txt
agrep -0 -c 'CATTGCGCAAAACCCAG' *.fastq > count/B2638_Rm0.txt
agrep -0 -c 'GATCCGCTGTCTTTCGT' *.fastq > count/B2641_Rm0.txt
agrep -0 -c 'TCGGGTTTGACTGGCCT' *.fastq > count/B2642_Rm0.txt
agrep -0 -c 'CGGTAAGAATCGTACTC' *.fastq > count/B2643_Rm0.txt
agrep -0 -c 'GGGTGTCACGATTTGAA' *.fastq > count/B2644_Rm0.txt
agrep -0 -c 'GGGTAAGACAACCAGCA' *.fastq > count/B2645_Rm0.txt
agrep -0 -c 'TCATCTTTTGCGCAGGT' *.fastq > count/B2646_Rm0.txt
agrep -0 -c 'ATAATCTAACCACTCGG' *.fastq > count/B2647_Rm0.txt
agrep -0 -c 'AGTGTTAGTATCCGATC' *.fastq > count/B2648_Rm0.txt
agrep -0 -c 'TCTTGAGTATACTGTCC' *.fastq > count/B2649_Rm0.txt
agrep -0 -c 'GGAAAGAACTTCGCTTA' *.fastq > count/B2650_Rm0.txt
agrep -0 -c 'CAAGATTTCTTAGGCGC' *.fastq > count/B2651_Rm0.txt
agrep -0 -c 'CCTTGGTAAAGTCTCAA' *.fastq > count/B2652_Rm0.txt
agrep -0 -c 'CCGAGGCTATAGTCACC' *.fastq > count/B2653_Rm0.txt
agrep -0 -c 'CATATGCACGTCTCGCT' *.fastq > count/B2654_Rm0.txt
agrep -0 -c 'CGAAATGCCGCGTTAAT' *.fastq > count/B2655_Rm0.txt
agrep -0 -c 'TTTCTTCCGCTATGACC' *.fastq > count/B2656_Rm0.txt
agrep -0 -c 'GCGCAGTGGATTAAGTT' *.fastq > count/B2657_Rm0.txt
agrep -0 -c 'CGTTGAGTGGCAGTTGT' *.fastq > count/B2658_Rm0.txt
agrep -0 -c 'CTTACCATTACGAGTGC' *.fastq > count/B2659_Rm0.txt
agrep -0 -c 'GTTTAAGACGAGAGACG' *.fastq > count/B2660_Rm0.txt
agrep -0 -c 'GATGCGACAACGATTCT' *.fastq > count/B2661_Rm0.txt
agrep -0 -c 'CGGTAGTCTCTCTGTCC' *.fastq > count/B2663_Rm0.txt
agrep -0 -c 'GAAAGTCCTTAGGAACG' *.fastq > count/B2664_Rm0.txt
agrep -0 -c 'GGGACCTGACGCTCATT' *.fastq > count/B2665_Rm0.txt
agrep -0 -c 'CCGAAACACGACCAAGT' *.fastq > count/B2666_Rm0.txt
agrep -0 -c 'GCAACCCTTACACTCCC' *.fastq > count/B2668_Rm0.txt
agrep -0 -c 'TACTCCTTGGAATACCT' *.fastq > count/B2670_Rm0.txt
agrep -0 -c 'TGAAGTGAGCGATCCGA' *.fastq > count/B2671_Rm0.txt
agrep -0 -c 'TCTAGGGGACTGTGCGT' *.fastq > count/B2672_Rm0.txt
agrep -0 -c 'ACCCGCACATTTGTGCC' *.fastq > count/B2673_Rm0.txt
agrep -0 -c 'ATGCTAGAAGTGGCACG' *.fastq > count/B2674_Rm0.txt
agrep -0 -c 'TCTCTCACGTGCACTTG' *.fastq > count/B2675_Rm0.txt
agrep -0 -c 'AGGGGCAACCCTTTACA' *.fastq > count/B2676_Rm0.txt
agrep -0 -c 'TATTACCAGAAGTGTCG' *.fastq > count/B2677_Rm0.txt
agrep -0 -c 'TAGCCCGGCGTGCAATA' *.fastq > count/B2679_Rm0.txt
agrep -0 -c 'GTAAACTACCTTGCCTC' *.fastq > count/B2680_Rm0.txt
agrep -0 -c 'GTTTCGGCTCCATGTCG' *.fastq > count/B2681_Rm0.txt
agrep -0 -c 'CGCGGATATTTCTCTGA' *.fastq > count/B2682_Rm0.txt
agrep -0 -c 'CCTGCAAGTGAACGGTT' *.fastq > count/B2683_Rm0.txt
agrep -0 -c 'TGACGGATAGAACAACA' *.fastq > count/B2684_Rm0.txt
agrep -0 -c 'CTGGTAGTAGTACCGGT' *.fastq > count/B2685_Rm0.txt
agrep -0 -c 'CGGCGTATCACACAGTT' *.fastq > count/B2686_Rm0.txt
agrep -0 -c 'TAAGACCGGTGCTAGCG' *.fastq > count/B2688_Rm0.txt
agrep -0 -c 'CCCGCTAACACCTGTTG' *.fastq > count/B2689_Rm0.txt
agrep -0 -c 'CAGACGCTAGTACGCGT' *.fastq > count/B2691_Rm0.txt
agrep -0 -c 'GACTGTATCCGGGCTGT' *.fastq > count/B2692_Rm0.txt
agrep -0 -c 'GTCTTAATTCTGGATCC' *.fastq > count/B2693_Rm0.txt
agrep -0 -c 'CCTGCTACTTACTGCTG' *.fastq > count/B2694_Rm0.txt
agrep -0 -c 'GAAGTAATCGGCTCAAT' *.fastq > count/B2696_Rm0.txt
agrep -0 -c 'GCTACGGTTACAATGTA' *.fastq > count/B2697_Rm0.txt
agrep -0 -c 'GATAGGATGGCAACCCC' *.fastq > count/B2698_Rm0.txt
agrep -0 -c 'CAGGTGCTGTTAAGCTG' *.fastq > count/B2699_Rm0.txt
agrep -0 -c 'TCCCGGAATGTACTCTT' *.fastq > count/B2700_Rm0.txt
agrep -0 -c 'CTCAGGTACGCTTCATT' *.fastq > count/B2702_Rm0.txt
agrep -0 -c 'ACACAAGCTGCGAATTA' *.fastq > count/B2703_Rm0.txt
agrep -0 -c 'CATTGTATCAGAGGTGA' *.fastq > count/B2704_Rm0.txt
agrep -0 -c 'ATAACTGGCGCTTGGCT' *.fastq > count/B2705_Rm0.txt
agrep -0 -c 'GTGATATTGCTGTCTCA' *.fastq > count/B2706_Rm0.txt
agrep -0 -c 'CAGCCAACAATGCGCTT' *.fastq > count/B2707_Rm0.txt
agrep -0 -c 'GACTTTATGAACCGACT' *.fastq > count/B2708_Rm0.txt
agrep -0 -c 'AAGATACATCGCTACCG' *.fastq > count/B2709_Rm0.txt
agrep -0 -c 'ATCCTACGCTGTCTCGG' *.fastq > count/B2710_Rm0.txt
agrep -0 -c 'TATGGCGATTTCCCCGG' *.fastq > count/B2712_Rm0.txt
agrep -0 -c 'TAACGTTGCATGCACGC' *.fastq > count/B2713_Rm0.txt
agrep -0 -c 'GAGCCACGTCTATGCTA' *.fastq > count/B2714_Rm0.txt
agrep -0 -c 'CCGGTATTACCGAAGTA' *.fastq > count/B2716_Rm0.txt
agrep -0 -c 'TGGACTATCGCCCTATA' *.fastq > count/B2717_Rm0.txt
agrep -0 -c 'TTCCGTCACATCACGCA' *.fastq > count/B2718_Rm0.txt
agrep -0 -c 'TTTCAAATTGGCGGAGC' *.fastq > count/B2719_Rm0.txt
agrep -0 -c 'CAACCATCAACGCGCCT' *.fastq > count/B2720_Rm0.txt
agrep -0 -c 'GGGACTATAACCTAGTG' *.fastq > count/B2721_Rm0.txt
agrep -0 -c 'GGGATTGCAAGTAAGGT' *.fastq > count/B2722_Rm0.txt
agrep -0 -c 'TTTCATAGACGGGTTCG' *.fastq > count/B2723_Rm0.txt
agrep -0 -c 'CGGCTTTGACGATCATA' *.fastq > count/B2724_Rm0.txt
agrep -0 -c 'CGGTCAATTTCAGCCCG' *.fastq > count/B2725_Rm0.txt
agrep -0 -c 'TACGTCCCCTGCTAATA' *.fastq > count/B2726_Rm0.txt
agrep -0 -c 'AGCTAAGTTGCTGTCAA' *.fastq > count/B2727_Rm0.txt
agrep -0 -c 'AAACTATCAGGACCCTA' *.fastq > count/B2728_Rm0.txt
agrep -0 -c 'GTAGGAGGACAGATCAT' *.fastq > count/B2729_Rm0.txt
agrep -0 -c 'CCTTTGAAGGTGTCTGA' *.fastq > count/B2730_Rm0.txt
agrep -0 -c 'GGACCAGCTTATTACAG' *.fastq > count/B2731_Rm0.txt
agrep -0 -c 'GTTGGCCGTAAGTCAAC' *.fastq > count/B2732_Rm0.txt
agrep -0 -c 'ACAAGATGAATACGCTC' *.fastq > count/B2734_Rm0.txt
agrep -0 -c 'AACCAGTAGCAACTCCC' *.fastq > count/B2735_Rm0.txt
agrep -0 -c 'TTAGCCTCCGGGACTTG' *.fastq > count/B2736_Rm0.txt
agrep -0 -c 'GGCCTGCTTGCAATAAT' *.fastq > count/B2737_Rm0.txt
agrep -0 -c 'AGCACGAACAGGAACCT' *.fastq > count/B2740_Rm0.txt
agrep -0 -c 'TCGATACTCACGTTGAG' *.fastq > count/B2741_Rm0.txt
agrep -0 -c 'TCATCTAAGTTGGAACG' *.fastq > count/B2743_Rm0.txt
agrep -0 -c 'TTCCGCAGGTATGTGCT' *.fastq > count/B2744_Rm0.txt
agrep -0 -c 'CTGACTAATGTTCTGGT' *.fastq > count/B2745_Rm0.txt
agrep -0 -c 'ACGGTTGGACAGGGACA' *.fastq > count/B2746_Rm0.txt
agrep -0 -c 'AGGATTCCGCACCTAGA' *.fastq > count/B2749_Rm0.txt
agrep -0 -c 'GAGGTGTTAGATCGCAC' *.fastq > count/B2750_Rm0.txt
agrep -0 -c 'GACTCCAAGTTATGCGG' *.fastq > count/B2751_Rm0.txt
agrep -0 -c 'AGTTATGCGCGCCAAAC' *.fastq > count/B2752_Rm0.txt
agrep -0 -c 'CGGCATTCATGCTTGAC' *.fastq > count/B2753_Rm0.txt
agrep -0 -c 'AGGACTAGTGGTGCCGA' *.fastq > count/B2754_Rm0.txt
agrep -0 -c 'CTAACTAAGAACCGTGA' *.fastq > count/B2755_Rm0.txt
agrep -0 -c 'GCATGACCGGTGACTAT' *.fastq > count/B2756_Rm0.txt
agrep -0 -c 'TTCCATGGGACGAATGG' *.fastq > count/B2759_Rm0.txt
agrep -0 -c 'GCAATGCGACATTTGCG' *.fastq > count/B2760_Rm0.txt
agrep -0 -c 'ACCCAGGTCGAGAACTC' *.fastq > count/B2761_Rm0.txt
agrep -0 -c 'GTCGGCATGAATTAGTA' *.fastq > count/B2762_Rm0.txt
agrep -0 -c 'TGGTGGAGCCTAACTAC' *.fastq > count/B2763_Rm0.txt
agrep -0 -c 'AGTGCTATTGCGGGCTA' *.fastq > count/B2764_Rm0.txt
agrep -0 -c 'GGTCATCCATTCTAGAA' *.fastq > count/B2765_Rm0.txt
agrep -0 -c 'CAATGCTACTTGCTTAG' *.fastq > count/B2766_Rm0.txt
agrep -0 -c 'GTGGAACAGGCGTCGTT' *.fastq > count/B2767_Rm0.txt
agrep -0 -c 'CGCTGCAATATGCTGCA' *.fastq > count/B2768_Rm0.txt
agrep -0 -c 'CGGATCGTAGGCTATCA' *.fastq > count/B2770_Rm0.txt
agrep -0 -c 'CCGCAAAGATTATACGA' *.fastq > count/B2771_Rm0.txt
agrep -0 -c 'GGGTCGCGAACAATGAC' *.fastq > count/B2772_Rm0.txt
agrep -0 -c 'GTCAAGTTACCACACGC' *.fastq > count/B2774_Rm0.txt
agrep -0 -c 'TCGGAACCATCGGAACT' *.fastq > count/B2775_Rm0.txt
agrep -0 -c 'GTCTACGGTTCGGTCAG' *.fastq > count/B2776_Rm0.txt
agrep -0 -c 'AGAAGGAGGGAACGCAT' *.fastq > count/B2777_Rm0.txt
agrep -0 -c 'CTACGAGGGGTTTACCT' *.fastq > count/B2778_Rm0.txt
agrep -0 -c 'GCAAAATTGTAGGAGCG' *.fastq > count/B2781_Rm0.txt
agrep -0 -c 'GTCTACTCAACGCAAAT' *.fastq > count/B2782_Rm0.txt
agrep -0 -c 'TTCAACTAAGACCTGGT' *.fastq > count/B2783_Rm0.txt
agrep -0 -c 'AACATCCGGGATGCTCG' *.fastq > count/B2784_Rm0.txt
agrep -0 -c 'AAACATCCTTCAACTGC' *.fastq > count/B2785_Rm0.txt
agrep -0 -c 'TACCATTCGGATGGACC' *.fastq > count/B2786_Rm0.txt
agrep -0 -c 'AAACCTACGGGATCGGT' *.fastq > count/B2788_Rm0.txt
agrep -0 -c 'TAGAGCCGGCTAAGCAG' *.fastq > count/B2789_Rm0.txt
agrep -0 -c 'AGCAGTAGTCGGCGTTG' *.fastq > count/B2790_Rm0.txt
agrep -0 -c 'GATCTCTAGAATGGGAC' *.fastq > count/B2791_Rm0.txt
agrep -0 -c 'AGTATCCGACTTCCTAA' *.fastq > count/B2792_Rm0.txt
agrep -0 -c 'GGATATCGAACCCCCAT' *.fastq > count/B2793_Rm0.txt
agrep -0 -c 'TAAGTTATTAGCAGGGC' *.fastq > count/B2795_Rm0.txt
agrep -0 -c 'GCACGGACAAGTCAGTG' *.fastq > count/B2796_Rm0.txt
agrep -0 -c 'CAACTTGGGATCAAATC' *.fastq > count/B2797_Rm0.txt
agrep -0 -c 'ACAGACACGCTACCCAC' *.fastq > count/B2798_Rm0.txt
agrep -0 -c 'AGCTTCCGATTGAGCCT' *.fastq > count/B2799_Rm0.txt
agrep -0 -c 'AGTCAAACCTCGAACAG' *.fastq > count/B2801_Rm0.txt
agrep -0 -c 'GACCCTGCGAGTCATCT' *.fastq > count/B2802_Rm0.txt
agrep -0 -c 'CTGGTGGTAAGATAAGT' *.fastq > count/B2803_Rm0.txt
agrep -0 -c 'CTTGGAGTATAACCGAG' *.fastq > count/B2804_Rm0.txt
agrep -0 -c 'ATCCTGCCAGTTCACGG' *.fastq > count/B2805_Rm0.txt
agrep -0 -c 'GCAACCTGTTACGGTCG' *.fastq > count/B2806_Rm0.txt
agrep -0 -c 'TACGTGTTCGTGAATCG' *.fastq > count/B2807_Rm0.txt
agrep -0 -c 'CATACTAAGGTTTCGCG' *.fastq > count/B2808_Rm0.txt
agrep -0 -c 'CTTTTATCCGTGGGCAT' *.fastq > count/B2809_Rm0.txt
agrep -0 -c 'CGGACAATTGTTGAGGT' *.fastq > count/B2810_Rm0.txt
agrep -0 -c 'GTGCTATCAAGATGAGG' *.fastq > count/B2813_Rm0.txt
agrep -0 -c 'CAGCTATGAGCGATAGC' *.fastq > count/B2814_Rm0.txt
agrep -0 -c 'GTTCAGATGGCGCCTCT' *.fastq > count/B2815_Rm0.txt
agrep -0 -c 'ATGCGGTTTTGCACCGG' *.fastq > count/B2816_Rm0.txt
agrep -0 -c 'TACGGTTGGTCAAGTTA' *.fastq > count/B2818_Rm0.txt
agrep -0 -c 'AGACGATTCGATGGCCC' *.fastq > count/B2819_Rm0.txt
agrep -0 -c 'CACCATAACGTCCAGCA' *.fastq > count/B2820_Rm0.txt
agrep -0 -c 'GGCTGCATTTGTAGTAT' *.fastq > count/B2821_Rm0.txt
agrep -0 -c 'CGACGAGTCCTTGCAAG' *.fastq > count/B2822_Rm0.txt
agrep -0 -c 'TGTCCTTACTCTGTCGC' *.fastq > count/B2823_Rm0.txt
agrep -0 -c 'ACAACGTAATGCTCGTT' *.fastq > count/B2824_Rm0.txt
agrep -0 -c 'AGCAGCAGCTTGACGTG' *.fastq > count/B2825_Rm0.txt
agrep -0 -c 'AAGGAGATAGAAGCTAC' *.fastq > count/B2826_Rm0.txt
agrep -0 -c 'ACGAGAGCATAATCGAT' *.fastq > count/B2827_Rm0.txt
agrep -0 -c 'ACGAGTCACTTAGATCT' *.fastq > count/B2828_Rm0.txt
agrep -0 -c 'ATAGCTACTCGTTGATC' *.fastq > count/B2829_Rm0.txt
agrep -0 -c 'TGTCTTCTGTCAAGTTG' *.fastq > count/B2831_Rm0.txt
agrep -0 -c 'GAAAGGCCTGAATCGAA' *.fastq > count/B2834_Rm0.txt
agrep -0 -c 'CAGTTACAAGGTCTCGC' *.fastq > count/B2835_Rm0.txt
agrep -0 -c 'CCGCAATGGTTATGTAT' *.fastq > count/B2836_Rm0.txt
agrep -0 -c 'TTGCCACGAATAAGTCA' *.fastq > count/B2837_Rm0.txt
agrep -0 -c 'CTATTCTGTGCGGCTAG' *.fastq > count/B2838_Rm0.txt
agrep -0 -c 'AATCGTGTGTATCCAGG' *.fastq > count/B2839_Rm0.txt
agrep -0 -c 'GCAGATGGACCTACCTT' *.fastq > count/B2842_Rm0.txt
agrep -0 -c 'AGTTATCGAATGTCCAC' *.fastq > count/B2844_Rm0.txt
agrep -0 -c 'TTCCCGTAAACCTGCGA' *.fastq > count/B2845_Rm0.txt
agrep -0 -c 'TCTCTCTGGCTAATCGT' *.fastq > count/B2847_Rm0.txt
agrep -0 -c 'CCTAGCCCATCAAACTC' *.fastq > count/B2848_Rm0.txt
agrep -0 -c 'CCGTGTAGTCTAGTCTA' *.fastq > count/B2850_Rm0.txt
agrep -0 -c 'CGTATTCGTGGACCGAT' *.fastq > count/B2851_Rm0.txt
agrep -0 -c 'ATCTAGTGTTTCAGCGG' *.fastq > count/B2852_Rm0.txt
agrep -0 -c 'AACCCAACCTAATACCC' *.fastq > count/B2853_Rm0.txt
agrep -0 -c 'CTTAATGGGACAAACGT' *.fastq > count/B2854_Rm0.txt
agrep -0 -c 'GGCTGATCATAATGGCA' *.fastq > count/B2855_Rm0.txt
agrep -0 -c 'TGTGGAAGATCAACCGG' *.fastq > count/B2857_Rm0.txt
agrep -0 -c 'TGCAAAAGGTCAACCTT' *.fastq > count/B2858_Rm0.txt
agrep -0 -c 'CCGATGACTCGACCAGT' *.fastq > count/B2859_Rm0.txt
agrep -0 -c 'TACTCCTCTCGCTGTTA' *.fastq > count/B2860_Rm0.txt
agrep -0 -c 'GACAGGATTCAACGAGT' *.fastq > count/B2861_Rm0.txt
agrep -0 -c 'GATTAATTTCGGGCGAT' *.fastq > count/B2862_Rm0.txt
agrep -0 -c 'CAGCACGTTGTAAACTG' *.fastq > count/B2863_Rm0.txt
agrep -0 -c 'TGCGCATATTTGTGGAT' *.fastq > count/B2864_Rm0.txt
agrep -0 -c 'AAAACTGGGTTTTGCAG' *.fastq > count/B2865_Rm0.txt
agrep -0 -c 'TATTGGCGTTACACTCG' *.fastq > count/B2866_Rm0.txt
agrep -0 -c 'AACCGCCTGCCTTATGT' *.fastq > count/B2867_Rm0.txt
agrep -0 -c 'TACGAGAAGGATGCCTC' *.fastq > count/B2869_Rm0.txt
agrep -0 -c 'ACCAGCCATATCCGATG' *.fastq > count/B2870_Rm0.txt
agrep -0 -c 'CTTCCAGGGCATACGTG' *.fastq > count/B2871_Rm0.txt
agrep -0 -c 'ACGTACTAGTGGTGTAC' *.fastq > count/B2872_Rm0.txt
agrep -0 -c 'CCACACTGACGTCATCG' *.fastq > count/B2873_Rm0.txt
agrep -0 -c 'GTCGCAAACCCCAGTGT' *.fastq > count/B2874_Rm0.txt
agrep -0 -c 'GAACGTGAGGTTCACCT' *.fastq > count/B2875_Rm0.txt
agrep -0 -c 'TACGCAAGAGTTCGTGA' *.fastq > count/B2876_Rm0.txt
agrep -0 -c 'CTTCTGCCGTTCAGACG' *.fastq > count/B2877_Rm0.txt
agrep -0 -c 'CCCATAAGTTATTCGCG' *.fastq > count/B2878_Rm0.txt
agrep -0 -c 'CAGGTAGACTTCTGCCG' *.fastq > count/B2880_Rm0.txt
agrep -0 -c 'AAGGTGAGCGTAACGTA' *.fastq > count/B2881_Rm0.txt
agrep -0 -c 'CAAGATAGTCCATGGAA' *.fastq > count/B2883_Rm0.txt
agrep -0 -c 'ATTCGACCAAGCCTCCC' *.fastq > count/B2884_Rm0.txt
agrep -0 -c 'GATCCGACAGTCGTAGG' *.fastq > count/B2885_Rm0.txt
agrep -0 -c 'GTTATTGAAACTGCGTG' *.fastq > count/B2886_Rm0.txt
agrep -0 -c 'CCCGTGCGGTTGATTAT' *.fastq > count/B2887_Rm0.txt
agrep -0 -c 'CTCATTTATGGTGGTTG' *.fastq > count/B2888_Rm0.txt
agrep -0 -c 'GCGGAATCGACATGAAC' *.fastq > count/B2889_Rm0.txt
agrep -0 -c 'TCAGTCTGGTTCCACGA' *.fastq > count/B2890_Rm0.txt
agrep -0 -c 'AGCATGATCGGACGCAC' *.fastq > count/B2892_Rm0.txt
agrep -0 -c 'CCATGTCTCAGATAATG' *.fastq > count/B2893_Rm0.txt
agrep -0 -c 'ATCCTACGATAACGGAT' *.fastq > count/B2894_Rm0.txt
agrep -0 -c 'CGTATCGCCTGCGAATT' *.fastq > count/B2896_Rm0.txt
agrep -0 -c 'GTCAATGCTGCACAGAC' *.fastq > count/B2897_Rm0.txt
agrep -0 -c 'GACTAGTGTAGCCGCAA' *.fastq > count/B2898_Rm0.txt
agrep -0 -c 'ATGCGATTCTACGGGGT' *.fastq > count/B2899_Rm0.txt
agrep -0 -c 'AGAAAGCGATGGAATGA' *.fastq > count/B2900_Rm0.txt
agrep -0 -c 'GGCAGCTTGTTGAATGG' *.fastq > count/B2901_Rm0.txt
agrep -0 -c 'CCTGGGTTGTTCTGAGG' *.fastq > count/B2902_Rm0.txt
agrep -0 -c 'GTATAACACGCGCCTGG' *.fastq > count/B2903_Rm0.txt
agrep -0 -c 'ACCGATGCCGAGTTGTA' *.fastq > count/B2904_Rm0.txt
agrep -0 -c 'AATAGCCATCCAGCGTG' *.fastq > count/B2905_Rm0.txt
agrep -0 -c 'GGCATGAAAATCACGTA' *.fastq > count/B2906_Rm0.txt
agrep -0 -c 'CAAGCCCACCATAAATA' *.fastq > count/B2907_Rm0.txt
agrep -0 -c 'TTCTGCGTGGAGTTCCG' *.fastq > count/B2910_Rm0.txt
agrep -0 -c 'GCATAATGTAAGTCGGC' *.fastq > count/B2911_Rm0.txt
agrep -0 -c 'TGATACCCACCCGTAGT' *.fastq > count/B2912_Rm0.txt
agrep -0 -c 'GGATACCGACCTGGTAG' *.fastq > count/B2914_Rm0.txt
agrep -0 -c 'TTTGAGTAGCGAAAGCT' *.fastq > count/B2915_Rm0.txt
agrep -0 -c 'TTGTCACGCGCAAGTTG' *.fastq > count/B2917_Rm0.txt
agrep -0 -c 'CCTCCCGTCTCTATATG' *.fastq > count/B2919_Rm0.txt
agrep -0 -c 'TCTATGACAGCAAGCTG' *.fastq > count/B2920_Rm0.txt
agrep -0 -c 'ATATGCAGTCAGTACGT' *.fastq > count/B2921_Rm0.txt
agrep -0 -c 'GTCTCACCTTTGCCATT' *.fastq > count/B2922_Rm0.txt
agrep -0 -c 'TGGCCTGACATTGAGGT' *.fastq > count/B2923_Rm0.txt
agrep -0 -c 'AACCATGCTGTGCGCTG' *.fastq > count/B2924_Rm0.txt
agrep -0 -c 'GTAAGTCTGCCCTGGTT' *.fastq > count/B2925_Rm0.txt
agrep -0 -c 'TTCACCGGGCCTCTATG' *.fastq > count/B2926_Rm0.txt
agrep -0 -c 'ACCCGGTGATATTGAAG' *.fastq > count/B2927_Rm0.txt
agrep -0 -c 'CTTGCCCGTGGCTGTTA' *.fastq > count/B2928_Rm0.txt
agrep -0 -c 'TGACCCGTAGCTAACCT' *.fastq > count/B2930_Rm0.txt
agrep -0 -c 'AACCGAAATCTGGACGG' *.fastq > count/B2931_Rm0.txt
agrep -0 -c 'AAACGCCTAGAAGCTGA' *.fastq > count/B2934_Rm0.txt
agrep -0 -c 'ACATACAGTGGCTCCGG' *.fastq > count/B2935_Rm0.txt
agrep -0 -c 'TATGGAGGGACAGAACT' *.fastq > count/B2936_Rm0.txt
agrep -0 -c 'CGATGTCACTGCTGGAG' *.fastq > count/B2937_Rm0.txt
agrep -0 -c 'GTTACCGAGTGAAACTT' *.fastq > count/B2943_Rm0.txt
agrep -0 -c 'TATGTAGCCGACTTAAC' *.fastq > count/B2944_Rm0.txt
agrep -0 -c 'GGCAGCTTGGAAACCGT' *.fastq > count/B2947_Rm0.txt
agrep -0 -c 'CTTTGGATGGGGGTGTT' *.fastq > count/B2948_Rm0.txt
agrep -0 -c 'GCGGATTCTCTTAGTGG' *.fastq > count/B2949_Rm0.txt
agrep -0 -c 'GTATCGGTGCACGCTGA' *.fastq > count/B2950_Rm0.txt
agrep -0 -c 'GCAGGGAATAAATGTAC' *.fastq > count/B2951_Rm0.txt
agrep -0 -c 'CGTGTAGGGTGAAGCGT' *.fastq > count/B2952_Rm0.txt
agrep -0 -c 'TATGGAGGAGCGACATC' *.fastq > count/B2954_Rm0.txt
agrep -0 -c 'CCCATTACCTGAACACC' *.fastq > count/B2956_Rm0.txt
agrep -0 -c 'TACCTCCAGAGTCATAC' *.fastq > count/B2957_Rm0.txt
agrep -0 -c 'AGTCTTGGGTACTCTCG' *.fastq > count/B2958_Rm0.txt
agrep -0 -c 'GTAAACATCGTCTCGTG' *.fastq > count/B2959_Rm0.txt
agrep -0 -c 'TCTGGGTTCTCCAATTA' *.fastq > count/B2960_Rm0.txt
agrep -0 -c 'CTATATCCTTGGGTTTG' *.fastq > count/B2961_Rm0.txt
agrep -0 -c 'TTATGGAGTGCGTGAGT' *.fastq > count/B2963_Rm0.txt
agrep -0 -c 'AGTAGAAAACTTGGGGT' *.fastq > count/B2964_Rm0.txt
agrep -0 -c 'TCGTATCGCATGGCCGA' *.fastq > count/B2965_Rm0.txt
agrep -0 -c 'TATCCCGACGCGTATGG' *.fastq > count/B2966_Rm0.txt
agrep -0 -c 'TATCAGTTGGCCCACTC' *.fastq > count/B2967_Rm0.txt
agrep -0 -c 'CTGTCATGCATACCATA' *.fastq > count/B2968_Rm0.txt
agrep -0 -c 'TCGTGCCAGCTGCTACT' *.fastq > count/B2969_Rm0.txt
agrep -0 -c 'ATGACATTTGGTGCATC' *.fastq > count/B2970_Rm0.txt
agrep -0 -c 'GATTGTTCAGGTTCGAT' *.fastq > count/B2971_Rm0.txt
agrep -0 -c 'CGTATAGTGTGAGGATT' *.fastq > count/B2973_Rm0.txt
agrep -0 -c 'CTAGATACCGGACCAGT' *.fastq > count/B2974_Rm0.txt
agrep -0 -c 'ATGTGGCAGGAGCTTGC' *.fastq > count/B2975_Rm0.txt
agrep -0 -c 'TCATCGTCGACTCGCTC' *.fastq > count/B2976_Rm0.txt
agrep -0 -c 'CGTCTACCACTATACAA' *.fastq > count/B2978_Rm0.txt
agrep -0 -c 'CAACGTGAATAGCACGC' *.fastq > count/B2979_Rm0.txt
agrep -0 -c 'TCTTTTCACAACGGGTT' *.fastq > count/B2980_Rm0.txt
agrep -0 -c 'CTCCGCTTAGATGCTAA' *.fastq > count/B2981_Rm0.txt
agrep -0 -c 'ACTCTTCTCAGCGGTTA' *.fastq > count/B2982_Rm0.txt
agrep -0 -c 'AACGTTAGTTCCTACGG' *.fastq > count/B2983_Rm0.txt
agrep -0 -c 'GCGAACGCATAGGTATT' *.fastq > count/B2985_Rm0.txt
agrep -0 -c 'AACTAGGGCCAGACCTA' *.fastq > count/B2986_Rm0.txt
agrep -0 -c 'AAATATCCGAAATCCGC' *.fastq > count/B2987_Rm0.txt
agrep -0 -c 'TTCGACGTGTTCGATAT' *.fastq > count/B2989_Rm0.txt
agrep -0 -c 'CGGTCGTCAATACCAAG' *.fastq > count/B2990_Rm0.txt
agrep -0 -c 'AATCACCTTCTCGGGAA' *.fastq > count/B2991_Rm0.txt
agrep -0 -c 'TCGTGCCATTCAGCATA' *.fastq > count/B2992_Rm0.txt
agrep -0 -c 'CCGTGAGTCAATTTTAG' *.fastq > count/B2993_Rm0.txt
agrep -0 -c 'CGTATCCAGTAGGCGCA' *.fastq > count/B2994_Rm0.txt
agrep -0 -c 'CTTCCGCACAACGTGAA' *.fastq > count/B2995_Rm0.txt
agrep -0 -c 'TTCCCTTCTGACGATAT' *.fastq > count/B2996_Rm0.txt
agrep -0 -c 'GACTGCAGGGATTCCTC' *.fastq > count/B2998_Rm0.txt
agrep -0 -c 'TAGTGCGCAAGAAAACC' *.fastq > count/B2999_Rm0.txt
agrep -0 -c 'GTCGTCATCTATCCTAT' *.fastq > count/B3001_Rm0.txt
agrep -0 -c 'TGCGTTTCTTCAATAGC' *.fastq > count/B3002_Rm0.txt
agrep -0 -c 'AAACCTAGTGAAGCTGC' *.fastq > count/B3003_Rm0.txt
agrep -0 -c 'CGTCGCAACTGTCGTAC' *.fastq > count/B3006_Rm0.txt
agrep -0 -c 'GAAGAAGGCACATTTAG' *.fastq > count/B3007_Rm0.txt
agrep -0 -c 'TCTCTCAAGACAGCGTC' *.fastq > count/B3008_Rm0.txt
agrep -0 -c 'CCGTGAGAGTTACACTG' *.fastq > count/B3009_Rm0.txt
agrep -0 -c 'AGATAGAACCCATGCCG' *.fastq > count/B3010_Rm0.txt
agrep -0 -c 'AACCAGACTGGTATCAG' *.fastq > count/B3011_Rm0.txt
agrep -0 -c 'ATGAGCGATCCCGCGTA' *.fastq > count/B3012_Rm0.txt
agrep -0 -c 'CAAGTTTGCTGCGATAC' *.fastq > count/B3013_Rm0.txt
agrep -0 -c 'TCCGACGTTGTTTAAGG' *.fastq > count/B3014_Rm0.txt
agrep -0 -c 'AAAGACGAGGTTCCTAT' *.fastq > count/B3015_Rm0.txt
agrep -0 -c 'GTAAGGGGCTGATCACG' *.fastq > count/B3016_Rm0.txt
agrep -0 -c 'TGATGTGGCTACCCGCT' *.fastq > count/B3018_Rm0.txt
agrep -0 -c 'CACTTAGATCCCCTACA' *.fastq > count/B3019_Rm0.txt
agrep -0 -c 'CTTTTGAAGCGGAATCA' *.fastq > count/B3021_Rm0.txt
agrep -0 -c 'GACCACGCTCTAAGATT' *.fastq > count/B3022_Rm0.txt
agrep -0 -c 'CCGGTGTATACGAGTGA' *.fastq > count/B3023_Rm0.txt
agrep -0 -c 'GTCATGAGCGTTTACGT' *.fastq > count/B3024_Rm0.txt
agrep -0 -c 'TGTGAACGGTCGAAATA' *.fastq > count/B3025_Rm0.txt
agrep -0 -c 'GGTATCAACGGGTGTGT' *.fastq > count/B3026_Rm0.txt
agrep -0 -c 'TACATCGATCTGGCGGC' *.fastq > count/B3027_Rm0.txt
agrep -0 -c 'CTTGTGGAGACGCAAGA' *.fastq > count/B3028_Rm0.txt
agrep -0 -c 'GACGGTTTTAGTATCTG' *.fastq > count/B3029_Rm0.txt
agrep -0 -c 'TTGCTTTCGGTCTTGCG' *.fastq > count/B3030_Rm0.txt
agrep -0 -c 'CCGTTAACCGTTTACGC' *.fastq > count/B3031_Rm0.txt
agrep -0 -c 'ACACGGTGTACGCGATG' *.fastq > count/B3032_Rm0.txt
agrep -0 -c 'CCGTGTAACCTAGAGAC' *.fastq > count/B3033_Rm0.txt
agrep -0 -c 'AGACTCGGTCATCATCT' *.fastq > count/B3034_Rm0.txt
agrep -0 -c 'TCCCCCACTAATCCTTA' *.fastq > count/B3035_Rm0.txt
agrep -0 -c 'ACTATGACCCTAACGGC' *.fastq > count/B3037_Rm0.txt
agrep -0 -c 'GATAGTGATGCGGAAGT' *.fastq > count/B3038_Rm0.txt
agrep -0 -c 'GAACCTCACGGGTCATA' *.fastq > count/B3039_Rm0.txt
agrep -0 -c 'GAGAGCCTTGAGGTTCG' *.fastq > count/B3041_Rm0.txt
agrep -0 -c 'TTGGCCTTGAGCGCTAG' *.fastq > count/B3042_Rm0.txt
agrep -0 -c 'GTGAGAGGGTGATTGCG' *.fastq > count/B3043_Rm0.txt
agrep -0 -c 'GGTGTCGCTGAAATGTT' *.fastq > count/B3044_Rm0.txt
agrep -0 -c 'GAAGTTCGACGTGAGGT' *.fastq > count/B3046_Rm0.txt
agrep -0 -c 'ACAAGTGGAGGGAAATC' *.fastq > count/B3047_Rm0.txt
agrep -0 -c 'GAAGGTCGGATGATGTA' *.fastq > count/B3048_Rm0.txt
agrep -0 -c 'ATTAGTCTCGCCCACAG' *.fastq > count/B3049_Rm0.txt
agrep -0 -c 'CATGCACCCCAACCGAA' *.fastq > count/B3051_Rm0.txt
agrep -0 -c 'AAAACGCAAATGCCGAC' *.fastq > count/B3052_Rm0.txt
agrep -0 -c 'GCTTGTTGCACGGAAAT' *.fastq > count/B3053_Rm0.txt
agrep -0 -c 'CGGCTTAGATGAGCCAG' *.fastq > count/B3054_Rm0.txt
agrep -0 -c 'AGGATCGGGCAGTTCTA' *.fastq > count/B3055_Rm0.txt
agrep -0 -c 'TCAGAGATTTCGCCACC' *.fastq > count/B3056_Rm0.txt
agrep -0 -c 'GGCGAACACATAGAGAC' *.fastq > count/B3057_Rm0.txt
agrep -0 -c 'ACACGGGGATCTATCGT' *.fastq > count/B3059_Rm0.txt
agrep -0 -c 'TATTCCGGTAAAGGTGT' *.fastq > count/B3060_Rm0.txt
agrep -0 -c 'CTCGACAAGAATCTGCT' *.fastq > count/B3061_Rm0.txt
agrep -0 -c 'CCCTGTACTAAGTACAG' *.fastq > count/B3062_Rm0.txt
agrep -0 -c 'ATCGCCCCCCTTTAGAA' *.fastq > count/B3063_Rm0.txt
agrep -0 -c 'TGGCTCTCCGTGTTAGT' *.fastq > count/B3064_Rm0.txt
agrep -0 -c 'GATTGCGTGGATAGGCC' *.fastq > count/B3067_Rm0.txt
agrep -0 -c 'GGACCTGGTTACTTGCG' *.fastq > count/B3068_Rm0.txt
agrep -0 -c 'CTCGCATTCAGAGTATT' *.fastq > count/B3069_Rm0.txt
agrep -0 -c 'ATTATGTATCGCGCGAA' *.fastq > count/B3070_Rm0.txt
agrep -0 -c 'TTGCTCGTGAGCCTCTG' *.fastq > count/B3071_Rm0.txt
agrep -0 -c 'CACTCTCTATGCCTTAT' *.fastq > count/B3072_Rm0.txt
agrep -0 -c 'ACCAGTCAACCTGTATT' *.fastq > count/B3073_Rm0.txt
agrep -0 -c 'CGGGAACGATGGTTAGA' *.fastq > count/B3074_Rm0.txt
agrep -0 -c 'AGAATGTTCCCGGCGTA' *.fastq > count/B3076_Rm0.txt
agrep -0 -c 'AAGATCGCATAGCACGC' *.fastq > count/B3077_Rm0.txt
agrep -0 -c 'CCTGTAGGAATCCTCCT' *.fastq > count/B3078_Rm0.txt
agrep -0 -c 'AAAAGTTTCCACCCCGG' *.fastq > count/B3079_Rm0.txt
agrep -0 -c 'AAATGCACTCCGACTAC' *.fastq > count/B3080_Rm0.txt
agrep -0 -c 'AAAGTAACTGGGCAGGT' *.fastq > count/B3083_Rm0.txt
agrep -0 -c 'GCTGTTAAATGGTTGGC' *.fastq > count/B3084_Rm0.txt
agrep -0 -c 'CAAGAATCCAGGATCGG' *.fastq > count/B3085_Rm0.txt
agrep -0 -c 'CTACGTGCGAACAGAGA' *.fastq > count/B3086_Rm0.txt
agrep -0 -c 'ATAACTTCGCTTCAACC' *.fastq > count/B3087_Rm0.txt
agrep -0 -c 'CCTACGGTTTCCCCAGT' *.fastq > count/B3088_Rm0.txt
agrep -0 -c 'CAAATCTCCACGGGACT' *.fastq > count/B3089_Rm0.txt
agrep -0 -c 'TATTCTTGTTGGGGACC' *.fastq > count/B3090_Rm0.txt
agrep -0 -c 'TGTTCGACAAAGAGGAC' *.fastq > count/B3091_Rm0.txt
agrep -0 -c 'CTCAAGCGCTGGCAAGT' *.fastq > count/B3092_Rm0.txt
agrep -0 -c 'GGGTAGTTAGGTAGCAC' *.fastq > count/B3094_Rm0.txt
agrep -0 -c 'CGGAGATGACCAACCTG' *.fastq > count/B3095_Rm0.txt
agrep -0 -c 'CTTTTGATACCCTCGAA' *.fastq > count/B3096_Rm0.txt
agrep -0 -c 'CAGTCACGGCTGATGCA' *.fastq > count/B3097_Rm0.txt
agrep -0 -c 'AAGGACACGGGTAATAG' *.fastq > count/B3098_Rm0.txt
agrep -0 -c 'AACCACGGTAACCCATT' *.fastq > count/B3099_Rm0.txt
agrep -0 -c 'GAGTACATTAGGTAACG' *.fastq > count/B3100_Rm0.txt
agrep -0 -c 'TGGTGTCACGTAACTCT' *.fastq > count/B3101_Rm0.txt
agrep -0 -c 'CTCCTGCAGCGATGTAA' *.fastq > count/B3102_Rm0.txt
agrep -0 -c 'TCATTCGCGCATCGACC' *.fastq > count/B3103_Rm0.txt
agrep -0 -c 'TTCTCGATTCACAGCAC' *.fastq > count/B3104_Rm0.txt
agrep -0 -c 'CCGCGAATTCTGGTTGC' *.fastq > count/B3105_Rm0.txt
agrep -0 -c 'TAGCGCAGAGCTTTCTA' *.fastq > count/B3106_Rm0.txt
agrep -0 -c 'CCATTTTGACGGTATTG' *.fastq > count/B3107_Rm0.txt
agrep -0 -c 'CTGGGACGGGCATAAGA' *.fastq > count/B3108_Rm0.txt
agrep -0 -c 'ATTATCCCACGCGAGAC' *.fastq > count/B3109_Rm0.txt
agrep -0 -c 'CTACCGACACCGCATGA' *.fastq > count/B3110_Rm0.txt
agrep -0 -c 'TGGCACAAAGCTGTGCC' *.fastq > count/B3112_Rm0.txt
agrep -0 -c 'CTGTGCCTAAGTGAACG' *.fastq > count/B3113_Rm0.txt
agrep -0 -c 'GCAACTGCAAGTCCGGT' *.fastq > count/B3114_Rm0.txt
agrep -0 -c 'AACACGCTTAAGGACTA' *.fastq > count/B3115_Rm0.txt
agrep -0 -c 'ATCTGGCATTTCGCCCT' *.fastq > count/B3116_Rm0.txt
agrep -0 -c 'GCCAATAGAAGGATGAC' *.fastq > count/B3117_Rm0.txt
agrep -0 -c 'CGGATTACAAGTCCTGA' *.fastq > count/B3118_Rm0.txt
agrep -0 -c 'ACTTAACGCCGCTATCA' *.fastq > count/B3119_Rm0.txt
agrep -0 -c 'CACGTGTACCGGAATCC' *.fastq > count/B3120_Rm0.txt
agrep -0 -c 'TTTTCCGAGGCTGCGGT' *.fastq > count/B3121_Rm0.txt
agrep -0 -c 'TCGGTGCGTGTTCGAGT' *.fastq > count/B3122_Rm0.txt
agrep -0 -c 'GTTCCTTCTATAGGTAG' *.fastq > count/B3123_Rm0.txt
agrep -0 -c 'GCACTTGAACTATGTGC' *.fastq > count/B3124_Rm0.txt
agrep -0 -c 'GTTAGAAAGACCGGACT' *.fastq > count/B3125_Rm0.txt
agrep -0 -c 'TCTCCGCAGAAGTAGGT' *.fastq > count/B3126_Rm0.txt
agrep -0 -c 'CTTTACATCCTGCGGTT' *.fastq > count/B3127_Rm0.txt
agrep -0 -c 'TCCACTCCTACGACCAT' *.fastq > count/B3128_Rm0.txt
agrep -0 -c 'ACCACGGGTACAGACCT' *.fastq > count/B3129_Rm0.txt
agrep -0 -c 'CGATAGAGCTGAAGTGC' *.fastq > count/B3130_Rm0.txt
agrep -0 -c 'CAATACTCAGTGGGGTG' *.fastq > count/B3131_Rm0.txt
agrep -0 -c 'ACGAGTAGTACGTTCCG' *.fastq > count/B3132_Rm0.txt
agrep -0 -c 'TTCCTAATGACCCGAAC' *.fastq > count/B3133_Rm0.txt
agrep -0 -c 'ACGCTGTCTTGAGGGGT' *.fastq > count/B3134_Rm0.txt
agrep -0 -c 'ACTAAATCCGCACGGAC' *.fastq > count/B3135_Rm0.txt
agrep -0 -c 'GATCCTATTGTACTGCT' *.fastq > count/B3137_Rm0.txt
agrep -0 -c 'GATTGATTGGCCCTTCG' *.fastq > count/B3138_Rm0.txt
agrep -0 -c 'CGTATTCGCTAGGGCAA' *.fastq > count/B3139_Rm0.txt
agrep -0 -c 'TCATATTATAGGGTGGC' *.fastq > count/B3140_Rm0.txt
agrep -0 -c 'TAGTACAGATGGTATGG' *.fastq > count/B3141_Rm0.txt
agrep -0 -c 'CTTCGATGCTGGTCTGG' *.fastq > count/B3142_Rm0.txt
agrep -0 -c 'ACAGTACGGACATCGTG' *.fastq > count/B3145_Rm0.txt
agrep -0 -c 'ATCGGGGACATACCACA' *.fastq > count/B3146_Rm0.txt
agrep -0 -c 'GAATCTCATTTGGCTCT' *.fastq > count/B3147_Rm0.txt
agrep -0 -c 'CTCTACAGCGACATTCT' *.fastq > count/B3148_Rm0.txt
agrep -0 -c 'GGCCGTGTATCGAAGTC' *.fastq > count/B3149_Rm0.txt
agrep -0 -c 'AACTGCTACGACCATTG' *.fastq > count/B3152_Rm0.txt
agrep -0 -c 'TCTAAAGCACCGTGGAT' *.fastq > count/B3153_Rm0.txt
agrep -0 -c 'CAACACTACATGACTCG' *.fastq > count/B3155_Rm0.txt
agrep -0 -c 'TCGTGGGATTACAAGAG' *.fastq > count/B3156_Rm0.txt
agrep -0 -c 'CTTACGTTGTAGCTAGC' *.fastq > count/B3157_Rm0.txt
agrep -0 -c 'GTAGTGCCGTTGTTACC' *.fastq > count/B3158_Rm0.txt
agrep -0 -c 'CGCTAACGAGGTGCTAT' *.fastq > count/B3159_Rm0.txt
agrep -0 -c 'TAGCCCTCCCTTAATCG' *.fastq > count/B3161_Rm0.txt
agrep -0 -c 'TAGTAAGGTAGACGCCT' *.fastq > count/B3163_Rm0.txt
agrep -0 -c 'TAGGGTCGAGGTACTAG' *.fastq > count/B3164_Rm0.txt
agrep -0 -c 'CGGGGACTTTTAGGGCA' *.fastq > count/B3165_Rm0.txt
agrep -0 -c 'CTGACAACTCGCTTCGT' *.fastq > count/B3166_Rm0.txt
agrep -0 -c 'AAACGAAACAAGGGTAC' *.fastq > count/B3167_Rm0.txt
agrep -0 -c 'ACCATACTCATCCAGTC' *.fastq > count/B3168_Rm0.txt
agrep -0 -c 'AATTCGCAGACATCCGG' *.fastq > count/B3169_Rm0.txt
agrep -0 -c 'GTCTTCCGAAGTATCCA' *.fastq > count/B3170_Rm0.txt
agrep -0 -c 'GGTTGCCATAACGAACG' *.fastq > count/B3171_Rm0.txt
agrep -0 -c 'TAACTATCCCGTATCAG' *.fastq > count/B3174_Rm0.txt
agrep -0 -c 'ATCCGAATTATCGGAGA' *.fastq > count/B3175_Rm0.txt
agrep -0 -c 'CATTTGGGATCGGAAGA' *.fastq > count/B3176_Rm0.txt
agrep -0 -c 'GTCACGCATTCCAATCG' *.fastq > count/B3178_Rm0.txt
agrep -0 -c 'GGTTAAACCCTCCCCGT' *.fastq > count/B3181_Rm0.txt
agrep -0 -c 'GCTCGGTAACATTAAGT' *.fastq > count/B3182_Rm0.txt
agrep -0 -c 'CCACGAACAAGCGGGAA' *.fastq > count/B3183_Rm0.txt
agrep -0 -c 'GGAACAGGCTTTATAGG' *.fastq > count/B3184_Rm0.txt
agrep -0 -c 'CCGTACAGGACAAATAG' *.fastq > count/B3185_Rm0.txt
agrep -0 -c 'TCACTGGCGGATACCTG' *.fastq > count/B3186_Rm0.txt
agrep -0 -c 'GGTAATTGCTTCCGCTC' *.fastq > count/B3187_Rm0.txt
agrep -0 -c 'CACGGTGCCATTATCGC' *.fastq > count/B3188_Rm0.txt
agrep -0 -c 'TAGCGCAGGGATAACGC' *.fastq > count/B3189_Rm0.txt
agrep -0 -c 'CCCTGGTTCTTACGCGT' *.fastq > count/B3190_Rm0.txt
agrep -0 -c 'GTCATTGGTACACGTAA' *.fastq > count/B3191_Rm0.txt
agrep -0 -c 'ACGAGTATAGGAGGTCT' *.fastq > count/B3192_Rm0.txt
agrep -0 -c 'GCAATTTAGACGCAGTC' *.fastq > count/B3193_Rm0.txt
agrep -0 -c 'TGGGTGTATACGTCCTT' *.fastq > count/B3195_Rm0.txt
agrep -0 -c 'TTTTAACCCTGGATTCC' *.fastq > count/B3197_Rm0.txt
agrep -0 -c 'GGAAGTATACCCTGGTT' *.fastq > count/B3198_Rm0.txt
agrep -0 -c 'ATGTCTTGGCGTTCACA' *.fastq > count/B3199_Rm0.txt
agrep -0 -c 'TAAGCGTTCGCCTTAGG' *.fastq > count/B3202_Rm0.txt
agrep -0 -c 'AGATTTGCGACCGGTCC' *.fastq > count/B3203_Rm0.txt
agrep -0 -c 'ATTATGCACTTCGCAGG' *.fastq > count/B3204_Rm0.txt
agrep -0 -c 'TAGATCGTACGGGGGCA' *.fastq > count/B3205_Rm0.txt
agrep -0 -c 'TGCCTGTTACGAGCTAG' *.fastq > count/B3206_Rm0.txt
agrep -0 -c 'TACGAAAATCCAAACGG' *.fastq > count/B3208_Rm0.txt
agrep -0 -c 'ATGGAGGAACAACGTCA' *.fastq > count/B3210_Rm0.txt
agrep -0 -c 'GCCGTTTCGGTCACAGA' *.fastq > count/B3211_Rm0.txt
agrep -0 -c 'TAACATCCCGAGTGCCC' *.fastq > count/B3212_Rm0.txt
agrep -0 -c 'AGGATTATGGCTGATCG' *.fastq > count/B3213_Rm0.txt
agrep -0 -c 'TCTATACGGGAAGCTAC' *.fastq > count/B3215_Rm0.txt
agrep -0 -c 'TAAATGCCAGACACCGT' *.fastq > count/B3216_Rm0.txt
agrep -0 -c 'AATTCACTGGCTCGTCG' *.fastq > count/B3217_Rm0.txt
agrep -0 -c 'CATTGCTTAGCCATCAC' *.fastq > count/B3218_Rm0.txt
agrep -0 -c 'TCAAGAGATAGCACTGC' *.fastq > count/B3220_Rm0.txt
agrep -0 -c 'GCATCGGATGAGATTTG' *.fastq > count/B3221_Rm0.txt
agrep -0 -c 'GAGCATGCGAGCCAATT' *.fastq > count/B3222_Rm0.txt
agrep -0 -c 'GTTATGCGTCGATAGCG' *.fastq > count/B3223_Rm0.txt
agrep -0 -c 'GTGGGGCGAAAATCATT' *.fastq > count/B3224_Rm0.txt
agrep -0 -c 'GACGTTACTACCTGTTA' *.fastq > count/B3226_Rm0.txt
agrep -0 -c 'AAGTATAGCTCGGGCCG' *.fastq > count/B3227_Rm0.txt
agrep -0 -c 'GAACCCACTTGCGCATT' *.fastq > count/B3228_Rm0.txt
agrep -0 -c 'TGACTACCCCGAGAGCA' *.fastq > count/B3229_Rm0.txt
agrep -0 -c 'TCTAATGGTGTGCAGCA' *.fastq > count/B3230_Rm0.txt
agrep -0 -c 'GCGGAGCATTCCCTATG' *.fastq > count/B3231_Rm0.txt
agrep -0 -c 'ACCCATGCAAGCGATAT' *.fastq > count/B3233_Rm0.txt
agrep -0 -c 'GCACTGGTTCATGCGCA' *.fastq > count/B3234_Rm0.txt
agrep -0 -c 'GATTTTCCGCGCGAATG' *.fastq > count/B3235_Rm0.txt
agrep -0 -c 'TTCTACATCATTCGCGC' *.fastq > count/B3236_Rm0.txt
agrep -0 -c 'ATTGTTCGCAGAACTGA' *.fastq > count/B3238_Rm0.txt
agrep -0 -c 'AGGGGAACAGCCTTTAT' *.fastq > count/B3239_Rm0.txt
agrep -0 -c 'TCCCCTGCTGATTCACA' *.fastq > count/B3240_Rm0.txt
agrep -0 -c 'GAGGGAGTAAGCCAGAT' *.fastq > count/B3241_Rm0.txt
agrep -0 -c 'TACGGTGAACTATCGGT' *.fastq > count/B3242_Rm0.txt
agrep -0 -c 'CTTAAGCACTAGGACCT' *.fastq > count/B3244_Rm0.txt
agrep -0 -c 'AATGCCCTTGGGTTAAC' *.fastq > count/B3245_Rm0.txt
agrep -0 -c 'AATGTAATCTCGACTGC' *.fastq > count/B3246_Rm0.txt
agrep -0 -c 'TCCATGGCACACCGTAG' *.fastq > count/B3247_Rm0.txt
agrep -0 -c 'GATCAAGGCGGATTGTA' *.fastq > count/B3248_Rm0.txt
agrep -0 -c 'TTACACCGAGAAAGCAA' *.fastq > count/B3249_Rm0.txt
agrep -0 -c 'GGGAAGGTGTGTTGACG' *.fastq > count/B3250_Rm0.txt
agrep -0 -c 'AAGAGGTTGCACGATAG' *.fastq > count/B3252_Rm0.txt
agrep -0 -c 'CTGTAGACTCCTGATAC' *.fastq > count/B3253_Rm0.txt
agrep -0 -c 'ATCGATGTGAGCTGGAT' *.fastq > count/B3254_Rm0.txt
agrep -0 -c 'CGATAGGCACCACCGTA' *.fastq > count/B3255_Rm0.txt
agrep -0 -c 'GCTTATCATACTCAGAG' *.fastq > count/B3256_Rm0.txt
agrep -0 -c 'TCGTGTCGCTCTCTTAT' *.fastq > count/B3257_Rm0.txt
agrep -0 -c 'AGCTGCCCTCCAAATCC' *.fastq > count/B3258_Rm0.txt
agrep -0 -c 'GCCAGCAGTCCGTATAA' *.fastq > count/B3259_Rm0.txt
agrep -0 -c 'GAACACCGCGACTTGCT' *.fastq > count/B3260_Rm0.txt
agrep -0 -c 'TGTTGCACAACGTAAAC' *.fastq > count/B3261_Rm0.txt
agrep -0 -c 'CCGAGCTTGTGTCCGTA' *.fastq > count/B3262_Rm0.txt
agrep -0 -c 'ACCATTAATGTTCGGAC' *.fastq > count/B3263_Rm0.txt
agrep -0 -c 'GTTAGTAACTTCACCTG' *.fastq > count/B3264_Rm0.txt
agrep -0 -c 'TAACCGTTGGACGGTAT' *.fastq > count/B3265_Rm0.txt
agrep -0 -c 'CGGATGGCTTTGTAGCT' *.fastq > count/B3266_Rm0.txt
agrep -0 -c 'GTCGCTGACAATACTCC' *.fastq > count/B3267_Rm0.txt
agrep -0 -c 'GCTCTACGTACTCCCTC' *.fastq > count/B3268_Rm0.txt
agrep -0 -c 'CTACGGGACATTTCTGC' *.fastq > count/B3269_Rm0.txt
agrep -0 -c 'ACTCGAGCACCGATAGT' *.fastq > count/B3270_Rm0.txt
agrep -0 -c 'CTGGCACTAAGTCCTGT' *.fastq > count/B3271_Rm0.txt
agrep -0 -c 'CACTTACAAGGATTCCG' *.fastq > count/B3272_Rm0.txt
agrep -0 -c 'ACGCTTGCGACCATTCG' *.fastq > count/B3273_Rm0.txt
agrep -0 -c 'GTACGCACTGGTCTACA' *.fastq > count/B3274_Rm0.txt
agrep -0 -c 'CATGCATCAATGAGCTA' *.fastq > count/B3275_Rm0.txt
agrep -0 -c 'TCTCCAAGTTGCCTGTA' *.fastq > count/B3276_Rm0.txt
agrep -0 -c 'AGGCTCCCGGAAACCAA' *.fastq > count/B3277_Rm0.txt
agrep -0 -c 'CAGAGTCCCAATCTATG' *.fastq > count/B3278_Rm0.txt
agrep -0 -c 'CGTGATCCCAAGATCGC' *.fastq > count/B3280_Rm0.txt
agrep -0 -c 'GCCCACGGAATGCTTAA' *.fastq > count/B3282_Rm0.txt
agrep -0 -c 'ACTGGCCTCAAAGATCC' *.fastq > count/B3283_Rm0.txt
agrep -0 -c 'TCGTCCCCCAATCTATT' *.fastq > count/B3284_Rm0.txt
agrep -0 -c 'CGGCTAGGAAGACCTCT' *.fastq > count/B3285_Rm0.txt
agrep -0 -c 'ACTGGCAGAGGTTACAA' *.fastq > count/B3287_Rm0.txt
agrep -0 -c 'GCTCGGAGCAAATATAT' *.fastq > count/B3289_Rm0.txt
agrep -0 -c 'TTCTCAGGGTAGTCACG' *.fastq > count/B3290_Rm0.txt
agrep -0 -c 'CAAATGGCTATTCGGAT' *.fastq > count/B3292_Rm0.txt
agrep -0 -c 'GCTAGTGCGCATAAATG' *.fastq > count/B3293_Rm0.txt
agrep -0 -c 'CCGGTCGAGACAAGACA' *.fastq > count/B3294_Rm0.txt
agrep -0 -c 'TTAGGTGAGAGCATCCG' *.fastq > count/B3295_Rm0.txt
agrep -0 -c 'CATGTTCAGCACTGGGT' *.fastq > count/B3296_Rm0.txt
agrep -0 -c 'CACATGTTGCACTTGCC' *.fastq > count/B3297_Rm0.txt
agrep -0 -c 'ACCGCCTCTTGGTCGAA' *.fastq > count/B3298_Rm0.txt
agrep -0 -c 'TATCGAACATAGCAAGC' *.fastq > count/B3299_Rm0.txt
agrep -0 -c 'GACTGCAGTTGGAGGAA' *.fastq > count/B3300_Rm0.txt
agrep -0 -c 'TGCTAACCCGAAGCACA' *.fastq > count/B3301_Rm0.txt
agrep -0 -c 'GGCAAGCTCTGTAACAC' *.fastq > count/B3302_Rm0.txt
agrep -0 -c 'CCCTTTCTGGGGCAACA' *.fastq > count/B3303_Rm0.txt
agrep -0 -c 'GGTAGGTTCCGACTAAG' *.fastq > count/B3304_Rm0.txt
agrep -0 -c 'CCTTCTATCTGCAGGTA' *.fastq > count/B3305_Rm0.txt
agrep -0 -c 'TTTGTTAGCCGCCTGGT' *.fastq > count/B3306_Rm0.txt
agrep -0 -c 'ACGTCGAATAGGTGCAA' *.fastq > count/B3307_Rm0.txt
agrep -0 -c 'TTGCTCAACTGGTCCCT' *.fastq > count/B3309_Rm0.txt
agrep -0 -c 'GGTAGTACCGGATATCC' *.fastq > count/B3310_Rm0.txt
agrep -0 -c 'AACAATGAAGGCGCGGC' *.fastq > count/B3311_Rm0.txt
agrep -0 -c 'AGCTCTACATAACGCCC' *.fastq > count/B3312_Rm0.txt
agrep -0 -c 'GCGGCGAGGGATAATAC' *.fastq > count/B3313_Rm0.txt
agrep -0 -c 'CAAGGGGTGGCATGTAG' *.fastq > count/B3314_Rm0.txt
agrep -0 -c 'TCTAGGGTATGCCTATT' *.fastq > count/B3315_Rm0.txt
agrep -0 -c 'GACGTTTTTACCCCACC' *.fastq > count/B3318_Rm0.txt
agrep -0 -c 'CACGTTACGAACGCTCG' *.fastq > count/B3319_Rm0.txt
agrep -0 -c 'ACATAAGCAGTGCCGAG' *.fastq > count/B3320_Rm0.txt
agrep -0 -c 'TCCCGTCCCATTCGAAT' *.fastq > count/B3321_Rm0.txt
agrep -0 -c 'CGGTTATTGCCATCTCA' *.fastq > count/B3322_Rm0.txt
agrep -0 -c 'CGCAGGCGCTACTAGAA' *.fastq > count/B3323_Rm0.txt
agrep -0 -c 'AGTACTGAGGGTACTGT' *.fastq > count/B3324_Rm0.txt
agrep -0 -c 'GGATCTGCGTAACCCTA' *.fastq > count/B3325_Rm0.txt
agrep -0 -c 'CGTACAAGTCCCTGTTG' *.fastq > count/B3326_Rm0.txt
agrep -0 -c 'GTGATCCACACGACTAG' *.fastq > count/B3327_Rm0.txt
agrep -0 -c 'ACGCACTCTGTTACTCA' *.fastq > count/B3328_Rm0.txt
agrep -0 -c 'TACGACTTCCTTTCTAC' *.fastq > count/B3329_Rm0.txt
agrep -0 -c 'AAATAACGGACGGCACA' *.fastq > count/B3330_Rm0.txt
agrep -0 -c 'GATGACCCAGTGATCTA' *.fastq > count/B3331_Rm0.txt
agrep -0 -c 'CACTCGCACCATATCAC' *.fastq > count/B3332_Rm0.txt
agrep -0 -c 'CTATCCGAACTACTTCC' *.fastq > count/B3333_Rm0.txt
agrep -0 -c 'AAGCTATCATGCGAAGC' *.fastq > count/B3336_Rm0.txt
agrep -0 -c 'GTATGGGCTTAGAGCGC' *.fastq > count/B3337_Rm0.txt
agrep -0 -c 'GAGCAGACAAACACGAG' *.fastq > count/B3338_Rm0.txt
agrep -0 -c 'GACACACGGCGTAAGTG' *.fastq > count/B3339_Rm0.txt
agrep -0 -c 'GAAGGACGGTGTTAATT' *.fastq > count/B3340_Rm0.txt
agrep -0 -c 'TAATCGCGTTGTGACTT' *.fastq > count/B3341_Rm0.txt
agrep -0 -c 'TCTTCATGCATACGGCA' *.fastq > count/B3342_Rm0.txt
agrep -0 -c 'CCATGCGACTAGGGCTA' *.fastq > count/B3343_Rm0.txt
agrep -0 -c 'TCGCAAGGGCGTCAAGT' *.fastq > count/B3344_Rm0.txt
agrep -0 -c 'TTCGTCGCGTTACCGTA' *.fastq > count/B3348_Rm0.txt
agrep -0 -c 'GATGGAGTATACGAGCC' *.fastq > count/B3349_Rm0.txt
agrep -0 -c 'TCGCTAATCCTCTCTAT' *.fastq > count/B3353_Rm0.txt
agrep -0 -c 'ATGACTACCAATCGACT' *.fastq > count/B3355_Rm0.txt
agrep -0 -c 'AAGTTCGTCACCCCACG' *.fastq > count/B3357_Rm0.txt
agrep -0 -c 'GCCAAACACTCGATTCC' *.fastq > count/B3358_Rm0.txt
agrep -0 -c 'GTCGCCCAGCTATCTTG' *.fastq > count/B3359_Rm0.txt
agrep -0 -c 'AAGACCTCTGTCGCCAG' *.fastq > count/B3360_Rm0.txt
agrep -0 -c 'AATCGAACCCGCGTACA' *.fastq > count/B3362_Rm0.txt
agrep -0 -c 'CCGAGTGCTTTCGTCTA' *.fastq > count/B3363_Rm0.txt
agrep -0 -c 'AGAAGTTTCAATCGGGC' *.fastq > count/B3364_Rm0.txt
agrep -0 -c 'AGAACCTTCCCAAGGAG' *.fastq > count/B3365_Rm0.txt
agrep -0 -c 'CGGCTAACCTATAACTT' *.fastq > count/B3366_Rm0.txt
agrep -0 -c 'CAAGAGGTTCACCCCTT' *.fastq > count/B3367_Rm0.txt
agrep -0 -c 'CCTTAGGTTATCTCTCC' *.fastq > count/B3370_Rm0.txt
agrep -0 -c 'CAATACGTACAAGTGCA' *.fastq > count/B3371_Rm0.txt
agrep -0 -c 'GGTGCATTAGACTATTG' *.fastq > count/B3374_Rm0.txt
agrep -0 -c 'CGAGTAACCTATTTAGC' *.fastq > count/B3375_Rm0.txt
agrep -0 -c 'ACCGTAGGAAGGTGATC' *.fastq > count/B3376_Rm0.txt
agrep -0 -c 'GTATGTCCTACCCATAA' *.fastq > count/B3377_Rm0.txt
agrep -0 -c 'CAGCTGCGTCACTGGTT' *.fastq > count/B3380_Rm0.txt
agrep -0 -c 'TATAAGAGCACGTGGAG' *.fastq > count/B3381_Rm0.txt
agrep -0 -c 'AATCTGCCCGTGGTTCG' *.fastq > count/B3382_Rm0.txt
agrep -0 -c 'GTTAAAACGACCACACA' *.fastq > count/B3383_Rm0.txt
agrep -0 -c 'GAACGCTCATAGACCCC' *.fastq > count/B3384_Rm0.txt
agrep -0 -c 'TCCACGGTGACAATTAT' *.fastq > count/B3386_Rm0.txt
agrep -0 -c 'TGACTCCCTTACTCGCG' *.fastq > count/B3387_Rm0.txt
agrep -0 -c 'TGCTCCCGAAGGCAGAT' *.fastq > count/B3389_Rm0.txt
agrep -0 -c 'GATTGCTTGGTAACGTC' *.fastq > count/B3390_Rm0.txt
agrep -0 -c 'GTCCTTTCATAAGCTCG' *.fastq > count/B3391_Rm0.txt
agrep -0 -c 'CTACAACCTAAATGCCA' *.fastq > count/B3392_Rm0.txt
agrep -0 -c 'TGGTGGGATTTTGTGAA' *.fastq > count/B3393_Rm0.txt
agrep -0 -c 'GCTATAACTGTGACGAC' *.fastq > count/B3394_Rm0.txt
agrep -0 -c 'ATATCTAGACTCGGCTC' *.fastq > count/B3395_Rm0.txt
agrep -0 -c 'ACGACTGCGAGTCACAC' *.fastq > count/B3396_Rm0.txt
agrep -0 -c 'ACGTTAACATATACCCG' *.fastq > count/B3397_Rm0.txt
agrep -0 -c 'CTCGTCGTGAAAACTAC' *.fastq > count/B3398_Rm0.txt
agrep -0 -c 'CCGAAAAGGTGTTGAGT' *.fastq > count/B3399_Rm0.txt
agrep -0 -c 'CTTCCACGGTTCCAAAT' *.fastq > count/B3400_Rm0.txt
agrep -0 -c 'GGGCCGTTTAACTTGAA' *.fastq > count/B3401_Rm0.txt
agrep -0 -c 'CCTTCTAGATCACCCTG' *.fastq > count/B3402_Rm0.txt
agrep -0 -c 'AGTCACTGGTTATAGCT' *.fastq > count/B3403_Rm0.txt
agrep -0 -c 'GTTTCAAAGTGGCCATT' *.fastq > count/B3404_Rm0.txt
agrep -0 -c 'GGACTCGACTGAGGTAT' *.fastq > count/B3406_Rm0.txt
agrep -0 -c 'GAGAACTGCACATAAAC' *.fastq > count/B3407_Rm0.txt
agrep -0 -c 'TTTAATCGAAACCGGTC' *.fastq > count/B3408_Rm0.txt
agrep -0 -c 'TCTCGGCTTCAAAGAGG' *.fastq > count/B3410_Rm0.txt
agrep -0 -c 'GTGACACGTATCTGCTG' *.fastq > count/B3412_Rm0.txt
agrep -0 -c 'ATCAGATTATGTCCCCG' *.fastq > count/B3413_Rm0.txt
agrep -0 -c 'AAGAGGGTTCCAAACGT' *.fastq > count/B3414_Rm0.txt
agrep -0 -c 'GATTGCTGTTTGTAGTG' *.fastq > count/B3415_Rm0.txt
agrep -0 -c 'TAACTACCTAGGTGCTA' *.fastq > count/B3417_Rm0.txt
agrep -0 -c 'CTACAGTGCGTCTGTGA' *.fastq > count/B3418_Rm0.txt
agrep -0 -c 'AACTATCGCGAGACTTA' *.fastq > count/B3419_Rm0.txt
agrep -0 -c 'ATTGCTCTAGTTCCTCG' *.fastq > count/B3420_Rm0.txt
agrep -0 -c 'GAATATTCATGCCGAAC' *.fastq > count/B3421_Rm0.txt
agrep -0 -c 'TGGGTACTACACGCATA' *.fastq > count/B3422_Rm0.txt
agrep -0 -c 'AATGACCTATTCTCCCC' *.fastq > count/B3423_Rm0.txt
agrep -0 -c 'ACCATAGCTCCCTAATC' *.fastq > count/B3424_Rm0.txt
agrep -0 -c 'GATGCCCGTGATCTTAA' *.fastq > count/B3426_Rm0.txt
agrep -0 -c 'GCATTGAGCTGTAAGCC' *.fastq > count/B3427_Rm0.txt
agrep -0 -c 'GCTCGGCTTCGTATAGG' *.fastq > count/B3428_Rm0.txt
agrep -0 -c 'GCCCTAGTACTGCTTAT' *.fastq > count/B3429_Rm0.txt
agrep -0 -c 'GCCTCGAGAGTCGACAA' *.fastq > count/B3430_Rm0.txt
agrep -0 -c 'CTATCGATCAAGGTGTG' *.fastq > count/B3431_Rm0.txt
agrep -0 -c 'TAAATCAGCCCCGCTAG' *.fastq > count/B3432_Rm0.txt
agrep -0 -c 'CCCACTCTAGTAGCTTA' *.fastq > count/B3433_Rm0.txt
agrep -0 -c 'CCTTGTAGAGGATCTGC' *.fastq > count/B3434_Rm0.txt
agrep -0 -c 'GAACCGACTTTCAACAT' *.fastq > count/B3435_Rm0.txt
agrep -0 -c 'AGCTAACGTTGTCGGCA' *.fastq > count/B3436_Rm0.txt
agrep -0 -c 'ACGGGGAGTAAATGGTG' *.fastq > count/B3437_Rm0.txt
agrep -0 -c 'CTAAAACCGACGGCTGT' *.fastq > count/B3438_Rm0.txt
agrep -0 -c 'TTTGATCACGCGCATAG' *.fastq > count/B3439_Rm0.txt
agrep -0 -c 'TAAGGGCGGTTCGCTTG' *.fastq > count/B3440_Rm0.txt
agrep -0 -c 'ATGTTGTTTTGCGGCTT' *.fastq > count/B3441_Rm0.txt
agrep -0 -c 'CGGAATCCCCAATGCAA' *.fastq > count/B3442_Rm0.txt
agrep -0 -c 'GCCCATATACAGGTTAG' *.fastq > count/B3443_Rm0.txt
agrep -0 -c 'CGTACGATTAAGGTATC' *.fastq > count/B3444_Rm0.txt
agrep -0 -c 'GATCGTTGTGCGAGTGC' *.fastq > count/B3446_Rm0.txt
agrep -0 -c 'AGGTTCAGCTAAGGGGC' *.fastq > count/B3447_Rm0.txt
agrep -0 -c 'TACCTTCGCCTTAACGG' *.fastq > count/B3448_Rm0.txt
agrep -0 -c 'AACGGACGGTTACCTTA' *.fastq > count/B3449_Rm0.txt
agrep -0 -c 'CATGCGACACCCTGACT' *.fastq > count/B3451_Rm0.txt
agrep -0 -c 'AGAACAGAGTGCTTCGC' *.fastq > count/B3452_Rm0.txt
agrep -0 -c 'CCTTCACCAAGCCCGAT' *.fastq > count/B3453_Rm0.txt
agrep -0 -c 'CGCTGATGTAGATCCGA' *.fastq > count/B3454_Rm0.txt
agrep -0 -c 'CATCTCTGATCAAAACC' *.fastq > count/B3456_Rm0.txt
agrep -0 -c 'TCTAGACGTCCGCTTTG' *.fastq > count/B3457_Rm0.txt
agrep -0 -c 'GTACGTCTGAGCTGGAG' *.fastq > count/B3458_Rm0.txt
agrep -0 -c 'CCCATTGTGGAATGCCT' *.fastq > count/B3459_Rm0.txt
agrep -0 -c 'TACACCAGTGAGGCATA' *.fastq > count/B3460_Rm0.txt
agrep -0 -c 'CGAGAAGAAAGGCCACT' *.fastq > count/B3461_Rm0.txt
agrep -0 -c 'CTAGGGTTCAGCGTTCT' *.fastq > count/B3462_Rm0.txt
agrep -0 -c 'TTTAGCCGGTGTAGAAG' *.fastq > count/B3463_Rm0.txt
agrep -0 -c 'TTTTTGTGACAGTGGGC' *.fastq > count/B3464_Rm0.txt
agrep -0 -c 'TCGGTCTTAAGCTCCGT' *.fastq > count/B3465_Rm0.txt
agrep -0 -c 'TGACATGTAAGTCGTAC' *.fastq > count/B3467_Rm0.txt
agrep -0 -c 'GCTGCCAAGCTATACCT' *.fastq > count/B3468_Rm0.txt
agrep -0 -c 'GCCGCCATTTACTATTG' *.fastq > count/B3469_Rm0.txt
agrep -0 -c 'GTTACTGTACGACCATA' *.fastq > count/B3471_Rm0.txt
agrep -0 -c 'AAGTGCAAGCGGGGTCT' *.fastq > count/B3472_Rm0.txt
agrep -0 -c 'GCCTTCACTACCTTTAA' *.fastq > count/B3473_Rm0.txt
agrep -0 -c 'ATACGGAAGGTTGTGCA' *.fastq > count/B3474_Rm0.txt
agrep -0 -c 'GAAGGATCTGACGGCCT' *.fastq > count/B3475_Rm0.txt
agrep -0 -c 'TACTCCGGGACGATCTG' *.fastq > count/B3476_Rm0.txt
agrep -0 -c 'GCGGACTGACCGACTAA' *.fastq > count/B3477_Rm0.txt
agrep -0 -c 'GGCAGGATTTGACTTAT' *.fastq > count/B3479_Rm0.txt
agrep -0 -c 'ACGTGACTATGCTACGC' *.fastq > count/B3480_Rm0.txt
agrep -0 -c 'TCCCGGAGTTTAGTGAC' *.fastq > count/B3481_Rm0.txt
agrep -0 -c 'ATTGCACAGCAGCTACA' *.fastq > count/B3482_Rm0.txt
agrep -0 -c 'TGTGTTGGACGGTACGA' *.fastq > count/B3483_Rm0.txt
agrep -0 -c 'GTAATTACGCGGACCGT' *.fastq > count/B3484_Rm0.txt
agrep -0 -c 'ACGTATGTCTTTGGACA' *.fastq > count/B3485_Rm0.txt
agrep -0 -c 'AGGCCTAGCCGTTCTAA' *.fastq > count/B3486_Rm0.txt
agrep -0 -c 'AGTCGGAATGGAGTGCA' *.fastq > count/B3487_Rm0.txt
agrep -0 -c 'CGGGTGACTTGACCCAA' *.fastq > count/B3488_Rm0.txt
agrep -0 -c 'CGTGGCTGACAAACCTT' *.fastq > count/B3490_Rm0.txt
agrep -0 -c 'ATGCTGGATCTGGAATC' *.fastq > count/B3491_Rm0.txt
agrep -0 -c 'CCCTTTCACGAGAGAGG' *.fastq > count/B3492_Rm0.txt
agrep -0 -c 'CTGCCCGTTTTTAGGAT' *.fastq > count/B3493_Rm0.txt
agrep -0 -c 'GACCCTAAGCATCAACG' *.fastq > count/B3494_Rm0.txt
agrep -0 -c 'ACACGTGCTATCGATGT' *.fastq > count/B3495_Rm0.txt
agrep -0 -c 'GTGGTGCATACATCTGA' *.fastq > count/B3496_Rm0.txt
agrep -0 -c 'GGATGAGCGTTCGCTCT' *.fastq > count/B3497_Rm0.txt
agrep -0 -c 'GAAACCGTAGAGAGTAC' *.fastq > count/B3498_Rm0.txt
agrep -0 -c 'TACATGTCTCAAGGCCT' *.fastq > count/B3499_Rm0.txt
agrep -0 -c 'AGATGTTGAGAAAGCCG' *.fastq > count/B3500_Rm0.txt
agrep -0 -c 'AATTAGATACACCGGCA' *.fastq > count/B3501_Rm0.txt
agrep -0 -c 'TCTTATTTTCGCCCACC' *.fastq > count/B3502_Rm0.txt
agrep -0 -c 'GTACTCGACCCAACAAT' *.fastq > count/B3503_Rm0.txt
agrep -0 -c 'AGGAACCCGTACACGTA' *.fastq > count/B3504_Rm0.txt
agrep -0 -c 'GCTACATCACCTCCTAC' *.fastq > count/B3506_Rm0.txt
agrep -0 -c 'CTATTCGCTGACCGTTA' *.fastq > count/B3507_Rm0.txt
agrep -0 -c 'AAGTACGAGCACGTGCA' *.fastq > count/B3508_Rm0.txt
agrep -0 -c 'GTACTGGAAAGGTCCTG' *.fastq > count/B3509_Rm0.txt
agrep -0 -c 'GCATCACCACCCAGGTA' *.fastq > count/B3510_Rm0.txt
agrep -0 -c 'ATATTTGACCACCAGCA' *.fastq > count/B3512_Rm0.txt
agrep -0 -c 'TGAAAGCCGTTGCCACC' *.fastq > count/B3513_Rm0.txt
agrep -0 -c 'TGTCTCATTTGCGAACG' *.fastq > count/B3515_Rm0.txt
agrep -0 -c 'CGACTACATAAGGCCGT' *.fastq > count/B3517_Rm0.txt
agrep -0 -c 'GACGGACTTTGGCCTCA' *.fastq > count/B3518_Rm0.txt
agrep -0 -c 'CGGCGGATTCCTATTGT' *.fastq > count/B3519_Rm0.txt
agrep -0 -c 'CGATCCCCAATATCAAG' *.fastq > count/B3520_Rm0.txt
agrep -0 -c 'TTCTGCGGACTTCGGTA' *.fastq > count/B3523_Rm0.txt
agrep -0 -c 'TCACACTTCGCGGCCTA' *.fastq > count/B3524_Rm0.txt
agrep -0 -c 'GCGCATGATCTCTATCT' *.fastq > count/B3525_Rm0.txt
agrep -0 -c 'ACATCGTCTGTTCTCGC' *.fastq > count/B3526_Rm0.txt
agrep -0 -c 'CAACCCAACACTATAGA' *.fastq > count/B3527_Rm0.txt
agrep -0 -c 'GAATAGACCCTCGATCA' *.fastq > count/B3528_Rm0.txt
agrep -0 -c 'GAGCTAAGGCGAGTTTG' *.fastq > count/B3529_Rm0.txt
agrep -0 -c 'GGGGACCTGAGAACACT' *.fastq > count/B3530_Rm0.txt
agrep -0 -c 'TTAACCGATTCAACGCT' *.fastq > count/B3531_Rm0.txt
agrep -0 -c 'TGTTTGCCAACGCCCAC' *.fastq > count/B3532_Rm0.txt
agrep -0 -c 'GAGTTCTAGGTTCGACA' *.fastq > count/B3533_Rm0.txt
agrep -0 -c 'ACTTGATCTAAGCGGAT' *.fastq > count/B3534_Rm0.txt
agrep -0 -c 'GGAATCAGACCCAATGG' *.fastq > count/B3535_Rm0.txt
agrep -0 -c 'ACATATCGGAGGGACTA' *.fastq > count/B3536_Rm0.txt
agrep -0 -c 'TTGCTCGCCTTACTATA' *.fastq > count/B3537_Rm0.txt
agrep -0 -c 'TAATTACGGCTATTGGC' *.fastq > count/B3540_Rm0.txt
agrep -0 -c 'CTTGGGACGGAGTGTCT' *.fastq > count/B3541_Rm0.txt
agrep -0 -c 'AGTCCATGTCTACTCAC' *.fastq > count/B3542_Rm0.txt
agrep -0 -c 'TCGTGCATGACGTCAGG' *.fastq > count/B3543_Rm0.txt
agrep -0 -c 'ACTGGCACCGAAAACGG' *.fastq > count/B3544_Rm0.txt
agrep -0 -c 'AACGCACTGTTAAGCAC' *.fastq > count/B3545_Rm0.txt
agrep -0 -c 'GGGATCGTTCTACCGTC' *.fastq > count/B3546_Rm0.txt
agrep -0 -c 'CGGAGATAGCGGTTTCA' *.fastq > count/B3547_Rm0.txt
agrep -0 -c 'GTGGGTACTGCCAATGA' *.fastq > count/B3548_Rm0.txt
agrep -0 -c 'TTTCAGTAATGCCGCCT' *.fastq > count/B3550_Rm0.txt
agrep -0 -c 'CTTCGTACCAGCTCCAG' *.fastq > count/B3551_Rm0.txt
agrep -0 -c 'ATCCCTGTAGAGCTCGT' *.fastq > count/B3552_Rm0.txt
agrep -0 -c 'GTTCAACCCCTTTAAGG' *.fastq > count/B3553_Rm0.txt
agrep -0 -c 'TCATGCCACTGTCATGC' *.fastq > count/B3554_Rm0.txt
agrep -0 -c 'CCGGTACTTTACTAACT' *.fastq > count/B3555_Rm0.txt
agrep -0 -c 'GAGTCTCTCTGACTGGC' *.fastq > count/B3557_Rm0.txt
agrep -0 -c 'TTATCGCGTGTGGGAGG' *.fastq > count/B3558_Rm0.txt
agrep -0 -c 'TAGTCTCTATGCACCAC' *.fastq > count/B3559_Rm0.txt
agrep -0 -c 'CATTGGGAGTTGTGGCT' *.fastq > count/B3560_Rm0.txt
agrep -0 -c 'GGCGGCATAATCTGGCA' *.fastq > count/B3561_Rm0.txt
agrep -0 -c 'GGCCGCATTCATTAACC' *.fastq > count/B3562_Rm0.txt
agrep -0 -c 'TATCGAGATCGTTCACT' *.fastq > count/B3563_Rm0.txt
agrep -0 -c 'TTACTTCCAGCCTGACT' *.fastq > count/B3564_Rm0.txt
agrep -0 -c 'AGGTATAACTTCCGACT' *.fastq > count/B3565_Rm0.txt
agrep -0 -c 'GGCTCTGGTCCTAAATA' *.fastq > count/B3566_Rm0.txt
agrep -0 -c 'CTTCAGGTGATTGGGTA' *.fastq > count/B3567_Rm0.txt
agrep -0 -c 'CCAACAACATCTCGACT' *.fastq > count/B3568_Rm0.txt
agrep -0 -c 'GGAGGCAAGTCCGACAA' *.fastq > count/B3569_Rm0.txt
agrep -0 -c 'AGTCCCTTTCTAAGTAG' *.fastq > count/B3570_Rm0.txt
agrep -0 -c 'TGCCGACTACTCACCAG' *.fastq > count/B3571_Rm0.txt
agrep -0 -c 'AGAATAGACGCCACGGC' *.fastq > count/B3572_Rm0.txt
agrep -0 -c 'TTGTGGGCGACCACACT' *.fastq > count/B3573_Rm0.txt
agrep -0 -c 'CCTCACAGAAGACGATA' *.fastq > count/B3574_Rm0.txt
agrep -0 -c 'GTCCCTCCGGAAATGTG' *.fastq > count/B3575_Rm0.txt
agrep -0 -c 'CATGCGGGCCAGTAGAA' *.fastq > count/B3577_Rm0.txt
agrep -0 -c 'ATGTCCCTAGATGATAC' *.fastq > count/B3578_Rm0.txt
agrep -0 -c 'TTCTACCGCTTTCCGAC' *.fastq > count/B3579_Rm0.txt
agrep -0 -c 'CCTTGGTAGGTTGGGAT' *.fastq > count/B3580_Rm0.txt
agrep -0 -c 'CGTTGTCCAACAAGACT' *.fastq > count/B3582_Rm0.txt
agrep -0 -c 'CGATTGAGAGAGTAAGT' *.fastq > count/B3583_Rm0.txt
agrep -0 -c 'ACGGGCTAGTACAAGTC' *.fastq > count/B3584_Rm0.txt
agrep -0 -c 'ACTCTGAGGAAAAAGAG' *.fastq > count/B3585_Rm0.txt
agrep -0 -c 'ACGAGACGCAAAGAGCA' *.fastq > count/B3586_Rm0.txt
agrep -0 -c 'ATCGCGAATACGCCTCC' *.fastq > count/B3587_Rm0.txt
agrep -0 -c 'AGCCTCTTTTGTAACAG' *.fastq > count/B3589_Rm0.txt
agrep -0 -c 'GTATATGACCTATGCCC' *.fastq > count/B3590_Rm0.txt
agrep -0 -c 'CGTGACAATTGGTCCCG' *.fastq > count/B3591_Rm0.txt
agrep -0 -c 'CGCAACTCGCTGATAAC' *.fastq > count/B3592_Rm0.txt
agrep -0 -c 'TATACGATGATTCCCGT' *.fastq > count/B3594_Rm0.txt
agrep -0 -c 'CTTACATGTGCGCGTGG' *.fastq > count/B3595_Rm0.txt
agrep -0 -c 'TCACTACAACCACATGG' *.fastq > count/B3596_Rm0.txt
agrep -0 -c 'CAGCACGCATGTCTTGC' *.fastq > count/B3597_Rm0.txt
agrep -0 -c 'CTATCTCGAAGCATCGT' *.fastq > count/B3598_Rm0.txt
agrep -0 -c 'GATAATACTCGGGGGAG' *.fastq > count/B3599_Rm0.txt
agrep -0 -c 'AGGTTACCGGAAAACAT' *.fastq > count/B3600_Rm0.txt
agrep -0 -c 'ATCGGGTCGTGCCATAG' *.fastq > count/B3601_Rm0.txt
agrep -0 -c 'CGGGTCTGTTAACCATA' *.fastq > count/B3603_Rm0.txt
agrep -0 -c 'TCATGCCGGAGTGAGTT' *.fastq > count/B3605_Rm0.txt
agrep -0 -c 'TCCTCCCTGTTATACAA' *.fastq > count/B3606_Rm0.txt
agrep -0 -c 'AGGCGCGTTCATGATCT' *.fastq > count/B3607_Rm0.txt
agrep -0 -c 'ATTCTCGGACATGGTCA' *.fastq > count/B3608_Rm0.txt
agrep -0 -c 'TAGAGGTCGCGTAAACG' *.fastq > count/B3609_Rm0.txt
agrep -0 -c 'AATGCCCAGATAGGAGG' *.fastq > count/B3610_Rm0.txt
agrep -0 -c 'AGCGGCAAATAAAGCAA' *.fastq > count/B3611_Rm0.txt
agrep -0 -c 'GTTTTTCGAGGTTTCGC' *.fastq > count/B3612_Rm0.txt
agrep -0 -c 'GAACCGACATTCCAGCC' *.fastq > count/B3614_Rm0.txt
agrep -0 -c 'GAGTGCGGGTTTCAAAT' *.fastq > count/B3616_Rm0.txt
agrep -0 -c 'CAACCCTAGTCTCGTTG' *.fastq > count/B3617_Rm0.txt
agrep -0 -c 'AAGACTGACTCTGGTCA' *.fastq > count/B3618_Rm0.txt
agrep -0 -c 'ACGTGCTGTTAATAGCA' *.fastq > count/B3619_Rm0.txt
agrep -0 -c 'TGGAACGGTAAGCGGTA' *.fastq > count/B3620_Rm0.txt
agrep -0 -c 'CGAAATGGTGTCGAAGC' *.fastq > count/B3621_Rm0.txt
agrep -0 -c 'AATCCAATCGCCCCAAT' *.fastq > count/B3622_Rm0.txt
agrep -0 -c 'ACCCACGTTTCTCGTCA' *.fastq > count/B3623_Rm0.txt
agrep -0 -c 'GCATCGCATCACCCTTG' *.fastq > count/B3624_Rm0.txt
agrep -0 -c 'CTAGAAGCTGTGAGCGA' *.fastq > count/B3626_Rm0.txt
agrep -0 -c 'TTAAAGAGTCTGTCGAG' *.fastq > count/B3627_Rm0.txt
agrep -0 -c 'AAAAGATCCCTAAACCG' *.fastq > count/B3628_Rm0.txt
agrep -0 -c 'GCCTTCAAGGTCCGCTT' *.fastq > count/B3629_Rm0.txt
agrep -0 -c 'TCGTGCATTCCCAGGTC' *.fastq > count/B3630_Rm0.txt
agrep -0 -c 'CCACAGTCTGCGTCGTA' *.fastq > count/B3631_Rm0.txt
agrep -0 -c 'TTTACGTTCCGATGGAC' *.fastq > count/B3632_Rm0.txt
agrep -0 -c 'GCTGACGCGGTTTATGG' *.fastq > count/B3633_Rm0.txt
agrep -0 -c 'TACGATTGGCGGGCTCT' *.fastq > count/B3634_Rm0.txt
agrep -0 -c 'GCCACGAGCTTGGTCAT' *.fastq > count/B3635_Rm0.txt
agrep -0 -c 'TACGGCTGTAGTTGGAC' *.fastq > count/B3636_Rm0.txt
agrep -0 -c 'CCAACTGGTATGAGCGG' *.fastq > count/B3637_Rm0.txt
agrep -0 -c 'GTATTAGCGGGAATAGT' *.fastq > count/B3638_Rm0.txt
agrep -0 -c 'AGATCCCCGCACCATAT' *.fastq > count/B3639_Rm0.txt
agrep -0 -c 'TTGACACCTTGCGTTGA' *.fastq > count/B3641_Rm0.txt
agrep -0 -c 'CGGATCCTACTGACCAC' *.fastq > count/B3642_Rm0.txt
agrep -0 -c 'ATTGAATGCGCTAGTGG' *.fastq > count/B3643_Rm0.txt
agrep -0 -c 'GTGGAGTTAATCTACGT' *.fastq > count/B3644_Rm0.txt
agrep -0 -c 'CACCTCCAAGGGACTAA' *.fastq > count/B3645_Rm0.txt
agrep -0 -c 'CAAAGCCTCCGCATAGA' *.fastq > count/B3646_Rm0.txt
agrep -0 -c 'GGGGCTACAGATACCTG' *.fastq > count/B3647_Rm0.txt
agrep -0 -c 'GACGCTCAATTAAGCAC' *.fastq > count/B3648_Rm0.txt
agrep -0 -c 'CCCTATAAGTGAAGCAT' *.fastq > count/B3652_Rm0.txt
agrep -0 -c 'ATTTGCTGCGAAATCAG' *.fastq > count/B3653_Rm0.txt
agrep -0 -c 'TAATCCACGTCACGGCA' *.fastq > count/B3654_Rm0.txt
agrep -0 -c 'GAGTTTGCGCTGATACA' *.fastq > count/B3655_Rm0.txt
agrep -0 -c 'ATCTGAAGATGAGGGGC' *.fastq > count/B3656_Rm0.txt
agrep -0 -c 'ATGCGTAGGCAAAAATC' *.fastq > count/B3658_Rm0.txt
agrep -0 -c 'CCCGATTGACGAGGTAA' *.fastq > count/B3659_Rm0.txt
agrep -0 -c 'CATTTGACGGGACAGTA' *.fastq > count/B3660_Rm0.txt
agrep -0 -c 'CTGGACTATAAAAGGCA' *.fastq > count/B3661_Rm0.txt
agrep -0 -c 'TATTGACTGACTACGGT' *.fastq > count/B3664_Rm0.txt
agrep -0 -c 'CGATCAGCAGCAATATC' *.fastq > count/B3666_Rm0.txt
agrep -0 -c 'AGGGGTTATCCGGCAGA' *.fastq > count/B3668_Rm0.txt
agrep -0 -c 'AGAGCTAAAGTTCGCCG' *.fastq > count/B3669_Rm0.txt
agrep -0 -c 'AGCCTATTGTTTGAGCA' *.fastq > count/B3670_Rm0.txt
agrep -0 -c 'TACTGCTGCCGACTTGG' *.fastq > count/B3671_Rm0.txt
agrep -0 -c 'AAACGACGCGGAAGAGC' *.fastq > count/B3673_Rm0.txt
agrep -0 -c 'CCCTGTACGGTTCTAAC' *.fastq > count/B3674_Rm0.txt
agrep -0 -c 'TCGTCTAGCAGGGACAA' *.fastq > count/B3675_Rm0.txt
agrep -0 -c 'ATCGATCAAGGCAGATG' *.fastq > count/B3676_Rm0.txt
agrep -0 -c 'GAGCCGTTCCTTGTGAC' *.fastq > count/B3677_Rm0.txt
agrep -0 -c 'AACCAGGGCTAAGCCGT' *.fastq > count/B3678_Rm0.txt
agrep -0 -c 'AGGATTTGACCGGACGC' *.fastq > count/B3679_Rm0.txt
agrep -0 -c 'TCCGAAACACAACTCTG' *.fastq > count/B3680_Rm0.txt
agrep -0 -c 'GGACATGTGGCACGAAC' *.fastq > count/B3682_Rm0.txt
agrep -0 -c 'CAGGGGAATATTTGCAC' *.fastq > count/B3683_Rm0.txt
agrep -0 -c 'ATAGCCCGCTTTGAGCT' *.fastq > count/B3685_Rm0.txt
agrep -0 -c 'CCTACGAGAGTTTAGTT' *.fastq > count/B3686_Rm0.txt
agrep -0 -c 'GGCATCCGAACATGACG' *.fastq > count/B3687_Rm0.txt
agrep -0 -c 'TGGGAACATTGCCTCGC' *.fastq > count/B3688_Rm0.txt
agrep -0 -c 'CATATCCTGGCACCAGC' *.fastq > count/B3689_Rm0.txt
agrep -0 -c 'CATCAACCGAGACGTCG' *.fastq > count/B3691_Rm0.txt
agrep -0 -c 'TGCGAAACAGGGATGAT' *.fastq > count/B3692_Rm0.txt
agrep -0 -c 'GGTATTACACCCGGATC' *.fastq > count/B3693_Rm0.txt
agrep -0 -c 'AGGGGAATTAACCCCGA' *.fastq > count/B3694_Rm0.txt
agrep -0 -c 'TCGCATCGACCTAGGAC' *.fastq > count/B3695_Rm0.txt
agrep -0 -c 'TGGCCATTAGGAGAAAC' *.fastq > count/B3696_Rm0.txt
agrep -0 -c 'TATAATTTGGGCGACAG' *.fastq > count/B3697_Rm0.txt
agrep -0 -c 'AAGGGGGATCCAACTTA' *.fastq > count/B3698_Rm0.txt
agrep -0 -c 'ACTCCGCCTGCATATCG' *.fastq > count/B3699_Rm0.txt
agrep -0 -c 'AATAAGTCCCCCCGCTG' *.fastq > count/B3700_Rm0.txt
agrep -0 -c 'GTGTACTACCTTTCACT' *.fastq > count/B3701_Rm0.txt
agrep -0 -c 'TGATGTCACAGCTACTC' *.fastq > count/B3703_Rm0.txt
agrep -0 -c 'GGTGCTAAGAGTAGACG' *.fastq > count/B3704_Rm0.txt
agrep -0 -c 'GTCGGATCAAGTAGCGA' *.fastq > count/B3705_Rm0.txt
agrep -0 -c 'GAGTCGAGTGTCTTGCC' *.fastq > count/B3706_Rm0.txt
agrep -0 -c 'GCACGTACTGTTATGCC' *.fastq > count/B3707_Rm0.txt
agrep -0 -c 'TCCGACTACAGTTCTTG' *.fastq > count/B3708_Rm0.txt
agrep -0 -c 'AGAAGAATTCGCCTCAG' *.fastq > count/B3709_Rm0.txt
agrep -0 -c 'GAGCGGAATCAAAATGC' *.fastq > count/B3710_Rm0.txt
agrep -0 -c 'GGATGCAGATGATAACC' *.fastq > count/B3711_Rm0.txt
agrep -0 -c 'GGCGCAAGGGCTTATAT' *.fastq > count/B3712_Rm0.txt
agrep -0 -c 'GAAGAGCAGTGTCGACT' *.fastq > count/B3713_Rm0.txt
agrep -0 -c 'TGGTCTGGACGCTAATT' *.fastq > count/B3714_Rm0.txt
agrep -0 -c 'AGTCTATGGCCGGTTCC' *.fastq > count/B3715_Rm0.txt
agrep -0 -c 'GAACGAACTCACCCGCT' *.fastq > count/B3716_Rm0.txt
agrep -0 -c 'AGTCACCCATCTGCGAT' *.fastq > count/B3717_Rm0.txt
agrep -0 -c 'CCATCAGTAAGCGTACC' *.fastq > count/B3718_Rm0.txt
agrep -0 -c 'AAAGCGGACCTCGCCTA' *.fastq > count/B3719_Rm0.txt
agrep -0 -c 'CCCATGATTATCTCACC' *.fastq > count/B3720_Rm0.txt
agrep -0 -c 'ATCCGAAGGACCACCTG' *.fastq > count/B3721_Rm0.txt
agrep -0 -c 'GACATTAATCCCCGCCT' *.fastq > count/B3722_Rm0.txt
agrep -0 -c 'GGGATCGGATGACGTAC' *.fastq > count/B3723_Rm0.txt
agrep -0 -c 'CGCTTTAGCAATGTCTG' *.fastq > count/B3724_Rm0.txt
agrep -0 -c 'ACTTAGGCTCTTTAGTC' *.fastq > count/B3725_Rm0.txt
agrep -0 -c 'TACCGAGCATATGACAC' *.fastq > count/B3726_Rm0.txt
agrep -0 -c 'GTCCTTTGATCGTGCGA' *.fastq > count/B3727_Rm0.txt
agrep -0 -c 'TTCCGGATGTAGCCGTG' *.fastq > count/B3728_Rm0.txt
agrep -0 -c 'GTGTACTATCAAGAACC' *.fastq > count/B3729_Rm0.txt
agrep -0 -c 'CCGTTTGCACTGACCTT' *.fastq > count/B3730_Rm0.txt
agrep -0 -c 'TGAAGCGTCTAAAGAGG' *.fastq > count/B3732_Rm0.txt
agrep -0 -c 'GGAAGACCAGATTTTCT' *.fastq > count/B3733_Rm0.txt
agrep -0 -c 'TCTAACAATGCGTTTCG' *.fastq > count/B3734_Rm0.txt
agrep -0 -c 'GAAACTTGGCCCAGCCA' *.fastq > count/B3735_Rm0.txt
agrep -0 -c 'TCGTATTCGTTGCCGCA' *.fastq > count/B3736_Rm0.txt
agrep -0 -c 'GATTCCGCCAGTCAGAC' *.fastq > count/B3737_Rm0.txt
agrep -0 -c 'TGTTAACGTGGCTCGGT' *.fastq > count/B3738_Rm0.txt
agrep -0 -c 'AGAATCCTTTGTGGCAG' *.fastq > count/B3739_Rm0.txt
agrep -0 -c 'GGACTTGTGCTGGCTAA' *.fastq > count/B3740_Rm0.txt
agrep -0 -c 'GTTAGAGTATGCTATCG' *.fastq > count/B3741_Rm0.txt
agrep -0 -c 'TGGACAAGCTCGTGCAA' *.fastq > count/B3742_Rm0.txt
agrep -0 -c 'CCTTTCAAGTTCCCGCC' *.fastq > count/B3744_Rm0.txt
agrep -0 -c 'CGCAATATGGATATACC' *.fastq > count/B3745_Rm0.txt
agrep -0 -c 'TTCGGACTACCGCTATG' *.fastq > count/B3746_Rm0.txt
agrep -0 -c 'CGCATGTATAGACAAAC' *.fastq > count/B3749_Rm0.txt
agrep -0 -c 'ACTTGGACTAACCCATA' *.fastq > count/B3750_Rm0.txt
agrep -0 -c 'GCCATTACGTGTACGAA' *.fastq > count/B3751_Rm0.txt
agrep -0 -c 'TCAGTAGAGCGAGACGC' *.fastq > count/B3752_Rm0.txt
agrep -0 -c 'AACCATCCGAAATCGGT' *.fastq > count/B3753_Rm0.txt
agrep -0 -c 'TGAGTTCGTGATCTGCT' *.fastq > count/B3754_Rm0.txt
agrep -0 -c 'CTAAGAAGTATCCACCC' *.fastq > count/B3755_Rm0.txt
agrep -0 -c 'CAGGTAGCCGATACTCT' *.fastq > count/B3756_Rm0.txt
agrep -0 -c 'AGGCCGGCTATAGGTTA' *.fastq > count/B3757_Rm0.txt
agrep -0 -c 'ACTAAACCTTGCCCGGC' *.fastq > count/B3758_Rm0.txt
agrep -0 -c 'CGAAATCGATTTTCGGC' *.fastq > count/B3759_Rm0.txt
agrep -0 -c 'GTAGCTAGAACGGGGTC' *.fastq > count/B3760_Rm0.txt
agrep -0 -c 'CTGGATAACGAAGACAA' *.fastq > count/B3761_Rm0.txt
agrep -0 -c 'CCTTTTACTGACCTCTA' *.fastq > count/B3762_Rm0.txt
agrep -0 -c 'GCCCGTTCTGGGAGTAA' *.fastq > count/B3763_Rm0.txt
agrep -0 -c 'GGCCTCTATGGTAGTTA' *.fastq > count/B3764_Rm0.txt
agrep -0 -c 'AGCGATGAAGTAGAATG' *.fastq > count/B3765_Rm0.txt
agrep -0 -c 'CGATTCCACCGAATCCG' *.fastq > count/B3766_Rm0.txt
agrep -0 -c 'GACACCAGTAGTTAGAC' *.fastq > count/B3767_Rm0.txt
agrep -0 -c 'AAGAATACCCGACCTGT' *.fastq > count/B3768_Rm0.txt
agrep -0 -c 'CAGCGTAGATACGGACA' *.fastq > count/B3769_Rm0.txt
agrep -0 -c 'CTGTTTGGGAGGCGAAT' *.fastq > count/B3770_Rm0.txt
agrep -0 -c 'CATTGTCCAGCAGGGTG' *.fastq > count/B3771_Rm0.txt
agrep -0 -c 'AGACTCCCAATACTCCG' *.fastq > count/B3772_Rm0.txt
agrep -0 -c 'GGGAACCCGTACGTTTG' *.fastq > count/B3773_Rm0.txt
agrep -0 -c 'GTCGATGACAACAGAAT' *.fastq > count/B3774_Rm0.txt
agrep -0 -c 'AAACGCATAAGCCAAGG' *.fastq > count/B3775_Rm0.txt
agrep -0 -c 'AGACCGTCGAGCATTCG' *.fastq > count/B3776_Rm0.txt
agrep -0 -c 'CGCAGCTGTACGGATAT' *.fastq > count/B3777_Rm0.txt
agrep -0 -c 'TCGTCTCTGGCCCTATA' *.fastq > count/B3778_Rm0.txt
agrep -0 -c 'GGCGAGGAGCAATACTG' *.fastq > count/B3779_Rm0.txt
agrep -0 -c 'AGAAGAAGTCACTAGCG' *.fastq > count/B3780_Rm0.txt
agrep -0 -c 'TTCTATCCCTCAGAGAA' *.fastq > count/B3781_Rm0.txt
agrep -0 -c 'CATCGGACATGCCATAT' *.fastq > count/B3782_Rm0.txt
agrep -0 -c 'GCACATCATGGTATCGA' *.fastq > count/B3784_Rm0.txt
agrep -0 -c 'TGGCCGTAGGTATGTAC' *.fastq > count/B3785_Rm0.txt
agrep -0 -c 'ACTGAGTATTAGTCCCC' *.fastq > count/B3786_Rm0.txt
agrep -0 -c 'CCGTGACCCAAAACCAG' *.fastq > count/B3788_Rm0.txt
agrep -0 -c 'TGAGGTACGTCAGTCCC' *.fastq > count/B3789_Rm0.txt
agrep -0 -c 'ATTCCCCGGGTGTTAGG' *.fastq > count/B3790_Rm0.txt
agrep -0 -c 'GTAGTCGTGCGCGAAAC' *.fastq > count/B3791_Rm0.txt
agrep -0 -c 'GCAAGATAGGTTGACTA' *.fastq > count/B3792_Rm0.txt
agrep -0 -c 'CGGCAGGCATGATGCTA' *.fastq > count/B3794_Rm0.txt
agrep -0 -c 'AAGTGATACTGAAACCG' *.fastq > count/B3795_Rm0.txt
agrep -0 -c 'GCTATGTCGATCGCGCT' *.fastq > count/B3797_Rm0.txt
agrep -0 -c 'GCCTGTAAGCAATTTAC' *.fastq > count/B3798_Rm0.txt
agrep -0 -c 'ACTCTTGTGGGAATATG' *.fastq > count/B3799_Rm0.txt
agrep -0 -c 'AGTGCATGCGGCTTACC' *.fastq > count/B3800_Rm0.txt
agrep -0 -c 'TTCTACTAGTGCACCGG' *.fastq > count/B3801_Rm0.txt
agrep -0 -c 'ACGTACTGGCCCTCATA' *.fastq > count/B3802_Rm0.txt
agrep -0 -c 'CGCTGTAAGTTCGGTCT' *.fastq > count/B3803_Rm0.txt
agrep -0 -c 'TGGGAGTAGAAGTCCGG' *.fastq > count/B3804_Rm0.txt
agrep -0 -c 'TTGTCCACTCGTTGTTA' *.fastq > count/B3805_Rm0.txt
agrep -0 -c 'AGTAGGTGGAAGCTTAC' *.fastq > count/B3806_Rm0.txt
agrep -0 -c 'CATTAATGCGAGGGCAC' *.fastq > count/B3808_Rm0.txt
agrep -0 -c 'AATATAGACGCGGTCCC' *.fastq > count/B3810_Rm0.txt
agrep -0 -c 'CAATGGGCTGATGAATT' *.fastq > count/B3811_Rm0.txt
agrep -0 -c 'GATGTCTTCAATGCCGA' *.fastq > count/B3813_Rm0.txt
agrep -0 -c 'ATGGGGTCCTTGGATTA' *.fastq > count/B3814_Rm0.txt
agrep -0 -c 'CCCAAGAATTTCAAACG' *.fastq > count/B3815_Rm0.txt
agrep -0 -c 'AGTTCAGGTAACTCGCA' *.fastq > count/B3816_Rm0.txt
agrep -0 -c 'CATACAATATGGAGGCT' *.fastq > count/B3817_Rm0.txt
agrep -0 -c 'GTCGCCGCTCATTAGAA' *.fastq > count/B3818_Rm0.txt
agrep -0 -c 'ACATAGCGTCGTTTGTC' *.fastq > count/B3819_Rm0.txt
agrep -0 -c 'TATTCAGGGAACCCCTT' *.fastq > count/B3820_Rm0.txt
agrep -0 -c 'ATGCAACCGTGGTCCGT' *.fastq > count/B3821_Rm0.txt
agrep -0 -c 'ATAGTGATAACCCTTGC' *.fastq > count/B3825_Rm0.txt
agrep -0 -c 'GGTGTGTTGAGCTCGTC' *.fastq > count/B3826_Rm0.txt
agrep -0 -c 'CCTACCGGACTTACCAC' *.fastq > count/B3827_Rm0.txt
agrep -0 -c 'ATCACCTCGAAGAAGTG' *.fastq > count/B3828_Rm0.txt
agrep -0 -c 'TCTGGAATGCGTCTCAC' *.fastq > count/B3829_Rm0.txt
agrep -0 -c 'ACAAAAGGTCTGAGCCC' *.fastq > count/B3830_Rm0.txt
agrep -0 -c 'ATACAACATAACGAGCG' *.fastq > count/B3831_Rm0.txt
agrep -0 -c 'TCGCTGTAAGACACTGA' *.fastq > count/B3832_Rm0.txt
agrep -0 -c 'ATCGCGACAAGCTTCTG' *.fastq > count/B3833_Rm0.txt
agrep -0 -c 'CATGTGAACCGGTGAGG' *.fastq > count/B3834_Rm0.txt
agrep -0 -c 'CGGTGGATCTGAAGACC' *.fastq > count/B3835_Rm0.txt
agrep -0 -c 'AGCTAGATCCAGCAGCT' *.fastq > count/B3836_Rm0.txt
agrep -0 -c 'CTCCTGTGTAAAGTTGT' *.fastq > count/B3837_Rm0.txt
agrep -0 -c 'GCTTGCTAAGACGCGAA' *.fastq > count/B3838_Rm0.txt
agrep -0 -c 'GCTTCCGCAGCTCTGTT' *.fastq > count/B3839_Rm0.txt
agrep -0 -c 'GCGCACATCATCGTGTA' *.fastq > count/B3840_Rm0.txt
agrep -0 -c 'TGACCCTTTGTAGTCGA' *.fastq > count/B3841_Rm0.txt
agrep -0 -c 'GACCATTTCTGCTTCAT' *.fastq > count/B3842_Rm0.txt
agrep -0 -c 'ATCTGGACGCCTAGGTT' *.fastq > count/B3843_Rm0.txt
agrep -0 -c 'AAATCTCTGGGGGCCTC' *.fastq > count/B3845_Rm0.txt
agrep -0 -c 'ATCTGAACCGGTTACGT' *.fastq > count/B3846_Rm0.txt
agrep -0 -c 'CTGTGCAGAGCATAATG' *.fastq > count/B3848_Rm0.txt
agrep -0 -c 'TATTCGCCGCACCTATT' *.fastq > count/B3849_Rm0.txt
agrep -0 -c 'ACGAGGAACATTCACAG' *.fastq > count/B3850_Rm0.txt
agrep -0 -c 'CAACAACCCGGTACCGT' *.fastq > count/B3851_Rm0.txt
agrep -0 -c 'GTTCCTCGTCTTTGCCA' *.fastq > count/B3852_Rm0.txt
agrep -0 -c 'CCAGGCTCAAATTGAAG' *.fastq > count/B3853_Rm0.txt
agrep -0 -c 'TATACGGTAAGCCTCCC' *.fastq > count/B3854_Rm0.txt
agrep -0 -c 'ACATCGATCCGGGTACC' *.fastq > count/B3855_Rm0.txt
agrep -0 -c 'ACATACTCGGACTAGAG' *.fastq > count/B3858_Rm0.txt
agrep -0 -c 'CTTGGTAATTCGCACCG' *.fastq > count/B3859_Rm0.txt
agrep -0 -c 'CAGCTGCGTGTTCGACA' *.fastq > count/B3860_Rm0.txt
agrep -0 -c 'GCCCCTTCCGTATGTCT' *.fastq > count/B3862_Rm0.txt
agrep -0 -c 'ATACCCTCTCGGCATCA' *.fastq > count/B3865_Rm0.txt
agrep -0 -c 'AATCCTAGAACAGCTAC' *.fastq > count/B3866_Rm0.txt
agrep -0 -c 'TTTAAGACAGCTCCTAC' *.fastq > count/B3867_Rm0.txt
agrep -0 -c 'ACAGTTGGGATGTGATC' *.fastq > count/B3868_Rm0.txt
agrep -0 -c 'TTCGCAGAGAGCTTCCC' *.fastq > count/B3869_Rm0.txt
agrep -0 -c 'ATTGCGCACAGCTGTAT' *.fastq > count/B3870_Rm0.txt
agrep -0 -c 'CGATATAAGGCTTAGAC' *.fastq > count/B3871_Rm0.txt
agrep -0 -c 'GGTCCGAATTACGGTCC' *.fastq > count/B3872_Rm0.txt
agrep -0 -c 'GGTGTTAAGGTATACGC' *.fastq > count/B3873_Rm0.txt
agrep -0 -c 'CCGAGAAGTCATGTTAA' *.fastq > count/B3874_Rm0.txt
agrep -0 -c 'ATTCCTTTTGCTCCCGG' *.fastq > count/B3875_Rm0.txt
agrep -0 -c 'TGTCAGTCCTTGTGAGT' *.fastq > count/B3876_Rm0.txt
agrep -0 -c 'TTTACCCGGCTTACCTA' *.fastq > count/B3877_Rm0.txt
agrep -0 -c 'TGAAAAATGCGCCCTAA' *.fastq > count/B3878_Rm0.txt
agrep -0 -c 'CCAAGTAGGGATGTGCC' *.fastq > count/B3879_Rm0.txt
agrep -0 -c 'TCCTAACGAGGGGATCG' *.fastq > count/B3880_Rm0.txt
agrep -0 -c 'TAGACTCACGCTGCAGA' *.fastq > count/B3882_Rm0.txt
agrep -0 -c 'TGGGACTAAAACCACGG' *.fastq > count/B3883_Rm0.txt
agrep -0 -c 'TCGCGCCATTTGAAGAG' *.fastq > count/B3884_Rm0.txt
agrep -0 -c 'GAACTGTCTGGGCTAGA' *.fastq > count/B3885_Rm0.txt
agrep -0 -c 'GGAGTAAGACTCTCCTG' *.fastq > count/B3886_Rm0.txt
agrep -0 -c 'ATTAGCCCGGGACGTCA' *.fastq > count/B3888_Rm0.txt
agrep -0 -c 'TAGCGACTCACGTTAGA' *.fastq > count/B3889_Rm0.txt
agrep -0 -c 'GTACCACGGAGGAAGTT' *.fastq > count/B3890_Rm0.txt
agrep -0 -c 'ACGCGCGCTCTGTATAT' *.fastq > count/B3891_Rm0.txt
agrep -0 -c 'CATTCTGAACCCCCCGA' *.fastq > count/B3892_Rm0.txt
agrep -0 -c 'GTGCCCACACATACTGC' *.fastq > count/B3894_Rm0.txt
agrep -0 -c 'GATTCTCCCGCTATATT' *.fastq > count/B3895_Rm0.txt
agrep -0 -c 'AGTTTATGGGAGGCCAG' *.fastq > count/B3897_Rm0.txt
agrep -0 -c 'GATATGAGTATACCGGC' *.fastq > count/B3898_Rm0.txt
agrep -0 -c 'ACATCGGGCTGAAACGC' *.fastq > count/B3899_Rm0.txt
agrep -0 -c 'CTATATGGCCCAGTAAG' *.fastq > count/B3900_Rm0.txt
agrep -0 -c 'TATGAACGTTTATGCGC' *.fastq > count/B3901_Rm0.txt
agrep -0 -c 'TAGAAACTGAGTCGAAG' *.fastq > count/B3903_Rm0.txt
agrep -0 -c 'TGCCCAAGCCAGTGGAA' *.fastq > count/B3905_Rm0.txt
agrep -0 -c 'ATTGCCTCGAGAGATAC' *.fastq > count/B3906_Rm0.txt
agrep -0 -c 'GATATGCGAACTTGCTC' *.fastq > count/B3907_Rm0.txt
agrep -0 -c 'CGCCTCATATGGCAGAG' *.fastq > count/B3908_Rm0.txt
agrep -0 -c 'AAATGAGAGTGAGCCTG' *.fastq > count/B3909_Rm0.txt
agrep -0 -c 'TCGCGGTTTCCTATTAC' *.fastq > count/B3910_Rm0.txt
agrep -0 -c 'CGCGGTTAATTCTGCGT' *.fastq > count/B3911_Rm0.txt
agrep -0 -c 'AGCTATTCTGGGCGCTG' *.fastq > count/B3913_Rm0.txt
agrep -0 -c 'GCAGGTAAGTCCACTGA' *.fastq > count/B3914_Rm0.txt
agrep -0 -c 'GTCAAATTACGCCCGTT' *.fastq > count/B3915_Rm0.txt
agrep -0 -c 'GGCTTTGTCTTTATCGG' *.fastq > count/B3916_Rm0.txt
agrep -0 -c 'TCAGGCGACCTCAATGA' *.fastq > count/B3917_Rm0.txt
agrep -0 -c 'GACTGTGCCTACATGAG' *.fastq > count/B3918_Rm0.txt
agrep -0 -c 'GCCCAGTAGAACTCCGA' *.fastq > count/B3919_Rm0.txt
agrep -0 -c 'GTTAGCGTTTACGCAGG' *.fastq > count/B3920_Rm0.txt
agrep -0 -c 'ACCACTCTTAAGCGGGT' *.fastq > count/B3921_Rm0.txt
agrep -0 -c 'CACCCGGTTCAAATTTG' *.fastq > count/B3922_Rm0.txt
agrep -0 -c 'TCCTCGCTTGTCGCTAT' *.fastq > count/B3923_Rm0.txt
agrep -0 -c 'TAATGCAGGATCGGGCG' *.fastq > count/B3924_Rm0.txt
agrep -0 -c 'TCCGTACTCCAGTACTC' *.fastq > count/B3925_Rm0.txt
agrep -0 -c 'TACGGACCACCCTTCAT' *.fastq > count/B3926_Rm0.txt
agrep -0 -c 'GAACATCTATTGCCACA' *.fastq > count/B3927_Rm0.txt
agrep -0 -c 'CGGTCATAACCCTTTGG' *.fastq > count/B3928_Rm0.txt
agrep -0 -c 'TGGGCGACTACCCTACA' *.fastq > count/B3929_Rm0.txt
agrep -0 -c 'CCTTTTCAGGCCCCCTT' *.fastq > count/B3930_Rm0.txt
agrep -0 -c 'GGAGCGGTAAAATAAGT' *.fastq > count/B3931_Rm0.txt
agrep -0 -c 'CGGAATCGAGTTTAAGC' *.fastq > count/B3932_Rm0.txt
agrep -0 -c 'TACCTTTCTTGGAGCGA' *.fastq > count/B3933_Rm0.txt
agrep -0 -c 'GGGTAGTAAGCCCCTGT' *.fastq > count/B3935_Rm0.txt
agrep -0 -c 'ATCGTCCAACTTTACGC' *.fastq > count/B3936_Rm0.txt
agrep -0 -c 'AATCGGACGAACTGGTC' *.fastq > count/B3937_Rm0.txt
agrep -0 -c 'CGCGACGCTCCGAAAAT' *.fastq > count/B3938_Rm0.txt
agrep -0 -c 'TAATCCTCTGTCGTACC' *.fastq > count/B3940_Rm0.txt
agrep -0 -c 'CTCGATCCTGCCCAAAC' *.fastq > count/B3941_Rm0.txt
agrep -0 -c 'CGAGGCAGCAAGCTTGA' *.fastq > count/B3942_Rm0.txt
agrep -0 -c 'GCCAGTGCAAATTTAAC' *.fastq > count/B3943_Rm0.txt
agrep -0 -c 'TCCTCCCGAGGTTTACA' *.fastq > count/B3944_Rm0.txt
agrep -0 -c 'GGCACGTACATGTTTCG' *.fastq > count/B3945_Rm0.txt
agrep -0 -c 'CCCTATTTTTGCGATGA' *.fastq > count/B3946_Rm0.txt
agrep -0 -c 'TGCGCAAGACAACCCTC' *.fastq > count/B3947_Rm0.txt
agrep -0 -c 'ATGTACACGCTAGCGGT' *.fastq > count/B3948_Rm0.txt
agrep -0 -c 'TTCGCATGCACGCCTAA' *.fastq > count/B3949_Rm0.txt
agrep -0 -c 'CCTCATAGTGATAGCAG' *.fastq > count/B3950_Rm0.txt
agrep -0 -c 'GAGACCGTATCCAGCAA' *.fastq > count/B3951_Rm0.txt
agrep -0 -c 'TATTCTGTACGTCCAGA' *.fastq > count/B3952_Rm0.txt
agrep -0 -c 'TACTGTAGTGGTCCTAG' *.fastq > count/B3953_Rm0.txt
agrep -0 -c 'ATCGGTGCCTTCGAAGA' *.fastq > count/B3954_Rm0.txt
agrep -0 -c 'ATAACTTGACGCCATAC' *.fastq > count/B3955_Rm0.txt
agrep -0 -c 'GTTTAATTCATTGCCCC' *.fastq > count/B3956_Rm0.txt
agrep -0 -c 'GCACAGTAAGCAGTTGC' *.fastq > count/B3957_Rm0.txt
agrep -0 -c 'TTCGTGTACATGTGGAC' *.fastq > count/B3958_Rm0.txt
agrep -0 -c 'AGCATCTGGACACGCAT' *.fastq > count/B3962_Rm0.txt
agrep -0 -c 'GATGAGCCGCACTTCTT' *.fastq > count/B3963_Rm0.txt
agrep -0 -c 'ACACCGTTTGCTCACCC' *.fastq > count/B3964_Rm0.txt
agrep -0 -c 'GACGTGCATGGTCCATC' *.fastq > count/B3965_Rm0.txt
agrep -0 -c 'CTGAGGATCGTAGCGTA' *.fastq > count/B3969_Rm0.txt
agrep -0 -c 'ATTCTTCTTGAGCTGAC' *.fastq > count/B3970_Rm0.txt
agrep -0 -c 'GAGCGGTTAAATCGTCG' *.fastq > count/B3972_Rm0.txt
agrep -0 -c 'TATCCATACTAGCCGTC' *.fastq > count/B3974_Rm0.txt
agrep -0 -c 'GCCGGCATTTCGTTATT' *.fastq > count/B3975_Rm0.txt
agrep -0 -c 'CTGAGGTTTACCCGAAT' *.fastq > count/B3976_Rm0.txt
agrep -0 -c 'CAATAGTCTGGCGCTGG' *.fastq > count/B3977_Rm0.txt
agrep -0 -c 'ACGTATGTCTTATTGCG' *.fastq > count/B3979_Rm0.txt
agrep -0 -c 'CTGAGCCGTTCCTTATG' *.fastq > count/B3981_Rm0.txt
agrep -0 -c 'ACAGTTATACGCCAGAC' *.fastq > count/B3983_Rm0.txt
agrep -0 -c 'CCGCATAACTAGCATGT' *.fastq > count/B3985_Rm0.txt
agrep -0 -c 'GTTTGCAGCGGAAACCC' *.fastq > count/B3986_Rm0.txt
agrep -0 -c 'TGGCTGGTGACTTGTAC' *.fastq > count/B3987_Rm0.txt
agrep -0 -c 'AATCTCCCCGGTTGAAC' *.fastq > count/B3988_Rm0.txt
agrep -0 -c 'GAAAGTGCAAATCCCCG' *.fastq > count/B3989_Rm0.txt
agrep -0 -c 'AACCCCAGGTTATGCGA' *.fastq > count/B3991_Rm0.txt
agrep -0 -c 'ATGGCGTGTGTGTTCAT' *.fastq > count/B3992_Rm0.txt
agrep -0 -c 'AAGAGTTTGACCTGCGC' *.fastq > count/B3993_Rm0.txt
agrep -0 -c 'GCTATCGTCCTCATAAG' *.fastq > count/B3994_Rm0.txt
agrep -0 -c 'CCAATGTATGCAAGTGC' *.fastq > count/B3995_Rm0.txt
agrep -0 -c 'AGGGGCACTCCAAGCTA' *.fastq > count/B3996_Rm0.txt
agrep -0 -c 'CAGCTTATGCTCCTTGT' *.fastq > count/B3997_Rm0.txt
agrep -0 -c 'TAGGGTGACTCAGTCAT' *.fastq > count/B3998_Rm0.txt
agrep -0 -c 'CTCACGAGCATAAGTCA' *.fastq > count/B3999_Rm0.txt
agrep -0 -c 'GATGTTTGTTGCGATTG' *.fastq > count/B4000_Rm0.txt
agrep -0 -c 'AATTTACTCCGGCAACA' *.fastq > count/B4001_Rm0.txt
agrep -0 -c 'ATCACTTTCGCCAAGTA' *.fastq > count/B4002_Rm0.txt
agrep -0 -c 'TTCCTCTTAAGGGCCAC' *.fastq > count/B4003_Rm0.txt
agrep -0 -c 'GTGGGATACTGGTCCAT' *.fastq > count/B4004_Rm0.txt
agrep -0 -c 'ACAATCCGCTAGCACGC' *.fastq > count/B4006_Rm0.txt
agrep -0 -c 'CAGGTCTACAGCGTACC' *.fastq > count/B4007_Rm0.txt
agrep -0 -c 'AATTGGGCAGCCTATGG' *.fastq > count/B4008_Rm0.txt
agrep -0 -c 'TGGCAGCAATCGATAGA' *.fastq > count/B4009_Rm0.txt
agrep -0 -c 'TTGCCAATGATTGGACC' *.fastq > count/B4010_Rm0.txt
agrep -0 -c 'ACTTGCTTGAACGAACG' *.fastq > count/B4011_Rm0.txt
agrep -0 -c 'GAATTCCGTTCAACCAT' *.fastq > count/B4013_Rm0.txt
agrep -0 -c 'AGTTTGCAGTGTAGTCT' *.fastq > count/B4014_Rm0.txt
agrep -0 -c 'GTTGTGTTGGGGTGTAC' *.fastq > count/B4016_Rm0.txt
agrep -0 -c 'CAATTAGACGCTGCAGT' *.fastq > count/B4017_Rm0.txt
agrep -0 -c 'CCGGGATCCACAATCTG' *.fastq > count/B4018_Rm0.txt
agrep -0 -c 'TCAACAGTTGGTTGCCC' *.fastq > count/B4019_Rm0.txt
agrep -0 -c 'CCACCCGCGAACATATA' *.fastq > count/B4020_Rm0.txt
agrep -0 -c 'CGCGATCCTGCAACTCA' *.fastq > count/B4022_Rm0.txt
agrep -0 -c 'GGAACGTCGTGTCAAGG' *.fastq > count/B4023_Rm0.txt
agrep -0 -c 'CCAACAGGTAATGTCCC' *.fastq > count/B4024_Rm0.txt
agrep -0 -c 'CCTTACGCCAATCTAAC' *.fastq > count/B4025_Rm0.txt
agrep -0 -c 'TTCGAAGGTTGTAGAAC' *.fastq > count/B4027_Rm0.txt
agrep -0 -c 'CGCAGCTTGCAGATGGT' *.fastq > count/B4028_Rm0.txt
agrep -0 -c 'ACTATTTACCATGCGGC' *.fastq > count/B4029_Rm0.txt
agrep -0 -c 'AAAGGGTATCGCCTACA' *.fastq > count/B4030_Rm0.txt
agrep -0 -c 'GCGGTTTTGGTTTTACT' *.fastq > count/B4031_Rm0.txt
agrep -0 -c 'TCTGCAGGAATCTCGAC' *.fastq > count/B4032_Rm0.txt
agrep -0 -c 'GTCTGCTGTACCTTCAA' *.fastq > count/B4034_Rm0.txt
agrep -0 -c 'GAATAGGCGATGATCGG' *.fastq > count/B4035_Rm0.txt
agrep -0 -c 'GGAAGGGCTGTGCCAAT' *.fastq > count/B4036_Rm0.txt
agrep -0 -c 'GGCTAGACCATTGCGTT' *.fastq > count/B4037_Rm0.txt
agrep -0 -c 'GTCCTCTAGTCACAATT' *.fastq > count/B4039_Rm0.txt
agrep -0 -c 'TTTCGGTGTGGTTAAGG' *.fastq > count/B4040_Rm0.txt
agrep -0 -c 'GGCCCCCGCATCATAAT' *.fastq > count/B4041_Rm0.txt
agrep -0 -c 'GTGCTCACCAAGCGCAA' *.fastq > count/B4042_Rm0.txt
agrep -0 -c 'ACCAACGCAAGGAACAC' *.fastq > count/B4043_Rm0.txt
agrep -0 -c 'AGATCTTGAGCTGGATA' *.fastq > count/B4046_Rm0.txt
agrep -0 -c 'CCCTACTGGACGTTCGA' *.fastq > count/B4047_Rm0.txt
agrep -0 -c 'AAGTACCACGAAAGAGT' *.fastq > count/B4048_Rm0.txt
agrep -0 -c 'TCGCGATTGTCGACCGA' *.fastq > count/B4049_Rm0.txt
agrep -0 -c 'TTAGGACCCACTGCGAT' *.fastq > count/B4051_Rm0.txt
agrep -0 -c 'TCTCGCAGGTCAAGAGA' *.fastq > count/B4052_Rm0.txt
agrep -0 -c 'ATTGATGTCTGGGGTCC' *.fastq > count/B4053_Rm0.txt
agrep -0 -c 'TTCTCGAACATTTAGCG' *.fastq > count/B4054_Rm0.txt
agrep -0 -c 'TGGCTCACTGACATATG' *.fastq > count/B4055_Rm0.txt
agrep -0 -c 'TGGAAGTAAGTGCGAAC' *.fastq > count/B4056_Rm0.txt
agrep -0 -c 'ACGGTACAATCAATTGG' *.fastq > count/B4057_Rm0.txt
agrep -0 -c 'TCGAAGGGACCCATTGG' *.fastq > count/B4058_Rm0.txt
agrep -0 -c 'GGGCGGATGTCACCTAT' *.fastq > count/B4059_Rm0.txt
agrep -0 -c 'ATTCAGAACCGTTCAAC' *.fastq > count/B4060_Rm0.txt
agrep -0 -c 'CTTGGGAGCATGGACTT' *.fastq > count/B4061_Rm0.txt
agrep -0 -c 'GGGGAGATCAACTGGTG' *.fastq > count/B4063_Rm0.txt
agrep -0 -c 'GATTACTCATTGTGGCC' *.fastq > count/B4066_Rm0.txt
agrep -0 -c 'CTCCTTAGTTTCTGAGT' *.fastq > count/B4067_Rm0.txt
agrep -0 -c 'GCTGGGGTGTCATTTCA' *.fastq > count/B4068_Rm0.txt
agrep -0 -c 'TCATTGGTTCGGCACTG' *.fastq > count/B4069_Rm0.txt
agrep -0 -c 'GGAGGCATACATGGGTA' *.fastq > count/B4071_Rm0.txt
agrep -0 -c 'TCCCTTCTATTCTGTGC' *.fastq > count/B4072_Rm0.txt
agrep -0 -c 'TTGATGATTCGACGGCA' *.fastq > count/B4074_Rm0.txt
agrep -0 -c 'TCTTCACGTACTTTGCA' *.fastq > count/B4075_Rm0.txt
agrep -0 -c 'CCACAATCAAAGGTTGG' *.fastq > count/B4076_Rm0.txt
agrep -0 -c 'CAAGTAGGAGCAAGGTT' *.fastq > count/B4077_Rm0.txt
agrep -0 -c 'AACAGAACGCCACCATG' *.fastq > count/B4078_Rm0.txt
agrep -0 -c 'CTGGTAGAAAGTCGCGG' *.fastq > count/B4080_Rm0.txt
agrep -0 -c 'ACGATTTGGGGAGCATT' *.fastq > count/B4081_Rm0.txt
agrep -0 -c 'TCTGGGTAAACAAGGTG' *.fastq > count/B4082_Rm0.txt
agrep -0 -c 'TGGTTTACCATTAGGCT' *.fastq > count/B4083_Rm0.txt
agrep -0 -c 'GGCCACCGAAATATGTC' *.fastq > count/B4084_Rm0.txt
agrep -0 -c 'TTCCCATTAGGTGGCTC' *.fastq > count/B4085_Rm0.txt
agrep -0 -c 'AGTGGTCAGAACTGTCT' *.fastq > count/B4086_Rm0.txt
agrep -0 -c 'TGGTCAGCCTTAAGTGC' *.fastq > count/B4088_Rm0.txt
agrep -0 -c 'TGGCAGGTAAGTTGTAA' *.fastq > count/B4089_Rm0.txt
agrep -0 -c 'GGGATAAGATGGCTCGC' *.fastq > count/B4090_Rm0.txt
agrep -0 -c 'CCGCGGTATTTTTGCAA' *.fastq > count/B4091_Rm0.txt
agrep -0 -c 'CCATTAAACGCGAGCAA' *.fastq > count/B4092_Rm0.txt
agrep -0 -c 'TCACTTAGAGCGAACGG' *.fastq > count/B4093_Rm0.txt
agrep -0 -c 'TTTCGAGTCAGGCTGCA' *.fastq > count/B4094_Rm0.txt
agrep -0 -c 'GTATGTGGAGTGAACAC' *.fastq > count/B4095_Rm0.txt
agrep -0 -c 'CAGCTAGGTCATCTTAC' *.fastq > count/B4096_Rm0.txt
agrep -0 -c 'GCTTGCACCGATTTTCT' *.fastq > count/B4097_Rm0.txt
agrep -0 -c 'AATACCCGATAAAGGTC' *.fastq > count/B4098_Rm0.txt
agrep -0 -c 'ACTCATGGTCTTTAGAC' *.fastq > count/B4099_Rm0.txt
agrep -0 -c 'AGCAAGCGTATGCTCGG' *.fastq > count/B4100_Rm0.txt
agrep -0 -c 'GAAGCGCTGGATTGTAT' *.fastq > count/B4102_Rm0.txt
agrep -0 -c 'GAGCTGTCTGAGTGTCC' *.fastq > count/B4103_Rm0.txt
agrep -0 -c 'CAACTTAACCCCTTACA' *.fastq > count/B4104_Rm0.txt
agrep -0 -c 'AAACTCCGGAGTGATCT' *.fastq > count/B4105_Rm0.txt
agrep -0 -c 'GTCTATAAGAGGGGTCA' *.fastq > count/B4106_Rm0.txt
agrep -0 -c 'GGAATCCACTCGTGGAC' *.fastq > count/B4107_Rm0.txt
agrep -0 -c 'ACAGTTCGTCCGGAACT' *.fastq > count/B4108_Rm0.txt
agrep -0 -c 'CTACGAATAAGTGCGTT' *.fastq > count/B4109_Rm0.txt
agrep -0 -c 'ACGCAGTACGGAGATAG' *.fastq > count/B4110_Rm0.txt
agrep -0 -c 'GGTGAGAAGGAACTAGC' *.fastq > count/B4111_Rm0.txt
agrep -0 -c 'TGAAATGAGCTGCTTGC' *.fastq > count/B4112_Rm0.txt
agrep -0 -c 'CTCTCTTGGGTTAATCG' *.fastq > count/B4114_Rm0.txt
agrep -0 -c 'ACTGTGCGAGATACGTA' *.fastq > count/B4115_Rm0.txt
agrep -0 -c 'CCATGTAGATCCTATAC' *.fastq > count/B4117_Rm0.txt
agrep -0 -c 'GTAAAGAGGTCCGTGAC' *.fastq > count/B4118_Rm0.txt
agrep -0 -c 'CGTTTCCACCTCACAGC' *.fastq > count/B4119_Rm0.txt
agrep -0 -c 'TCGGATTCAGGTGGTCG' *.fastq > count/B4120_Rm0.txt
agrep -0 -c 'GAAAGAGAACAGCGCGT' *.fastq > count/B4121_Rm0.txt
agrep -0 -c 'TTCTGAGCTATGAACGC' *.fastq > count/B4122_Rm0.txt
agrep -0 -c 'TGACTACTCTGACCTAC' *.fastq > count/B4123_Rm0.txt
agrep -0 -c 'AGAGTCGTTACACCTAC' *.fastq > count/B4124_Rm0.txt
agrep -0 -c 'TTCTGTCTACTGTTCGG' *.fastq > count/B4125_Rm0.txt
agrep -0 -c 'GACCTACTAATTTCGGT' *.fastq > count/B4126_Rm0.txt
agrep -0 -c 'CCTCTCGTCTGTGGTAT' *.fastq > count/B4127_Rm0.txt
agrep -0 -c 'AGCAGGTAGACGCAATG' *.fastq > count/B4128_Rm0.txt
agrep -0 -c 'TCACGAGGGACGAATGC' *.fastq > count/B4129_Rm0.txt
agrep -0 -c 'CACCACCTGTATGGGAG' *.fastq > count/B4130_Rm0.txt
agrep -0 -c 'AATCGGTGCGAGGGTCA' *.fastq > count/B4131_Rm0.txt
agrep -0 -c 'CGGATATAGACACATGA' *.fastq > count/B4132_Rm0.txt
agrep -0 -c 'GATTGGGGATCGGTCTT' *.fastq > count/B4133_Rm0.txt
agrep -0 -c 'AATGTCCAATACACGTC' *.fastq > count/B4134_Rm0.txt
agrep -0 -c 'AAGCCCAGACTACAACC' *.fastq > count/B4135_Rm0.txt
agrep -0 -c 'GGCGTGTGAACGGTTTA' *.fastq > count/B4137_Rm0.txt
agrep -0 -c 'TGAGAGTGGACCTTCAC' *.fastq > count/B4139_Rm0.txt
agrep -0 -c 'AAAAACCTAGCTTGGGC' *.fastq > count/B4140_Rm0.txt
agrep -0 -c 'GCCCTGTATGCTCATCC' *.fastq > count/B4141_Rm0.txt
agrep -0 -c 'TTGTGATCTTGTAGAGC' *.fastq > count/B4142_Rm0.txt
agrep -0 -c 'CTGGAGCTGTAATCCAA' *.fastq > count/B4144_Rm0.txt
agrep -0 -c 'TAGTCAGCTGCGGAACA' *.fastq > count/B4145_Rm0.txt
agrep -0 -c 'CACAGACTGTACTCTAT' *.fastq > count/B4146_Rm0.txt
agrep -0 -c 'CAGACACTATGCAACCG' *.fastq > count/B4147_Rm0.txt
agrep -0 -c 'GTGGGGCTATGAGTGAA' *.fastq > count/B4148_Rm0.txt
agrep -0 -c 'CACTACCAGGTGATTAA' *.fastq > count/B4149_Rm0.txt
agrep -0 -c 'CTAAACATCCCGCCATG' *.fastq > count/B4150_Rm0.txt
agrep -0 -c 'ACCCGGTAACTCCTGCT' *.fastq > count/B4151_Rm0.txt
agrep -0 -c 'ACCTAAGCCTGACGAGT' *.fastq > count/B4152_Rm0.txt
agrep -0 -c 'TGATGCGTTGACGGTGG' *.fastq > count/B4153_Rm0.txt
agrep -0 -c 'GGCTAATTAACCTGACT' *.fastq > count/B4154_Rm0.txt
agrep -0 -c 'TGAATATGAGGAACCGC' *.fastq > count/B4155_Rm0.txt
agrep -0 -c 'AAACAGCCATGATCACC' *.fastq > count/B4156_Rm0.txt
agrep -0 -c 'TGGCGGTGCGGGTAAAT' *.fastq > count/B4157_Rm0.txt
agrep -0 -c 'ATGGCGGACTCCAAATA' *.fastq > count/B4158_Rm0.txt
agrep -0 -c 'TTTGATATGGCGTTGCC' *.fastq > count/B4159_Rm0.txt
agrep -0 -c 'ATGTGAGATCAATGGCA' *.fastq > count/B4160_Rm0.txt
agrep -0 -c 'CCCGTCGTTAAGTTCTA' *.fastq > count/B4164_Rm0.txt
agrep -0 -c 'GGTATAACCAAGGGAGG' *.fastq > count/B4165_Rm0.txt
agrep -0 -c 'AGGCAGATAGTGCTAAT' *.fastq > count/B4166_Rm0.txt
agrep -0 -c 'GCTTGACCTAATAGCCG' *.fastq > count/B4167_Rm0.txt
agrep -0 -c 'GCATGTAAGGAAATACC' *.fastq > count/B4168_Rm0.txt
agrep -0 -c 'TAGGGAGCAATAGTGTT' *.fastq > count/B4169_Rm0.txt
agrep -0 -c 'CAAACTTCACGTCTCCC' *.fastq > count/B4170_Rm0.txt
agrep -0 -c 'ATCGTTCCAGAGTTGCG' *.fastq > count/B4171_Rm0.txt
agrep -0 -c 'AAGTGCTCCTAATGGAT' *.fastq > count/B4172_Rm0.txt
agrep -0 -c 'TGGTAATGTCCCATACT' *.fastq > count/B4173_Rm0.txt
agrep -0 -c 'TTGTATGGATCCACAAC' *.fastq > count/B4174_Rm0.txt
agrep -0 -c 'CCTTAATGCCGAAGTGG' *.fastq > count/B4175_Rm0.txt
agrep -0 -c 'CTCTTCGATCACTTCGC' *.fastq > count/B4176_Rm0.txt
agrep -0 -c 'ACTGATCAGTTCTCGAC' *.fastq > count/B4177_Rm0.txt
agrep -0 -c 'TTCCCAGTTGCGCTCTG' *.fastq > count/B4178_Rm0.txt
agrep -0 -c 'ATCATCTTGACGAAGCT' *.fastq > count/B4179_Rm0.txt
agrep -0 -c 'CTGGTATGTGATGTTCT' *.fastq > count/B4181_Rm0.txt
agrep -0 -c 'ACGTGGACTGTAACCAA' *.fastq > count/B4182_Rm0.txt
agrep -0 -c 'TTGCACCAAGGGAAGTG' *.fastq > count/B4183_Rm0.txt
agrep -0 -c 'GTACTATAGGGCCACTA' *.fastq > count/B4184_Rm0.txt
agrep -0 -c 'TATATGGCCCCAGATGC' *.fastq > count/B4185_Rm0.txt
agrep -0 -c 'ACACCGGAGTTAATTAG' *.fastq > count/B4186_Rm0.txt
agrep -0 -c 'CCTATACTTGTGAGGCG' *.fastq > count/B4187_Rm0.txt
agrep -0 -c 'TAGCTAGTGATTGTCGG' *.fastq > count/B4188_Rm0.txt
agrep -0 -c 'CAAGAACACCATAGTCA' *.fastq > count/B4190_Rm0.txt
agrep -0 -c 'GTCGAAAGGCCGTCCAA' *.fastq > count/B4191_Rm0.txt
agrep -0 -c 'CAATGGCAAATCTGACG' *.fastq > count/B4193_Rm0.txt
agrep -0 -c 'TGAATCTCCAGACCCGC' *.fastq > count/B4194_Rm0.txt
agrep -0 -c 'CGATACATATAACGGGT' *.fastq > count/B4195_Rm0.txt
agrep -0 -c 'CGTCGTTTCGTCCAGTT' *.fastq > count/B4196_Rm0.txt
agrep -0 -c 'CGTAGAACAGGAAATAC' *.fastq > count/B4197_Rm0.txt
agrep -0 -c 'AGTGCACCCGAATTCCC' *.fastq > count/B4198_Rm0.txt
agrep -0 -c 'GTCAACGATCCTTTAAC' *.fastq > count/B4199_Rm0.txt
agrep -0 -c 'GACTAGTCTTATAGCAC' *.fastq > count/B4200_Rm0.txt
agrep -0 -c 'AGTTGCTACACTGCTAG' *.fastq > count/B4201_Rm0.txt
agrep -0 -c 'TTCGTGTTGTATTGTGC' *.fastq > count/B4202_Rm0.txt
agrep -0 -c 'TGGCGGTAATGAAGTAG' *.fastq > count/B4204_Rm0.txt
agrep -0 -c 'GAAGTACCGGACCGGTA' *.fastq > count/B4205_Rm0.txt
agrep -0 -c 'ACCTATCTGATGCAGTG' *.fastq > count/B4206_Rm0.txt
agrep -0 -c 'GTAACGCCCGAGATCTC' *.fastq > count/B4207_Rm0.txt
agrep -0 -c 'AACCAGTATGGGAAGCG' *.fastq > count/B4208_Rm0.txt
agrep -0 -c 'GATCCCGTGAATGCTAC' *.fastq > count/B4209_Rm0.txt
agrep -0 -c 'CAAATTGTCGCTGGTTG' *.fastq > count/B4210_Rm0.txt
agrep -0 -c 'GAATTGGTTAGCTTCAC' *.fastq > count/B4213_Rm0.txt
agrep -0 -c 'CTTCATGCTTAAATCCG' *.fastq > count/B4215_Rm0.txt
agrep -0 -c 'ACGCGGTTCGTCCTTCT' *.fastq > count/B4216_Rm0.txt
agrep -0 -c 'GATACCGTCGGTTGCTG' *.fastq > count/B4217_Rm0.txt
agrep -0 -c 'ACGTTGCGTGGAGTGGT' *.fastq > count/B4218_Rm0.txt
agrep -0 -c 'TCGACGGACATTACACG' *.fastq > count/B4219_Rm0.txt
agrep -0 -c 'TCTGAAACTAAGCACTC' *.fastq > count/B4220_Rm0.txt
agrep -0 -c 'GCCTAGCTTCGTACAGC' *.fastq > count/B4221_Rm0.txt
agrep -0 -c 'CTCTGCCATACGCGTAA' *.fastq > count/B4222_Rm0.txt
agrep -0 -c 'ATAGGAATGTCACGCTG' *.fastq > count/B4223_Rm0.txt
agrep -0 -c 'ATTGGCGTTCGGCGCAA' *.fastq > count/B4224_Rm0.txt
agrep -0 -c 'ATCCCGTTTCCACCTAT' *.fastq > count/B4225_Rm0.txt
agrep -0 -c 'CACGCGACCTGACACAA' *.fastq > count/B4227_Rm0.txt
agrep -0 -c 'TCGATTTAACCAACCCT' *.fastq > count/B4228_Rm0.txt
agrep -0 -c 'TGACACGCGGAAACAGA' *.fastq > count/B4229_Rm0.txt
agrep -0 -c 'GCCGACTTTCGTCTCTA' *.fastq > count/B4232_Rm0.txt
agrep -0 -c 'CTGTAAAAACGGCCCTG' *.fastq > count/B4234_Rm0.txt
agrep -0 -c 'CCTGTCTGAGGACTTAC' *.fastq > count/B4235_Rm0.txt
agrep -0 -c 'CCTTGGTCGCGCAGAAT' *.fastq > count/B4237_Rm0.txt
agrep -0 -c 'CTTGAGGGTTAAAGAAC' *.fastq > count/B4238_Rm0.txt
agrep -0 -c 'GCACTTTTGAGTACGCT' *.fastq > count/B4239_Rm0.txt
agrep -0 -c 'GTTTTACGATCCAGTGT' *.fastq > count/B4240_Rm0.txt
agrep -0 -c 'CTCTAAGCGGAAGATTA' *.fastq > count/B4241_Rm0.txt
agrep -0 -c 'GATGACGCTGTAATTAC' *.fastq > count/B4243_Rm0.txt
agrep -0 -c 'CATGCGGGTATATTGTG' *.fastq > count/B4244_Rm0.txt
agrep -0 -c 'AGTCAGGGTGTTACCAG' *.fastq > count/B4245_Rm0.txt
agrep -0 -c 'ATTTAAGAGGGCTCCGC' *.fastq > count/B4246_Rm0.txt
agrep -0 -c 'ACACCAGGTTATGTCTA' *.fastq > count/B4248_Rm0.txt
agrep -0 -c 'GCCTGCATGGTCATTCT' *.fastq > count/B4250_Rm0.txt
agrep -0 -c 'AGAGCTCAGACAGAGTT' *.fastq > count/B4251_Rm0.txt
agrep -0 -c 'ATATGCGTATCGGTCAA' *.fastq > count/B4252_Rm0.txt
agrep -0 -c 'GTAGCGATAGGAGGCTC' *.fastq > count/B4253_Rm0.txt
agrep -0 -c 'GCGCTTATTACGGCGAT' *.fastq > count/B4254_Rm0.txt
agrep -0 -c 'TCGACACCATGATTGAG' *.fastq > count/B4255_Rm0.txt
agrep -0 -c 'TAGCCGGAAAGATCTCC' *.fastq > count/B4256_Rm0.txt
agrep -0 -c 'GCTTACCGGAGCTCGAA' *.fastq > count/B4257_Rm0.txt
agrep -0 -c 'GAGCCGGACCGAATTAA' *.fastq > count/B4258_Rm0.txt
agrep -0 -c 'GTACCACGCAATTCCGC' *.fastq > count/B4259_Rm0.txt
agrep -0 -c 'AACCATTCACCTGCGGC' *.fastq > count/B4260_Rm0.txt
agrep -0 -c 'TTCTATGGACGAGACAC' *.fastq > count/B4261_Rm0.txt
agrep -0 -c 'CTTACACCAGATGACGT' *.fastq > count/B4262_Rm0.txt
agrep -0 -c 'CAAGGTCGAACACTGAG' *.fastq > count/B4263_Rm0.txt
agrep -0 -c 'ACACCCTTACGTAAAGT' *.fastq > count/B4264_Rm0.txt
agrep -0 -c 'GACGTATTTCCGGCTAG' *.fastq > count/B4265_Rm0.txt
agrep -0 -c 'GCTTATAAACCTGGGCT' *.fastq > count/B4266_Rm0.txt
agrep -0 -c 'GACCCTCTAAAGAGTGG' *.fastq > count/B4267_Rm0.txt
agrep -0 -c 'AAACCGACCAAGATAGG' *.fastq > count/B4268_Rm0.txt
agrep -0 -c 'TCGTGTGGCAATCAGCA' *.fastq > count/B4269_Rm0.txt
agrep -0 -c 'GATCGGGTACATTCTCC' *.fastq > count/B4270_Rm0.txt
agrep -0 -c 'TATCATTGCCCGGTGTC' *.fastq > count/B4271_Rm0.txt
agrep -0 -c 'TCGCGCTGCTACTATGT' *.fastq > count/B4272_Rm0.txt
agrep -0 -c 'GTCTCTGACGGCATACG' *.fastq > count/B4274_Rm0.txt
agrep -0 -c 'TAGAAGTGTGGCGTTGT' *.fastq > count/B4275_Rm0.txt
agrep -0 -c 'AGGACTCCTTCGGCATT' *.fastq > count/B4276_Rm0.txt
agrep -0 -c 'GGTTAAGCAAACCCGCG' *.fastq > count/B4277_Rm0.txt
agrep -0 -c 'GGTTGCTAGGGCTTAAC' *.fastq > count/B4278_Rm0.txt
agrep -0 -c 'CGTCGCAATGAAGGCAT' *.fastq > count/B4279_Rm0.txt
agrep -0 -c 'GAATGTTTCCATAACCG' *.fastq > count/B4280_Rm0.txt
agrep -0 -c 'GAAGCTGCTTCGTGTGC' *.fastq > count/B4281_Rm0.txt
agrep -0 -c 'ACCACAACAGGCTGGTG' *.fastq > count/B4282_Rm0.txt
agrep -0 -c 'AGAGTAAGGCGAGAGAA' *.fastq > count/B4283_Rm0.txt
agrep -0 -c 'ACCTTCTCCACTTCGTT' *.fastq > count/B4284_Rm0.txt
agrep -0 -c 'CCGACGTGTCATATCTA' *.fastq > count/B4285_Rm0.txt
agrep -0 -c 'ATTTGACCCCAACTGTT' *.fastq > count/B4286_Rm0.txt
agrep -0 -c 'CATTTTTCATCCCGAGA' *.fastq > count/B4287_Rm0.txt
agrep -0 -c 'GAACTGGACCACTAGCT' *.fastq > count/B4288_Rm0.txt
agrep -0 -c 'GACCTTTATCGTAACCT' *.fastq > count/B4289_Rm0.txt
agrep -0 -c 'GATTCAGGTGCCGAAGG' *.fastq > count/B4290_Rm0.txt
agrep -0 -c 'ATCACCGACACGATATT' *.fastq > count/B4292_Rm0.txt
agrep -0 -c 'GATGTAGTTAAGGACCT' *.fastq > count/B4295_Rm0.txt
agrep -0 -c 'AGAGGACTGGTCGGGTT' *.fastq > count/B4296_Rm0.txt
agrep -0 -c 'ACGACTCCGTTATGCCA' *.fastq > count/B4297_Rm0.txt
agrep -0 -c 'TACGCATGCTCTACAGA' *.fastq > count/B4298_Rm0.txt
agrep -0 -c 'TGTCGAGCTGAGCGTAA' *.fastq > count/B4299_Rm0.txt
agrep -0 -c 'TACACAGGTTGTCATGG' *.fastq > count/B4300_Rm0.txt
agrep -0 -c 'ATCTCCCACTCGTCGAG' *.fastq > count/B4301_Rm0.txt
agrep -0 -c 'TCGAATATACGTGCGGT' *.fastq > count/B4303_Rm0.txt
agrep -0 -c 'CTAACCTTGCTGGATGC' *.fastq > count/B4304_Rm0.txt
agrep -0 -c 'CATGGGCAGGTTCGATT' *.fastq > count/B4305_Rm0.txt
agrep -0 -c 'CATTGTAATCGGGTGAG' *.fastq > count/B4308_Rm0.txt
agrep -0 -c 'ACTGAGGAACAATTCTG' *.fastq > count/B4309_Rm0.txt
agrep -0 -c 'GATGGCGTACTTTCGTT' *.fastq > count/B4311_Rm0.txt
agrep -0 -c 'CTTAACTTCGTGGTTGA' *.fastq > count/B4313_Rm0.txt
agrep -0 -c 'TCATGTCACGGCCTTCC' *.fastq > count/B4314_Rm0.txt
agrep -0 -c 'CGCTATCATAGCGTATT' *.fastq > count/B4315_Rm0.txt
agrep -0 -c 'GATTCGCCGGACTTATA' *.fastq > count/B4316_Rm0.txt
agrep -0 -c 'TAACTCCGGGGTCTACG' *.fastq > count/B4317_Rm0.txt
agrep -0 -c 'GGAGAGATAGGCGGAAG' *.fastq > count/B4318_Rm0.txt
agrep -0 -c 'CATGAGCACTTTCTCGT' *.fastq > count/B4319_Rm0.txt
agrep -0 -c 'GATAGTCCATAGCGACC' *.fastq > count/B4320_Rm0.txt
agrep -0 -c 'GGCTCCTTAAGCGTATG' *.fastq > count/B4321_Rm0.txt
agrep -0 -c 'TACCGATTCTGAAAAGG' *.fastq > count/B4322_Rm0.txt
agrep -0 -c 'CGCGGTACACAATATGA' *.fastq > count/B4323_Rm0.txt
agrep -0 -c 'GTCCAGAAAATTGCGGT' *.fastq > count/B4324_Rm0.txt
agrep -0 -c 'AGTGAACGAAGGGTTAT' *.fastq > count/B4325_Rm0.txt
agrep -0 -c 'TTCCTAAGGTGCTTCAT' *.fastq > count/B4326_Rm0.txt
agrep -0 -c 'TGTTTAGCGGCTCGAAT' *.fastq > count/B4327_Rm0.txt
agrep -0 -c 'AACTTATGTAGACGTGG' *.fastq > count/B4328_Rm0.txt
agrep -0 -c 'AGATCTGTCGGCGGATT' *.fastq > count/B4329_Rm0.txt
agrep -0 -c 'ACATTATGTACGACGCA' *.fastq > count/B4330_Rm0.txt
agrep -0 -c 'TAAAGCAATAGCGTCGC' *.fastq > count/B4331_Rm0.txt
agrep -0 -c 'GCTCGAGATATACAGAG' *.fastq > count/B4332_Rm0.txt
agrep -0 -c 'AGGAACGTCGGATGCGA' *.fastq > count/B4333_Rm0.txt
agrep -0 -c 'ACTCACTTATTCGGGTT' *.fastq > count/B4335_Rm0.txt
agrep -0 -c 'CCGGCAGAGTAGTTTCA' *.fastq > count/B4336_Rm0.txt
agrep -0 -c 'TGATCTGTATCGAGTCA' *.fastq > count/B4337_Rm0.txt
agrep -0 -c 'GATCGCACCAGGATATG' *.fastq > count/B4338_Rm0.txt
agrep -0 -c 'GGGGCTCTTCCGTAGTA' *.fastq > count/B4340_Rm0.txt
agrep -0 -c 'TCAGCGCAATAGATAGG' *.fastq > count/B4341_Rm0.txt
agrep -0 -c 'TACTAAATTCGGCGGTT' *.fastq > count/B4342_Rm0.txt
agrep -0 -c 'AGTTGCATGCGTCAAAT' *.fastq > count/B4343_Rm0.txt
agrep -0 -c 'CAATGAACGGGACGTGA' *.fastq > count/B4344_Rm0.txt
agrep -0 -c 'ACTAGCAAGCTGACATA' *.fastq > count/B4345_Rm0.txt
agrep -0 -c 'GCCGGCACCATATTTTA' *.fastq > count/B4346_Rm0.txt
agrep -0 -c 'TCAAGTCCGCTGTCGAA' *.fastq > count/B4347_Rm0.txt
agrep -0 -c 'CTCATTAGCACCCTGCG' *.fastq > count/B4348_Rm0.txt
agrep -0 -c 'GTTTGAAACAAGAGCCG' *.fastq > count/B4350_Rm0.txt
agrep -0 -c 'AGATGGGGTTAACGAGT' *.fastq > count/B4351_Rm0.txt
agrep -0 -c 'GACGTAGTACTCACTAA' *.fastq > count/B4352_Rm0.txt
agrep -0 -c 'CTTGACCATCGCGACAT' *.fastq > count/B4353_Rm0.txt
agrep -0 -c 'TAGTAGCAGGGCCCGTT' *.fastq > count/B4354_Rm0.txt
agrep -0 -c 'ACCGTTTGAGCTGCGAA' *.fastq > count/B4356_Rm0.txt
agrep -0 -c 'TTTTAAGCATGGGACAG' *.fastq > count/B4357_Rm0.txt
agrep -0 -c 'GCGACCCGTTCGTAGAT' *.fastq > count/B4358_Rm0.txt
agrep -0 -c 'ATGCTACTCAAGTTCCG' *.fastq > count/B4359_Rm0.txt
agrep -0 -c 'CGTGCGATTCATCACAA' *.fastq > count/B4360_Rm0.txt
agrep -0 -c 'GGGTCAACGGTGTGGAT' *.fastq > count/B4362_Rm0.txt
agrep -0 -c 'ATAAGTTCGACCGCATC' *.fastq > count/B4363_Rm0.txt
agrep -0 -c 'GGTGCCAAACTAGTCGT' *.fastq > count/B4364_Rm0.txt
agrep -0 -c 'TTCTATCCGCACTACCC' *.fastq > count/B4365_Rm0.txt
agrep -0 -c 'AAGGAGGCCTAATCAGG' *.fastq > count/B4366_Rm0.txt
agrep -0 -c 'GCAATCTGGGTGTCTAA' *.fastq > count/B4367_Rm0.txt
agrep -0 -c 'TGGGCGTAAGGGTACTA' *.fastq > count/B4368_Rm0.txt
agrep -0 -c 'GGAACACCAAGCATTAC' *.fastq > count/B4369_Rm0.txt
agrep -0 -c 'GGGAAGATTCGATACTA' *.fastq > count/B4370_Rm0.txt
agrep -0 -c 'ATTGGACGAAAAGCGTT' *.fastq > count/B4372_Rm0.txt
agrep -0 -c 'TTTGTACCTGAGGCAGG' *.fastq > count/B4374_Rm0.txt
agrep -0 -c 'TACGCAATTGTGGTTAG' *.fastq > count/B4375_Rm0.txt
agrep -0 -c 'GTGTGACGGCTACTCAC' *.fastq > count/B4376_Rm0.txt
agrep -0 -c 'CGGAGACTATCGAGGAT' *.fastq > count/B4377_Rm0.txt
agrep -0 -c 'GGGCTCAGGTTAATCGA' *.fastq > count/B4378_Rm0.txt
agrep -0 -c 'AAACTTGATGAGGCCCC' *.fastq > count/B4379_Rm0.txt
agrep -0 -c 'AGACATGACGGTAACGA' *.fastq > count/B4380_Rm0.txt
agrep -0 -c 'CAAGCTGATCTTTCGCG' *.fastq > count/B4381_Rm0.txt
agrep -0 -c 'CAGCGGTTCTTCCGTTG' *.fastq > count/B4382_Rm0.txt
agrep -0 -c 'TGAAGGTTGTCCCGCTG' *.fastq > count/B4383_Rm0.txt
agrep -0 -c 'CTGGCATAGCGCAGGTT' *.fastq > count/B4384_Rm0.txt
agrep -0 -c 'TCTTTGCGAAATGCGAC' *.fastq > count/B4386_Rm0.txt
agrep -0 -c 'TTTAGAACATCTCGGTC' *.fastq > count/B4387_Rm0.txt
agrep -0 -c 'CTGCTGACGGACTCAAT' *.fastq > count/B4388_Rm0.txt
agrep -0 -c 'CCTGAGCATAAAAAGTG' *.fastq > count/B4389_Rm0.txt
agrep -0 -c 'CGGCCAAATCTGAACTC' *.fastq > count/B4390_Rm0.txt
agrep -0 -c 'TAAATCACCAACGGTGA' *.fastq > count/B4391_Rm0.txt
agrep -0 -c 'TACACATAGAGCCCCGA' *.fastq > count/B4393_Rm0.txt
agrep -0 -c 'ATAGCTTGCGGGTGATA' *.fastq > count/B4394_Rm0.txt
agrep -0 -c 'TATAGAGTACGCCACGC' *.fastq > count/B4396_Rm0.txt
agrep -0 -c 'GATTAGCATCCGTTGCC' *.fastq > count/B4398_Rm0.txt
agrep -0 -c 'CTCGATGCTACTTGTAA' *.fastq > count/B4399_Rm0.txt
agrep -0 -c 'CCATTCGGGCTTGACGT' *.fastq > count/B4400_Rm0.txt
agrep -0 -c 'CTTCTGGGCGGTTCAAC' *.fastq > count/B4401_Rm0.txt
agrep -0 -c 'TTTTGCAGAACGGACGA' *.fastq > count/B4404_Rm0.txt
agrep -0 -c 'CCTGCTTTGAGCGGTCT' *.fastq > count/B4405_Rm0.txt
agrep -0 -c 'TGTGATCAAAGCCTTGC' *.fastq > count/B4406_Rm0.txt
agrep -0 -c 'GGGTGATGCGCTCATAC' *.fastq > count/B4407_Rm0.txt
agrep -0 -c 'AATAGCTGTCGCACGTA' *.fastq > count/B4409_Rm0.txt
agrep -0 -c 'TTTGTTGTGTGTCGGGC' *.fastq > count/B4411_Rm0.txt
agrep -0 -c 'GCTACCCCAGCGCAAAT' *.fastq > count/B4412_Rm0.txt
agrep -0 -c 'CGATACCGTTGGTGATG' *.fastq > count/B4415_Rm0.txt
agrep -0 -c 'GCTGGATTGTATGCGAG' *.fastq > count/B4416_Rm0.txt
agrep -0 -c 'CCCGGATGACTCATGTC' *.fastq > count/B4417_Rm0.txt
agrep -0 -c 'AAACTATATGACCACCG' *.fastq > count/B4418_Rm0.txt
agrep -0 -c 'TATTCGCGTACAGGCAT' *.fastq > count/B4419_Rm0.txt
agrep -0 -c 'CGATGTAGCCATTCCAG' *.fastq > count/B4420_Rm0.txt
agrep -0 -c 'AAGGCCTCCTGCACTAC' *.fastq > count/B4421_Rm0.txt
agrep -0 -c 'CGATTCGATACTTGCCT' *.fastq > count/B4422_Rm0.txt
agrep -0 -c 'ACTTGTGATTGTGTCCT' *.fastq > count/B4424_Rm0.txt
agrep -0 -c 'TGACACGTCAGATGATA' *.fastq > count/B4426_Rm0.txt
agrep -0 -c 'TCCAGCATTACGTGGCG' *.fastq > count/B4427_Rm0.txt
agrep -0 -c 'GTATCGGACTAGCGTCA' *.fastq > count/B4429_Rm0.txt
agrep -0 -c 'TTAAAGACCGCCGAATT' *.fastq > count/B4430_Rm0.txt
agrep -0 -c 'ATTTTCGGCAATTAGCC' *.fastq > count/B4431_Rm0.txt
agrep -0 -c 'ATTGGCTCCCGGCTTGA' *.fastq > count/B4432_Rm0.txt
agrep -0 -c 'GATAAACCCCAGAAGGC' *.fastq > count/B4433_Rm0.txt
agrep -0 -c 'GGCAATACCGACCTAAC' *.fastq > count/B4434_Rm0.txt
agrep -0 -c 'AACTTACGGTGAAACGT' *.fastq > count/B4435_Rm0.txt
agrep -0 -c 'CGGAGCCTGAACCAATT' *.fastq > count/B4437_Rm0.txt
agrep -0 -c 'ACGGTCGGACAAACAGG' *.fastq > count/B4438_Rm0.txt
agrep -0 -c 'GGCTATCAGGAATGGAT' *.fastq > count/B4440_Rm0.txt
agrep -0 -c 'GTTTTACCGGAGATTAC' *.fastq > count/B4441_Rm0.txt
agrep -0 -c 'GACTCATATCCATCTGG' *.fastq > count/B4442_Rm0.txt
agrep -0 -c 'TGTTGACTGACTACTTG' *.fastq > count/B4443_Rm0.txt
agrep -0 -c 'GAGCGGTTGAAAATACT' *.fastq > count/B4444_Rm0.txt
agrep -0 -c 'GGGAGTCTTGAGTGCCT' *.fastq > count/B4445_Rm0.txt
agrep -0 -c 'ATGCTTCACCATTGTCT' *.fastq > count/B4446_Rm0.txt
agrep -0 -c 'TAAGACGTGATTGCAGT' *.fastq > count/B4447_Rm0.txt
agrep -0 -c 'TGTCAATAGTGTTGACC' *.fastq > count/B4448_Rm0.txt
agrep -0 -c 'GAAGTACTCAGCTCGAC' *.fastq > count/B4449_Rm0.txt
agrep -0 -c 'ATCCGGTCTTGGTTCCA' *.fastq > count/B4450_Rm0.txt
agrep -0 -c 'AGAACGTAGCAAGACGC' *.fastq > count/B4452_Rm0.txt
agrep -0 -c 'GGGAACGGTTAGTTCTT' *.fastq > count/B4453_Rm0.txt
agrep -0 -c 'GATAGCCCAACAGGGTG' *.fastq > count/B4455_Rm0.txt
agrep -0 -c 'AGGACACAATGCGAGTA' *.fastq > count/B4456_Rm0.txt
agrep -0 -c 'CACGAAAGGGCGATCAT' *.fastq > count/B4457_Rm0.txt
agrep -0 -c 'TAACACTTTGTCAACGC' *.fastq > count/B4458_Rm0.txt
agrep -0 -c 'TTGACCGCAACGCTTGT' *.fastq > count/B4459_Rm0.txt
agrep -0 -c 'TATACCACGAAAGGTGG' *.fastq > count/B4460_Rm0.txt
agrep -0 -c 'ACGCCGAGACTTTCATA' *.fastq > count/B4461_Rm0.txt
agrep -0 -c 'CCATCGTATCCCTCTGA' *.fastq > count/B4462_Rm0.txt
agrep -0 -c 'CGTACTGGTACACCTGT' *.fastq > count/B4463_Rm0.txt
agrep -0 -c 'TGGAACGAACGATTGAA' *.fastq > count/B4465_Rm0.txt
agrep -0 -c 'TCGGTCGTAATCGGTGT' *.fastq > count/B4467_Rm0.txt
agrep -0 -c 'TTCAGTCGCGTGAGGAC' *.fastq > count/B4468_Rm0.txt
agrep -0 -c 'AGGCTGCCTGACCAATA' *.fastq > count/B4469_Rm0.txt
agrep -0 -c 'TAGACCTTGATGGGGGT' *.fastq > count/B4470_Rm0.txt
agrep -0 -c 'TCGTAAATACGAGAGAC' *.fastq > count/B4471_Rm0.txt
agrep -0 -c 'CTCGGCACATCAGATAA' *.fastq > count/B4472_Rm0.txt
agrep -0 -c 'GGAAACCACCCTTCGAG' *.fastq > count/B4473_Rm0.txt
agrep -0 -c 'TTCTTACGCTTGAGCCT' *.fastq > count/B4474_Rm0.txt
agrep -0 -c 'TTAGTGGTCGGCAGGCT' *.fastq > count/B4475_Rm0.txt
agrep -0 -c 'ACTCTTGAACGGTGCGG' *.fastq > count/B4476_Rm0.txt
agrep -0 -c 'AGTATCCCGGTGCTCAT' *.fastq > count/B4477_Rm0.txt
agrep -0 -c 'CTTTTTCGGCGGAGTTG' *.fastq > count/B4478_Rm0.txt
agrep -0 -c 'ATCTAGGCGTAGTACGA' *.fastq > count/B4479_Rm0.txt
agrep -0 -c 'TGCCGTCCTCGCTATAC' *.fastq > count/B4481_Rm0.txt
agrep -0 -c 'CTCACTCATGAACTGAG' *.fastq > count/B4482_Rm0.txt
agrep -0 -c 'CGTTTGGTTCAACTCTG' *.fastq > count/B4483_Rm0.txt
agrep -0 -c 'CCAAGCTCGATTAGCGC' *.fastq > count/B4485_Rm0.txt
agrep -0 -c 'CAGGTTAACGAGGAGTT' *.fastq > count/B4487_Rm0.txt
agrep -0 -c 'ACCGGGATTCTTGCAGT' *.fastq > count/B4488_Rm0.txt
agrep -0 -c 'ACTTGCGGAGTAATCCA' *.fastq > count/B4489_Rm0.txt
agrep -0 -c 'ATTTGCCCGCTGGCAAG' *.fastq > count/B4491_Rm0.txt
agrep -0 -c 'CGAAGTAATACGGAGAA' *.fastq > count/B4492_Rm0.txt
agrep -0 -c 'CCGAACATGCGGGAAAC' *.fastq > count/B4494_Rm0.txt
agrep -0 -c 'AGACGGGCGGCATGATT' *.fastq > count/B4495_Rm0.txt
agrep -0 -c 'CCAAGGTTATAGCGCAT' *.fastq > count/B4496_Rm0.txt
agrep -0 -c 'GTAGGAAATAACACGAC' *.fastq > count/B4497_Rm0.txt
agrep -0 -c 'AACGACCCCATTTTAGG' *.fastq > count/B4498_Rm0.txt
agrep -0 -c 'TCTAGCCCGAAGTAATG' *.fastq > count/B4499_Rm0.txt
agrep -0 -c 'TGCGAGCAGTTCCCCTT' *.fastq > count/B4500_Rm0.txt
agrep -0 -c 'GGGCTATACTCTATTAC' *.fastq > count/B4501_Rm0.txt
agrep -0 -c 'TTTGAAGCCAAGCGGTT' *.fastq > count/B4502_Rm0.txt
agrep -0 -c 'CGTTGAGGAGAAGCTGT' *.fastq > count/B4504_Rm0.txt
agrep -0 -c 'TGTAGACCGAACGACGC' *.fastq > count/B4505_Rm0.txt
agrep -0 -c 'TCGTTTGATGTCTTACC' *.fastq > count/B4506_Rm0.txt
agrep -0 -c 'CTGGGGATTCATCGGAC' *.fastq > count/B4508_Rm0.txt
agrep -0 -c 'TACTACGAGTGTCCCAC' *.fastq > count/B4509_Rm0.txt
agrep -0 -c 'GTATCAGGTTATCGTAG' *.fastq > count/B4510_Rm0.txt
agrep -0 -c 'CCTCTGGCAACAATCGA' *.fastq > count/B4512_Rm0.txt
agrep -0 -c 'GGACGTACTGAGCAACG' *.fastq > count/B4514_Rm0.txt
agrep -0 -c 'GCGGACCAACTCTTTAT' *.fastq > count/B4515_Rm0.txt
agrep -0 -c 'ACACGTACTCGAAGCGT' *.fastq > count/B4517_Rm0.txt
agrep -0 -c 'AACGCGTTCAAAGAACC' *.fastq > count/B4518_Rm0.txt
agrep -0 -c 'ACCCTATCGTTTGATAG' *.fastq > count/B4519_Rm0.txt
agrep -0 -c 'GGATCTATAAGGACAGG' *.fastq > count/B4520_Rm0.txt
agrep -0 -c 'AGAAGACATAGTGGAGT' *.fastq > count/B4522_Rm0.txt
agrep -0 -c 'AGGCGGGTTAGGTGTAA' *.fastq > count/B4523_Rm0.txt
agrep -0 -c 'CTCGTTAGCTTTGGGGT' *.fastq > count/B4525_Rm0.txt
agrep -0 -c 'GCCGATCCATAAGGGTA' *.fastq > count/B4526_Rm0.txt
agrep -0 -c 'CTCTATTAGCTCCAAGG' *.fastq > count/B4527_Rm0.txt
agrep -0 -c 'GTGGTCTGATTTGATGG' *.fastq > count/B4528_Rm0.txt
agrep -0 -c 'CAGCGTTTAGCACTTAC' *.fastq > count/B4529_Rm0.txt
agrep -0 -c 'ACAGGGGTTACCGTTAC' *.fastq > count/B4530_Rm0.txt
agrep -0 -c 'GCTCCTTTACATGAAGG' *.fastq > count/B4531_Rm0.txt
agrep -0 -c 'TGGCATTAGCTGACCGA' *.fastq > count/B4532_Rm0.txt
agrep -0 -c 'ATACAAACCGCGCATCC' *.fastq > count/B4533_Rm0.txt
agrep -0 -c 'TGTCGACCTGACGACGT' *.fastq > count/B4534_Rm0.txt
agrep -0 -c 'CAGACTGTTTTCTCTTG' *.fastq > count/B4535_Rm0.txt
agrep -0 -c 'GGCTACTACTGGCGAAC' *.fastq > count/B4536_Rm0.txt
agrep -0 -c 'ATGCCCTGTTGGGCAAG' *.fastq > count/B4537_Rm0.txt
agrep -0 -c 'CCACACCTATGCATAGT' *.fastq > count/B4538_Rm0.txt
agrep -0 -c 'CAGCATAAGGCTGGTAC' *.fastq > count/B4539_Rm0.txt
agrep -0 -c 'TAGTGCCACGTTGTACT' *.fastq > count/B4540_Rm0.txt
agrep -0 -c 'AACCGTGGAGACTATAT' *.fastq > count/B4541_Rm0.txt
agrep -0 -c 'GGCAAATGATAACCGCC' *.fastq > count/B4542_Rm0.txt
agrep -0 -c 'TCGGTGCGAGATGGTTA' *.fastq > count/B4543_Rm0.txt
agrep -0 -c 'TGCCGGTGGTCACATAT' *.fastq > count/B4544_Rm0.txt
agrep -0 -c 'AGGCTCTACCAAGTTCC' *.fastq > count/B4545_Rm0.txt
agrep -0 -c 'GCCTGTTCAGTCAACCG' *.fastq > count/B4547_Rm0.txt
agrep -0 -c 'ATCCTAGGCGTTCATAA' *.fastq > count/B4548_Rm0.txt
agrep -0 -c 'GTAAAATGTGTCCGGAG' *.fastq > count/B4549_Rm0.txt
agrep -0 -c 'GCGCGTGATGTCGCATT' *.fastq > count/B4551_Rm0.txt
agrep -0 -c 'TTTTTGAATCTGGACGC' *.fastq > count/B4553_Rm0.txt
agrep -0 -c 'GTAACTTCGTACTGTAG' *.fastq > count/B4554_Rm0.txt
agrep -0 -c 'ATGGAGGTACTGCGGTG' *.fastq > count/B4556_Rm0.txt
agrep -0 -c 'GTAACTGGACTCGGGTA' *.fastq > count/B4558_Rm0.txt
agrep -0 -c 'CGCACTCTATGGTATCC' *.fastq > count/B4559_Rm0.txt
agrep -0 -c 'ATGGGGATACCATAGTG' *.fastq > count/B4561_Rm0.txt
agrep -0 -c 'CAACGGTAGGCACGGTT' *.fastq > count/B4562_Rm0.txt
agrep -0 -c 'ATTTCGCGCGAGTACAA' *.fastq > count/B4563_Rm0.txt
agrep -0 -c 'TATTCGTACCGCGGTAC' *.fastq > count/B4564_Rm0.txt
agrep -0 -c 'ATGTTGGAGTTCCTTCA' *.fastq > count/B4566_Rm0.txt
agrep -0 -c 'AGTTATACCGAACCATC' *.fastq > count/B4567_Rm0.txt
agrep -0 -c 'CGACCTTGCTGTACTGC' *.fastq > count/B4568_Rm0.txt
agrep -0 -c 'TTTAACGCGCATGGCAT' *.fastq > count/B4569_Rm0.txt
agrep -0 -c 'GGACCTTCTTCAGACTC' *.fastq > count/B4570_Rm0.txt
agrep -0 -c 'TACCGATCCGCTGAAAC' *.fastq > count/B4572_Rm0.txt
agrep -0 -c 'AAGTGAAGACACCCCTG' *.fastq > count/B4574_Rm0.txt
agrep -0 -c 'TGCATTACCAACGTTCG' *.fastq > count/B4575_Rm0.txt
agrep -0 -c 'CGTTCGAATAATCCATG' *.fastq > count/B4576_Rm0.txt
agrep -0 -c 'CATAGTTTGCCGAATCG' *.fastq > count/B4580_Rm0.txt
agrep -0 -c 'ACTGCGAATACTCGATC' *.fastq > count/B4581_Rm0.txt
agrep -0 -c 'TCAAGTGCGCACGTATT' *.fastq > count/B4583_Rm0.txt
agrep -0 -c 'GGTCTGAGTAATCTAGT' *.fastq > count/B4584_Rm0.txt
agrep -0 -c 'CCGAATCACGAACGACC' *.fastq > count/B4585_Rm0.txt
agrep -0 -c 'GTTCGAGGACCCAAATT' *.fastq > count/B4586_Rm0.txt
agrep -0 -c 'TCAGCGTAGTCCAACGA' *.fastq > count/B4587_Rm0.txt
agrep -0 -c 'GAACCCACGAGTAAGTC' *.fastq > count/B4589_Rm0.txt
agrep -0 -c 'GTGGCGAGGCGCTAATA' *.fastq > count/B4590_Rm0.txt
agrep -0 -c 'TAGGCCTTCCTATCAGT' *.fastq > count/B4591_Rm0.txt
agrep -0 -c 'CGACGTGAATGTTAGCA' *.fastq > count/B4592_Rm0.txt
agrep -0 -c 'AGGCACGTTGGATCGTG' *.fastq > count/B4593_Rm0.txt
agrep -0 -c 'TTGGTACACGGTTTGCG' *.fastq > count/B4594_Rm0.txt
agrep -0 -c 'TTTAGGCTTCGGCGACG' *.fastq > count/B4595_Rm0.txt
agrep -0 -c 'AATACGCGGTACGTATC' *.fastq > count/B4596_Rm0.txt
agrep -0 -c 'GAATACCAATGGGGCAC' *.fastq > count/B4597_Rm0.txt
agrep -0 -c 'ATACTTACCTCTACCGT' *.fastq > count/B4600_Rm0.txt
agrep -0 -c 'GGCCTCGTCATGACATT' *.fastq > count/B4601_Rm0.txt
agrep -0 -c 'GCGAGCTTTGAGATATA' *.fastq > count/B4602_Rm0.txt
agrep -0 -c 'TCGCCAGATACCAAGAA' *.fastq > count/B4604_Rm0.txt
agrep -0 -c 'GAGATAGGCCTTTGTGT' *.fastq > count/B4605_Rm0.txt
agrep -0 -c 'CTGAGGACAGTGTCTAC' *.fastq > count/B4606_Rm0.txt
agrep -0 -c 'CCGTAGCCTTAGTGTAA' *.fastq > count/B4607_Rm0.txt
agrep -0 -c 'TTGTCCTTGCATCCCTT' *.fastq > count/B4609_Rm0.txt
agrep -0 -c 'CTGCGATCAGTGCTCAG' *.fastq > count/B4610_Rm0.txt
agrep -0 -c 'AAACAACTGGGCTAGAT' *.fastq > count/B4611_Rm0.txt
agrep -0 -c 'CTCAGCTACTCCAATCG' *.fastq > count/B4612_Rm0.txt
agrep -0 -c 'GTAGCCGATATGCCGCA' *.fastq > count/B4613_Rm0.txt
agrep -0 -c 'CTCGGCAATCCAAATGG' *.fastq > count/B4614_Rm0.txt
agrep -0 -c 'GTTCAATTCCTCGGCCT' *.fastq > count/B4616_Rm0.txt
agrep -0 -c 'GTAAGTCTTCCGAGGCT' *.fastq > count/B4617_Rm0.txt
agrep -0 -c 'GGGTAAGCCAAGGGTAC' *.fastq > count/B4618_Rm0.txt
agrep -0 -c 'ATGACATCCGTAGAAGA' *.fastq > count/B4619_Rm0.txt
agrep -0 -c 'AACACTTCGACTTTCGA' *.fastq > count/B4620_Rm0.txt
agrep -0 -c 'AAATCTACCTTCGGGGC' *.fastq > count/B4621_Rm0.txt
agrep -0 -c 'GATGTAGGCGAACACTC' *.fastq > count/B4622_Rm0.txt
agrep -0 -c 'TTGATACGCATGCCTCA' *.fastq > count/B4623_Rm0.txt
agrep -0 -c 'AATCCAGCGTGACGCGT' *.fastq > count/B4624_Rm0.txt
agrep -0 -c 'GCATATCGCCTGTAGGT' *.fastq > count/B4625_Rm0.txt
agrep -0 -c 'CTCTCGAATGCTTGGCA' *.fastq > count/B4626_Rm0.txt
agrep -0 -c 'ACGTCGTATTCCAGTCG' *.fastq > count/B4627_Rm0.txt
agrep -0 -c 'ACCTTGGGTATCCTCTT' *.fastq > count/B4628_Rm0.txt
agrep -0 -c 'AAGCATTAGCAAACTGC' *.fastq > count/B4629_Rm0.txt
agrep -0 -c 'AAAGTTACTTCGGCGGC' *.fastq > count/B4630_Rm0.txt
agrep -0 -c 'TACGGATAATCGCTGTT' *.fastq > count/B4631_Rm0.txt
agrep -0 -c 'CTCTTCGTCAAAAGATG' *.fastq > count/B4633_Rm0.txt
agrep -0 -c 'AATATTGCTGCCTCCCG' *.fastq > count/B4634_Rm0.txt
agrep -0 -c 'GACACCCAGGAAAATCT' *.fastq > count/B4635_Rm0.txt
agrep -0 -c 'AGCGGGTAACCATCAGT' *.fastq > count/B4636_Rm0.txt
agrep -0 -c 'TTATAGTCTGTAACCGG' *.fastq > count/B4637_Rm0.txt
agrep -0 -c 'GTACATTCGGGAAGAAG' *.fastq > count/B4639_Rm0.txt
agrep -0 -c 'TAGTCCGCCAACTGGAT' *.fastq > count/B4642_Rm0.txt
agrep -0 -c 'CCCAGGTCCGACATTAC' *.fastq > count/B4643_Rm0.txt
agrep -0 -c 'CCCCATGTCGTCACTCT' *.fastq > count/B4644_Rm0.txt
agrep -0 -c 'ACGGAGACATTACGGAG' *.fastq > count/B4645_Rm0.txt
agrep -0 -c 'AGGCCAAAACTAAGGCC' *.fastq > count/B4646_Rm0.txt
agrep -0 -c 'TCTGCAGATATTCCGAG' *.fastq > count/B4647_Rm0.txt
agrep -0 -c 'TGATGCCAACTCCGACT' *.fastq > count/B4648_Rm0.txt
agrep -0 -c 'CCGGACTTCGTAACCAG' *.fastq > count/B4649_Rm0.txt
agrep -0 -c 'CCGTGGATCCCGATGAT' *.fastq > count/B4650_Rm0.txt
agrep -0 -c 'CGCCAAGATTAGAGATA' *.fastq > count/B4651_Rm0.txt
agrep -0 -c 'TGGGTACCCGACATCTT' *.fastq > count/B4653_Rm0.txt
agrep -0 -c 'ATTTCCGTCGGACTTAA' *.fastq > count/B4654_Rm0.txt
agrep -0 -c 'GTCCTGGTTTAAGGAGC' *.fastq > count/B4655_Rm0.txt
agrep -0 -c 'ACGTCGAGCCTATGAAT' *.fastq > count/B4656_Rm0.txt
agrep -0 -c 'ATCAACTCAGTGAAACG' *.fastq > count/B4657_Rm0.txt
agrep -0 -c 'AGCAGGAGATATATCTC' *.fastq > count/B4659_Rm0.txt
agrep -0 -c 'TCGCAACTCCAAGGATG' *.fastq > count/B4660_Rm0.txt
agrep -0 -c 'AAGATCTGGTTGCGACG' *.fastq > count/B4661_Rm0.txt
agrep -0 -c 'ATTGTACCGGGAGTATC' *.fastq > count/B4662_Rm0.txt
agrep -0 -c 'CTATCAAGGTCCTGACA' *.fastq > count/B4663_Rm0.txt
agrep -0 -c 'ACTCGAATAATGCCTCC' *.fastq > count/B4665_Rm0.txt
agrep -0 -c 'CATGTTCCCAGCGATAA' *.fastq > count/B4666_Rm0.txt
agrep -0 -c 'TGCGTGCGACTGGTTAA' *.fastq > count/B4668_Rm0.txt
agrep -0 -c 'GCGTGAACTCATTCTCA' *.fastq > count/B4669_Rm0.txt
agrep -0 -c 'GTGTGCCACTGCCTTTA' *.fastq > count/B4671_Rm0.txt
agrep -0 -c 'AACCCAATGGATTCCAC' *.fastq > count/B4672_Rm0.txt
agrep -0 -c 'TTGGACCGGACCTCAAC' *.fastq > count/B4673_Rm0.txt
agrep -0 -c 'TGACCATGGGGGATAAG' *.fastq > count/B4674_Rm0.txt
agrep -0 -c 'ACAAAAGCGGCAGTGAT' *.fastq > count/B4675_Rm0.txt
agrep -0 -c 'GCCTCAGTTAGACGTCA' *.fastq > count/B4676_Rm0.txt
agrep -0 -c 'TGCAATCCGCGATCGCT' *.fastq > count/B4677_Rm0.txt
agrep -0 -c 'GCATAACGGCATGACCG' *.fastq > count/B4678_Rm0.txt
agrep -0 -c 'TCTAGGTAGGTCAAGAT' *.fastq > count/B4679_Rm0.txt
agrep -0 -c 'GCCCACCCTAAGTCAAG' *.fastq > count/B4680_Rm0.txt
agrep -0 -c 'AACACGAGTCCGTCATG' *.fastq > count/B4681_Rm0.txt
agrep -0 -c 'TTTCTCGAACGACAGGT' *.fastq > count/B4682_Rm0.txt
agrep -0 -c 'TACTTGCTTTACGTCCG' *.fastq > count/B4683_Rm0.txt
agrep -0 -c 'CGCTGCCAACAATTACA' *.fastq > count/B4684_Rm0.txt
agrep -0 -c 'GCATTAATTCACAGCCA' *.fastq > count/B4685_Rm0.txt
agrep -0 -c 'GCAATACCAACAGTCGG' *.fastq > count/B4687_Rm0.txt
agrep -0 -c 'GGGATCCGTTTGAGTCA' *.fastq > count/B4689_Rm0.txt
agrep -0 -c 'TTTAACGAGTACGTAGC' *.fastq > count/B4690_Rm0.txt
agrep -0 -c 'TGGCTAGAGTGCTACAA' *.fastq > count/B4691_Rm0.txt
agrep -0 -c 'TTGCATCATGAGGGCTA' *.fastq > count/B4693_Rm0.txt
agrep -0 -c 'GTCTGGACAGAGTGTAC' *.fastq > count/B4694_Rm0.txt
agrep -0 -c 'AACGGGCGGTATAACTT' *.fastq > count/B4695_Rm0.txt
agrep -0 -c 'TAACCGTCAGCCAAGTC' *.fastq > count/B4696_Rm0.txt
agrep -0 -c 'TTCGGCGTTTCCCGATT' *.fastq > count/B4697_Rm0.txt
agrep -0 -c 'GCACGCGAAATAAGACG' *.fastq > count/B4698_Rm0.txt
agrep -0 -c 'GATTGGAGAAATTGTCG' *.fastq > count/B4699_Rm0.txt
agrep -0 -c 'TTGTGGCCGTACGAATG' *.fastq > count/B4700_Rm0.txt
agrep -0 -c 'TCCGAATGTTTATTGCG' *.fastq > count/B4701_Rm0.txt
agrep -0 -c 'TGATGACTAGTTTGCCC' *.fastq > count/B4702_Rm0.txt
agrep -0 -c 'GTACATAGACAAATGGC' *.fastq > count/B4704_Rm0.txt
agrep -0 -c 'TCGTGGCGCCAATGTCT' *.fastq > count/B4705_Rm0.txt
agrep -0 -c 'ACCATGCCTTTCGCAGC' *.fastq > count/B4706_Rm0.txt
agrep -0 -c 'TGTACGAACGGCGCTCA' *.fastq > count/B4707_Rm0.txt
agrep -0 -c 'ATGGTGACCTATTGTAG' *.fastq > count/B4708_Rm0.txt
agrep -0 -c 'AGTCTTTGAGTAACGGC' *.fastq > count/B4710_Rm0.txt
agrep -0 -c 'TAGAGGGGTCTTAACTC' *.fastq > count/B4712_Rm0.txt
agrep -0 -c 'ATTCGCATTATCTGACG' *.fastq > count/B4713_Rm0.txt
agrep -0 -c 'AAGATGGCTACGCTAAT' *.fastq > count/B4714_Rm0.txt
agrep -0 -c 'GTACGTTAGCTCCTAGC' *.fastq > count/B4716_Rm0.txt
agrep -0 -c 'CCAATACGCATCCATAC' *.fastq > count/B4717_Rm0.txt
agrep -0 -c 'TTAGAGTTGTCGCTTGT' *.fastq > count/B4719_Rm0.txt
agrep -0 -c 'CAAAACCTAAAAGTCCG' *.fastq > count/B4720_Rm0.txt
agrep -0 -c 'TGACGCGAGTCAGTAGA' *.fastq > count/B4721_Rm0.txt
agrep -0 -c 'ATATCTATTGGGGCTCA' *.fastq > count/B4722_Rm0.txt
agrep -0 -c 'CTAGATAGAACGCTCGT' *.fastq > count/B4723_Rm0.txt
agrep -0 -c 'TATCTTAGCAAAGCTCC' *.fastq > count/B4724_Rm0.txt
agrep -0 -c 'TGAAGATACCGTTCCTA' *.fastq > count/B4726_Rm0.txt
agrep -0 -c 'GGAAAAGTTTGACACGG' *.fastq > count/B4727_Rm0.txt
agrep -0 -c 'TTTACCAACACCATTCC' *.fastq > count/B4728_Rm0.txt
agrep -0 -c 'TCTGGTACGCCTCTTTG' *.fastq > count/B4729_Rm0.txt
agrep -0 -c 'GATGGAACTAGTCTCTT' *.fastq > count/B4731_Rm0.txt
agrep -0 -c 'CGCCTAAAATTTGCTGG' *.fastq > count/B4732_Rm0.txt
agrep -0 -c 'CTACTTCAATTGCGATG' *.fastq > count/B4733_Rm0.txt
agrep -0 -c 'CCGTGGTGCTGATATCC' *.fastq > count/B4734_Rm0.txt
agrep -0 -c 'CTTGTTCGTGAAGTCAA' *.fastq > count/B4735_Rm0.txt
agrep -0 -c 'CGCCACTTTATGAGATG' *.fastq > count/B4736_Rm0.txt
agrep -0 -c 'GTCGTCTGGGACGGTTA' *.fastq > count/B4737_Rm0.txt
agrep -0 -c 'CATATACTCCAACCGTG' *.fastq > count/B4738_Rm0.txt
agrep -0 -c 'CGGCCGCCATTATACTC' *.fastq > count/B4739_Rm0.txt
agrep -0 -c 'GCTCAAAGTCTTCCTAA' *.fastq > count/B4740_Rm0.txt
agrep -0 -c 'TATCAGCTAGCGCAACG' *.fastq > count/B4741_Rm0.txt
agrep -0 -c 'TGGGTCTAGAGTTACGC' *.fastq > count/B4742_Rm0.txt
agrep -0 -c 'CTCGACGTTCGGTTGCA' *.fastq > count/B4743_Rm0.txt
agrep -0 -c 'CAAAATTGGCGTGATCT' *.fastq > count/B4744_Rm0.txt
agrep -0 -c 'ATCAGCTTCTTCCTACC' *.fastq > count/B4745_Rm0.txt
agrep -0 -c 'CCAACACACTAGGAGGC' *.fastq > count/B4746_Rm0.txt
agrep -0 -c 'AGAGTGTAACTCTGAAG' *.fastq > count/B4747_Rm0.txt
agrep -0 -c 'GTTGATCCCTACTTATC' *.fastq > count/B4750_Rm0.txt
agrep -0 -c 'GTAAGTGGAAGGCGTAA' *.fastq > count/B4752_Rm0.txt
agrep -0 -c 'AGACCCAAATCCTATCG' *.fastq > count/B4753_Rm0.txt
agrep -0 -c 'GTGCTTCGTTCTGATCG' *.fastq > count/B4757_Rm0.txt
agrep -0 -c 'ACCTACGTGCAGGTATT' *.fastq > count/B4758_Rm0.txt
agrep -0 -c 'TCACCGACCAAGACCAG' *.fastq > count/B4759_Rm0.txt
agrep -0 -c 'AACGCCACCTTGAATCT' *.fastq > count/B4762_Rm0.txt
agrep -0 -c 'CAGAAAATCACTGTCGC' *.fastq > count/B4763_Rm0.txt
agrep -0 -c 'GACGCGTTGATTTACCG' *.fastq > count/B4765_Rm0.txt
agrep -0 -c 'ACAAGGTGACAACACGT' *.fastq > count/B4766_Rm0.txt
agrep -0 -c 'GATGTGGTCAGGTGGTC' *.fastq > count/B4769_Rm0.txt
agrep -0 -c 'ATGGTGCTAAACCCGAT' *.fastq > count/B4770_Rm0.txt
agrep -0 -c 'CAGAATTTTGCCCGTAC' *.fastq > count/B4771_Rm0.txt
agrep -0 -c 'AACCAGAGTAGGCAATC' *.fastq > count/B4772_Rm0.txt
agrep -0 -c 'TAATCACGTGCTTTGCC' *.fastq > count/B4773_Rm0.txt
agrep -0 -c 'TGTCACAGATAGAACGC' *.fastq > count/B4774_Rm0.txt
agrep -0 -c 'TTAAGCGCGGGAGTTGA' *.fastq > count/B4775_Rm0.txt
agrep -0 -c 'TGTGTTTCCTCCGGGTA' *.fastq > count/B4776_Rm0.txt
agrep -0 -c 'TTGATAAGTTCGGTTCC' *.fastq > count/B4780_Rm0.txt
agrep -0 -c 'TCGTTTCCGATTCATCT' *.fastq > count/B4781_Rm0.txt
agrep -0 -c 'CAGTGCCACGATTGGAA' *.fastq > count/B4782_Rm0.txt
agrep -0 -c 'CATACTTTCACGCCCGG' *.fastq > count/B4783_Rm0.txt
agrep -0 -c 'TCTCATAAGTACGGACT' *.fastq > count/B4784_Rm0.txt
agrep -0 -c 'ATCCTAGGTTGGGAATC' *.fastq > count/B4785_Rm0.txt
agrep -0 -c 'GGGTTCAGCCCTTTGAG' *.fastq > count/B4786_Rm0.txt
agrep -0 -c 'CACGGATACGATGTGAT' *.fastq > count/B4787_Rm0.txt
agrep -0 -c 'AATTTTCCGCGCAGGTC' *.fastq > count/B4789_Rm0.txt
agrep -0 -c 'AAGCTATTCGGAACTCT' *.fastq > count/B4790_Rm0.txt
agrep -0 -c 'TATTTTCCTCGCAGCGC' *.fastq > count/B4791_Rm0.txt
agrep -0 -c 'GCTCAGAACACTACTAT' *.fastq > count/B4792_Rm0.txt
agrep -0 -c 'GCAGCCGAGTTCAAGAT' *.fastq > count/B4793_Rm0.txt
agrep -0 -c 'TGAGGCGGGTAAGTGTC' *.fastq > count/B4794_Rm0.txt
agrep -0 -c 'AGTATAAGACGCCGAAG' *.fastq > count/B4795_Rm0.txt
agrep -0 -c 'AAGGCAGGAGAAGTTAT' *.fastq > count/B4796_Rm0.txt
agrep -0 -c 'TGGATTGGTGCGTGACT' *.fastq > count/B4797_Rm0.txt
agrep -0 -c 'GGACTCAATGAACAGGC' *.fastq > count/B4799_Rm0.txt
agrep -0 -c 'TACGAAGGTGCTGGACG' *.fastq > count/B4800_Rm0.txt
agrep -0 -c 'AAAGGTGCAGCGATCCG' *.fastq > count/B4801_Rm0.txt
agrep -0 -c 'ACAATTCGCAACCTCCC' *.fastq > count/B4802_Rm0.txt
agrep -0 -c 'ACAACATTGCCTTAGTC' *.fastq > count/B4803_Rm0.txt
agrep -0 -c 'TATGTGTTTGTCGCTCC' *.fastq > count/B4804_Rm0.txt
agrep -0 -c 'TCAAGAAATGGCAGTTG' *.fastq > count/B4806_Rm0.txt
agrep -0 -c 'AATCGTCCTAAGAAGCG' *.fastq > count/B4807_Rm0.txt
agrep -0 -c 'ATGGTATCTTGCATACC' *.fastq > count/B4809_Rm0.txt
agrep -0 -c 'AAGCCATGATGTAGACC' *.fastq > count/B4810_Rm0.txt
agrep -0 -c 'AATGGGACTAGTCCAAC' *.fastq > count/B4811_Rm0.txt
agrep -0 -c 'AAGTTAGTGCCCACGTT' *.fastq > count/B4812_Rm0.txt
agrep -0 -c 'GTCTCCCATGATGCTAC' *.fastq > count/B4816_Rm0.txt
agrep -0 -c 'GTGCCCATGGTCGAATA' *.fastq > count/B4817_Rm0.txt
agrep -0 -c 'TCCCCCGTTGGATCACT' *.fastq > count/B4818_Rm0.txt
agrep -0 -c 'AGTGAGCATACTGCTCG' *.fastq > count/B4819_Rm0.txt
agrep -0 -c 'ATCGTATTCTACGTTCC' *.fastq > count/B4820_Rm0.txt
agrep -0 -c 'TTGGACTTCACAACGTG' *.fastq > count/B4821_Rm0.txt
agrep -0 -c 'CAAAGGCAACTTCTAAC' *.fastq > count/B4822_Rm0.txt
agrep -0 -c 'ATATTCACTTCTCCTGC' *.fastq > count/B4823_Rm0.txt
agrep -0 -c 'TCTTAGGTTGGCGAAAT' *.fastq > count/B4825_Rm0.txt
agrep -0 -c 'CACGAGGAAAAAGTTGC' *.fastq > count/B4826_Rm0.txt
agrep -0 -c 'TATCGGGCGTCCTATAG' *.fastq > count/B4827_Rm0.txt
agrep -0 -c 'CGATTTAAGATCGCTCA' *.fastq > count/B4828_Rm0.txt
agrep -0 -c 'CCCCAGGTTAACCGTCT' *.fastq > count/B4829_Rm0.txt
agrep -0 -c 'TAGTGCTGACTGCCGTT' *.fastq > count/B4830_Rm0.txt
agrep -0 -c 'CTTACGGTTCTCTGCGC' *.fastq > count/B4831_Rm0.txt
agrep -0 -c 'TCTAGTAACGAAGACGC' *.fastq > count/B4833_Rm0.txt
agrep -0 -c 'TCGATCCGTTTCGGCCT' *.fastq > count/B4834_Rm0.txt
agrep -0 -c 'ACAGTTTTTTGGACAGC' *.fastq > count/B4835_Rm0.txt
agrep -0 -c 'TCCTTACCCCCGGCATT' *.fastq > count/B4836_Rm0.txt
agrep -0 -c 'AATCAATGCTACCGATC' *.fastq > count/B4838_Rm0.txt
agrep -0 -c 'GAGAGTTGCATAGCGTT' *.fastq > count/B4839_Rm0.txt
agrep -0 -c 'GGTCGATTTTCGACCTT' *.fastq > count/B4840_Rm0.txt
agrep -0 -c 'AATGCGTTAGGGGATAT' *.fastq > count/B4841_Rm0.txt
agrep -0 -c 'CATAAGTTAGGTCGAGT' *.fastq > count/B4842_Rm0.txt
agrep -0 -c 'CGTTGAACGATGGACAC' *.fastq > count/B4844_Rm0.txt
agrep -0 -c 'CGCGTATAATCGCTTTG' *.fastq > count/B4845_Rm0.txt
agrep -0 -c 'TACTGTGTAGTCACCAC' *.fastq > count/B4846_Rm0.txt
agrep -0 -c 'CCTCTTGGACAACCTGG' *.fastq > count/B4847_Rm0.txt
agrep -0 -c 'CGAACGTAACACTGGCG' *.fastq > count/B4848_Rm0.txt
agrep -0 -c 'ACGTCCTTATCCGACGG' *.fastq > count/B4850_Rm0.txt
agrep -0 -c 'CGAGGAAGGCATAAGTA' *.fastq > count/B4851_Rm0.txt
agrep -0 -c 'CGAATCCTGTCCGTAAT' *.fastq > count/B4852_Rm0.txt
agrep -0 -c 'TCGACAAACCGCGTGAA' *.fastq > count/B4854_Rm0.txt
agrep -0 -c 'CACTTCTCGCTCTGATA' *.fastq > count/B4855_Rm0.txt
agrep -0 -c 'ACTCATCGTGAGCTGGC' *.fastq > count/B4856_Rm0.txt
agrep -0 -c 'CCGTATATTGGGTTCCG' *.fastq > count/B4857_Rm0.txt
agrep -0 -c 'CCCCCACTTAGATTCGG' *.fastq > count/B4859_Rm0.txt
agrep -0 -c 'TCCAATTTTGTCCCTCG' *.fastq > count/B4860_Rm0.txt
agrep -0 -c 'ACGGTAAGGGTCACTAG' *.fastq > count/B4861_Rm0.txt
agrep -0 -c 'CGTCATGGCTATCGATC' *.fastq > count/B4862_Rm0.txt
agrep -0 -c 'GTTCCTATCTCAGTGCG' *.fastq > count/B4863_Rm0.txt
agrep -0 -c 'GAAACAACTCTCGTTGT' *.fastq > count/B4865_Rm0.txt
agrep -0 -c 'AAAGTAGCCACCTATTG' *.fastq > count/B4866_Rm0.txt
agrep -0 -c 'CGTACTTAGTAGCCGAG' *.fastq > count/B4867_Rm0.txt
agrep -0 -c 'GGAAACAGCAACCGGAG' *.fastq > count/B4868_Rm0.txt
agrep -0 -c 'ACATCTACTAGACCTGA' *.fastq > count/B4869_Rm0.txt
agrep -0 -c 'TACTCCAGATCGGAGAC' *.fastq > count/B4871_Rm0.txt
agrep -0 -c 'ACACCAGTTCCTCCTAA' *.fastq > count/B4872_Rm0.txt
agrep -0 -c 'TGATGGGAGCGGAATGT' *.fastq > count/B4873_Rm0.txt
agrep -0 -c 'TCTTCGTTAAACCGCTG' *.fastq > count/B4875_Rm0.txt
agrep -0 -c 'GCTTGTATTAAGGTAGC' *.fastq > count/B4876_Rm0.txt
agrep -0 -c 'GCTCGTACAGGTGACAC' *.fastq > count/B4877_Rm0.txt
agrep -0 -c 'AGTGAGGGAGCGTTTGG' *.fastq > count/B4878_Rm0.txt
agrep -0 -c 'CTGAAGCGTAATTCTCC' *.fastq > count/B4879_Rm0.txt
agrep -0 -c 'ACCTGACATGGATTCGC' *.fastq > count/B4881_Rm0.txt
agrep -0 -c 'TAGGATTCAGTAGACCC' *.fastq > count/B4882_Rm0.txt
agrep -0 -c 'AACGCCTCTATATGAGT' *.fastq > count/B4883_Rm0.txt
agrep -0 -c 'TTAGAGTGCATCTTCCT' *.fastq > count/B4884_Rm0.txt
agrep -0 -c 'AAAATCCCGTTCGGAAC' *.fastq > count/B4885_Rm0.txt
agrep -0 -c 'TGGGAACTACTCGTGAC' *.fastq > count/B4886_Rm0.txt
agrep -0 -c 'CGAATCTAGTCGAGTCA' *.fastq > count/B4887_Rm0.txt
agrep -0 -c 'GATCAGATCGTGTATGA' *.fastq > count/B4888_Rm0.txt
agrep -0 -c 'CAAACCGCGACGTTCTT' *.fastq > count/B4889_Rm0.txt
agrep -0 -c 'GCTCTCGTGGAATCCAC' *.fastq > count/B4890_Rm0.txt
agrep -0 -c 'ATCCGGACTTATTGGCT' *.fastq > count/B4891_Rm0.txt
agrep -0 -c 'GGATCGAGACTGCCAAG' *.fastq > count/B4892_Rm0.txt
agrep -0 -c 'ATAAGTCAACGCGGGCC' *.fastq > count/B4894_Rm0.txt
agrep -0 -c 'CGCTCGATAAAGTTAGA' *.fastq > count/B4896_Rm0.txt
agrep -0 -c 'AGCTGCTACGGGGAATT' *.fastq > count/B4897_Rm0.txt
agrep -0 -c 'GCGATTCTCTGCGTCAG' *.fastq > count/B4898_Rm0.txt
agrep -0 -c 'CGTTCTGAGAGTGGAAG' *.fastq > count/B4899_Rm0.txt
agrep -0 -c 'GTGTTGTATCCCATGTG' *.fastq > count/B4900_Rm0.txt
agrep -0 -c 'TTCTCACGAGTGTCAAC' *.fastq > count/B4901_Rm0.txt
agrep -0 -c 'AAACTAGACCGTCTCGC' *.fastq > count/B4902_Rm0.txt
agrep -0 -c 'CTAAGCTGACGACGAAC' *.fastq > count/B4904_Rm0.txt
agrep -0 -c 'AACGCCGTTGTTTACGT' *.fastq > count/B4905_Rm0.txt
agrep -0 -c 'CTTGGTTTTACATGGCT' *.fastq > count/B4906_Rm0.txt
agrep -0 -c 'CATTCATGGACGTCTTA' *.fastq > count/B4907_Rm0.txt
agrep -0 -c 'ACCTGTTACGTGCTCGG' *.fastq > count/B4909_Rm0.txt
agrep -0 -c 'TACAATTGGGTACTAGG' *.fastq > count/B4910_Rm0.txt
agrep -0 -c 'GGCCGAAAGCAACTCTA' *.fastq > count/B4911_Rm0.txt
agrep -0 -c 'TGCGCTTATAACTGGTG' *.fastq > count/B4912_Rm0.txt
agrep -0 -c 'AGTATAATGCAGCCACA' *.fastq > count/B4913_Rm0.txt
agrep -0 -c 'GTCGTCGCTGAACGTAT' *.fastq > count/B4914_Rm0.txt
agrep -0 -c 'GAGAAGGACCGGGAGTA' *.fastq > count/B4915_Rm0.txt
agrep -0 -c 'AGTAGGATTGCCGCCGT' *.fastq > count/B4916_Rm0.txt
agrep -0 -c 'ATAGTATTGCGAGGTAC' *.fastq > count/B4918_Rm0.txt
agrep -0 -c 'TCGGCCCTGTCATCGTT' *.fastq > count/B4919_Rm0.txt
agrep -0 -c 'AAAGGCTGCATTCGACG' *.fastq > count/B4920_Rm0.txt
agrep -0 -c 'AAAAGCGGGGATGCTGT' *.fastq > count/B4921_Rm0.txt
agrep -0 -c 'GCAACTAATTCGCCTTG' *.fastq > count/B4922_Rm0.txt
agrep -0 -c 'TGCTTTAGGAAACGGGC' *.fastq > count/B4923_Rm0.txt
agrep -0 -c 'CGAACAGGTGTGCGCTA' *.fastq > count/B4924_Rm0.txt
agrep -0 -c 'TCGATACACTGGCGGTT' *.fastq > count/B4925_Rm0.txt
agrep -0 -c 'ATTACCGGGTAAGGCAA' *.fastq > count/B4926_Rm0.txt
agrep -0 -c 'GAGGCTGGTAGATTGTG' *.fastq > count/B4927_Rm0.txt
agrep -0 -c 'ATTGCAGCAATCTAACC' *.fastq > count/B4928_Rm0.txt
agrep -0 -c 'ATAGGAATGCAGGTTAG' *.fastq > count/B4929_Rm0.txt
agrep -0 -c 'TTGAGTCCGATCATGCC' *.fastq > count/B4930_Rm0.txt
agrep -0 -c 'CATCTACAAGGTCATCA' *.fastq > count/B4932_Rm0.txt
agrep -0 -c 'TCCGCTAAGTGACCAAG' *.fastq > count/B4933_Rm0.txt
agrep -0 -c 'CACATTAGGTAGTCACC' *.fastq > count/B4936_Rm0.txt
agrep -0 -c 'GCCTTCTTACGGTGTTG' *.fastq > count/B4937_Rm0.txt
agrep -0 -c 'ATGAGGGAGGGTTCGAC' *.fastq > count/B4938_Rm0.txt
agrep -0 -c 'GGGATGTTGTGAGACTG' *.fastq > count/B4939_Rm0.txt
agrep -0 -c 'ACACAGGACGTCCAACT' *.fastq > count/B4940_Rm0.txt
agrep -0 -c 'CGGGAAGGAACTTAAGA' *.fastq > count/B4941_Rm0.txt
agrep -0 -c 'TCGCCGGAATTTTTTGA' *.fastq > count/B4942_Rm0.txt
agrep -0 -c 'TTGCCAAACTGAGCTCA' *.fastq > count/B4943_Rm0.txt
agrep -0 -c 'GTACATATCTCACGGTT' *.fastq > count/B4944_Rm0.txt
agrep -0 -c 'GTACGCAATGGTACTCC' *.fastq > count/B4945_Rm0.txt
agrep -0 -c 'ATTTCCTTCGCTAGTTG' *.fastq > count/B4946_Rm0.txt
agrep -0 -c 'GACCGGGACTAGTTGCT' *.fastq > count/B4947_Rm0.txt
agrep -0 -c 'ACCATCAAGTGGGAGGT' *.fastq > count/B4948_Rm0.txt
agrep -0 -c 'AATCCATACGATGAGTC' *.fastq > count/B4950_Rm0.txt
agrep -0 -c 'ATCCGGGCATTCTTCTG' *.fastq > count/B4951_Rm0.txt
agrep -0 -c 'TTGACGGCGGTCAGTAT' *.fastq > count/B4952_Rm0.txt
agrep -0 -c 'AGCTACTAGGCAAGTCG' *.fastq > count/B4954_Rm0.txt
agrep -0 -c 'CTGCTCTTCATGAATTG' *.fastq > count/B4955_Rm0.txt
agrep -0 -c 'CTAGCCTCTTTCAACGT' *.fastq > count/B4956_Rm0.txt
agrep -0 -c 'CACTAGTTTCGCTTGCA' *.fastq > count/B4958_Rm0.txt
agrep -0 -c 'AACATGTCGTACGTACT' *.fastq > count/B4959_Rm0.txt
agrep -0 -c 'GACCACATAAGCCAAGT' *.fastq > count/B4960_Rm0.txt
agrep -0 -c 'ACGTCAATCTTTCACGA' *.fastq > count/B4962_Rm0.txt
agrep -0 -c 'CGGATCGCTCAAGTTGT' *.fastq > count/B4963_Rm0.txt
agrep -0 -c 'AACGTTAGCACGGGCTG' *.fastq > count/B4964_Rm0.txt
agrep -0 -c 'GCAGTAGGATTGGGAAC' *.fastq > count/B4965_Rm0.txt
agrep -0 -c 'ATACGCATTTCCGCAGA' *.fastq > count/B4966_Rm0.txt
agrep -0 -c 'TTACGTAGTGCCAATCC' *.fastq > count/B4968_Rm0.txt
agrep -0 -c 'CGTGATATTTTGTAGCG' *.fastq > count/B4969_Rm0.txt
agrep -0 -c 'GGGCAAAAAGAAAGTCG' *.fastq > count/B4970_Rm0.txt
agrep -0 -c 'TAAGTCCGATGTACATC' *.fastq > count/B4971_Rm0.txt
agrep -0 -c 'GCCGACGCCCTTTTACT' *.fastq > count/B4972_Rm0.txt
agrep -0 -c 'GCATTCATTGACTTGGC' *.fastq > count/B4974_Rm0.txt
agrep -0 -c 'TAGGCCGATCAGGCACT' *.fastq > count/B4975_Rm0.txt
agrep -0 -c 'TGATAGAAGTGTGCCAA' *.fastq > count/B4976_Rm0.txt
agrep -0 -c 'TCTGCTCGCGGGTAATA' *.fastq > count/B4977_Rm0.txt
agrep -0 -c 'TACACGATCATAGCTAG' *.fastq > count/B4978_Rm0.txt
agrep -0 -c 'AGTCTTTGTCGTGGGTT' *.fastq > count/B4979_Rm0.txt
agrep -0 -c 'CAAAGACCAAGCCTACA' *.fastq > count/B4980_Rm0.txt
agrep -0 -c 'CGGACATTACGAGTCGC' *.fastq > count/B4981_Rm0.txt
agrep -0 -c 'CTATACGAAGCCAGTAC' *.fastq > count/B4983_Rm0.txt
agrep -0 -c 'AGGTTTGTCAACTTAGG' *.fastq > count/B4986_Rm0.txt
agrep -0 -c 'AACTGAGGACGATTGCT' *.fastq > count/B4987_Rm0.txt
agrep -0 -c 'TTTGACGATTGGCCGTG' *.fastq > count/B4989_Rm0.txt
agrep -0 -c 'TACTTCTGTGGATAGCA' *.fastq > count/B4990_Rm0.txt
agrep -0 -c 'AGGACTCCGTTATCCAT' *.fastq > count/B4991_Rm0.txt
agrep -0 -c 'GCCCATTAGGGTCTGTG' *.fastq > count/B4992_Rm0.txt
agrep -0 -c 'CGACCCAGCGATACGTT' *.fastq > count/B4993_Rm0.txt
agrep -0 -c 'CCTGGAACTGTAGCCGT' *.fastq > count/B4995_Rm0.txt
agrep -0 -c 'TGAGAAGCACTTGTGAG' *.fastq > count/B4996_Rm0.txt
agrep -0 -c 'CTACGGGGCCAGGTTTA' *.fastq > count/B4997_Rm0.txt
agrep -0 -c 'AATGTGAAGCGATTCCG' *.fastq > count/B4998_Rm0.txt
agrep -0 -c 'ATGGTGACGATACCAAT' *.fastq > count/B4999_Rm0.txt
agrep -0 -c 'GCGGCCTTTCACATTCC' *.fastq > count/B5001_Rm0.txt
agrep -0 -c 'GATCAAACTTGCGAGGC' *.fastq > count/B5002_Rm0.txt
agrep -0 -c 'GTACGACCCTACCTGTG' *.fastq > count/B5003_Rm0.txt
agrep -0 -c 'TGCAGATACCTTGAAGG' *.fastq > count/B5004_Rm0.txt
agrep -0 -c 'ACTAGTTGAGAAGTTGG' *.fastq > count/B5005_Rm0.txt
agrep -0 -c 'TTACCCGAACGAGGGCA' *.fastq > count/B5007_Rm0.txt
agrep -0 -c 'TCGTGTCATTTGTCGTA' *.fastq > count/B5009_Rm0.txt
agrep -0 -c 'TTAGGGATGGGAACCAT' *.fastq > count/B5010_Rm0.txt
agrep -0 -c 'AACCTGTCAAGTCTATC' *.fastq > count/B5011_Rm0.txt
agrep -0 -c 'TAGCGTTGCATCTGGCG' *.fastq > count/B5012_Rm0.txt
agrep -0 -c 'AAGGTACTAAAACGACC' *.fastq > count/B5013_Rm0.txt
agrep -0 -c 'CATCTTGCTCCCGGAAC' *.fastq > count/B5014_Rm0.txt
agrep -0 -c 'ACTGAGGAGGCTTATCC' *.fastq > count/B5019_Rm0.txt
agrep -0 -c 'TCTGCCATAGCATCCGG' *.fastq > count/B5020_Rm0.txt
agrep -0 -c 'CCGGAGATTACGGGTAG' *.fastq > count/B5021_Rm0.txt
agrep -0 -c 'TACCGAGAGGATCGAGT' *.fastq > count/B5022_Rm0.txt
agrep -0 -c 'CCTGAAGTTGGACTTGC' *.fastq > count/B5023_Rm0.txt
agrep -0 -c 'CACTGTCACTATGAGAC' *.fastq > count/B5025_Rm0.txt
agrep -0 -c 'CGTTACTGATTACGAAC' *.fastq > count/B5026_Rm0.txt
agrep -0 -c 'ACGAATCACGGAGATAT' *.fastq > count/B5027_Rm0.txt
agrep -0 -c 'CAGCTAAGGAGACGGAA' *.fastq > count/B5028_Rm0.txt
agrep -0 -c 'GTAGCAGCTACATAGCT' *.fastq > count/B5029_Rm0.txt
agrep -0 -c 'ACAGGCTTACGGAATCC' *.fastq > count/B5030_Rm0.txt
agrep -0 -c 'CTCTGGTACTGGCGAAG' *.fastq > count/B5031_Rm0.txt
agrep -0 -c 'CTGAATTGTATAGGCGC' *.fastq > count/B5032_Rm0.txt
agrep -0 -c 'GCCTACTTAGGTGAAGG' *.fastq > count/B5034_Rm0.txt
agrep -0 -c 'CAGAGGAATTTACCCGT' *.fastq > count/B5035_Rm0.txt
agrep -0 -c 'CTCGACTTGAACCGGAT' *.fastq > count/B5037_Rm0.txt
agrep -0 -c 'CTTACCATGTACGCCTT' *.fastq > count/B5038_Rm0.txt
agrep -0 -c 'ATTGCCTGAAGGACCCT' *.fastq > count/B5040_Rm0.txt
agrep -0 -c 'CTTTTGTACGGTTTCTC' *.fastq > count/B5041_Rm0.txt
agrep -0 -c 'TTTATTCGGGGCCCAGA' *.fastq > count/B5042_Rm0.txt
agrep -0 -c 'CATGGACACCTTCTGAA' *.fastq > count/B5045_Rm0.txt
agrep -0 -c 'ACCTGTAGTGACCGAGC' *.fastq > count/B5046_Rm0.txt
agrep -0 -c 'GCATTACACATGCTAAC' *.fastq > count/B5048_Rm0.txt
agrep -0 -c 'AATTGCATAAGCGTGTC' *.fastq > count/B5049_Rm0.txt
agrep -0 -c 'GGGGACATAAGGAGCAT' *.fastq > count/B5050_Rm0.txt
agrep -0 -c 'GTCCAGAAACCACAATC' *.fastq > count/B5051_Rm0.txt
agrep -0 -c 'AGGAAGCTCTCGTATCA' *.fastq > count/B5052_Rm0.txt
agrep -0 -c 'AAATTGGTCCTGCCCTC' *.fastq > count/B5053_Rm0.txt
agrep -0 -c 'TCTGCCGGATCTTAGTC' *.fastq > count/B5054_Rm0.txt
agrep -0 -c 'TGCCAACGACACCCAGT' *.fastq > count/B5055_Rm0.txt
agrep -0 -c 'TTTTTTGGCCCAGCACT' *.fastq > count/B5058_Rm0.txt
agrep -0 -c 'GCGGCTTTATCGAACTA' *.fastq > count/B5062_Rm0.txt
agrep -0 -c 'TCGACTTAGTAATCGCG' *.fastq > count/B5063_Rm0.txt
agrep -0 -c 'GGTAATCGACGCATTAG' *.fastq > count/B5064_Rm0.txt
agrep -0 -c 'AGAAGGCCCGCTTAACT' *.fastq > count/B5065_Rm0.txt
agrep -0 -c 'TACTGCCAGTGGGTTAA' *.fastq > count/B5066_Rm0.txt
agrep -0 -c 'GTCTGAGGGCACGTACA' *.fastq > count/B5067_Rm0.txt
agrep -0 -c 'GCAACATAACACCCGAC' *.fastq > count/B5068_Rm0.txt
agrep -0 -c 'GTGGTTCCCGTTCCATC' *.fastq > count/B5069_Rm0.txt
agrep -0 -c 'ATCTTGCATTTCCCGTG' *.fastq > count/B5070_Rm0.txt
agrep -0 -c 'TCGCTGGATGACTGATG' *.fastq > count/B5071_Rm0.txt
agrep -0 -c 'TGTACCGAGTGGACTCT' *.fastq > count/B5072_Rm0.txt
agrep -0 -c 'TCCGCCCTGTTACGCAT' *.fastq > count/B5075_Rm0.txt
agrep -0 -c 'CCCAGGTACTGTACTCA' *.fastq > count/B5076_Rm0.txt
agrep -0 -c 'AGCCGAAGTACTACCTC' *.fastq > count/B5077_Rm0.txt
agrep -0 -c 'CGCAGGGTGTACATCGT' *.fastq > count/B5078_Rm0.txt
agrep -0 -c 'CTTGGACACGTTATTGC' *.fastq > count/B5079_Rm0.txt
agrep -0 -c 'TTGCACGTATCCATCTG' *.fastq > count/B5080_Rm0.txt
agrep -0 -c 'TTTGTGGACCTGGCACG' *.fastq > count/B5081_Rm0.txt
agrep -0 -c 'ACCCGAGAGATATGCTT' *.fastq > count/B5083_Rm0.txt
agrep -0 -c 'AGTATTCCTCCCGGTCA' *.fastq > count/B5084_Rm0.txt
agrep -0 -c 'AATAGGGAGTGGTAGAT' *.fastq > count/B5085_Rm0.txt
agrep -0 -c 'GTGATCGGAGGCATTCC' *.fastq > count/B5086_Rm0.txt
agrep -0 -c 'CTGGTACTATCCGTAGG' *.fastq > count/B5087_Rm0.txt
agrep -0 -c 'AGGAATTAAACCATGCG' *.fastq > count/B5088_Rm0.txt
agrep -0 -c 'CCAGCTATGCATCAAGA' *.fastq > count/B5089_Rm0.txt
agrep -0 -c 'CAGATCCTAAAGTTGCC' *.fastq > count/B5090_Rm0.txt
agrep -0 -c 'TGTCCGGAAAGCGAATA' *.fastq > count/B5091_Rm0.txt
agrep -0 -c 'GTATAACTGGATTCCCG' *.fastq > count/B5092_Rm0.txt
agrep -0 -c 'CGACTATGCGGTCGAAG' *.fastq > count/B5093_Rm0.txt
agrep -0 -c 'CAGGCTTCAGCGAATAA' *.fastq > count/B5094_Rm0.txt
agrep -0 -c 'AACTCCGCTCAGTTCAC' *.fastq > count/B5095_Rm0.txt
agrep -0 -c 'GTCGTCCTGCGATACAG' *.fastq > count/B5096_Rm0.txt
agrep -0 -c 'AAGGGGTTTGGGAACGG' *.fastq > count/B5097_Rm0.txt
agrep -0 -c 'TAGTCGAGGACATCGGC' *.fastq > count/B5098_Rm0.txt
agrep -0 -c 'GCCGCGGATCTAATGTG' *.fastq > count/B5099_Rm0.txt
agrep -0 -c 'GAGCTAGAATCGATGAC' *.fastq > count/B5100_Rm0.txt
agrep -0 -c 'CGATGAAGACCCCATAA' *.fastq > count/B5101_Rm0.txt
agrep -0 -c 'CTTCCAAGCAAAGTGCA' *.fastq > count/B5102_Rm0.txt
agrep -0 -c 'GTATATGCAAGATCACG' *.fastq > count/B5103_Rm0.txt
agrep -0 -c 'CGTAGTGCGGATTCAAC' *.fastq > count/B5104_Rm0.txt
agrep -0 -c 'AACTTTCTCCGCACCGT' *.fastq > count/B5106_Rm0.txt
agrep -0 -c 'CGCACTTCTCGCCTAAT' *.fastq > count/B5107_Rm0.txt
agrep -0 -c 'GAGTGCTCTGTCAGTAC' *.fastq > count/B5108_Rm0.txt
agrep -0 -c 'GCACGTCATTCGCCCTA' *.fastq > count/B5109_Rm0.txt
agrep -0 -c 'CTACTCGGAAGGATTAG' *.fastq > count/B5110_Rm0.txt
agrep -0 -c 'TGTGTATCGTCTCGATA' *.fastq > count/B5111_Rm0.txt
agrep -0 -c 'TTTGCCTATGCGCCGTC' *.fastq > count/B5113_Rm0.txt
agrep -0 -c 'AACCTCGCTAGCCGTAA' *.fastq > count/B5114_Rm0.txt
agrep -0 -c 'CGGCTAAGACGTTCTCG' *.fastq > count/B5115_Rm0.txt
agrep -0 -c 'GCAACGCGATTCCAGTA' *.fastq > count/B5116_Rm0.txt
agrep -0 -c 'AGCTGCGGACATCACGT' *.fastq > count/B5118_Rm0.txt
agrep -0 -c 'AGGTTTCCGCAACTGAA' *.fastq > count/B5119_Rm0.txt
agrep -0 -c 'TCGCGGCTGTTCATGTG' *.fastq > count/B5120_Rm0.txt
agrep -0 -c 'CCATTACCGTGACTCGA' *.fastq > count/B5121_Rm0.txt
agrep -0 -c 'ACATTAGGGAGCTGGCT' *.fastq > count/B5122_Rm0.txt
agrep -0 -c 'TCGTAGCGAAACCGGAA' *.fastq > count/B5123_Rm0.txt
agrep -0 -c 'ATCCTTCGAACACCGTG' *.fastq > count/B5124_Rm0.txt
agrep -0 -c 'CAATACAAGCGCCCGAG' *.fastq > count/B5125_Rm0.txt
agrep -0 -c 'ACTCCCGCGCAAATAGA' *.fastq > count/B5126_Rm0.txt
agrep -0 -c 'CAGGGAGCTCGGCTATA' *.fastq > count/B5127_Rm0.txt
agrep -0 -c 'CTTGCAGCCTGTGAAGA' *.fastq > count/B5128_Rm0.txt
agrep -0 -c 'CTCCAACGAATAGATAC' *.fastq > count/B5129_Rm0.txt
agrep -0 -c 'CTTCGAGTACGGTACTT' *.fastq > count/B5131_Rm0.txt
agrep -0 -c 'AACATAAGGTACGCTCT' *.fastq > count/B5132_Rm0.txt
agrep -0 -c 'CTAGACCAGATCGTGTA' *.fastq > count/B5133_Rm0.txt
agrep -0 -c 'CATCGGACAGCTAATAT' *.fastq > count/B5134_Rm0.txt
agrep -0 -c 'GCATCGATCTGTATTTG' *.fastq > count/B5135_Rm0.txt
agrep -0 -c 'AGTACTTCGGGTTGTTA' *.fastq > count/B5136_Rm0.txt
agrep -0 -c 'ACGACCCTAGATATGCG' *.fastq > count/B5137_Rm0.txt
agrep -0 -c 'CGCCAATGAGACCACAC' *.fastq > count/B5138_Rm0.txt
agrep -0 -c 'TTCCGATAACGGGATCG' *.fastq > count/B5139_Rm0.txt
agrep -0 -c 'CCGACTCCAAACTGGCT' *.fastq > count/B5140_Rm0.txt
agrep -0 -c 'TTTCGTCGTCAATAACC' *.fastq > count/B5141_Rm0.txt
agrep -0 -c 'GTGGCATGTATTATACC' *.fastq > count/B5142_Rm0.txt
agrep -0 -c 'GAAAGATCACCGACTGT' *.fastq > count/B5144_Rm0.txt
agrep -0 -c 'CCGATATAGCACTGCGC' *.fastq > count/B5147_Rm0.txt
agrep -0 -c 'CGTTGGGTCGGCTTTTG' *.fastq > count/B5148_Rm0.txt
agrep -0 -c 'TCGTACATCACTGCAGT' *.fastq > count/B5149_Rm0.txt
agrep -0 -c 'CATTTGAGCACCCGTGT' *.fastq > count/B5150_Rm0.txt
agrep -0 -c 'ACGTGAGACTACACAGG' *.fastq > count/B5151_Rm0.txt
agrep -0 -c 'GTACGACACCGTGTTAG' *.fastq > count/B5152_Rm0.txt
agrep -0 -c 'TTCAGTAGCGGGCAAGG' *.fastq > count/B5153_Rm0.txt
agrep -0 -c 'ATACTTCCTCACGCGCT' *.fastq > count/B5154_Rm0.txt
agrep -0 -c 'TTACTACAGAGCGACAA' *.fastq > count/B5155_Rm0.txt
agrep -0 -c 'CCCGCAGTTCGATACAG' *.fastq > count/B5156_Rm0.txt
agrep -0 -c 'GACCGGCATCGTTATTA' *.fastq > count/B5158_Rm0.txt
agrep -0 -c 'GTTAAATGGCGGGCTAA' *.fastq > count/B5159_Rm0.txt
agrep -0 -c 'CCGTTGGGGAGACTAAC' *.fastq > count/B5160_Rm0.txt
agrep -0 -c 'TGCGTACCGGTCAACGT' *.fastq > count/B5161_Rm0.txt
agrep -0 -c 'ACTTGGGTCAAGCCTAC' *.fastq > count/B5163_Rm0.txt
agrep -0 -c 'CATGAGCGAGGTTTCTA' *.fastq > count/B5164_Rm0.txt
agrep -0 -c 'AACACCGCAGACAAGCC' *.fastq > count/B5166_Rm0.txt
agrep -0 -c 'CACTATACGTCTGTGAC' *.fastq > count/B5168_Rm0.txt
agrep -0 -c 'GAGCTCCACCATCAATA' *.fastq > count/B5169_Rm0.txt
agrep -0 -c 'TAGATTGCCGCATGGGT' *.fastq > count/B5170_Rm0.txt
agrep -0 -c 'GATCTAAGGCAAGTTCA' *.fastq > count/B5171_Rm0.txt
agrep -0 -c 'TGTGCAGTCCGGGTATC' *.fastq > count/B5172_Rm0.txt
agrep -0 -c 'CAGGTATTAGTCGGTAA' *.fastq > count/B5174_Rm0.txt
agrep -0 -c 'TCATCCTTAGAGTCGGT' *.fastq > count/B5176_Rm0.txt
agrep -0 -c 'AGACCAGTTCTAGAAAC' *.fastq > count/B5177_Rm0.txt
agrep -0 -c 'ACTCGTTGTAACTGTGC' *.fastq > count/B5180_Rm0.txt
agrep -0 -c 'GGATTTGAAAGACCCGC' *.fastq > count/B5182_Rm0.txt
agrep -0 -c 'AAGCAACGTACTGGTCA' *.fastq > count/B5183_Rm0.txt
agrep -0 -c 'CTGTTGGTCTTGGAGTA' *.fastq > count/B5184_Rm0.txt
agrep -0 -c 'GCCAGGACACTTTGTGT' *.fastq > count/B5185_Rm0.txt
agrep -0 -c 'TGCAAAGTTGTCAGCTC' *.fastq > count/B5188_Rm0.txt
agrep -0 -c 'ACACGTAATCTCCGTCA' *.fastq > count/B5189_Rm0.txt
agrep -0 -c 'CCGTACTGACTAGTAAG' *.fastq > count/B5190_Rm0.txt
agrep -0 -c 'ATTGATATCGAAGCCCG' *.fastq > count/B5191_Rm0.txt
agrep -0 -c 'GACGTACTTTGAAGGTT' *.fastq > count/B5192_Rm0.txt
agrep -0 -c 'GTCCAGCATGCGTGTAA' *.fastq > count/B5194_Rm0.txt
agrep -0 -c 'CTCCGGTGAGATAAATG' *.fastq > count/B5195_Rm0.txt
agrep -0 -c 'CTTACACCAACTGATGA' *.fastq > count/B5196_Rm0.txt
agrep -0 -c 'AAGCTGAAGTCCGAAAC' *.fastq > count/B5197_Rm0.txt
agrep -0 -c 'CTATACTGGGTTACACC' *.fastq > count/B5198_Rm0.txt
agrep -0 -c 'ATCTATGGAACACGTCT' *.fastq > count/B5199_Rm0.txt
agrep -0 -c 'GGAACAGACCACGACCT' *.fastq > count/B5200_Rm0.txt
agrep -0 -c 'TGTGCTGATGTCCTCCC' *.fastq > count/B5201_Rm0.txt
agrep -0 -c 'TCCACCCCGTGCAGATT' *.fastq > count/B5202_Rm0.txt
agrep -0 -c 'ACTAGACAGCGTCCCCT' *.fastq > count/B5203_Rm0.txt
agrep -0 -c 'TTCGTTCAGGTAGTATC' *.fastq > count/B5204_Rm0.txt
agrep -0 -c 'CGCGTATGGTCGTATAC' *.fastq > count/B5205_Rm0.txt
agrep -0 -c 'GACCGTCATCTCATGAT' *.fastq > count/B5206_Rm0.txt
agrep -0 -c 'AGTTTCAGGTCCGTCTG' *.fastq > count/B5207_Rm0.txt
agrep -0 -c 'TGAATGCTCACTACTCT' *.fastq > count/B5209_Rm0.txt
agrep -0 -c 'ATTGGAACGATGCCAGG' *.fastq > count/B5210_Rm0.txt
agrep -0 -c 'GCGAAATTAGAGTCCAA' *.fastq > count/B5211_Rm0.txt
agrep -0 -c 'TTGCCGGTTAAGAGGCA' *.fastq > count/B5212_Rm0.txt
agrep -0 -c 'CAACTCAGAATATCGTG' *.fastq > count/B5214_Rm0.txt
agrep -0 -c 'GACTCTGGGAGCAAACG' *.fastq > count/B5215_Rm0.txt
agrep -0 -c 'CTGTCTACACTTACCTT' *.fastq > count/B5216_Rm0.txt
agrep -0 -c 'CACAACATCTAGTCTCT' *.fastq > count/B5217_Rm0.txt
agrep -0 -c 'TTTATTGTCTACCCCGT' *.fastq > count/B5218_Rm0.txt
agrep -0 -c 'GTTCCCGTCCTATGCTG' *.fastq > count/B5220_Rm0.txt
agrep -0 -c 'ACGTGTTTAGAGTGTCA' *.fastq > count/B5221_Rm0.txt
agrep -0 -c 'ACTTGGTGCCACCCTAT' *.fastq > count/B5222_Rm0.txt
agrep -0 -c 'CACCTGTAGATTTGCCC' *.fastq > count/B5224_Rm0.txt
agrep -0 -c 'ATAAGTCCGGGAATGCA' *.fastq > count/B5225_Rm0.txt
agrep -0 -c 'ATAAACGCTAAACTCCC' *.fastq > count/B5227_Rm0.txt
agrep -0 -c 'ATCTGGACGTATGGATC' *.fastq > count/B5228_Rm0.txt
agrep -0 -c 'ATGCGCGTACTAGCTTG' *.fastq > count/B5229_Rm0.txt
agrep -0 -c 'TGACCGTCGCTTGAACT' *.fastq > count/B5230_Rm0.txt
agrep -0 -c 'AAAGATAGTCGTGCCTG' *.fastq > count/B5231_Rm0.txt
agrep -0 -c 'CGGGTTAGAATGTCGAT' *.fastq > count/B5232_Rm0.txt
agrep -0 -c 'TCCCTAGCTATCCATCG' *.fastq > count/B5233_Rm0.txt
agrep -0 -c 'AATGACGGTACCCCACT' *.fastq > count/B5234_Rm0.txt
agrep -0 -c 'TAATGCCGATTTGTCGG' *.fastq > count/B5236_Rm0.txt
agrep -0 -c 'CTAACCGTTACCCTATC' *.fastq > count/B5239_Rm0.txt
agrep -0 -c 'TTCGCGAATGGGGGCTA' *.fastq > count/B5240_Rm0.txt
agrep -0 -c 'AGCCTCAGTAGGGTGGT' *.fastq > count/B5241_Rm0.txt
agrep -0 -c 'TCAGGTTACGCCTACGA' *.fastq > count/B5243_Rm0.txt
agrep -0 -c 'CAATTTGGCATCCGTCA' *.fastq > count/B5244_Rm0.txt
agrep -0 -c 'AGTTGAGGGGAACGGTC' *.fastq > count/B5245_Rm0.txt
agrep -0 -c 'CTGGTAATGAGGAGGCC' *.fastq > count/B5246_Rm0.txt
agrep -0 -c 'CGCCCGATGTGATAGTC' *.fastq > count/B5248_Rm0.txt
agrep -0 -c 'AGCTTATTGGTCAGTAC' *.fastq > count/B5249_Rm0.txt
agrep -0 -c 'ATATAGACAAGTGCGTC' *.fastq > count/B5250_Rm0.txt
agrep -0 -c 'GCGTACGGAATTCTCTC' *.fastq > count/B5252_Rm0.txt
agrep -0 -c 'CTGACACAATTGTGTGA' *.fastq > count/B5253_Rm0.txt
agrep -0 -c 'GACTAAGTGATCGGGCG' *.fastq > count/B5254_Rm0.txt
agrep -0 -c 'GAACCAAGGTTTACCGT' *.fastq > count/B5255_Rm0.txt
agrep -0 -c 'ATATCTAGATGCCACCC' *.fastq > count/B5256_Rm0.txt
agrep -0 -c 'CTACGCACATATGTCAT' *.fastq > count/B5257_Rm0.txt
agrep -0 -c 'CCAGTGCCTGTTTCCGA' *.fastq > count/B5258_Rm0.txt
agrep -0 -c 'TAAGGTGATTGCCCAGT' *.fastq > count/B5259_Rm0.txt
agrep -0 -c 'TCCTGATAGATACCAGA' *.fastq > count/B5261_Rm0.txt
agrep -0 -c 'TAACTACCCACACCGCA' *.fastq > count/B5265_Rm0.txt
agrep -0 -c 'CGCTTGACATGAGAGGT' *.fastq > count/B5266_Rm0.txt
agrep -0 -c 'CCGCCCATATCTTCCTG' *.fastq > count/B5267_Rm0.txt
agrep -0 -c 'AACCAACCTTTTCGGTA' *.fastq > count/B5268_Rm0.txt
agrep -0 -c 'AGGGCATTAAGATTAGG' *.fastq > count/B5269_Rm0.txt
agrep -0 -c 'TCTGCGATTTCGCCTCT' *.fastq > count/B5270_Rm0.txt
agrep -0 -c 'TTATCTGTCCGCCCACG' *.fastq > count/B5271_Rm0.txt
agrep -0 -c 'TAGAGCGCCGTTAACAA' *.fastq > count/B5272_Rm0.txt
agrep -0 -c 'AGCAGGACCTTCGTATC' *.fastq > count/B5273_Rm0.txt
agrep -0 -c 'GATACGTAAGTTCGGTG' *.fastq > count/B5274_Rm0.txt
agrep -0 -c 'AAGAGACATCGTCTCTT' *.fastq > count/B5275_Rm0.txt
agrep -0 -c 'TCTTAGCTGCCACACGC' *.fastq > count/B5276_Rm0.txt
agrep -0 -c 'TAGTATCTCGGGTATAC' *.fastq > count/B5278_Rm0.txt
agrep -0 -c 'GGAGTATGAATGTGAGC' *.fastq > count/B5280_Rm0.txt
agrep -0 -c 'GCTGAACATGTCATTAC' *.fastq > count/B5281_Rm0.txt
agrep -0 -c 'ATATTGGCGCTTGACTA' *.fastq > count/B5282_Rm0.txt
agrep -0 -c 'CGGAACTAACCAGAAGA' *.fastq > count/B5283_Rm0.txt
agrep -0 -c 'CGCCAACTAGGGAATCG' *.fastq > count/B5284_Rm0.txt
agrep -0 -c 'CCCGGAGGTAATACGAC' *.fastq > count/B5285_Rm0.txt
agrep -0 -c 'GTAAAGGTGCTGCCTCG' *.fastq > count/B5286_Rm0.txt
agrep -0 -c 'TCCACCCCGAATTACAC' *.fastq > count/B5289_Rm0.txt
agrep -0 -c 'GCTGGCCCAGATCGATA' *.fastq > count/B5290_Rm0.txt
agrep -0 -c 'TAATGTCACGCTCCACC' *.fastq > count/B5294_Rm0.txt
agrep -0 -c 'TACAGTGGCAGAGTTGG' *.fastq > count/B5295_Rm0.txt
agrep -0 -c 'GAATTGAGAGCCCCTAG' *.fastq > count/B5296_Rm0.txt
agrep -0 -c 'AATAGGAAGCCAAACGC' *.fastq > count/B5297_Rm0.txt
agrep -0 -c 'CCCCTGATACCGTCTAA' *.fastq > count/B5298_Rm0.txt
agrep -0 -c 'TTCATCGATCCATACGG' *.fastq > count/B5299_Rm0.txt
agrep -0 -c 'CGACCAAAAAGAAAGTG' *.fastq > count/B5300_Rm0.txt
agrep -0 -c 'TGGTTAAAAGCCCGCCG' *.fastq > count/B5301_Rm0.txt
agrep -0 -c 'GCCGAGAAGTCCATCGA' *.fastq > count/B5302_Rm0.txt
agrep -0 -c 'GCTAGCAATGGAGGGAA' *.fastq > count/B5303_Rm0.txt
agrep -0 -c 'TCAAGTGCGCAACGGGT' *.fastq > count/B5304_Rm0.txt
agrep -0 -c 'CCCTGTAGAAACTGGCG' *.fastq > count/B5305_Rm0.txt
agrep -0 -c 'GCGTCGTTGTTAAGGCC' *.fastq > count/B5306_Rm0.txt
agrep -0 -c 'CGCTCACAGTTCAGACG' *.fastq > count/B5307_Rm0.txt
agrep -0 -c 'CTTCAGCAGGTGCATGC' *.fastq > count/B5308_Rm0.txt
agrep -0 -c 'TCGCCAAAGCCAGCTCT' *.fastq > count/B5310_Rm0.txt
agrep -0 -c 'GGAACGTAACTAAAGCT' *.fastq > count/B5311_Rm0.txt
agrep -0 -c 'AACGCTTACCTACGCTC' *.fastq > count/B5312_Rm0.txt
agrep -0 -c 'TCTCCGTCACGATCGTG' *.fastq > count/B5313_Rm0.txt
agrep -0 -c 'TCATGAGTGGCACAAGA' *.fastq > count/B5314_Rm0.txt
agrep -0 -c 'GTCCTGGACTATGCTGT' *.fastq > count/B5315_Rm0.txt
agrep -0 -c 'AATAGGAACTAGCGTCT' *.fastq > count/B5316_Rm0.txt
agrep -0 -c 'ATACTTCCTGAACGAGG' *.fastq > count/B5317_Rm0.txt
agrep -0 -c 'TCGTATGCACTAACGTG' *.fastq > count/B5318_Rm0.txt
agrep -0 -c 'TGACAGTCGGGACGTAC' *.fastq > count/B5320_Rm0.txt
agrep -0 -c 'TCCGGAGCGAGAGTTAG' *.fastq > count/B5323_Rm0.txt
agrep -0 -c 'TCCAGTCACTCGCTAAT' *.fastq > count/B5324_Rm0.txt
agrep -0 -c 'GTTGACCATTGTCTCGC' *.fastq > count/B5325_Rm0.txt
agrep -0 -c 'GACTACTCTTAAACAGG' *.fastq > count/B5326_Rm0.txt
agrep -0 -c 'TCTGAAAGTATACTGCG' *.fastq > count/B5327_Rm0.txt
agrep -0 -c 'ACAAACGAAGGGTCAGT' *.fastq > count/B5330_Rm0.txt
agrep -0 -c 'TATGTACGGGAATGACG' *.fastq > count/B5331_Rm0.txt
agrep -0 -c 'TCGGTTACCATTCAATC' *.fastq > count/B5332_Rm0.txt
agrep -0 -c 'AGAAAGTGAGAGCGCGC' *.fastq > count/B5333_Rm0.txt
agrep -0 -c 'AGTCCTCTCGACGTATT' *.fastq > count/B5334_Rm0.txt
agrep -0 -c 'TATGATATGTCGGACCG' *.fastq > count/B5335_Rm0.txt
agrep -0 -c 'TGGTCAAATGGCTAACC' *.fastq > count/B5338_Rm0.txt
agrep -0 -c 'GTGGACTGCCTTGGCAT' *.fastq > count/B5340_Rm0.txt
agrep -0 -c 'TGAGAAGTCAAGATCAC' *.fastq > count/B5341_Rm0.txt
agrep -0 -c 'ATTTACCGGATGGGATG' *.fastq > count/B5342_Rm0.txt
agrep -0 -c 'AATCGCTTCCAATACCT' *.fastq > count/B5343_Rm0.txt
agrep -0 -c 'GTTCTGCTAGCCTCGAA' *.fastq > count/B5344_Rm0.txt
agrep -0 -c 'TTTCTTGCACAATGGTC' *.fastq > count/B5345_Rm0.txt
agrep -0 -c 'AGATCACACTGAAGCAT' *.fastq > count/B5347_Rm0.txt
agrep -0 -c 'CCTGCGCTCCATTGCTA' *.fastq > count/B5348_Rm0.txt
agrep -0 -c 'TGTTACTCGTCTTTAGG' *.fastq > count/B5349_Rm0.txt
agrep -0 -c 'GGGGTGTCAATCATCAC' *.fastq > count/B5350_Rm0.txt
agrep -0 -c 'ACACGGTACGAACCATT' *.fastq > count/B5352_Rm0.txt
agrep -0 -c 'TGTGCAGCGATCAAGGT' *.fastq > count/B5353_Rm0.txt
agrep -0 -c 'ACTGGAGGGTTGCAAGA' *.fastq > count/B5355_Rm0.txt
agrep -0 -c 'GGAATCAAGGGGTACTT' *.fastq > count/B5356_Rm0.txt
agrep -0 -c 'CAGTAGTGGACGTCCGT' *.fastq > count/B5357_Rm0.txt
agrep -0 -c 'CTGCAAGCGAAGAAGTT' *.fastq > count/B5358_Rm0.txt
agrep -0 -c 'AAAGGCGTTCCGTCTTA' *.fastq > count/B5359_Rm0.txt
agrep -0 -c 'TCGCCCAAAATTCATGT' *.fastq > count/B5360_Rm0.txt
agrep -0 -c 'TTAGCCATTCGCGTCCA' *.fastq > count/B5361_Rm0.txt
agrep -0 -c 'GTAATCGACAATGTCAC' *.fastq > count/B5362_Rm0.txt
agrep -0 -c 'CCGATATGAAACGGCGA' *.fastq > count/B5363_Rm0.txt
agrep -0 -c 'AAGAGCTCTTGTGGAGC' *.fastq > count/B5365_Rm0.txt
agrep -0 -c 'GGGAAGTTGATCGCAAG' *.fastq > count/B5366_Rm0.txt
agrep -0 -c 'GAAGGTTAGCGGAGCTA' *.fastq > count/B5367_Rm0.txt
agrep -0 -c 'AGTACTGCATATCACGC' *.fastq > count/B5368_Rm0.txt
agrep -0 -c 'CACCCGATTCTATACCG' *.fastq > count/B5369_Rm0.txt
agrep -0 -c 'AGTAGGCGAGCTTCCAT' *.fastq > count/B5370_Rm0.txt
agrep -0 -c 'CGGTTTGAGTTGTACGT' *.fastq > count/B5371_Rm0.txt
agrep -0 -c 'AAGAGATTCGCTGTCGA' *.fastq > count/B5372_Rm0.txt
agrep -0 -c 'CTGGCCACTTATTTAGG' *.fastq > count/B5374_Rm0.txt
agrep -0 -c 'CTTAGTCAAGTGGGAGT' *.fastq > count/B5375_Rm0.txt
agrep -0 -c 'GTCAGCTCTGGCAGTAC' *.fastq > count/B5376_Rm0.txt
agrep -0 -c 'CCATTGGTACCAACGTG' *.fastq > count/B5377_Rm0.txt
agrep -0 -c 'GAAACGTCATCAACATC' *.fastq > count/B5378_Rm0.txt
agrep -0 -c 'GTAGGCTGGGGCCATAT' *.fastq > count/B5379_Rm0.txt
agrep -0 -c 'TTTCATGGCTGGAGTCC' *.fastq > count/B5380_Rm0.txt
agrep -0 -c 'CGGGGTCATTTAGAGTC' *.fastq > count/B5381_Rm0.txt
agrep -0 -c 'ACGTGGAGTCATCTGCT' *.fastq > count/B5382_Rm0.txt
agrep -0 -c 'GTAACGAGGCACATGAA' *.fastq > count/B5384_Rm0.txt
agrep -0 -c 'ACCCCGGGACATTCCTA' *.fastq > count/B5385_Rm0.txt
agrep -0 -c 'TAGATCTAGTGGATGTG' *.fastq > count/B5386_Rm0.txt
agrep -0 -c 'TACGCCTTCTTACGATA' *.fastq > count/B5387_Rm0.txt
agrep -0 -c 'TCGATAGGTCTCCTTCG' *.fastq > count/B5388_Rm0.txt
agrep -0 -c 'ATCGGTACATTTTGGCG' *.fastq > count/B5389_Rm0.txt
agrep -0 -c 'GAGCTAACAGACGTCTA' *.fastq > count/B5390_Rm0.txt
agrep -0 -c 'GCAAAATCGAGTTCGCC' *.fastq > count/B5391_Rm0.txt
agrep -0 -c 'GATTAGGAAGGGTCTTA' *.fastq > count/B5393_Rm0.txt
agrep -0 -c 'TTCCGCGAGGTACGTCT' *.fastq > count/B5394_Rm0.txt
agrep -0 -c 'AGATCCAATTATGAGCG' *.fastq > count/B5395_Rm0.txt
agrep -0 -c 'CTACCTATGCGGCAGTT' *.fastq > count/B5397_Rm0.txt
agrep -0 -c 'GGAGGTCAATTATAACG' *.fastq > count/B5398_Rm0.txt
agrep -0 -c 'CAGGATCACTGGCATTA' *.fastq > count/B5399_Rm0.txt
agrep -0 -c 'CTTCATCGGTACCAAGC' *.fastq > count/B5400_Rm0.txt
agrep -0 -c 'TTGTGAGGCACATCGTC' *.fastq > count/B5401_Rm0.txt
agrep -0 -c 'GGATCAACGACAACAGA' *.fastq > count/B5402_Rm0.txt
agrep -0 -c 'GTGATTGCGTGTTGTCG' *.fastq > count/B5405_Rm0.txt
agrep -0 -c 'GTAGTCCAACGAAGTGT' *.fastq > count/B5406_Rm0.txt
agrep -0 -c 'GACGACAATTGGCCTGG' *.fastq > count/B5407_Rm0.txt
agrep -0 -c 'ACCTACGATAAGAGGAT' *.fastq > count/B5408_Rm0.txt
agrep -0 -c 'AGCGAGTTTTCCGGTCG' *.fastq > count/B5410_Rm0.txt
agrep -0 -c 'CTCGGTTAGCGGTTACA' *.fastq > count/B5411_Rm0.txt
agrep -0 -c 'GTTAGCGGACCTCATCA' *.fastq > count/B5412_Rm0.txt
agrep -0 -c 'GAAGATCGATGAATGGC' *.fastq > count/B5413_Rm0.txt
agrep -0 -c 'CGAAGCACAGATACACT' *.fastq > count/B5414_Rm0.txt
agrep -0 -c 'TCTGTACTAAAGGACGA' *.fastq > count/B5415_Rm0.txt
agrep -0 -c 'AAACATCGACCTGTGAC' *.fastq > count/B5416_Rm0.txt
agrep -0 -c 'GCGTGTGTTCATCCCTT' *.fastq > count/B5417_Rm0.txt
agrep -0 -c 'TGACCCCTTAGACATAT' *.fastq > count/B5418_Rm0.txt
agrep -0 -c 'TGGCACGTAAAAGAGTA' *.fastq > count/B5420_Rm0.txt
agrep -0 -c 'CGCGAATTGCAAACTGC' *.fastq > count/B5421_Rm0.txt
agrep -0 -c 'CTTCGATGTCGTTATCC' *.fastq > count/B5422_Rm0.txt
agrep -0 -c 'TCGTTGCGCTATAACCG' *.fastq > count/B5423_Rm0.txt
agrep -0 -c 'CGGGTCTTGAACACCAT' *.fastq > count/B5424_Rm0.txt
agrep -0 -c 'TTTGCGGTCGTGATAGG' *.fastq > count/B5425_Rm0.txt
agrep -0 -c 'GCTAAACTGGTACTTCA' *.fastq > count/B5426_Rm0.txt
agrep -0 -c 'GGGAGTGGTAAACGCGT' *.fastq > count/B5429_Rm0.txt
agrep -0 -c 'AAGGCCGAATTTACGTC' *.fastq > count/B5431_Rm0.txt
agrep -0 -c 'GATTCTCGCCAGATTCA' *.fastq > count/B5432_Rm0.txt
agrep -0 -c 'TCCAGAGCACGCAACGT' *.fastq > count/B5433_Rm0.txt
agrep -0 -c 'GTGAGAGGAACGAATTG' *.fastq > count/B5435_Rm0.txt
agrep -0 -c 'CCTCTGAGGTAACTCAG' *.fastq > count/B5436_Rm0.txt
agrep -0 -c 'ATCCGTGGGAACTAATG' *.fastq > count/B5437_Rm0.txt
agrep -0 -c 'CCTTCCACAATTGAAGC' *.fastq > count/B5439_Rm0.txt
agrep -0 -c 'ACGCCAATGAATCTCGT' *.fastq > count/B5440_Rm0.txt
agrep -0 -c 'AGAGGGACAATACTCGG' *.fastq > count/B5442_Rm0.txt
agrep -0 -c 'CTCTATGCTAGGGCGAT' *.fastq > count/B5443_Rm0.txt
agrep -0 -c 'CTGCGTTGTGATTTGCG' *.fastq > count/B5444_Rm0.txt
agrep -0 -c 'CTATCCGGGGTATGGTA' *.fastq > count/B5445_Rm0.txt
agrep -0 -c 'TATGCTGAAGCGGATGA' *.fastq > count/B5447_Rm0.txt
agrep -0 -c 'GCGGTCTGCATAAACTT' *.fastq > count/B5448_Rm0.txt
agrep -0 -c 'CCTTTCTAACTTACCTG' *.fastq > count/B5449_Rm0.txt
agrep -0 -c 'GAGCGACTTGAATGCTA' *.fastq > count/B5450_Rm0.txt
agrep -0 -c 'AACTGCACGAACCAGAA' *.fastq > count/B5452_Rm0.txt
agrep -0 -c 'GATCGACATTCGTGGAT' *.fastq > count/B5453_Rm0.txt
agrep -0 -c 'ACGAGGTGTGTCTCCCT' *.fastq > count/B5454_Rm0.txt
agrep -0 -c 'ACTCTATCGAGTGGGCA' *.fastq > count/B5455_Rm0.txt
agrep -0 -c 'GCGCACCTTTAAACCAT' *.fastq > count/B5456_Rm0.txt
agrep -0 -c 'ACTGGCTACGTGAGTAG' *.fastq > count/B5457_Rm0.txt
agrep -0 -c 'TTTGGCAATAGCGGATA' *.fastq > count/B5458_Rm0.txt
agrep -0 -c 'GACGTGGTCACTCCCAT' *.fastq > count/B5459_Rm0.txt
agrep -0 -c 'GCCGGAGCACGTTTATG' *.fastq > count/B5460_Rm0.txt
agrep -0 -c 'TTCTCCGCTGCTCTTAG' *.fastq > count/B5462_Rm0.txt
agrep -0 -c 'ATGAAACCCTCTTGTGT' *.fastq > count/B5463_Rm0.txt
agrep -0 -c 'CTGCCGCAGTTCCAAAT' *.fastq > count/B5464_Rm0.txt
agrep -0 -c 'CGGATTCAGTAATAGCG' *.fastq > count/B5465_Rm0.txt
agrep -0 -c 'AAGGAAAGTCGGTTGAG' *.fastq > count/B5466_Rm0.txt
agrep -0 -c 'CGGATTCGGGACATTCA' *.fastq > count/B5467_Rm0.txt
agrep -0 -c 'AGCGGGAGTTACAGCTC' *.fastq > count/B5468_Rm0.txt
agrep -0 -c 'GTGGAGGCTTAACGCGT' *.fastq > count/B5470_Rm0.txt
agrep -0 -c 'AGCATTGAATATCCAGC' *.fastq > count/B5471_Rm0.txt
agrep -0 -c 'GACTAGGATCCGATCGT' *.fastq > count/B5472_Rm0.txt
agrep -0 -c 'GCCTATCGCTCGGCTAA' *.fastq > count/B5473_Rm0.txt
agrep -0 -c 'CGGACCGGATTACGTTA' *.fastq > count/B5474_Rm0.txt
agrep -0 -c 'TTCGGACACTCCGAAGT' *.fastq > count/B5475_Rm0.txt
agrep -0 -c 'TGAAGGGACTTCAACTT' *.fastq > count/B5476_Rm0.txt
agrep -0 -c 'GTTCCCACGCTAGCAAG' *.fastq > count/B5478_Rm0.txt
agrep -0 -c 'GGAAGTCGTGTCCTAGC' *.fastq > count/B5479_Rm0.txt
agrep -0 -c 'AACCCTAGTTTTGCGAT' *.fastq > count/B5480_Rm0.txt
agrep -0 -c 'GGTCTGCTCTCCGGTAA' *.fastq > count/B5482_Rm0.txt
agrep -0 -c 'TAACGATAGTTACCTGC' *.fastq > count/B5483_Rm0.txt
agrep -0 -c 'AATCGGTGACCATTTTG' *.fastq > count/B5484_Rm0.txt
agrep -0 -c 'CGATAAACCGTCAGTGG' *.fastq > count/B5485_Rm0.txt
agrep -0 -c 'AGTTCTTCCTGATTGTC' *.fastq > count/B5486_Rm0.txt
agrep -0 -c 'GCGGCATCTCTACACTG' *.fastq > count/B5487_Rm0.txt
agrep -0 -c 'TTCTACGGAGTTAAGGT' *.fastq > count/B5488_Rm0.txt
agrep -0 -c 'TATGCCGTATTGACCTG' *.fastq > count/B5489_Rm0.txt
agrep -0 -c 'CCCATATGGCAGCAAGT' *.fastq > count/B5491_Rm0.txt
agrep -0 -c 'ATATGCCAACAGGGACT' *.fastq > count/B5492_Rm0.txt
agrep -0 -c 'GTTCCATACCATCAGGC' *.fastq > count/B5493_Rm0.txt
agrep -0 -c 'GCATTTAGCCATCGTAT' *.fastq > count/B5494_Rm0.txt
agrep -0 -c 'TATCTAGTGCGACACTG' *.fastq > count/B5496_Rm0.txt
agrep -0 -c 'TACGCATCCACCAGGCT' *.fastq > count/B5497_Rm0.txt
agrep -0 -c 'ACCCAATCGATTGCCGA' *.fastq > count/B5500_Rm0.txt
agrep -0 -c 'CCGTAACCGGTGTGAAG' *.fastq > count/B5501_Rm0.txt
agrep -0 -c 'GGCTTGCACTGACACCT' *.fastq > count/B5502_Rm0.txt
agrep -0 -c 'TCTGGATTTTACGGCTC' *.fastq > count/B5503_Rm0.txt
agrep -0 -c 'CTCTCGTCCTTAGTTTA' *.fastq > count/B5504_Rm0.txt
agrep -0 -c 'AAATACGGAAGGGATTG' *.fastq > count/B5505_Rm0.txt
agrep -0 -c 'GTACATAGCGGTAACCG' *.fastq > count/B5507_Rm0.txt
agrep -0 -c 'CATGTATGCTATTGACC' *.fastq > count/B5508_Rm0.txt
agrep -0 -c 'ATAGCGTCTTTATCCGA' *.fastq > count/B5510_Rm0.txt
agrep -0 -c 'CATGATCAATGGGCACC' *.fastq > count/B5511_Rm0.txt
agrep -0 -c 'GCTTCACCGAAGGATCC' *.fastq > count/B5512_Rm0.txt
agrep -0 -c 'GAGTGTTGCTATGATTG' *.fastq > count/B5513_Rm0.txt
agrep -0 -c 'TAGGTCTTACGCTGGAC' *.fastq > count/B5514_Rm0.txt
agrep -0 -c 'AAGTGTCGAGGAATTCG' *.fastq > count/B5515_Rm0.txt
agrep -0 -c 'CGTTACACAACTCGGTG' *.fastq > count/B5516_Rm0.txt
agrep -0 -c 'TTGGGGAACTAAATCAC' *.fastq > count/B5518_Rm0.txt
agrep -0 -c 'GCGGAGTGATTGACATG' *.fastq > count/B5520_Rm0.txt
agrep -0 -c 'TCGTGCGTAGATACGAA' *.fastq > count/B5522_Rm0.txt
agrep -0 -c 'GCAATGCGAATCCTTAG' *.fastq > count/B5523_Rm0.txt
agrep -0 -c 'CGCATTGATTTCAGCAC' *.fastq > count/B5524_Rm0.txt
agrep -0 -c 'CCCTTACGACAGACATA' *.fastq > count/B5525_Rm0.txt
agrep -0 -c 'TCCAGACTTACTACATG' *.fastq > count/B5526_Rm0.txt
agrep -0 -c 'TTACGTCTCGCTGCACG' *.fastq > count/B5527_Rm0.txt
agrep -0 -c 'TTTTGATAATCAGCCCG' *.fastq > count/B5530_Rm0.txt
agrep -0 -c 'TTGCCCGTTACCCGAAC' *.fastq > count/B5531_Rm0.txt
agrep -0 -c 'GATTCACTAAAGCTCAC' *.fastq > count/B5532_Rm0.txt
agrep -0 -c 'AGCTGCGCTAGCCGATT' *.fastq > count/B5533_Rm0.txt
agrep -0 -c 'TACATCAGCACCTGGTA' *.fastq > count/B5537_Rm0.txt
agrep -0 -c 'GGCCTCGATAGGTGTAA' *.fastq > count/B5538_Rm0.txt
agrep -0 -c 'GGATGCGCTAACATGAC' *.fastq > count/B5539_Rm0.txt
agrep -0 -c 'ATCATAGTGACTCCCAG' *.fastq > count/B5540_Rm0.txt
agrep -0 -c 'ATGCGGTGGAACCTATT' *.fastq > count/B5541_Rm0.txt
agrep -0 -c 'TGGATTGAGTGACTATG' *.fastq > count/B5542_Rm0.txt
agrep -0 -c 'CGTAAAGCGCCCTAATC' *.fastq > count/B5543_Rm0.txt
agrep -0 -c 'CCACTTGAGTTGGCGAC' *.fastq > count/B5544_Rm0.txt
agrep -0 -c 'GATGCTATCTGGCCGAT' *.fastq > count/B5545_Rm0.txt
agrep -0 -c 'TCAGTGAATTCGCCGTG' *.fastq > count/B5546_Rm0.txt
agrep -0 -c 'CTAGAGTCGGCAACTAT' *.fastq > count/B5549_Rm0.txt
agrep -0 -c 'CAGTAAGCGTGTTGGCT' *.fastq > count/B5550_Rm0.txt
agrep -0 -c 'CAGACACACGAAGGCAC' *.fastq > count/B5551_Rm0.txt
agrep -0 -c 'CGGGATACGTACCATTA' *.fastq > count/B5552_Rm0.txt
agrep -0 -c 'GCCGTCTATTACCTTCC' *.fastq > count/B5553_Rm0.txt
agrep -0 -c 'GTTGATAGACACCCGCC' *.fastq > count/B5554_Rm0.txt
agrep -0 -c 'CACCGTGTTGGAGGTTG' *.fastq > count/B5555_Rm0.txt
agrep -0 -c 'TGGGCTAGGAATAGATC' *.fastq > count/B5556_Rm0.txt
agrep -0 -c 'GTTGGAGAACATGCAGT' *.fastq > count/B5557_Rm0.txt
agrep -0 -c 'GCCTGACCACTACTCAG' *.fastq > count/B5559_Rm0.txt
agrep -0 -c 'TTGTAGGACTCGTGTCT' *.fastq > count/B5560_Rm0.txt
agrep -0 -c 'CTCTAAATCGAAGGGCA' *.fastq > count/B5562_Rm0.txt
agrep -0 -c 'AGAGGGTAACTAGATCA' *.fastq > count/B5563_Rm0.txt
agrep -0 -c 'CATTGACGATGGCTAGG' *.fastq > count/B5564_Rm0.txt
agrep -0 -c 'CTGCAATTCTTTCTCGC' *.fastq > count/B5565_Rm0.txt
agrep -0 -c 'GAAAGGCATCCTAGGCT' *.fastq > count/B5566_Rm0.txt
agrep -0 -c 'GAGATACCGTGTCATAG' *.fastq > count/B5567_Rm0.txt
agrep -0 -c 'GTATCTGCTCGAAATCT' *.fastq > count/B5571_Rm0.txt
agrep -0 -c 'ATAGTGGTGGGACGAAG' *.fastq > count/B5572_Rm0.txt
agrep -0 -c 'CCTATTAGTTCACACGT' *.fastq > count/B5573_Rm0.txt
agrep -0 -c 'AGTCACGCTGCTATCCT' *.fastq > count/B5574_Rm0.txt
agrep -0 -c 'GCAGTTACCTAACGATA' *.fastq > count/B5576_Rm0.txt
agrep -0 -c 'GTGCATGTAGAATTCGG' *.fastq > count/B5577_Rm0.txt
agrep -0 -c 'TTCGGACACCACACTGA' *.fastq > count/B5578_Rm0.txt
agrep -0 -c 'GGAGAGGCCGCATAAAT' *.fastq > count/B5579_Rm0.txt
agrep -0 -c 'ATTAAGTCGCGGGAACA' *.fastq > count/B5580_Rm0.txt
agrep -0 -c 'TTGTCCATAGCATCGCT' *.fastq > count/B5581_Rm0.txt
agrep -0 -c 'TACTCATGCACGAGAAG' *.fastq > count/B5582_Rm0.txt
agrep -0 -c 'ATGTGGGAGGACCGCAA' *.fastq > count/B5585_Rm0.txt
agrep -0 -c 'TACGTCAGCGTACGACC' *.fastq > count/B5586_Rm0.txt
agrep -0 -c 'GCCTAATGGTTGCGAAG' *.fastq > count/B5587_Rm0.txt
agrep -0 -c 'GTGCGAAATTAACGGTG' *.fastq > count/B5588_Rm0.txt
agrep -0 -c 'CTGGTAGGCGGAATTAA' *.fastq > count/B5591_Rm0.txt
agrep -0 -c 'TATAACGATCGCGGCAG' *.fastq > count/B5592_Rm0.txt
agrep -0 -c 'CCATCCCGCATCTAGAT' *.fastq > count/B5593_Rm0.txt
agrep -0 -c 'CCTCTGTATACTAGGTA' *.fastq > count/B5595_Rm0.txt
agrep -0 -c 'GAGAAACCCCCTTCAGC' *.fastq > count/B5596_Rm0.txt
agrep -0 -c 'TTAATGACGGGAGGTGG' *.fastq > count/B5597_Rm0.txt
agrep -0 -c 'GGAGTTGTACAGCACCT' *.fastq > count/B5599_Rm0.txt
agrep -0 -c 'CTCGGATTTCTGGGGTA' *.fastq > count/B5600_Rm0.txt
agrep -0 -c 'AGGGGAATTTCCAACTA' *.fastq > count/B5601_Rm0.txt
agrep -0 -c 'TAGCTAGTACAGTGGAG' *.fastq > count/B5602_Rm0.txt
agrep -0 -c 'TTCTCGCGAGTTACACT' *.fastq > count/B5603_Rm0.txt
agrep -0 -c 'CGTGTATGTAACCACCT' *.fastq > count/B5604_Rm0.txt
agrep -0 -c 'CGGACACGGAGACCATA' *.fastq > count/B5606_Rm0.txt
agrep -0 -c 'CGTAGACACCATGGCTT' *.fastq > count/B5607_Rm0.txt
agrep -0 -c 'TAATCCTGTGGACTGAA' *.fastq > count/B5608_Rm0.txt
agrep -0 -c 'AGAATTCACGTTCGTGC' *.fastq > count/B5609_Rm0.txt
agrep -0 -c 'GACCAGTCTTCCATGCT' *.fastq > count/B5610_Rm0.txt
agrep -0 -c 'TGCCCTTAAGAACCTCC' *.fastq > count/B5611_Rm0.txt
agrep -0 -c 'TGACGATAGATGACCGG' *.fastq > count/B5612_Rm0.txt
agrep -0 -c 'CACGGGCCACAATTGAT' *.fastq > count/B5614_Rm0.txt
agrep -0 -c 'GTTCCGATGAATTTCAC' *.fastq > count/B5615_Rm0.txt
agrep -0 -c 'TCTCCGACTACGCACAA' *.fastq > count/B5616_Rm0.txt
agrep -0 -c 'AGATGCTCTATTCGGGT' *.fastq > count/B5617_Rm0.txt
agrep -0 -c 'TAACGTCCCACTTCCAT' *.fastq > count/B5618_Rm0.txt
agrep -0 -c 'GTACGGGTTAGACATGG' *.fastq > count/B5621_Rm0.txt
agrep -0 -c 'CTGTCGCAAACGGACAC' *.fastq > count/B5622_Rm0.txt
agrep -0 -c 'CAAATACTCCCCCTACA' *.fastq > count/B5623_Rm0.txt
agrep -0 -c 'AAACCGAACGAGTCCAC' *.fastq > count/B5624_Rm0.txt
agrep -0 -c 'TAAAATACCCGCGTTGT' *.fastq > count/B5625_Rm0.txt
agrep -0 -c 'TTATTGTGCTGGTGGCC' *.fastq > count/B5626_Rm0.txt
agrep -0 -c 'CGCACTACTTCACTTTA' *.fastq > count/B5627_Rm0.txt
agrep -0 -c 'TAATGAATGGATCGGGT' *.fastq > count/B5629_Rm0.txt
agrep -0 -c 'TGATGATCGAAACACTG' *.fastq > count/B5630_Rm0.txt
agrep -0 -c 'CACGATAAGCCCGTGCT' *.fastq > count/B5631_Rm0.txt
agrep -0 -c 'ATGGAATGGGCCGCGAA' *.fastq > count/B5632_Rm0.txt
agrep -0 -c 'GCAGGAATTCGCGCACA' *.fastq > count/B5634_Rm0.txt
agrep -0 -c 'CGTACAAGAAACTGGTG' *.fastq > count/B5635_Rm0.txt
agrep -0 -c 'AATCACTAATGGATGCG' *.fastq > count/B5636_Rm0.txt
agrep -0 -c 'TCGCATACAACCAGCTG' *.fastq > count/B5637_Rm0.txt
agrep -0 -c 'GACATAAGGTGGTCTGA' *.fastq > count/B5638_Rm0.txt
agrep -0 -c 'ACCTATTCCTTCACACC' *.fastq > count/B5639_Rm0.txt
agrep -0 -c 'TCAGTGCATGACCTCTA' *.fastq > count/B5641_Rm0.txt
agrep -0 -c 'CGACCCAGGTTACGGTT' *.fastq > count/B5642_Rm0.txt
agrep -0 -c 'GCACACTAGGAAAGTAG' *.fastq > count/B5643_Rm0.txt
agrep -0 -c 'CAGGTAAATGAGTTACG' *.fastq > count/B5645_Rm0.txt
agrep -0 -c 'GTTACCCGAGCTCACTA' *.fastq > count/B5646_Rm0.txt
agrep -0 -c 'TTCACAAGCGACCATGC' *.fastq > count/B5647_Rm0.txt
agrep -0 -c 'CCCTTATTTGCCGGCTG' *.fastq > count/B5648_Rm0.txt
agrep -0 -c 'ATAACGGCTCATGCCTG' *.fastq > count/B5649_Rm0.txt
agrep -0 -c 'ACCTTGACGCTATCCGA' *.fastq > count/B5650_Rm0.txt
agrep -0 -c 'AGGAGACTAGAGCGTCG' *.fastq > count/B5651_Rm0.txt
agrep -0 -c 'GGAATGATGGTGCAATC' *.fastq > count/B5652_Rm0.txt
agrep -0 -c 'TTCATAGTGTCGGCCCC' *.fastq > count/B5653_Rm0.txt
agrep -0 -c 'CATCGATACGAGTCATG' *.fastq > count/B5655_Rm0.txt
agrep -0 -c 'GCATCGACTGTTAGGGC' *.fastq > count/B5658_Rm0.txt
agrep -0 -c 'AATTCGAGCTTGAATGG' *.fastq > count/B5659_Rm0.txt
agrep -0 -c 'GCGCTGTAACTTTCTAC' *.fastq > count/B5660_Rm0.txt
agrep -0 -c 'TAGACGAAGGCGTACGG' *.fastq > count/B5661_Rm0.txt
agrep -0 -c 'GCAACTAGTTTGTAGAG' *.fastq > count/B5662_Rm0.txt
agrep -0 -c 'ACACCTCCTAAAAACTG' *.fastq > count/B5663_Rm0.txt
agrep -0 -c 'GGCAATCAACTCCATAA' *.fastq > count/B5664_Rm0.txt
agrep -0 -c 'TTGCCACTCTTTCACTA' *.fastq > count/B5665_Rm0.txt
agrep -0 -c 'ACTCTAGTCACCGTTCT' *.fastq > count/B5666_Rm0.txt
agrep -0 -c 'TACCAACCTAGCGTAGT' *.fastq > count/B5668_Rm0.txt
agrep -0 -c 'GTATGAGGTCGTGTGCA' *.fastq > count/B5669_Rm0.txt
agrep -0 -c 'CTGTTTGAGTGAGCTCG' *.fastq > count/B5670_Rm0.txt
agrep -0 -c 'CACGAATCGGGTAACAG' *.fastq > count/B5671_Rm0.txt
agrep -0 -c 'TACACAGGTAGTGGTCT' *.fastq > count/B5672_Rm0.txt
agrep -0 -c 'CTTTGAAGCGTCGCTGT' *.fastq > count/B5673_Rm0.txt
agrep -0 -c 'AAACCCGACCTGAGCCA' *.fastq > count/B5674_Rm0.txt
agrep -0 -c 'CAAGTAGGAATCGGTGG' *.fastq > count/B5675_Rm0.txt
agrep -0 -c 'AGGGTCGTTGCAATACG' *.fastq > count/B5676_Rm0.txt
agrep -0 -c 'AGCCCGCTATCTGTGTA' *.fastq > count/B5677_Rm0.txt
agrep -0 -c 'AGTGGCGTCAGAGGGTT' *.fastq > count/B5678_Rm0.txt
agrep -0 -c 'GAGCAAGATAGTGGGCT' *.fastq > count/B5679_Rm0.txt
agrep -0 -c 'GATGGCCAGAAGCGGAA' *.fastq > count/B5680_Rm0.txt
agrep -0 -c 'GTTTTGCTCGGCCATGG' *.fastq > count/B5681_Rm0.txt
agrep -0 -c 'TATCGCTTTCCTCCTGC' *.fastq > count/B5683_Rm0.txt
agrep -0 -c 'TACAACGATGTATCCGG' *.fastq > count/B5684_Rm0.txt
agrep -0 -c 'TGGAGATTCTACACTCG' *.fastq > count/B5687_Rm0.txt
agrep -0 -c 'TGGAAGGATCTCTCCGA' *.fastq > count/B5689_Rm0.txt
agrep -0 -c 'CAAAATTGCACAGGGGC' *.fastq > count/B5690_Rm0.txt
agrep -0 -c 'GGCATTATCAATAGTCG' *.fastq > count/B5691_Rm0.txt
agrep -0 -c 'TGCTGGGCACAGACTTA' *.fastq > count/B5692_Rm0.txt
agrep -0 -c 'TGTTGATGTGACACCGG' *.fastq > count/B5693_Rm0.txt
agrep -0 -c 'CGACTAATGGGACAGCC' *.fastq > count/B5694_Rm0.txt
agrep -0 -c 'CCTCCTCGCATAGTAGG' *.fastq > count/B5697_Rm0.txt
agrep -0 -c 'CCGGGTTTCATACCTGT' *.fastq > count/B5698_Rm0.txt
agrep -0 -c 'CCAATTCTCAAGGGTCC' *.fastq > count/B5699_Rm0.txt
agrep -0 -c 'GATCGTGACTATAATCC' *.fastq > count/B5700_Rm0.txt
agrep -0 -c 'TGGAGTTCTTGTGTCCC' *.fastq > count/B5701_Rm0.txt
agrep -0 -c 'TATCCCCAAGGCATGCC' *.fastq > count/B5702_Rm0.txt
agrep -0 -c 'CCCGGACCAATCTAGTT' *.fastq > count/B5703_Rm0.txt
agrep -0 -c 'TAGCGACACTGAGGCCA' *.fastq > count/B5704_Rm0.txt
agrep -0 -c 'AGCCATGGGAGTACACG' *.fastq > count/B5705_Rm0.txt
agrep -0 -c 'GGAGTCTTCCCCGTATA' *.fastq > count/B5706_Rm0.txt
agrep -0 -c 'TGCCTGCAGTTTTCCGC' *.fastq > count/B5707_Rm0.txt
agrep -0 -c 'TAACTGATTGAGGTCGA' *.fastq > count/B5709_Rm0.txt
agrep -0 -c 'ACGCCTAACTCGCAACT' *.fastq > count/B5710_Rm0.txt
agrep -0 -c 'GCCATGGAATACCTGAC' *.fastq > count/B5712_Rm0.txt
agrep -0 -c 'TAACCATCACACGGTGC' *.fastq > count/B5714_Rm0.txt
agrep -0 -c 'GGTTTCGACAGTGTGCC' *.fastq > count/B5715_Rm0.txt
agrep -0 -c 'GGAGTATAGAGCGGTTA' *.fastq > count/B5716_Rm0.txt
agrep -0 -c 'ACCTTGAGAGAATGCGT' *.fastq > count/B5717_Rm0.txt
agrep -0 -c 'AAATCCCTGCGCTCGTT' *.fastq > count/B5718_Rm0.txt
agrep -0 -c 'AACGGAATAAGCGGGGT' *.fastq > count/B5719_Rm0.txt
agrep -0 -c 'TTAAAACGCCGCGATGA' *.fastq > count/B5720_Rm0.txt
agrep -0 -c 'CGAGATGATCACAACTA' *.fastq > count/B5721_Rm0.txt
agrep -0 -c 'GATTACGTGCGGACTGG' *.fastq > count/B5722_Rm0.txt
agrep -0 -c 'AGAGCAGGTATTATACC' *.fastq > count/B5723_Rm0.txt
agrep -0 -c 'TCGAGGCTGAGTTACGG' *.fastq > count/B5725_Rm0.txt
agrep -0 -c 'AAGCTTTTGATGACGCA' *.fastq > count/B5726_Rm0.txt
agrep -0 -c 'AGCGCCTGGTAATGAGG' *.fastq > count/B5727_Rm0.txt
agrep -0 -c 'CGATGTCAAGCTGATCG' *.fastq > count/B5728_Rm0.txt
agrep -0 -c 'CGGCAGTTCAATTAGGT' *.fastq > count/B5729_Rm0.txt
agrep -0 -c 'CATGCAGAAGATAAACC' *.fastq > count/B5730_Rm0.txt
agrep -0 -c 'GATTGCCGCTGGTTTCG' *.fastq > count/B5731_Rm0.txt
agrep -0 -c 'AAGCGATAGAGCGCTAA' *.fastq > count/B5732_Rm0.txt
agrep -0 -c 'GGACACCAGTAGTAAGA' *.fastq > count/B5734_Rm0.txt
agrep -0 -c 'GAGCAACGACCTTTTCG' *.fastq > count/B5735_Rm0.txt
agrep -0 -c 'GCAGTTACCGGGGTGAA' *.fastq > count/B5736_Rm0.txt
agrep -0 -c 'ATCGACGTGCTAGGGTG' *.fastq > count/B5737_Rm0.txt
agrep -0 -c 'GTGGGAGCGTTTCTTCT' *.fastq > count/B5738_Rm0.txt
agrep -0 -c 'GTGTTAAGACGAATGCT' *.fastq > count/B5739_Rm0.txt
agrep -0 -c 'TGAATACGTTGTAAGCC' *.fastq > count/B5740_Rm0.txt
agrep -0 -c 'GTAACACTCCGCTGGAC' *.fastq > count/B5741_Rm0.txt
agrep -0 -c 'TCAATCTCGGGCGATTA' *.fastq > count/B5742_Rm0.txt
agrep -0 -c 'TGGATTGGTTCCTATCC' *.fastq > count/B5743_Rm0.txt
agrep -0 -c 'CAAACTCGATCCAACGC' *.fastq > count/B5746_Rm0.txt
agrep -0 -c 'CCTGATCACGGATATCA' *.fastq > count/B5747_Rm0.txt
agrep -0 -c 'CCCTATAGTCGAAATCC' *.fastq > count/B5749_Rm0.txt
agrep -0 -c 'CACTCCTCTCTGGCATT' *.fastq > count/B5750_Rm0.txt
agrep -0 -c 'TAACCCCAAGAGCGGAC' *.fastq > count/B5751_Rm0.txt
agrep -0 -c 'AACGTCGATCGCCGGAA' *.fastq > count/B5752_Rm0.txt
agrep -0 -c 'ATAGGCCGACTCAACTA' *.fastq > count/B5753_Rm0.txt
agrep -0 -c 'CCGACTTATTGGCGAAT' *.fastq > count/B5754_Rm0.txt
agrep -0 -c 'CTTGGCCACAAGCGATT' *.fastq > count/B5755_Rm0.txt
agrep -0 -c 'ATCACCAGGCTAGCTAT' *.fastq > count/B5756_Rm0.txt
agrep -0 -c 'GGAGAAGGTACGCTCAT' *.fastq > count/B5757_Rm0.txt
agrep -0 -c 'ATCAACGAAAGCGCCTT' *.fastq > count/B5758_Rm0.txt
agrep -0 -c 'GAATAGCGGCAGGTTCA' *.fastq > count/B5759_Rm0.txt
agrep -0 -c 'AAGGCGTCTATCCTGGT' *.fastq > count/B5760_Rm0.txt
agrep -0 -c 'GATACCGTCCTTGTCTC' *.fastq > count/B5762_Rm0.txt
agrep -0 -c 'GACTTACGGCAAGACAC' *.fastq > count/B5763_Rm0.txt
agrep -0 -c 'CCTCCTGGTCTACTAGT' *.fastq > count/B5764_Rm0.txt
agrep -0 -c 'TTTCTTGGGTTATGGCT' *.fastq > count/B5765_Rm0.txt
agrep -0 -c 'GGCTAAAGACGAACAGA' *.fastq > count/B5767_Rm0.txt
agrep -0 -c 'TCCTGTGGTGACTCATT' *.fastq > count/B5768_Rm0.txt
agrep -0 -c 'GTCTTGTATGTGACCGA' *.fastq > count/B5769_Rm0.txt
agrep -0 -c 'AGCTAGACATTCGGTTA' *.fastq > count/B5770_Rm0.txt
agrep -0 -c 'TAGGAGGTACCCATACT' *.fastq > count/B5771_Rm0.txt
agrep -0 -c 'TGCCGCGTGAGATATGG' *.fastq > count/B5772_Rm0.txt
agrep -0 -c 'TTCCGAGCTGGATGTGA' *.fastq > count/B5773_Rm0.txt
agrep -0 -c 'CCCACGGCCTTAGATTA' *.fastq > count/B5774_Rm0.txt
agrep -0 -c 'TTCTTGATCCCCTACAA' *.fastq > count/B5775_Rm0.txt
agrep -0 -c 'TACCTCTGAGCAACAGT' *.fastq > count/B5776_Rm0.txt
agrep -0 -c 'AAAGGCGCAAGCAACGG' *.fastq > count/B5777_Rm0.txt
agrep -0 -c 'TCCATCAAAGGGCGAGG' *.fastq > count/B5778_Rm0.txt
agrep -0 -c 'ATGCGCCGTGGTAGTGA' *.fastq > count/B5779_Rm0.txt
agrep -0 -c 'AACCGATAGGGAGAGGT' *.fastq > count/B5780_Rm0.txt
agrep -0 -c 'GTAAGCGAACCAGTTCC' *.fastq > count/B5781_Rm0.txt
agrep -0 -c 'CAGTCGGATCCTGATAA' *.fastq > count/B5782_Rm0.txt
agrep -0 -c 'CGTAGTGCTTTTGTAAG' *.fastq > count/B5783_Rm0.txt
agrep -0 -c 'ATGCCCATTCGCTTTAT' *.fastq > count/B5785_Rm0.txt
agrep -0 -c 'GGAGATACGGGTTCCTC' *.fastq > count/B5786_Rm0.txt
agrep -0 -c 'CGTCGCGAAGGTTAGAA' *.fastq > count/B5787_Rm0.txt
agrep -0 -c 'CCTAACCATCGTTTTGT' *.fastq > count/B5789_Rm0.txt
agrep -0 -c 'GATTTCAAACGTCCACG' *.fastq > count/B5790_Rm0.txt
agrep -0 -c 'AACACTAGTGTCTGCCC' *.fastq > count/B5792_Rm0.txt
agrep -0 -c 'ACGTTTTCCAGAGGCCC' *.fastq > count/B5793_Rm0.txt
agrep -0 -c 'AGGCAGACAAAGTCTCG' *.fastq > count/B5795_Rm0.txt
agrep -0 -c 'TCGCTAAGGCTTTGATA' *.fastq > count/B5797_Rm0.txt
agrep -0 -c 'GCTAGGGAATAGCGGTA' *.fastq > count/B5798_Rm0.txt
agrep -0 -c 'CCCTGAAATCTCTACGA' *.fastq > count/B5799_Rm0.txt
agrep -0 -c 'TCGCTTGATCGCACTTG' *.fastq > count/B5800_Rm0.txt
agrep -0 -c 'GTTGCCGGGTATTCAAG' *.fastq > count/B5801_Rm0.txt
agrep -0 -c 'CCAAGAGCAATGATCGC' *.fastq > count/B5802_Rm0.txt
agrep -0 -c 'ACGTTGACTGCTAGGTT' *.fastq > count/B5803_Rm0.txt
agrep -0 -c 'CGGTAGTATTATGTGGT' *.fastq > count/B5804_Rm0.txt
agrep -0 -c 'TATCTACTGCGCGGAGA' *.fastq > count/B5805_Rm0.txt
agrep -0 -c 'TTGCAGCTAGGGTCTAG' *.fastq > count/B5806_Rm0.txt
agrep -0 -c 'CCGTGTTGCTTAGCCTA' *.fastq > count/B5807_Rm0.txt
agrep -0 -c 'GAGGTCAGAGAGGTCCT' *.fastq > count/B5808_Rm0.txt
agrep -0 -c 'CGATAATGAGTGGCATT' *.fastq > count/B5809_Rm0.txt
agrep -0 -c 'GAACAGGGCACCCAATG' *.fastq > count/B5810_Rm0.txt
agrep -0 -c 'AACGATTCAGTCCCAGA' *.fastq > count/B5811_Rm0.txt
agrep -0 -c 'TGATCCGTATACAACGG' *.fastq > count/B5812_Rm0.txt
agrep -0 -c 'CCTGACGTTGGAATCAA' *.fastq > count/B5813_Rm0.txt
agrep -0 -c 'CTCATTGCATAAGGACT' *.fastq > count/B5814_Rm0.txt
agrep -0 -c 'CGACACGGTTTAGACCG' *.fastq > count/B5815_Rm0.txt
agrep -0 -c 'ACTCAGAAACGAGCCGG' *.fastq > count/B5816_Rm0.txt
agrep -0 -c 'GCATAAAGTCGCCGCAT' *.fastq > count/B5817_Rm0.txt
agrep -0 -c 'CTGAACGAGACATGTTA' *.fastq > count/B5818_Rm0.txt
agrep -0 -c 'GCGCATACCTAACAATC' *.fastq > count/B5821_Rm0.txt
agrep -0 -c 'TTCCAACAATTTAGGCC' *.fastq > count/B5822_Rm0.txt
agrep -0 -c 'CCCACATCGATATCTGG' *.fastq > count/B5823_Rm0.txt
agrep -0 -c 'TCTCGACGCAGAACTTA' *.fastq > count/B5824_Rm0.txt
agrep -0 -c 'ACTCGTTTCGAGTGCGA' *.fastq > count/B5825_Rm0.txt
agrep -0 -c 'TTCAGTTGGCTGGACGA' *.fastq > count/B5826_Rm0.txt
agrep -0 -c 'CATCAAGCGGCACTGAC' *.fastq > count/B5827_Rm0.txt
agrep -0 -c 'GAGCCGATACCTTAGAG' *.fastq > count/B5828_Rm0.txt
agrep -0 -c 'TACACTGGTTGCCAATA' *.fastq > count/B5829_Rm0.txt
agrep -0 -c 'CCGTGGTTCCAACGCTA' *.fastq > count/B5830_Rm0.txt
agrep -0 -c 'GCAGAGTTCGTCACAAT' *.fastq > count/B5831_Rm0.txt
agrep -0 -c 'AGGTCTGTTACGGTGAC' *.fastq > count/B5833_Rm0.txt
agrep -0 -c 'GTGGTGAAATTACTCGG' *.fastq > count/B5834_Rm0.txt
agrep -0 -c 'TTAGGATCCATCGCCGC' *.fastq > count/B5835_Rm0.txt
agrep -0 -c 'TCATTTCGAACGAACGG' *.fastq > count/B5836_Rm0.txt
agrep -0 -c 'ATATGTCCCTGTTGAGA' *.fastq > count/B5837_Rm0.txt
agrep -0 -c 'GTCGGTAACCATCTTCG' *.fastq > count/B5838_Rm0.txt
agrep -0 -c 'CGGATATGGGGATTCAG' *.fastq > count/B5839_Rm0.txt
agrep -0 -c 'AAGTCGATATCAGGCGG' *.fastq > count/B5840_Rm0.txt
agrep -0 -c 'AATACGTGTTGAAGTCG' *.fastq > count/B5841_Rm0.txt
agrep -0 -c 'TTAGGGTACATTTGGCA' *.fastq > count/B5842_Rm0.txt
agrep -0 -c 'CACCTGACCGTGAGATA' *.fastq > count/B5843_Rm0.txt
agrep -0 -c 'ACATCATATTGGGATCG' *.fastq > count/B5844_Rm0.txt
agrep -0 -c 'CTGATTGTCTCACATGC' *.fastq > count/B5847_Rm0.txt
agrep -0 -c 'GAGTAGGATTACGTCGA' *.fastq > count/B5848_Rm0.txt
agrep -0 -c 'GTAGGCTGGACTCCAAC' *.fastq > count/B5849_Rm0.txt
agrep -0 -c 'TGAGCTAGTTCGCATCC' *.fastq > count/B5850_Rm0.txt
agrep -0 -c 'CCCGGAATCTATCGCAT' *.fastq > count/B5851_Rm0.txt
agrep -0 -c 'TATACCGGGCTGTTTGC' *.fastq > count/B5852_Rm0.txt
agrep -0 -c 'CATCAAATGGGCGGTCA' *.fastq > count/B5853_Rm0.txt
agrep -0 -c 'CTTAGGCGGGTATAGTA' *.fastq > count/B5854_Rm0.txt
agrep -0 -c 'ATGTTGGCAAGGCTGAT' *.fastq > count/B5855_Rm0.txt
agrep -0 -c 'ATCTCTGTCTGTGTTAG' *.fastq > count/B5856_Rm0.txt
agrep -0 -c 'TAATTAGAGGACGGAGC' *.fastq > count/B5858_Rm0.txt
agrep -0 -c 'CAGGAACCCACGAGAAG' *.fastq > count/B5859_Rm0.txt
agrep -0 -c 'GGGGGCACCCTAAATAC' *.fastq > count/B5860_Rm0.txt
agrep -0 -c 'CACTTTGTTGACTCACT' *.fastq > count/B5861_Rm0.txt
agrep -0 -c 'CTGATTCATGGACCTGG' *.fastq > count/B5862_Rm0.txt
agrep -0 -c 'TGACATAAACCCGGCTC' *.fastq > count/B5863_Rm0.txt
agrep -0 -c 'CCGGGTCAATGAGTTGA' *.fastq > count/B5864_Rm0.txt
agrep -0 -c 'GCAATCATGAATGCGCG' *.fastq > count/B5865_Rm0.txt
agrep -0 -c 'ACTATTCATGGTGCAGT' *.fastq > count/B5866_Rm0.txt
agrep -0 -c 'TGTCATGGCTAGGCATT' *.fastq > count/B5867_Rm0.txt
agrep -0 -c 'GAGCCAGTCTTAGAAAC' *.fastq > count/B5868_Rm0.txt
agrep -0 -c 'GCGCGCGTTTAACGACT' *.fastq > count/B5869_Rm0.txt
agrep -0 -c 'ATCCCGTTCTGTATTCG' *.fastq > count/B5870_Rm0.txt
agrep -0 -c 'CGCTGTGTTGGATTTGA' *.fastq > count/B5871_Rm0.txt
agrep -0 -c 'TATAAGAGTAGAGCGCG' *.fastq > count/B5873_Rm0.txt
agrep -0 -c 'TCCCGAATCCCTTACTT' *.fastq > count/B5874_Rm0.txt
agrep -0 -c 'AGTCTCAGTCAAAACCG' *.fastq > count/B5876_Rm0.txt
agrep -0 -c 'AATCAGCTAGTCAACTC' *.fastq > count/B5877_Rm0.txt
agrep -0 -c 'ACAGTGATCGCTAGAAC' *.fastq > count/B5878_Rm0.txt
agrep -0 -c 'TCTAGATGCTACGGATG' *.fastq > count/B5879_Rm0.txt
agrep -0 -c 'ACGGACTTGCTACGGAT' *.fastq > count/B5880_Rm0.txt
agrep -0 -c 'CACTGAAAATAGCCACG' *.fastq > count/B5882_Rm0.txt
agrep -0 -c 'AAGCGGGCGATATAACT' *.fastq > count/B5884_Rm0.txt
agrep -0 -c 'GACGATACTACCTGCTG' *.fastq > count/B5885_Rm0.txt
agrep -0 -c 'GGTATGCTTGCTGCGAG' *.fastq > count/B5886_Rm0.txt
agrep -0 -c 'ACAATGGAGCCACGCAT' *.fastq > count/B5887_Rm0.txt
agrep -0 -c 'ATGCCTGCTACAGACTT' *.fastq > count/B5888_Rm0.txt
agrep -0 -c 'CCTTTTGCGTTCAGGTG' *.fastq > count/B5889_Rm0.txt
agrep -0 -c 'ACGGCCATGGTTAGAGA' *.fastq > count/B5890_Rm0.txt
agrep -0 -c 'CTGGACGCAGACTAGAC' *.fastq > count/B5891_Rm0.txt
agrep -0 -c 'GCACACCATAGTCAGGC' *.fastq > count/B5893_Rm0.txt
agrep -0 -c 'AAGCATTGACTTGTCGA' *.fastq > count/B5894_Rm0.txt
agrep -0 -c 'CGCCATATATTTCGCTG' *.fastq > count/B5895_Rm0.txt
agrep -0 -c 'TACTGTCAACCACGCCT' *.fastq > count/B5897_Rm0.txt
agrep -0 -c 'CGACTGACGTAACTTAC' *.fastq > count/B5898_Rm0.txt
agrep -0 -c 'CAATTAATACGCTCCGA' *.fastq > count/B5899_Rm0.txt
agrep -0 -c 'GTTTTGAAATGACAGCG' *.fastq > count/B5900_Rm0.txt
agrep -0 -c 'TTGACTACTTAGCACGA' *.fastq > count/B5901_Rm0.txt
agrep -0 -c 'GAACGCTACAACTGAAT' *.fastq > count/B5902_Rm0.txt
agrep -0 -c 'CTGAGTAACGGAATGCC' *.fastq > count/B5903_Rm0.txt
agrep -0 -c 'CGCTTAGGGTACGGTAG' *.fastq > count/B5904_Rm0.txt
agrep -0 -c 'CGCACAAGTCATTACTA' *.fastq > count/B5905_Rm0.txt
agrep -0 -c 'TTAAGGAGCCGCGGAGT' *.fastq > count/B5906_Rm0.txt
agrep -0 -c 'AAGTGGCTTCAACATGT' *.fastq > count/B5907_Rm0.txt
agrep -0 -c 'CACACAGACACTCAACG' *.fastq > count/B5908_Rm0.txt
agrep -0 -c 'TTATGGTAAGGGGCTGT' *.fastq > count/B5909_Rm0.txt
agrep -0 -c 'GGGAAGCTTTCATGGCT' *.fastq > count/B5910_Rm0.txt
agrep -0 -c 'TCCTGGTACTAGAGAAC' *.fastq > count/B5911_Rm0.txt
agrep -0 -c 'TTCCCCCTGGGTGGTAT' *.fastq > count/B5912_Rm0.txt
agrep -0 -c 'GGGCATTAGTACTCCGC' *.fastq > count/B5913_Rm0.txt
agrep -0 -c 'AACGATCCCACCCTAGC' *.fastq > count/B5915_Rm0.txt
agrep -0 -c 'AGTTGACACTCAGCGCG' *.fastq > count/B5917_Rm0.txt
agrep -0 -c 'TTCTTGGTTCTGAAGTC' *.fastq > count/B5918_Rm0.txt
agrep -0 -c 'ACCTGTAGCCAGTAACG' *.fastq > count/B5919_Rm0.txt
agrep -0 -c 'AAGTCGTCAGAGCAGTT' *.fastq > count/B5920_Rm0.txt
agrep -0 -c 'ATGGGATGGAACGGCAG' *.fastq > count/B5921_Rm0.txt
agrep -0 -c 'TTGTTCGTAGGCCAGCT' *.fastq > count/B5922_Rm0.txt
agrep -0 -c 'AGTGTATCCCGGTAGCG' *.fastq > count/B5924_Rm0.txt
agrep -0 -c 'GGCTCAATGCAAGATAG' *.fastq > count/B5926_Rm0.txt
agrep -0 -c 'TTAGCCCGCGAACTATT' *.fastq > count/B5927_Rm0.txt
agrep -0 -c 'AAACGATATTGCCCCTT' *.fastq > count/B5928_Rm0.txt
agrep -0 -c 'GTTCACAGTTAGAGTCG' *.fastq > count/B5929_Rm0.txt
agrep -0 -c 'CGTATAGGTAGACCAGA' *.fastq > count/B5930_Rm0.txt
agrep -0 -c 'TCCGACAGAGTGGGTTA' *.fastq > count/B5931_Rm0.txt
agrep -0 -c 'ACGGCATAAAGCCGAGC' *.fastq > count/B5932_Rm0.txt
agrep -0 -c 'ATTGCGTTAGGACCCGT' *.fastq > count/B5933_Rm0.txt
agrep -0 -c 'GTCCCTAAACTCCGGAA' *.fastq > count/B5934_Rm0.txt
agrep -0 -c 'TTGGGAGCAACTATGCT' *.fastq > count/B5935_Rm0.txt
agrep -0 -c 'GGTCGGGATGTGATATC' *.fastq > count/B5936_Rm0.txt
agrep -0 -c 'ATGGAGCTAAAGCCAAT' *.fastq > count/B5937_Rm0.txt
agrep -0 -c 'CGAGTAACTCTGATGCC' *.fastq > count/B5939_Rm0.txt
agrep -0 -c 'GCGGCTACTCGGTGATT' *.fastq > count/B5940_Rm0.txt
agrep -0 -c 'ACGAATTAGCCGTCGAA' *.fastq > count/B5941_Rm0.txt
agrep -0 -c 'CGAAAAGCAACAGCTAG' *.fastq > count/B5943_Rm0.txt
agrep -0 -c 'CATTTGCGAGTGAAGCT' *.fastq > count/B5944_Rm0.txt
agrep -0 -c 'CGTTTGGGGTGATATAG' *.fastq > count/B5945_Rm0.txt
agrep -0 -c 'ATAAGGAGTGTGCGCTG' *.fastq > count/B5946_Rm0.txt
agrep -0 -c 'AATTCCGTGTCGACTAC' *.fastq > count/B5949_Rm0.txt
agrep -0 -c 'ACGACACGCATCACATA' *.fastq > count/B5950_Rm0.txt
agrep -0 -c 'TTGCGATCGAGTGCGCA' *.fastq > count/B5952_Rm0.txt
agrep -0 -c 'CAAAGACAGCATTAGCA' *.fastq > count/B5953_Rm0.txt
agrep -0 -c 'AAGCCCACATTCGCGGT' *.fastq > count/B5954_Rm0.txt
agrep -0 -c 'AGCTTCCGTTATCTGAG' *.fastq > count/B5955_Rm0.txt
agrep -0 -c 'TTGCGCGTGATGATGGC' *.fastq > count/B5957_Rm0.txt
agrep -0 -c 'GCACCCCCCATGTGTAT' *.fastq > count/B5958_Rm0.txt
agrep -0 -c 'GAAGGGGGTCGTTTTCG' *.fastq > count/B5959_Rm0.txt
agrep -0 -c 'GGTCTGTACCACACCAA' *.fastq > count/B5960_Rm0.txt
agrep -0 -c 'CTCTTATGCACGGGCGA' *.fastq > count/B5961_Rm0.txt
agrep -0 -c 'GGTAGAGGAGCCAAACT' *.fastq > count/B5962_Rm0.txt
agrep -0 -c 'AACGTAGGTTGGAGGTG' *.fastq > count/B5963_Rm0.txt
agrep -0 -c 'AGGCGGGGGAATTTAAC' *.fastq > count/B5964_Rm0.txt
agrep -0 -c 'TCAGTACTCCGGTTTGA' *.fastq > count/B5968_Rm0.txt
agrep -0 -c 'GATTCAGTCCACGCTCA' *.fastq > count/B5970_Rm0.txt
agrep -0 -c 'AGTGCTCCTCATGGCAG' *.fastq > count/B5971_Rm0.txt
agrep -0 -c 'GACCGATCAAATTGTTG' *.fastq > count/B5972_Rm0.txt
agrep -0 -c 'AAAACAGGACTGTGTCT' *.fastq > count/B5973_Rm0.txt
agrep -0 -c 'TGAATTAGTACACGGCT' *.fastq > count/B5974_Rm0.txt
agrep -0 -c 'TTAGCTAAGACGGACTA' *.fastq > count/B5975_Rm0.txt
agrep -0 -c 'TGTTCAGCGTGACCTTA' *.fastq > count/B5976_Rm0.txt
agrep -0 -c 'ATACGTAGAACTCACTC' *.fastq > count/B5977_Rm0.txt
agrep -0 -c 'CGATAGCATCTCTGAAT' *.fastq > count/B5978_Rm0.txt
agrep -0 -c 'TAGTGCCCCTATGCTGA' *.fastq > count/B5979_Rm0.txt
agrep -0 -c 'TGCGGATACATATATGC' *.fastq > count/B5980_Rm0.txt
agrep -0 -c 'CTGGTCGCAAAGAGTGA' *.fastq > count/B5981_Rm0.txt
agrep -0 -c 'CACAAGAGTAAAGGACA' *.fastq > count/B5982_Rm0.txt
agrep -0 -c 'AACCGCTGAGAACACGA' *.fastq > count/B5983_Rm0.txt
agrep -0 -c 'GCATAACCTCGAGCGTC' *.fastq > count/B5984_Rm0.txt
agrep -0 -c 'TCGATCATTGGACACTC' *.fastq > count/B5985_Rm0.txt
agrep -0 -c 'AGTGTACCTCCGGCAGT' *.fastq > count/B5986_Rm0.txt
agrep -0 -c 'TCAGGAGGCTTGTCTCA' *.fastq > count/B5987_Rm0.txt
agrep -0 -c 'TTAAACTGTAGGGCATG' *.fastq > count/B5988_Rm0.txt
agrep -0 -c 'GTATCTTCCTGTCGCGA' *.fastq > count/B5989_Rm0.txt
agrep -0 -c 'TCAGGTTATGTAGCTTG' *.fastq > count/B5990_Rm0.txt
agrep -0 -c 'GACTCAGGCTTGTCTTA' *.fastq > count/B5991_Rm0.txt
agrep -0 -c 'TGCACGTTGCTACTAAC' *.fastq > count/B5993_Rm0.txt
agrep -0 -c 'ACGACCCATTGTCCAGA' *.fastq > count/B5994_Rm0.txt
agrep -0 -c 'TCTTAGGGTATTCCTAG' *.fastq > count/B5995_Rm0.txt
agrep -0 -c 'TTAACGCGGGCAAATGG' *.fastq > count/B5996_Rm0.txt
agrep -0 -c 'ATTGTTATTGCCGGCCC' *.fastq > count/B5999_Rm0.txt
agrep -0 -c 'GGAGAGATACCACCTCT' *.fastq > count/B6000_Rm0.txt
agrep -0 -c 'TCCTCCGGCAATATATT' *.fastq > count/B6001_Rm0.txt
agrep -0 -c 'TCCAGGTGCCAATCTGG' *.fastq > count/B6002_Rm0.txt
agrep -0 -c 'AACATGCGCACCCGATT' *.fastq > count/B6003_Rm0.txt
agrep -0 -c 'AAGTAGGCAATCAATGG' *.fastq > count/B6004_Rm0.txt
agrep -0 -c 'AGTTATATGTCGCGATG' *.fastq > count/B6005_Rm0.txt
agrep -0 -c 'GCTTGTGCATGATCCTG' *.fastq > count/B6007_Rm0.txt
agrep -0 -c 'CCCTCATTGACATTTGC' *.fastq > count/B6008_Rm0.txt
agrep -0 -c 'GCCCTGGTAATGGTATC' *.fastq > count/B6009_Rm0.txt
agrep -0 -c 'GGCATCTACTTCATAGC' *.fastq > count/B6011_Rm0.txt
agrep -0 -c 'GCAGGTTCTCTAGGCAA' *.fastq > count/B6012_Rm0.txt
agrep -0 -c 'TACTCAAACCTGCGGAT' *.fastq > count/B6013_Rm0.txt
agrep -0 -c 'TTAACTCGAATGGTCGG' *.fastq > count/B6014_Rm0.txt
agrep -0 -c 'CGTAGATGGCAGCGACA' *.fastq > count/B6015_Rm0.txt
agrep -0 -c 'GTTAAGGAGGCTTGGAG' *.fastq > count/B6018_Rm0.txt
agrep -0 -c 'GGTTCGGGAATCTTGCG' *.fastq > count/B6019_Rm0.txt
agrep -0 -c 'GACCTATGAGCTCCTCC' *.fastq > count/B6021_Rm0.txt
agrep -0 -c 'CTTTCTCCGCTGGTACA' *.fastq > count/B6022_Rm0.txt
agrep -0 -c 'TACAAATTTGTCCCCCC' *.fastq > count/B6024_Rm0.txt
agrep -0 -c 'AGTCCATTGGCAGAGCA' *.fastq > count/B6025_Rm0.txt
agrep -0 -c 'AGGAAATCGTAGGTTCG' *.fastq > count/B6026_Rm0.txt
agrep -0 -c 'GGAGCGTTTGTCATAAG' *.fastq > count/B6027_Rm0.txt
agrep -0 -c 'TTGCGTCGACTATATCC' *.fastq > count/B6028_Rm0.txt
agrep -0 -c 'GGTCATCGTGGTCAGGT' *.fastq > count/B6030_Rm0.txt
agrep -0 -c 'TGGCCGATCGCAATCAT' *.fastq > count/B6031_Rm0.txt
agrep -0 -c 'ATCTCGCAATGAGTATG' *.fastq > count/B6032_Rm0.txt
agrep -0 -c 'GATAAGCCCCCATTGCG' *.fastq > count/B6034_Rm0.txt
agrep -0 -c 'CATGGCTACCCGATGAA' *.fastq > count/B6036_Rm0.txt
agrep -0 -c 'GACCAAACCCTAGACCG' *.fastq > count/B6037_Rm0.txt
agrep -0 -c 'CGCATTCGCCTCTTCAT' *.fastq > count/B6038_Rm0.txt
agrep -0 -c 'ACCATAGCGAGAAACCT' *.fastq > count/B6040_Rm0.txt
agrep -0 -c 'TCGATTGCGTCACCGTT' *.fastq > count/B6041_Rm0.txt
agrep -0 -c 'CAAGCAGTGTTAACGAG' *.fastq > count/B6042_Rm0.txt
agrep -0 -c 'GAGTGTACGGCATTCTT' *.fastq > count/B6043_Rm0.txt
agrep -0 -c 'GCACTTTGCGTGCCATA' *.fastq > count/B6044_Rm0.txt
agrep -0 -c 'GTTCCCGGTCATCACAT' *.fastq > count/B6045_Rm0.txt
agrep -0 -c 'AAGCAGTTGACTAGGTT' *.fastq > count/B6046_Rm0.txt
agrep -0 -c 'CATGACGGAGAACAGAT' *.fastq > count/B6047_Rm0.txt
agrep -0 -c 'CAATAGTGATACGACCG' *.fastq > count/B6048_Rm0.txt
agrep -0 -c 'TACCTTCGACGCTCTAC' *.fastq > count/B6049_Rm0.txt
agrep -0 -c 'GCTAAATCAGAAAGTCG' *.fastq > count/B6050_Rm0.txt
agrep -0 -c 'GCGGATAGGGTCTATCA' *.fastq > count/B6051_Rm0.txt
agrep -0 -c 'GAATGCGAGCGAAATAA' *.fastq > count/B6052_Rm0.txt
agrep -0 -c 'CCAACGTGTGCTCCATT' *.fastq > count/B6053_Rm0.txt
agrep -0 -c 'TTCGTAGACTCAGTAGA' *.fastq > count/B6054_Rm0.txt
agrep -0 -c 'CGTGTAAGGAATAGGAC' *.fastq > count/B6055_Rm0.txt
agrep -0 -c 'GTATTGCCCATGTGCAC' *.fastq > count/B6056_Rm0.txt
agrep -0 -c 'ACCGGGAAATACGAGCC' *.fastq > count/B6057_Rm0.txt
agrep -0 -c 'AGAGACTCAGAACTACT' *.fastq > count/B6058_Rm0.txt
agrep -0 -c 'CCATTACTTCTCTTGCG' *.fastq > count/B6059_Rm0.txt
agrep -0 -c 'CCTTTTATGACGCAGAT' *.fastq > count/B6060_Rm0.txt
agrep -0 -c 'TGGTGACAGAGCTATAC' *.fastq > count/B6061_Rm0.txt
agrep -0 -c 'GCCTGGATCATTATCCA' *.fastq > count/B6062_Rm0.txt
agrep -0 -c 'CTTCGTGCACCCTCATG' *.fastq > count/B6063_Rm0.txt
agrep -0 -c 'GTATAAAAACTGCCCCG' *.fastq > count/B6064_Rm0.txt
agrep -0 -c 'TGTGATTCCATGGGTCT' *.fastq > count/B6065_Rm0.txt
agrep -0 -c 'CCAGTGTATCGTTAGGT' *.fastq > count/B6066_Rm0.txt
agrep -0 -c 'CACAGAGTAAGACCGAA' *.fastq > count/B6068_Rm0.txt
agrep -0 -c 'GGTGTGTCACTCTGTTA' *.fastq > count/B6069_Rm0.txt
agrep -0 -c 'TCAACGTTTCATGGCTT' *.fastq > count/B6070_Rm0.txt
agrep -0 -c 'CACTCGTGAACGATTGC' *.fastq > count/B6072_Rm0.txt
agrep -0 -c 'CCGGATACGAAATCTAC' *.fastq > count/B6073_Rm0.txt
agrep -0 -c 'ACGATCGATCTCACTTG' *.fastq > count/B6074_Rm0.txt
agrep -0 -c 'CGGCCTTGACCTGTGTT' *.fastq > count/B6075_Rm0.txt
agrep -0 -c 'CGTGTAATGACGGCGAT' *.fastq > count/B6076_Rm0.txt
agrep -0 -c 'GTAACTTGGGAAGGATG' *.fastq > count/B6077_Rm0.txt
agrep -0 -c 'GATCCTGACTTTAGAAG' *.fastq > count/B6079_Rm0.txt
agrep -0 -c 'CGGTAGTCACCATGACT' *.fastq > count/B6080_Rm0.txt
agrep -0 -c 'GGTGTGGCGTAGTAATG' *.fastq > count/B6081_Rm0.txt
agrep -0 -c 'TCCGAATCCTGAATCGC' *.fastq > count/B6083_Rm0.txt
agrep -0 -c 'CCGGTGTGGTTAATCCT' *.fastq > count/B6084_Rm0.txt
agrep -0 -c 'AGTACATTCGTCGTCAC' *.fastq > count/B6085_Rm0.txt
agrep -0 -c 'CTCACCCTTACTGCGCA' *.fastq > count/B6086_Rm0.txt
agrep -0 -c 'GTTTCTCGGAAACGTGA' *.fastq > count/B6087_Rm0.txt
agrep -0 -c 'AGGGGGTGTTGTCTATT' *.fastq > count/B6090_Rm0.txt
agrep -0 -c 'TCTGTGGTCCCGAGTAT' *.fastq > count/B6091_Rm0.txt
agrep -0 -c 'GTCGATGTTCGGAGCAT' *.fastq > count/B6093_Rm0.txt
agrep -0 -c 'GCAGCGTGAGTAGAGTC' *.fastq > count/B6094_Rm0.txt
agrep -0 -c 'TCAAACGTTGCCGCTGC' *.fastq > count/B6095_Rm0.txt
agrep -0 -c 'TTTACCTGTGAGTGGTA' *.fastq > count/B6096_Rm0.txt
agrep -0 -c 'AGACATTCTAATGTCCC' *.fastq > count/B6097_Rm0.txt
agrep -0 -c 'CACGAAGTCGATCCTCC' *.fastq > count/B6098_Rm0.txt
agrep -0 -c 'GTTGCGTTCGACCGAGT' *.fastq > count/B6099_Rm0.txt
agrep -0 -c 'GCGCCTGAACAACTGAG' *.fastq > count/B6100_Rm0.txt
agrep -0 -c 'ACCTTTAGTGTAGGCAG' *.fastq > count/B6103_Rm0.txt
agrep -0 -c 'TAGAGGGACGCCTTATG' *.fastq > count/B6104_Rm0.txt
agrep -0 -c 'GCCGTATCTGATGGACA' *.fastq > count/B6105_Rm0.txt
agrep -0 -c 'ATGCACACTCGAACAGT' *.fastq > count/B6106_Rm0.txt
agrep -0 -c 'TTTAATACGCCACAGAC' *.fastq > count/B6107_Rm0.txt
agrep -0 -c 'AGTCAAGGTGTTAGCGC' *.fastq > count/B6110_Rm0.txt
agrep -0 -c 'TGACTGCGATACGTGTA' *.fastq > count/B6111_Rm0.txt
agrep -0 -c 'GTAGACGTCCCAGAAGC' *.fastq > count/B6112_Rm0.txt
agrep -0 -c 'CGAACAGCGTCCTATAG' *.fastq > count/B6113_Rm0.txt
agrep -0 -c 'GCGGCCCAACAACTAGA' *.fastq > count/B6114_Rm0.txt
agrep -0 -c 'GATGAAGTTGCTTCCAC' *.fastq > count/B6115_Rm0.txt
agrep -0 -c 'GCGACCTGTGAACGCAA' *.fastq > count/B6116_Rm0.txt
agrep -0 -c 'GGGCAGGTTCGTTGTGT' *.fastq > count/B6117_Rm0.txt
agrep -0 -c 'GTACATAGGTGGCTAAC' *.fastq > count/B6118_Rm0.txt
agrep -0 -c 'TGCATAAAAAGAGGGCT' *.fastq > count/B6119_Rm0.txt
agrep -0 -c 'ACGTTAACAACGCCACC' *.fastq > count/B6121_Rm0.txt
agrep -0 -c 'AAGAACGAACTCTCGAC' *.fastq > count/B6122_Rm0.txt
agrep -0 -c 'ATGAGAGGTCTGTTAAG' *.fastq > count/B6123_Rm0.txt
agrep -0 -c 'TCACATGACTAGTACGC' *.fastq > count/B6124_Rm0.txt
agrep -0 -c 'GAGTAGCCTCCGTATCC' *.fastq > count/B6126_Rm0.txt
agrep -0 -c 'CTTACAACAACGCTATG' *.fastq > count/B6127_Rm0.txt
agrep -0 -c 'CCTATAGCAATACACCG' *.fastq > count/B6128_Rm0.txt
agrep -0 -c 'CCTAGCGACATAGTACA' *.fastq > count/B6129_Rm0.txt
agrep -0 -c 'TACGTCCGCAACTCCTT' *.fastq > count/B6131_Rm0.txt
agrep -0 -c 'TCATCGACCAATGGGTA' *.fastq > count/B6132_Rm0.txt
agrep -0 -c 'CGTGACGCAAGAGTACG' *.fastq > count/B6133_Rm0.txt
agrep -0 -c 'ACGAGCACTGACAGGCT' *.fastq > count/B6134_Rm0.txt
agrep -0 -c 'ACGCCCTTGCCTTTCCA' *.fastq > count/B6135_Rm0.txt
agrep -0 -c 'TGACGCTTTTTAGGTCC' *.fastq > count/B6136_Rm0.txt
agrep -0 -c 'TATTTGCCATGGGTAAC' *.fastq > count/B6137_Rm0.txt
agrep -0 -c 'CACCATACTTGTAGACT' *.fastq > count/B6138_Rm0.txt
agrep -0 -c 'ACATTGCATGTCAACGG' *.fastq > count/B6139_Rm0.txt
agrep -0 -c 'TTCAGCATGCCGTCTGG' *.fastq > count/B6140_Rm0.txt
agrep -0 -c 'ATGATCGGTCTGTGTCA' *.fastq > count/B6141_Rm0.txt
agrep -0 -c 'TTCAGTCGTGTGTAACT' *.fastq > count/B6143_Rm0.txt
agrep -0 -c 'CGTTTGACAGTACACTA' *.fastq > count/B6144_Rm0.txt
agrep -0 -c 'ATGTGGTTGATAGGACC' *.fastq > count/B6145_Rm0.txt
agrep -0 -c 'GGTAGACACCTAGAGTG' *.fastq > count/B6146_Rm0.txt
agrep -0 -c 'CTGCACACGTATGACAG' *.fastq > count/B6147_Rm0.txt
agrep -0 -c 'TTGCTATGGGGGTGAGG' *.fastq > count/B6148_Rm0.txt
agrep -0 -c 'CGATGCCCACAAAGGTC' *.fastq > count/B6149_Rm0.txt
agrep -0 -c 'AGAGCAGTTCGCCAAGA' *.fastq > count/B6150_Rm0.txt
agrep -0 -c 'CGTTGCATACTAGACGG' *.fastq > count/B6151_Rm0.txt
agrep -0 -c 'ACCATGGGGATACTAGA' *.fastq > count/B6152_Rm0.txt
agrep -0 -c 'ATGGTCTAGGAGTTGCC' *.fastq > count/B6153_Rm0.txt
agrep -0 -c 'AGTGAGCCGTGGTCCTT' *.fastq > count/B6155_Rm0.txt
agrep -0 -c 'ACATAACGCTAAACGCG' *.fastq > count/B6156_Rm0.txt
agrep -0 -c 'TCGGCGTTAGGAGTTGG' *.fastq > count/B6157_Rm0.txt
agrep -0 -c 'CCGCAGGTATAACCCGA' *.fastq > count/B6158_Rm0.txt
agrep -0 -c 'GATCTGATGGGACTGCC' *.fastq > count/B6160_Rm0.txt
agrep -0 -c 'TCTAGTACGCTGTCGTT' *.fastq > count/B6161_Rm0.txt
agrep -0 -c 'GATAGCCCATATAAGCA' *.fastq > count/B6162_Rm0.txt
agrep -0 -c 'AAACGGATGCCGTTATA' *.fastq > count/B6163_Rm0.txt
agrep -0 -c 'GGATTTTAAGCCCAGAA' *.fastq > count/B6164_Rm0.txt
agrep -0 -c 'CGATGTACGTCGACAGC' *.fastq > count/B6165_Rm0.txt
agrep -0 -c 'GCTGTAGCGTGGTTCGA' *.fastq > count/B6166_Rm0.txt
agrep -0 -c 'AGTCACCTTCGGGTGCA' *.fastq > count/B6167_Rm0.txt
agrep -0 -c 'GCAGTCAACCCTTAGTT' *.fastq > count/B6168_Rm0.txt
agrep -0 -c 'GGGGTATGCGTTTTGAC' *.fastq > count/B6169_Rm0.txt
agrep -0 -c 'TTGTCACTCATATTGCC' *.fastq > count/B6170_Rm0.txt
agrep -0 -c 'CGAAAAAGCCCGACAAT' *.fastq > count/B6171_Rm0.txt
agrep -0 -c 'ACGCTTACAGCACCTGC' *.fastq > count/B6172_Rm0.txt
agrep -0 -c 'TCGCTTCCTGTACTTCG' *.fastq > count/B6173_Rm0.txt
agrep -0 -c 'GATGTCCACCGAGATCG' *.fastq > count/B6174_Rm0.txt
agrep -0 -c 'CGTCCGTATTCGTCGAA' *.fastq > count/B6175_Rm0.txt
agrep -0 -c 'TACACATACCCACGTGT' *.fastq > count/B6177_Rm0.txt
agrep -0 -c 'AACGTCGACATGTAGCG' *.fastq > count/B6178_Rm0.txt
agrep -0 -c 'GGGCATGAATCCGATTA' *.fastq > count/B6180_Rm0.txt
agrep -0 -c 'GTACAAGGCGATAACTT' *.fastq > count/B6182_Rm0.txt
agrep -0 -c 'CGTGCATAGTGAAAACT' *.fastq > count/B6183_Rm0.txt
agrep -0 -c 'TACCAGCGATGCCTGCA' *.fastq > count/B6184_Rm0.txt
agrep -0 -c 'TCCTTTCGGGTCGGATC' *.fastq > count/B6185_Rm0.txt
agrep -0 -c 'GCCGCTGTTTCATTTCT' *.fastq > count/B6186_Rm0.txt
agrep -0 -c 'CGCATGTGTTGAAGTCT' *.fastq > count/B6187_Rm0.txt
agrep -0 -c 'CGGTCTAACGCCCTTCA' *.fastq > count/B6188_Rm0.txt
agrep -0 -c 'TCGTTTACCAGTGTTCA' *.fastq > count/B6189_Rm0.txt
agrep -0 -c 'CCGGTCGCGCAATCTAT' *.fastq > count/B6190_Rm0.txt
agrep -0 -c 'ATCGGAATCCGTTATCC' *.fastq > count/B6191_Rm0.txt
agrep -0 -c 'AGAAAGCTATGATGCCT' *.fastq > count/B6193_Rm0.txt
agrep -0 -c 'ACTAATCCTGCCGATAT' *.fastq > count/B6194_Rm0.txt
agrep -0 -c 'GAAGTAAGCGGCCTACG' *.fastq > count/B6195_Rm0.txt
agrep -0 -c 'AGGCCCCCGTAACTATC' *.fastq > count/B6196_Rm0.txt
agrep -0 -c 'TGTGTCATATCGGTTGA' *.fastq > count/B6197_Rm0.txt
agrep -0 -c 'AGCGTAGAGGTCGAATC' *.fastq > count/B6198_Rm0.txt
agrep -0 -c 'CTAACGGCTTAGTACTA' *.fastq > count/B6199_Rm0.txt
agrep -0 -c 'GACAGGTGCGGTAAGAG' *.fastq > count/B6200_Rm0.txt
agrep -0 -c 'GGAACGATTAGCCCCAT' *.fastq > count/B6201_Rm0.txt
agrep -0 -c 'CAGATTCAGATTACCAG' *.fastq > count/B6202_Rm0.txt
agrep -0 -c 'GGACATCCTACCCTTGA' *.fastq > count/B6203_Rm0.txt
agrep -0 -c 'GCCTACTTGAAGACGAC' *.fastq > count/B6204_Rm0.txt
agrep -0 -c 'ACGCCGTGTTCATCACT' *.fastq > count/B6205_Rm0.txt
agrep -0 -c 'GATTCACAGTAAGCTGC' *.fastq > count/B6206_Rm0.txt
agrep -0 -c 'CGCGTGTAAGAGATCTT' *.fastq > count/B6208_Rm0.txt
agrep -0 -c 'TTTCGATGTTGCCCGTT' *.fastq > count/B6209_Rm0.txt
agrep -0 -c 'CTGGTCCGGACTATCAG' *.fastq > count/B6212_Rm0.txt
agrep -0 -c 'GTGAAATTTATCGCTGC' *.fastq > count/B6213_Rm0.txt
agrep -0 -c 'GGATGGTTTGAATGGCG' *.fastq > count/B6214_Rm0.txt
agrep -0 -c 'CGTTGCGTTCATTCTAA' *.fastq > count/B6215_Rm0.txt
agrep -0 -c 'TTATTCTCACTGCGACT' *.fastq > count/B6216_Rm0.txt
agrep -0 -c 'TACGGACTAGCTTTACA' *.fastq > count/B6217_Rm0.txt
agrep -0 -c 'CGAGAAGGGTTAGTACA' *.fastq > count/B6219_Rm0.txt
agrep -0 -c 'AAGTTACTACCGAGGAT' *.fastq > count/B6220_Rm0.txt
agrep -0 -c 'CTTACCTTGGGCGTATA' *.fastq > count/B6224_Rm0.txt
agrep -0 -c 'CAGTAAACCCCTATAGA' *.fastq > count/B6225_Rm0.txt
agrep -0 -c 'GGTAAGTTGCGACGATG' *.fastq > count/B6226_Rm0.txt
agrep -0 -c 'CGTCAAGCGGTGTTGGT' *.fastq > count/B6227_Rm0.txt
agrep -0 -c 'TTTTTTACCCGCTACGA' *.fastq > count/B6228_Rm0.txt
agrep -0 -c 'GGCTTTAGTACATCGCC' *.fastq > count/B6229_Rm0.txt
agrep -0 -c 'TGGAGCTACATAGCCCC' *.fastq > count/B6230_Rm0.txt
agrep -0 -c 'TCGCTCTATGCCAGGTG' *.fastq > count/B6231_Rm0.txt
agrep -0 -c 'CGCGAGTGGTATCAGAA' *.fastq > count/B6232_Rm0.txt
agrep -0 -c 'TTAACTGGCATCCGCAT' *.fastq > count/B6233_Rm0.txt
agrep -0 -c 'ATGCCTTGGCATAAATC' *.fastq > count/B6234_Rm0.txt
agrep -0 -c 'TAGGTCTAGTGGGGCAA' *.fastq > count/B6235_Rm0.txt
agrep -0 -c 'GTGTGAGTACTGTTCCC' *.fastq > count/B6238_Rm0.txt
agrep -0 -c 'AGTTGTCCGAGGACTCT' *.fastq > count/B6239_Rm0.txt
agrep -0 -c 'ATGTGTGCTTCGCCGAC' *.fastq > count/B6240_Rm0.txt
agrep -0 -c 'AAGACGCCATCTGGAGG' *.fastq > count/B6241_Rm0.txt
agrep -0 -c 'CCAGGGTACGAGAACTA' *.fastq > count/B6242_Rm0.txt
agrep -0 -c 'ATTGGTCCGGATTGAAT' *.fastq > count/B6243_Rm0.txt
agrep -0 -c 'CCAACAGCATGATTGCG' *.fastq > count/B6244_Rm0.txt
agrep -0 -c 'ATACGATCATGAACACG' *.fastq > count/B6246_Rm0.txt
agrep -0 -c 'CGCGGTAGCTGGTCAAT' *.fastq > count/B6247_Rm0.txt
agrep -0 -c 'TCGGCGTTCATCTCCCT' *.fastq > count/B6248_Rm0.txt
agrep -0 -c 'CGTAGTGAGTCAATCTC' *.fastq > count/B6249_Rm0.txt
agrep -0 -c 'ACACTACCGGATGCACT' *.fastq > count/B6250_Rm0.txt
agrep -0 -c 'CTGCCATTACTTTGTGG' *.fastq > count/B6251_Rm0.txt
agrep -0 -c 'TGGGTAGCAGGTGAAAT' *.fastq > count/B6252_Rm0.txt
agrep -0 -c 'TTAAGAGTTCCCAAAGG' *.fastq > count/B6253_Rm0.txt
agrep -0 -c 'GATTGTTCGCATTGATC' *.fastq > count/B6255_Rm0.txt
agrep -0 -c 'TCAGGTCCGTGCGTGTA' *.fastq > count/B6256_Rm0.txt
agrep -0 -c 'ACTTCCAGTACTTCGTA' *.fastq > count/B6257_Rm0.txt
agrep -0 -c 'CGACACAGTTTTCGGCG' *.fastq > count/B6258_Rm0.txt
agrep -0 -c 'ACCGGACACAATTTGAC' *.fastq > count/B6259_Rm0.txt
agrep -0 -c 'GCCTAGCCAAACGTTTG' *.fastq > count/B6260_Rm0.txt
agrep -0 -c 'GTAGCATACTCGTCACC' *.fastq > count/B6261_Rm0.txt
agrep -0 -c 'CGTGCACGGCAAAGATC' *.fastq > count/B6263_Rm0.txt
agrep -0 -c 'TCCATGGAGTCCTTCAA' *.fastq > count/B6264_Rm0.txt
agrep -0 -c 'TTTGGTGGAGGTTGGCG' *.fastq > count/B6265_Rm0.txt
agrep -0 -c 'CCTGGATAATCTACCGT' *.fastq > count/B6266_Rm0.txt
agrep -0 -c 'GGGGAGTAGACTACGCT' *.fastq > count/B6267_Rm0.txt
agrep -0 -c 'TTTGGCTACCGCAAGAG' *.fastq > count/B6268_Rm0.txt
agrep -0 -c 'CCTTTCAATAGGCTCAC' *.fastq > count/B6270_Rm0.txt
agrep -0 -c 'TCTAGCTCATCGGAATC' *.fastq > count/B6271_Rm0.txt
agrep -0 -c 'TTGTTCATGAGTTGCCA' *.fastq > count/B6272_Rm0.txt
agrep -0 -c 'ATGACGAAATAGGAGCG' *.fastq > count/B6273_Rm0.txt
agrep -0 -c 'CGCTAGGCTACTATACG' *.fastq > count/B6274_Rm0.txt
agrep -0 -c 'CTAAGGCGGTACTCGTG' *.fastq > count/B6275_Rm0.txt
agrep -0 -c 'TGATCTATGGTTAACCC' *.fastq > count/B6276_Rm0.txt
agrep -0 -c 'ACACGTCGACCTTGAAC' *.fastq > count/B6277_Rm0.txt
agrep -0 -c 'TCAAACGACTCTTCCAT' *.fastq > count/B6278_Rm0.txt
agrep -0 -c 'CGGACATGATGAATTTG' *.fastq > count/B6279_Rm0.txt
agrep -0 -c 'GACCTGGAGACTTACTC' *.fastq > count/B6280_Rm0.txt
agrep -0 -c 'GACATACCCCTATTAGA' *.fastq > count/B6281_Rm0.txt
agrep -0 -c 'AACGTATTGTGCGGCAG' *.fastq > count/B6282_Rm0.txt
agrep -0 -c 'CTGTAATAACGAGCCCC' *.fastq > count/B6283_Rm0.txt
agrep -0 -c 'GTGAACCCTAGCATTCG' *.fastq > count/B6285_Rm0.txt
agrep -0 -c 'TTGAACCGGTGTCTTAC' *.fastq > count/B6286_Rm0.txt
agrep -0 -c 'CTTCAGAAATCGACCAC' *.fastq > count/B6288_Rm0.txt
agrep -0 -c 'CGTGTCCGCTTTTGACT' *.fastq > count/B6289_Rm0.txt
agrep -0 -c 'TCGCTATACATCTTTCG' *.fastq > count/B6290_Rm0.txt
agrep -0 -c 'CCTGTGAGGGGTCTTGA' *.fastq > count/B6291_Rm0.txt
agrep -0 -c 'GATCTTTTCGGTGGCGC' *.fastq > count/B6293_Rm0.txt
agrep -0 -c 'ATTTACTCCGTGCCCTT' *.fastq > count/B6295_Rm0.txt
agrep -0 -c 'GATGCATGAGATCAGAC' *.fastq > count/B6296_Rm0.txt
agrep -0 -c 'ACCAGAAACGGCAGTAT' *.fastq > count/B6297_Rm0.txt
agrep -0 -c 'ACCCAAAAGCCGAAAAT' *.fastq > count/B6299_Rm0.txt
agrep -0 -c 'ACCGACTTATCACAGAT' *.fastq > count/B6301_Rm0.txt
agrep -0 -c 'ACTGCGGTGCGAAACTA' *.fastq > count/B6302_Rm0.txt
agrep -0 -c 'GACACCTCTCCGACATG' *.fastq > count/B6304_Rm0.txt
agrep -0 -c 'AACCCCTATAACGGGTT' *.fastq > count/B6306_Rm0.txt
agrep -0 -c 'TAGTCTAGCTCGCTTGC' *.fastq > count/B6307_Rm0.txt
agrep -0 -c 'TCGGTCCTTAACGTCTA' *.fastq > count/B6308_Rm0.txt
agrep -0 -c 'CCTTTGCTTGACGAGTC' *.fastq > count/B6309_Rm0.txt
agrep -0 -c 'TGTAGGACCGCGTCAAC' *.fastq > count/B6310_Rm0.txt
agrep -0 -c 'AAAAGGCACGGACTGAA' *.fastq > count/B6311_Rm0.txt
agrep -0 -c 'AGAAATGACGAGGACTT' *.fastq > count/B6312_Rm0.txt
agrep -0 -c 'AATTGTGCCCCCTTTCA' *.fastq > count/B6313_Rm0.txt
agrep -0 -c 'CCTTACTATGAACCCTC' *.fastq > count/B6314_Rm0.txt
agrep -0 -c 'TATTAACCCCCACATGA' *.fastq > count/B6315_Rm0.txt
agrep -0 -c 'GTGTGCGACAAGCTCAC' *.fastq > count/B6316_Rm0.txt
agrep -0 -c 'ACCCCGACGCTAAGACT' *.fastq > count/B6317_Rm0.txt
agrep -0 -c 'TCCTCACCGCTAGGTCA' *.fastq > count/B6318_Rm0.txt
agrep -0 -c 'TCCATTTGATAGCCAGC' *.fastq > count/B6319_Rm0.txt
agrep -0 -c 'GCTACTGAAGATTTGCG' *.fastq > count/B6320_Rm0.txt
agrep -0 -c 'TTCCTCTTATGCTGGAA' *.fastq > count/B6321_Rm0.txt
agrep -0 -c 'CGCAACGGAATCTTAAC' *.fastq > count/B6322_Rm0.txt
agrep -0 -c 'ACATGAACTACGATAGG' *.fastq > count/B6323_Rm0.txt
agrep -0 -c 'ATTGTCGAAGGTTGGCA' *.fastq > count/B6324_Rm0.txt
agrep -0 -c 'CGAGGGTTACTTTATGT' *.fastq > count/B6325_Rm0.txt
agrep -0 -c 'TCGAGTACCTAATCATC' *.fastq > count/B6326_Rm0.txt
agrep -0 -c 'AGACTTGGTATGAAGCT' *.fastq > count/B6327_Rm0.txt
agrep -0 -c 'GCTGTTATTGGTCGAAG' *.fastq > count/B6328_Rm0.txt
agrep -0 -c 'TCAGGCACATGTAACTT' *.fastq > count/B6329_Rm0.txt
agrep -0 -c 'CCCTTCCCTTTAGAATA' *.fastq > count/B6331_Rm0.txt
agrep -0 -c 'AAGAGATGTTGGCGTAG' *.fastq > count/B6332_Rm0.txt
agrep -0 -c 'CCCATGACAGGATATCG' *.fastq > count/B6333_Rm0.txt
agrep -0 -c 'GGACCTACTAGTTTCCG' *.fastq > count/B6334_Rm0.txt
agrep -0 -c 'AAAATGCTCCGTGTGCG' *.fastq > count/B6335_Rm0.txt
agrep -0 -c 'GCGGCCAAGTGCATTAT' *.fastq > count/B6336_Rm0.txt
agrep -0 -c 'TTTTAACGATGTCGCCG' *.fastq > count/B6338_Rm0.txt
agrep -0 -c 'ACGAACAAATGCCAGGT' *.fastq > count/B6339_Rm0.txt
agrep -0 -c 'AGGCAGATCTTCCGCGA' *.fastq > count/B6340_Rm0.txt
agrep -0 -c 'TCGACACTCCATAAGTC' *.fastq > count/B6341_Rm0.txt
agrep -0 -c 'ATAGGCCGGTTCATAGA' *.fastq > count/B6342_Rm0.txt
agrep -0 -c 'GACCATTAGGCTAGCAG' *.fastq > count/B6343_Rm0.txt
agrep -0 -c 'CGGGATTAGTGCCCTAC' *.fastq > count/B6344_Rm0.txt
agrep -0 -c 'AACGGGTCGTTTCTTTG' *.fastq > count/B6345_Rm0.txt
agrep -0 -c 'GGTGGCTAGTTAGTGTA' *.fastq > count/B6346_Rm0.txt
agrep -0 -c 'ACTCCTATGGCGTCGAA' *.fastq > count/B6347_Rm0.txt
agrep -0 -c 'GACTGTGCGGGTTCTCT' *.fastq > count/B6348_Rm0.txt
agrep -0 -c 'GCTAGCGCACATAAAAC' *.fastq > count/B6349_Rm0.txt
agrep -0 -c 'ATTATGTCCGGGACCTA' *.fastq > count/B6350_Rm0.txt
agrep -0 -c 'CTGGCGTGATCACTTGT' *.fastq > count/B6351_Rm0.txt
agrep -0 -c 'TGTCTACAGTCCGAGTA' *.fastq > count/B6352_Rm0.txt
agrep -0 -c 'CTGGCCTAGTAATGATA' *.fastq > count/B6353_Rm0.txt
agrep -0 -c 'ACGATCCCTTACGGAGG' *.fastq > count/B6354_Rm0.txt
agrep -0 -c 'CTGGTGGCACGATTATT' *.fastq > count/B6355_Rm0.txt
agrep -0 -c 'ATTATTGCGCTTTGACC' *.fastq > count/B6356_Rm0.txt
agrep -0 -c 'CACATCTAGCCGGTGGT' *.fastq > count/B6359_Rm0.txt
agrep -0 -c 'TTAAACGCGCAGTTGCC' *.fastq > count/B6361_Rm0.txt
agrep -0 -c 'ACGTGCATGCATGGATA' *.fastq > count/B6362_Rm0.txt
agrep -0 -c 'GTTTAGGCAGAGCCCTT' *.fastq > count/B6363_Rm0.txt
agrep -0 -c 'TGTCCTTAAGCCTTGGT' *.fastq > count/B6364_Rm0.txt
agrep -0 -c 'TATCCGCGTCACATACC' *.fastq > count/B6365_Rm0.txt
agrep -0 -c 'TCTTGTCGTTAACATGG' *.fastq > count/B6366_Rm0.txt
agrep -0 -c 'AGACATCTCTTTCCAAG' *.fastq > count/B6368_Rm0.txt
agrep -0 -c 'TGTCCACATCCTTGACC' *.fastq > count/B6369_Rm0.txt
agrep -0 -c 'CTCGAAGCATCATTCCC' *.fastq > count/B6370_Rm0.txt
agrep -0 -c 'CCTCGAGCATGCTATCG' *.fastq > count/B6372_Rm0.txt
agrep -0 -c 'AACCGGAAAAGCGCATC' *.fastq > count/B6373_Rm0.txt
agrep -0 -c 'CGTCGAGCCACATTCCA' *.fastq > count/B6374_Rm0.txt
agrep -0 -c 'TACGAGACGCCGACTGA' *.fastq > count/B6375_Rm0.txt
agrep -0 -c 'GGTGACATTCAGACTGC' *.fastq > count/B6376_Rm0.txt
agrep -0 -c 'ACATATTCGGCTCGTAG' *.fastq > count/B6377_Rm0.txt
agrep -0 -c 'CTACGCGCTACTAAGAT' *.fastq > count/B6379_Rm0.txt
agrep -0 -c 'GCGACCTAATGTCACCT' *.fastq > count/B6380_Rm0.txt
agrep -0 -c 'CCTTAAGTCCTCCACGG' *.fastq > count/B6381_Rm0.txt
agrep -0 -c 'GAGACATTTCTGGCCGG' *.fastq > count/B6382_Rm0.txt
agrep -0 -c 'TCTAAAACACCTCCCGA' *.fastq > count/B6384_Rm0.txt
agrep -0 -c 'GGCCACAGATATCGCTA' *.fastq > count/B6385_Rm0.txt
agrep -0 -c 'CGCGTAAAGACTACGCC' *.fastq > count/B6386_Rm0.txt
agrep -0 -c 'GACATGGAAGTCGAATA' *.fastq > count/B6388_Rm0.txt
agrep -0 -c 'GGCTATTACTAGCCGCC' *.fastq > count/B6389_Rm0.txt
agrep -0 -c 'AAGTGTCCGCTGGTCAA' *.fastq > count/B6390_Rm0.txt
agrep -0 -c 'CGTCGGGGAGAATACTT' *.fastq > count/B6391_Rm0.txt
agrep -0 -c 'AATGCGCCTCGACGATA' *.fastq > count/B6392_Rm0.txt
agrep -0 -c 'GCATACCGTGACGACTT' *.fastq > count/B6393_Rm0.txt
agrep -0 -c 'GACTTTGTTGATACTCC' *.fastq > count/B6394_Rm0.txt
agrep -0 -c 'GGCTTTAAGGGGTTTGT' *.fastq > count/B6395_Rm0.txt
agrep -0 -c 'GATCAACGACCACTCAA' *.fastq > count/B6396_Rm0.txt
agrep -0 -c 'TTCAAAGCTCGCACCGG' *.fastq > count/B6397_Rm0.txt
agrep -0 -c 'GAGAGTACAGTGTTCCC' *.fastq > count/B6398_Rm0.txt
agrep -0 -c 'GAGGCGAATCGCCAAAC' *.fastq > count/B6399_Rm0.txt
agrep -0 -c 'CGTGGATACTAGGCTAC' *.fastq > count/B6401_Rm0.txt
agrep -0 -c 'AATCGACCATGGGTGTC' *.fastq > count/B6402_Rm0.txt
agrep -0 -c 'CGAGTATGGAGTCACCT' *.fastq > count/B6403_Rm0.txt
agrep -0 -c 'AAGACTCAAGCGTTCGC' *.fastq > count/B6404_Rm0.txt
agrep -0 -c 'CCGCCAGATCAATATAA' *.fastq > count/B6405_Rm0.txt
agrep -0 -c 'CGCTGCACATGAGGAAC' *.fastq > count/B6407_Rm0.txt
agrep -0 -c 'TGCGCACTGTATCAGCT' *.fastq > count/B6408_Rm0.txt
agrep -0 -c 'GGTGAGATTTAGCGACG' *.fastq > count/B6409_Rm0.txt
agrep -0 -c 'GACTATGGCTTGCTGTT' *.fastq > count/B6411_Rm0.txt
agrep -0 -c 'AATCATCTAGTCCGACA' *.fastq > count/B6412_Rm0.txt
agrep -0 -c 'CGTTCATAACTTTAGCC' *.fastq > count/B6413_Rm0.txt
agrep -0 -c 'CAATAGCCTGTTCCGTT' *.fastq > count/B6414_Rm0.txt
agrep -0 -c 'GGGAAAAGCTAGCTCAT' *.fastq > count/B6415_Rm0.txt
agrep -0 -c 'TCACGCGCTTATAGGAA' *.fastq > count/B6416_Rm0.txt
agrep -0 -c 'GTATCCACTAGGTCCCT' *.fastq > count/B6418_Rm0.txt
agrep -0 -c 'GTTGGCGCTGAAAGGCT' *.fastq > count/B6420_Rm0.txt
agrep -0 -c 'ATCTCCGATTGGATAAG' *.fastq > count/B6421_Rm0.txt
agrep -0 -c 'GCGCTGGACCTTACACA' *.fastq > count/B6422_Rm0.txt
agrep -0 -c 'GCGTACGACGTTCAGAG' *.fastq > count/B6423_Rm0.txt
agrep -0 -c 'TTGGCAGCATATAACGC' *.fastq > count/B6424_Rm0.txt
agrep -0 -c 'CAATGCCTTTCCTACTT' *.fastq > count/B6425_Rm0.txt
agrep -0 -c 'AGCGTACTACTTCAGAC' *.fastq > count/B6426_Rm0.txt
agrep -0 -c 'CCGTTAAGCTTGCAATC' *.fastq > count/B6427_Rm0.txt
agrep -0 -c 'AGCGAAAACCTAGAATG' *.fastq > count/B6429_Rm0.txt
agrep -0 -c 'CGAGAGACCCTATCGAT' *.fastq > count/B6430_Rm0.txt
agrep -0 -c 'TTGCGATGAAGCACGAT' *.fastq > count/B6432_Rm0.txt
agrep -0 -c 'ACTTGATAGTTCGTGCT' *.fastq > count/B6433_Rm0.txt
agrep -0 -c 'TACGGCAGTTGCTAGTC' *.fastq > count/B6435_Rm0.txt
agrep -0 -c 'CGATTCCAGCGGACAGA' *.fastq > count/B6436_Rm0.txt
agrep -0 -c 'AGAGAGGACGTAAAGTG' *.fastq > count/B6437_Rm0.txt
agrep -0 -c 'CACGCAGTAACGACCAC' *.fastq > count/B6439_Rm0.txt
agrep -0 -c 'GTCTCCCTATTGCGGCA' *.fastq > count/B6440_Rm0.txt
agrep -0 -c 'AAAAACGGAAGTCCCCC' *.fastq > count/B6441_Rm0.txt
agrep -0 -c 'TGCTACAATGACGCGAC' *.fastq > count/B6442_Rm0.txt
agrep -0 -c 'AATATCCAACATGCTCG' *.fastq > count/B6443_Rm0.txt
agrep -0 -c 'CGTATCGAAGGGCCTCA' *.fastq > count/B6444_Rm0.txt
agrep -0 -c 'CATATGCGTACGATCAG' *.fastq > count/B6445_Rm0.txt
agrep -0 -c 'ATAGCACGCCTGGACTC' *.fastq > count/B6446_Rm0.txt
agrep -0 -c 'CTGGTAACGCGCGAAAC' *.fastq > count/B6447_Rm0.txt
agrep -0 -c 'AAACCTTCAGGAGCTTA' *.fastq > count/B6449_Rm0.txt
agrep -0 -c 'ATATACCGGCCATGATA' *.fastq > count/B6450_Rm0.txt
agrep -0 -c 'GTGTTTGCACGCATGGT' *.fastq > count/B6451_Rm0.txt
agrep -0 -c 'ATTGCGCCGAAGATCGC' *.fastq > count/B6452_Rm0.txt
agrep -0 -c 'CACTTCGGCGACTGTAA' *.fastq > count/B6453_Rm0.txt
agrep -0 -c 'CAGTTGAGGCTGACACC' *.fastq > count/B6454_Rm0.txt
agrep -0 -c 'CGTAATAGTCCTCGGGC' *.fastq > count/B6455_Rm0.txt
agrep -0 -c 'TGCCCAATACCAAACGG' *.fastq > count/B6457_Rm0.txt
agrep -0 -c 'CCTTTTCCGTTTGATCC' *.fastq > count/B6458_Rm0.txt
agrep -0 -c 'TTGGGTCTAGAGTTCCT' *.fastq > count/B6459_Rm0.txt
agrep -0 -c 'CACGTTTGTCTACATCT' *.fastq > count/B6460_Rm0.txt
agrep -0 -c 'CGCTACCGAGGTTCTTA' *.fastq > count/B6461_Rm0.txt
agrep -0 -c 'CTTGCCCACGTTAGATA' *.fastq > count/B6462_Rm0.txt
agrep -0 -c 'ACGCCAAGATCCTTAGC' *.fastq > count/B6463_Rm0.txt
agrep -0 -c 'GAACTGGGCGCTAAGAC' *.fastq > count/B6464_Rm0.txt
agrep -0 -c 'GATTTCGTACGAGCCTG' *.fastq > count/B6465_Rm0.txt
agrep -0 -c 'ATGTTGTCTCGGTCTGG' *.fastq > count/B6466_Rm0.txt
agrep -0 -c 'AGTTTAAGGGATACCTG' *.fastq > count/B6468_Rm0.txt
agrep -0 -c 'ATGTCGTTCCTTGTTTG' *.fastq > count/B6469_Rm0.txt
agrep -0 -c 'GATGTAACGATTCACTC' *.fastq > count/B6471_Rm0.txt
agrep -0 -c 'ACTGTTTACAAGGGCAA' *.fastq > count/B6472_Rm0.txt
agrep -0 -c 'ATAGGCAGTATCTTTGC' *.fastq > count/B6473_Rm0.txt
agrep -0 -c 'ATCGGGTCCTTTCGTAG' *.fastq > count/B6474_Rm0.txt
agrep -0 -c 'TGGTTTCAATATGGGCG' *.fastq > count/B6477_Rm0.txt
agrep -0 -c 'GAACTCCTTACGACTGT' *.fastq > count/B6478_Rm0.txt
agrep -0 -c 'TCGTATGCTGCGGACAG' *.fastq > count/B6479_Rm0.txt
agrep -0 -c 'TCAGGGTCATATCGTAG' *.fastq > count/B6480_Rm0.txt
agrep -0 -c 'GTATTCATATCGGTTCC' *.fastq > count/B6483_Rm0.txt
agrep -0 -c 'ACGACATAAATGGCTCC' *.fastq > count/B6484_Rm0.txt
agrep -0 -c 'TTCAGCGTGCTATGATG' *.fastq > count/B6485_Rm0.txt
agrep -0 -c 'GAGTCTGCTCGCTTACT' *.fastq > count/B6486_Rm0.txt
agrep -0 -c 'TTATCTCCCCCCCTTCC' *.fastq > count/B6487_Rm0.txt
agrep -0 -c 'CCAGTCAAACATCGTCT' *.fastq > count/B6488_Rm0.txt
agrep -0 -c 'GCCTGAAAGTTTAGACC' *.fastq > count/B6489_Rm0.txt
agrep -0 -c 'AAGACTGTCCCGACAGG' *.fastq > count/B6490_Rm0.txt
agrep -0 -c 'TGTTGTCGCTGTATTCA' *.fastq > count/B6492_Rm0.txt
agrep -0 -c 'TGAAAAGGTCCTAGGCT' *.fastq > count/B6493_Rm0.txt
agrep -0 -c 'CTGTGTGACAGCGAGGT' *.fastq > count/B6494_Rm0.txt
agrep -0 -c 'CTGTCGGGATTGGGTCT' *.fastq > count/B6495_Rm0.txt
agrep -0 -c 'TGACATAGCACGTATGT' *.fastq > count/B6496_Rm0.txt
agrep -0 -c 'TTCACTTAACCTGTGCT' *.fastq > count/B6497_Rm0.txt
agrep -0 -c 'GCAGACCCAGTAACCCT' *.fastq > count/B6498_Rm0.txt
agrep -0 -c 'AGAGCCCATTGTATCCA' *.fastq > count/B6499_Rm0.txt
agrep -0 -c 'TGTGATAGGTAGGCCCT' *.fastq > count/B6500_Rm0.txt
agrep -0 -c 'TATCGTCTTGCGCTCAC' *.fastq > count/B6501_Rm0.txt
agrep -0 -c 'TAGGGTTACAACTGCAA' *.fastq > count/B6502_Rm0.txt
agrep -0 -c 'CTTATGGTGAACGGATC' *.fastq > count/B6504_Rm0.txt
agrep -0 -c 'AGCAACCCTCAGGTCTT' *.fastq > count/B6505_Rm0.txt
agrep -0 -c 'TCTGGAGCAGTGCACTG' *.fastq > count/B6506_Rm0.txt
agrep -0 -c 'ATGCCTGTGCGGAGTTA' *.fastq > count/B6508_Rm0.txt
agrep -0 -c 'GTTGGCATCGCTTCAGA' *.fastq > count/B6509_Rm0.txt
agrep -0 -c 'CGCTTTGAGACGTGACC' *.fastq > count/B6510_Rm0.txt
agrep -0 -c 'TTTGCCCATAGCACATA' *.fastq > count/B6511_Rm0.txt
agrep -0 -c 'TAAGTAGTGACTTCGCA' *.fastq > count/B6514_Rm0.txt
agrep -0 -c 'TTCGACCTCCGCGTAAG' *.fastq > count/B6515_Rm0.txt
agrep -0 -c 'TTCGCGCTAACTAGAAT' *.fastq > count/B6516_Rm0.txt
agrep -0 -c 'GGGCACACACTTTTAAG' *.fastq > count/B6517_Rm0.txt
agrep -0 -c 'GAACTGTGTAACACTCA' *.fastq > count/B6518_Rm0.txt
agrep -0 -c 'GTAGCAGTGGACGTATG' *.fastq > count/B6520_Rm0.txt
agrep -0 -c 'ATGGCATCCCAGCTAAC' *.fastq > count/B6521_Rm0.txt
agrep -0 -c 'CCGCCAAGTGTGCCATA' *.fastq > count/B6522_Rm0.txt
agrep -0 -c 'GGGAAGAAAGATACTCG' *.fastq > count/B6523_Rm0.txt
agrep -0 -c 'ACTGTGCGACACCTCTA' *.fastq > count/B6524_Rm0.txt
agrep -0 -c 'GCACGTTGAATTATGGT' *.fastq > count/B6525_Rm0.txt
agrep -0 -c 'AAGCCGCTGAGTCGAGT' *.fastq > count/B6526_Rm0.txt
agrep -0 -c 'CTCTGGTTGGCATCATA' *.fastq > count/B6527_Rm0.txt
agrep -0 -c 'ACGTCTCGGAACCGTAT' *.fastq > count/B6528_Rm0.txt
agrep -0 -c 'CTCTGTAGGGTTAGTGC' *.fastq > count/B6529_Rm0.txt
agrep -0 -c 'CGGCCGTTAAGTATCGT' *.fastq > count/B6531_Rm0.txt
agrep -0 -c 'GTTTCCTCGCGACGGAA' *.fastq > count/B6532_Rm0.txt
agrep -0 -c 'GGCAACCAAAGACTACA' *.fastq > count/B6534_Rm0.txt
agrep -0 -c 'GAGATCAAGGGCCAACC' *.fastq > count/B6536_Rm0.txt
agrep -0 -c 'TGCTTAATGCTGTTGTC' *.fastq > count/B6537_Rm0.txt
agrep -0 -c 'TGGTCACCCTAAAGGAA' *.fastq > count/B6538_Rm0.txt
agrep -0 -c 'CCATATCGCAGTCCTCG' *.fastq > count/B6540_Rm0.txt
agrep -0 -c 'TGTCTAATGGCAGACTA' *.fastq > count/B6541_Rm0.txt
agrep -0 -c 'CTCAAACCTAGGGCGTA' *.fastq > count/B6542_Rm0.txt
agrep -0 -c 'CTGCGCAGTTCTGAACC' *.fastq > count/B6543_Rm0.txt
agrep -0 -c 'ACAAACGATCACCCAAT' *.fastq > count/B6544_Rm0.txt
agrep -0 -c 'TTGCGTCTCGGACAGTA' *.fastq > count/B6545_Rm0.txt
agrep -0 -c 'TCGTAACATGAACGGCA' *.fastq > count/B6546_Rm0.txt
agrep -0 -c 'TGCTTGCAGTATCGCAG' *.fastq > count/B6547_Rm0.txt
agrep -0 -c 'CTACTTTTGGTAAGGAC' *.fastq > count/B6548_Rm0.txt
agrep -0 -c 'TTTCCACTGCAACGTAA' *.fastq > count/B6549_Rm0.txt
agrep -0 -c 'GATGTGTACGTGGTCTG' *.fastq > count/B6550_Rm0.txt
agrep -0 -c 'TGCTCGTAACAGCTCTT' *.fastq > count/B6552_Rm0.txt
agrep -0 -c 'CCCTTACGAACGTACTT' *.fastq > count/B6553_Rm0.txt
agrep -0 -c 'GTATTCCAAGCGGTATC' *.fastq > count/B6555_Rm0.txt
agrep -0 -c 'AGGAGCCATCGCTCAGT' *.fastq > count/B6556_Rm0.txt
agrep -0 -c 'CGACGCCTATTTTTGCA' *.fastq > count/B6557_Rm0.txt
agrep -0 -c 'CTGATCAAAATCAGTCG' *.fastq > count/B6558_Rm0.txt
agrep -0 -c 'TATTGCAGGTACATTGC' *.fastq > count/B6559_Rm0.txt
agrep -0 -c 'GTAACAGTTTGTCCACC' *.fastq > count/B6560_Rm0.txt
agrep -0 -c 'TGGGGATCACGGGAATG' *.fastq > count/B6561_Rm0.txt
agrep -0 -c 'CCTGAAGGGGACATGGT' *.fastq > count/B6562_Rm0.txt
agrep -0 -c 'TACAAGTTAGCCGAGGC' *.fastq > count/B6563_Rm0.txt
agrep -0 -c 'GAATGTGCGTCAAGCAA' *.fastq > count/B6564_Rm0.txt
agrep -0 -c 'GCGAGACAATTCCCTGC' *.fastq > count/B6565_Rm0.txt
agrep -0 -c 'AAAACGCGTGGGACGAA' *.fastq > count/B6567_Rm0.txt
agrep -0 -c 'GATACACGTTGCCTGAA' *.fastq > count/B6568_Rm0.txt
agrep -0 -c 'ATCAAAGGCGCTACAAG' *.fastq > count/B6569_Rm0.txt
agrep -0 -c 'GCTACAAACCTATGTCC' *.fastq > count/B6570_Rm0.txt
agrep -0 -c 'GCGTAACCACTTTGAGC' *.fastq > count/B6571_Rm0.txt
agrep -0 -c 'AGGTTCGATTTAGAGGT' *.fastq > count/B6572_Rm0.txt
agrep -0 -c 'TGAACGTCCATGACATC' *.fastq > count/B6573_Rm0.txt
agrep -0 -c 'TAGTCCAGCACTGGGTA' *.fastq > count/B6575_Rm0.txt
agrep -0 -c 'CAGAGTGCCTAAGGTGG' *.fastq > count/B6576_Rm0.txt
agrep -0 -c 'TGGTTGGCTAAGACGAT' *.fastq > count/B6577_Rm0.txt
agrep -0 -c 'CCACCACAGGAAAACGC' *.fastq > count/B6578_Rm0.txt
agrep -0 -c 'TCGCACAAAGACTCACA' *.fastq > count/B6579_Rm0.txt
agrep -0 -c 'AGCGTTAACTTCGCTCC' *.fastq > count/B6580_Rm0.txt
agrep -0 -c 'TCTTGTGGGCCCAAAAC' *.fastq > count/B6581_Rm0.txt
agrep -0 -c 'TAAAAACTGGTGGGTTG' *.fastq > count/B6585_Rm0.txt
agrep -0 -c 'AGCCAAATCAAATGCGG' *.fastq > count/B6586_Rm0.txt
agrep -0 -c 'AAGCCCTAAAACGGTAT' *.fastq > count/B6587_Rm0.txt
agrep -0 -c 'TACGCGCCTATACTATA' *.fastq > count/B6589_Rm0.txt
agrep -0 -c 'GATGTTTGCGTCATAGG' *.fastq > count/B6591_Rm0.txt
agrep -0 -c 'GGTTTTGGATTGGCGGT' *.fastq > count/B6592_Rm0.txt
agrep -0 -c 'CGGTCCGTACTACACTT' *.fastq > count/B6593_Rm0.txt
agrep -0 -c 'GGATACGTCAACCCAGT' *.fastq > count/B6594_Rm0.txt
agrep -0 -c 'TTGGATCACCACCCAGC' *.fastq > count/B6597_Rm0.txt
agrep -0 -c 'AATGCAAGGTCAGTCGT' *.fastq > count/B6598_Rm0.txt
agrep -0 -c 'CAGTTCTCACGAGGATT' *.fastq > count/B6599_Rm0.txt
agrep -0 -c 'ACGAAGCCCATTCCGTC' *.fastq > count/B6600_Rm0.txt
agrep -0 -c 'GGAATCGACCCTAAGCA' *.fastq > count/B6601_Rm0.txt
agrep -0 -c 'CACATGCTAGAGTATCT' *.fastq > count/B6602_Rm0.txt
agrep -0 -c 'CCTTGCAAGGTAACTGG' *.fastq > count/B6604_Rm0.txt
agrep -0 -c 'TTATGCACGCGGAGCCT' *.fastq > count/B6606_Rm0.txt
agrep -0 -c 'CCCTGGGGTAAGTGTCT' *.fastq > count/B6607_Rm0.txt
agrep -0 -c 'CGACTAGTTTTTGCCTT' *.fastq > count/B6608_Rm0.txt
agrep -0 -c 'ACGTATCGTCGATGACA' *.fastq > count/B6609_Rm0.txt
agrep -0 -c 'ATCATGGGTCCACGTCT' *.fastq > count/B6610_Rm0.txt
agrep -0 -c 'ACCTCTGGATGGCTTTG' *.fastq > count/B6611_Rm0.txt
agrep -0 -c 'CGTAGTCAAGAACACTG' *.fastq > count/B6612_Rm0.txt
agrep -0 -c 'TAGAGGGATACTTTCGC' *.fastq > count/B6613_Rm0.txt
agrep -0 -c 'GCTACTATTCAACGTTG' *.fastq > count/B6614_Rm0.txt
agrep -0 -c 'TCCCGCTTTTCGCTCCT' *.fastq > count/B6615_Rm0.txt
agrep -0 -c 'TCGTCTCAAGAGATGTC' *.fastq > count/B6617_Rm0.txt
agrep -0 -c 'CCCTGCTAACCAGCTAG' *.fastq > count/B6619_Rm0.txt
agrep -0 -c 'GGGTCAATCGGGATCGT' *.fastq > count/B6621_Rm0.txt
agrep -0 -c 'GCTGGTCACTTGTCTCG' *.fastq > count/B6624_Rm0.txt
agrep -0 -c 'AATTCAGTCGGCTCCCT' *.fastq > count/B6625_Rm0.txt
agrep -0 -c 'ACGATGCTACACCATGT' *.fastq > count/B6626_Rm0.txt
agrep -0 -c 'GCACGTAGTCAGCGGAA' *.fastq > count/B6627_Rm0.txt
agrep -0 -c 'TTCCATCAGCTGTATGC' *.fastq > count/B6628_Rm0.txt
agrep -0 -c 'AAGCTTGTTCAACCATG' *.fastq > count/B6629_Rm0.txt
agrep -0 -c 'GACTTAAAGCAGGCCCC' *.fastq > count/B6630_Rm0.txt
agrep -0 -c 'TCGAAATCCCGCGCACT' *.fastq > count/B6633_Rm0.txt
agrep -0 -c 'AGTCTTTAGCATTTCCG' *.fastq > count/B6634_Rm0.txt
agrep -0 -c 'GGGCTAAGGGCAATGAA' *.fastq > count/B6635_Rm0.txt
agrep -0 -c 'GATCGATGTGTATCAAC' *.fastq > count/B6636_Rm0.txt
agrep -0 -c 'AGTTTACGGCGTCTAGC' *.fastq > count/B6637_Rm0.txt
agrep -0 -c 'TAGACCCGCACGCAGTT' *.fastq > count/B6639_Rm0.txt
agrep -0 -c 'ATACGCCTAGTACGGAT' *.fastq > count/B6641_Rm0.txt
agrep -0 -c 'CACGCAGGTGATCTTGA' *.fastq > count/B6642_Rm0.txt
agrep -0 -c 'GGCTACGCGTAGCTACA' *.fastq > count/B6645_Rm0.txt
agrep -0 -c 'CAGCTGCGGTATTTCTC' *.fastq > count/B6646_Rm0.txt
agrep -0 -c 'GAACCAAAGCGTACACC' *.fastq > count/B6647_Rm0.txt
agrep -0 -c 'TATGCAAACGTACAGTG' *.fastq > count/B6648_Rm0.txt
agrep -0 -c 'ATCCCTTAGCCTCCGTT' *.fastq > count/B6649_Rm0.txt
agrep -0 -c 'GCTGAGGTACAATAATC' *.fastq > count/B6650_Rm0.txt
agrep -0 -c 'GAGGCTCCTACAAACCG' *.fastq > count/B6652_Rm0.txt
agrep -0 -c 'TGATGACGCATAGTGTT' *.fastq > count/B6653_Rm0.txt
agrep -0 -c 'CGGTAGCATGTCTCTGA' *.fastq > count/B6655_Rm0.txt
agrep -0 -c 'TGTTTACCCTCGCGCTA' *.fastq > count/B6657_Rm0.txt
agrep -0 -c 'GCAGTTGACGATATGGT' *.fastq > count/B6659_Rm0.txt
agrep -0 -c 'CTACGAATGTACCGGCA' *.fastq > count/B6660_Rm0.txt
agrep -0 -c 'ACCTCTATTTTGTCTCG' *.fastq > count/B6661_Rm0.txt
agrep -0 -c 'TCACGCATCACTGCACT' *.fastq > count/B6662_Rm0.txt
agrep -0 -c 'GATAGCTTGTCTCCGAG' *.fastq > count/B6663_Rm0.txt
agrep -0 -c 'GTGGGAGTATGCCTACG' *.fastq > count/B6664_Rm0.txt
agrep -0 -c 'TTGATTGTCCCGTGGTC' *.fastq > count/B6666_Rm0.txt
agrep -0 -c 'TGCTCCGCGAAGTCACA' *.fastq > count/B6667_Rm0.txt
agrep -0 -c 'ACAATACGAGCCTATAC' *.fastq > count/B6668_Rm0.txt
agrep -0 -c 'CATAGAAGGCCCCACTG' *.fastq > count/B6669_Rm0.txt
agrep -0 -c 'CTGTTCCACGGTAACTC' *.fastq > count/B6670_Rm0.txt
agrep -0 -c 'CAAGCCTTTACTAAGAC' *.fastq > count/B6671_Rm0.txt
agrep -0 -c 'GCGGAATCGAAGGTATG' *.fastq > count/B6672_Rm0.txt
agrep -0 -c 'TGAATCTCGAGTGCATC' *.fastq > count/B6673_Rm0.txt
agrep -0 -c 'CAGCGCTCGATAAGTCG' *.fastq > count/B6674_Rm0.txt
agrep -0 -c 'TTCGCTGATCATCCCGA' *.fastq > count/B6675_Rm0.txt
agrep -0 -c 'TGTTCTGGGATTGCAGC' *.fastq > count/B6676_Rm0.txt
agrep -0 -c 'ATAGTGACCCGCAAACG' *.fastq > count/B6677_Rm0.txt
agrep -0 -c 'CCAATGATAGGGTGTTA' *.fastq > count/B6678_Rm0.txt
agrep -0 -c 'AACCGCCAAGGTGATAC' *.fastq > count/B6679_Rm0.txt
agrep -0 -c 'CTACTAACCTCACTACC' *.fastq > count/B6680_Rm0.txt
agrep -0 -c 'TGCCATAGACAGACTCT' *.fastq > count/B6681_Rm0.txt
agrep -0 -c 'TGTGGATCCGAGTTATA' *.fastq > count/B6682_Rm0.txt
agrep -0 -c 'ACCGTCACCGCTTTACT' *.fastq > count/B6683_Rm0.txt
agrep -0 -c 'TAGCTCGACCCAAGCAC' *.fastq > count/B6684_Rm0.txt
agrep -0 -c 'CCGTTGCTACCATTATC' *.fastq > count/B6685_Rm0.txt
agrep -0 -c 'TTTGCTGGTAGGCCCGA' *.fastq > count/B6687_Rm0.txt
agrep -0 -c 'GCCGTGCCATAATTATG' *.fastq > count/B6688_Rm0.txt
agrep -0 -c 'CCTCATCCATTCGGGTA' *.fastq > count/B6689_Rm0.txt
agrep -0 -c 'TGGTACGAATGGAGGCT' *.fastq > count/B6690_Rm0.txt
agrep -0 -c 'CAAGTACGTGGACGCAC' *.fastq > count/B6692_Rm0.txt
agrep -0 -c 'CTCTACGATCTTCCTCA' *.fastq > count/B6693_Rm0.txt
agrep -0 -c 'GCCAAGATAAGAATCCC' *.fastq > count/B6694_Rm0.txt
agrep -0 -c 'AGCAAGGTATGCCTTCA' *.fastq > count/B6696_Rm0.txt
agrep -0 -c 'GATTGTGTAAATGGCCG' *.fastq > count/B6697_Rm0.txt
agrep -0 -c 'CCCTACGTCTTTTCCAG' *.fastq > count/B6698_Rm0.txt
agrep -0 -c 'GTACGTGTGATCAGGTG' *.fastq > count/B6699_Rm0.txt
agrep -0 -c 'CTTGTCAAGCAACTTCG' *.fastq > count/B6700_Rm0.txt
agrep -0 -c 'AAGCCGGTGGATATTGG' *.fastq > count/B6701_Rm0.txt
agrep -0 -c 'CCACATACATAGTAGCC' *.fastq > count/B6702_Rm0.txt
agrep -0 -c 'CGGGAAGTCAGTGACTG' *.fastq > count/B6703_Rm0.txt
agrep -0 -c 'CAATAACGTGACATGCA' *.fastq > count/B6704_Rm0.txt
agrep -0 -c 'TCGCACCGAGTTAGGCT' *.fastq > count/B6705_Rm0.txt
agrep -0 -c 'CCTATGTATACCTCTAG' *.fastq > count/B6706_Rm0.txt
agrep -0 -c 'GTTCATGGGGTAATCAA' *.fastq > count/B6707_Rm0.txt
agrep -0 -c 'TCTCAAAACTATGCCCG' *.fastq > count/B6708_Rm0.txt
agrep -0 -c 'ATCGAATTGTACCTGCT' *.fastq > count/B6709_Rm0.txt
agrep -0 -c 'CAGATACCGAATGTCTT' *.fastq > count/B6710_Rm0.txt
agrep -0 -c 'GAGATGAAGCGCCATAC' *.fastq > count/B6711_Rm0.txt
agrep -0 -c 'GCCGTTGGAAACCAATG' *.fastq > count/B6712_Rm0.txt
agrep -0 -c 'TGCGTCAGGTTATACAA' *.fastq > count/B6713_Rm0.txt
agrep -0 -c 'GTCAATACTGGCGACGA' *.fastq > count/B6714_Rm0.txt
agrep -0 -c 'GCACGGTTTGTGAGCAT' *.fastq > count/B6715_Rm0.txt
agrep -0 -c 'TAGAGCAATGCTGTTAC' *.fastq > count/B6717_Rm0.txt
agrep -0 -c 'CTTCTTGCCAAGCTTCC' *.fastq > count/B6718_Rm0.txt
agrep -0 -c 'AATGCAGCTTTCAAAGG' *.fastq > count/B6719_Rm0.txt
agrep -0 -c 'AAAGCCGCATGGCCGTA' *.fastq > count/B6720_Rm0.txt
agrep -0 -c 'CCTATCAAACGGCTCTA' *.fastq > count/B6721_Rm0.txt
agrep -0 -c 'AGGTTCTATCCTCGGAG' *.fastq > count/B6722_Rm0.txt
agrep -0 -c 'CTCGGTTAGTCCTGCTG' *.fastq > count/B6723_Rm0.txt
agrep -0 -c 'GGTAATCGAATATCGCC' *.fastq > count/B6724_Rm0.txt
agrep -0 -c 'AAGGACCCCAATCGCTG' *.fastq > count/B6726_Rm0.txt
agrep -0 -c 'GTTGTCACAGTAAAGCG' *.fastq > count/B6727_Rm0.txt
agrep -0 -c 'AGTGTGGAAGGTAACAC' *.fastq > count/B6728_Rm0.txt
agrep -0 -c 'ATATCCTTGGGCGGGAG' *.fastq > count/B6729_Rm0.txt
agrep -0 -c 'GCATCACTGGCGAACTT' *.fastq > count/B6730_Rm0.txt
agrep -0 -c 'GACAGTCTCAAATCCGA' *.fastq > count/B6731_Rm0.txt
agrep -0 -c 'CCGCGCCTTTACGACAT' *.fastq > count/B6733_Rm0.txt
agrep -0 -c 'AAGGGGCATCAGAGTTG' *.fastq > count/B6734_Rm0.txt
agrep -0 -c 'TGTATAGTTGCGGGGGT' *.fastq > count/B6735_Rm0.txt
agrep -0 -c 'AGGAGTAGGGTGAGCAA' *.fastq > count/B6736_Rm0.txt
agrep -0 -c 'GGACTCTACCGCCATCT' *.fastq > count/B6738_Rm0.txt
agrep -0 -c 'CATGAATACCGCCCGAG' *.fastq > count/B6739_Rm0.txt
agrep -0 -c 'CAGATCAGAGCCAAGGC' *.fastq > count/B6741_Rm0.txt
agrep -0 -c 'GACTGCTGATCGCCAAT' *.fastq > count/B6742_Rm0.txt
agrep -0 -c 'CGGAAAATTTCTGATGG' *.fastq > count/B6743_Rm0.txt
agrep -0 -c 'TCCTCGTGCAGCGTCAT' *.fastq > count/B6745_Rm0.txt
agrep -0 -c 'AGGGTGTGGCTCCTTAC' *.fastq > count/B6746_Rm0.txt
agrep -0 -c 'AGCTGAACCAAAGCGGC' *.fastq > count/B6747_Rm0.txt
agrep -0 -c 'AAACCGGTTGAGTCCGC' *.fastq > count/B6748_Rm0.txt
agrep -0 -c 'TTCATCCCGGACTAAAC' *.fastq > count/B6749_Rm0.txt
agrep -0 -c 'AGACTGTCACAGCGATC' *.fastq > count/B6750_Rm0.txt
agrep -0 -c 'GTACCCTCATAGATTAC' *.fastq > count/B6751_Rm0.txt
agrep -0 -c 'TCGCTCAGGCCAAATGC' *.fastq > count/B6752_Rm0.txt
agrep -0 -c 'CAGTATCGGTGGTCATG' *.fastq > count/B6753_Rm0.txt
agrep -0 -c 'GCCTTACGTACGCATTG' *.fastq > count/B6754_Rm0.txt
agrep -0 -c 'TGGACGATCTCCCGATC' *.fastq > count/B6755_Rm0.txt
agrep -0 -c 'CCCTGATTCGCGAATAT' *.fastq > count/B6756_Rm0.txt
agrep -0 -c 'CGTTTGGTCTCGCTAGA' *.fastq > count/B6758_Rm0.txt
agrep -0 -c 'GATAACTGCTAGGCGAT' *.fastq > count/B6759_Rm0.txt
agrep -0 -c 'GGGAGCATCATCACATC' *.fastq > count/B6760_Rm0.txt
agrep -0 -c 'GGTCGAGATCATGACTG' *.fastq > count/B6761_Rm0.txt
agrep -0 -c 'ACCTAGTGTTGCCGTTG' *.fastq > count/B6762_Rm0.txt
agrep -0 -c 'CCTACAATGGTCGTGAA' *.fastq > count/B6763_Rm0.txt
agrep -0 -c 'GCGGTTTTGGACTAGAA' *.fastq > count/B6764_Rm0.txt
agrep -0 -c 'AGGGTAAGCAGGCGACT' *.fastq > count/B6765_Rm0.txt
agrep -0 -c 'TAACGTGATGGTACCCT' *.fastq > count/B6766_Rm0.txt
agrep -0 -c 'AGCCTAACGGCCACATC' *.fastq > count/B6767_Rm0.txt
agrep -0 -c 'ATGTGCCATTAGATGCG' *.fastq > count/B6768_Rm0.txt
agrep -0 -c 'TGACAGAGTCGTATACG' *.fastq > count/B6769_Rm0.txt
agrep -0 -c 'TCTGGGCAACAACGCCA' *.fastq > count/B6770_Rm0.txt
agrep -0 -c 'GCCGATAGGCCATCCTT' *.fastq > count/B6771_Rm0.txt
agrep -0 -c 'CACCTGTCAGTTGTGCC' *.fastq > count/B6772_Rm0.txt
agrep -0 -c 'CGGGCGATGTATTCTAA' *.fastq > count/B6773_Rm0.txt
agrep -0 -c 'CCCCGTTTCCACTGTGA' *.fastq > count/B6775_Rm0.txt
agrep -0 -c 'CGCTCTTGAGCGTAGGT' *.fastq > count/B6776_Rm0.txt
agrep -0 -c 'TATAAACGACCGGATAC' *.fastq > count/B6778_Rm0.txt
agrep -0 -c 'ATGACGAACACACTTCC' *.fastq > count/B6779_Rm0.txt
agrep -0 -c 'TCAGATGTAGTCTACAG' *.fastq > count/B6780_Rm0.txt
agrep -0 -c 'GCATCAATGTCGGGGCA' *.fastq > count/B6781_Rm0.txt
agrep -0 -c 'ATGTCGTGATTATGTCC' *.fastq > count/B6782_Rm0.txt
agrep -0 -c 'CTTTACTCCCACAATTG' *.fastq > count/B6784_Rm0.txt
agrep -0 -c 'AAGGTGGGGACAAACGC' *.fastq > count/B6787_Rm0.txt
agrep -0 -c 'AGAACATTTCGCTCTTG' *.fastq > count/B6788_Rm0.txt
agrep -0 -c 'GCCCGTTTTTAGCGTGC' *.fastq > count/B6789_Rm0.txt
agrep -0 -c 'CTACCTCATCGTAGCGT' *.fastq > count/B6790_Rm0.txt
agrep -0 -c 'CGGACCCATTGCTAGAA' *.fastq > count/B6791_Rm0.txt
agrep -0 -c 'TTGGACTTGGGCGATGG' *.fastq > count/B6792_Rm0.txt
agrep -0 -c 'TCTCGACATCACGTGTA' *.fastq > count/B6793_Rm0.txt
agrep -0 -c 'AACGGCTCCAATCCTAG' *.fastq > count/B6794_Rm0.txt
agrep -0 -c 'CGCTGTAAGCGAGTTTG' *.fastq > count/B6795_Rm0.txt
agrep -0 -c 'GAGTAACTTTATCGACC' *.fastq > count/B6796_Rm0.txt
agrep -0 -c 'ACTACCCGCAACGTCAA' *.fastq > count/B6800_Rm0.txt
agrep -0 -c 'GTACGAACGACCTTCGA' *.fastq > count/B6801_Rm0.txt
agrep -0 -c 'TATGACATAACAAGGCG' *.fastq > count/B6802_Rm0.txt
agrep -0 -c 'GGTCAGACCAACTCTTA' *.fastq > count/B6803_Rm0.txt
agrep -0 -c 'GGCGACACCGAATAAGG' *.fastq > count/B6804_Rm0.txt
agrep -0 -c 'GTCACATCGGAACTGCA' *.fastq > count/B6806_Rm0.txt
agrep -0 -c 'CCTGCACACGGTGTATA' *.fastq > count/B6807_Rm0.txt
agrep -0 -c 'AGCCGTCTCAATGTCAG' *.fastq > count/B6810_Rm0.txt
agrep -0 -c 'GCTAAGCGCCAAACAGA' *.fastq > count/B6811_Rm0.txt
agrep -0 -c 'AGAAATACTGCGCTTGT' *.fastq > count/B6812_Rm0.txt
agrep -0 -c 'AGCGCAGAAGTATTCCG' *.fastq > count/B6813_Rm0.txt
agrep -0 -c 'TCCAGTGCATTCGATAC' *.fastq > count/B6814_Rm0.txt
agrep -0 -c 'ATTCGTTTGTACCCACT' *.fastq > count/B6815_Rm0.txt
agrep -0 -c 'CCGCTTTCTGTGAGCAA' *.fastq > count/B6816_Rm0.txt
agrep -0 -c 'AATCCAGGACTGTTACG' *.fastq > count/B6817_Rm0.txt
agrep -0 -c 'CAAGATCGCCTGTTGGC' *.fastq > count/B6818_Rm0.txt
agrep -0 -c 'GAAGACAAACATGAGCC' *.fastq > count/B6819_Rm0.txt
agrep -0 -c 'AGCTTGCTACAAAGCGT' *.fastq > count/B6821_Rm0.txt
agrep -0 -c 'TTGCGTTAGTCCGACCT' *.fastq > count/B6822_Rm0.txt
agrep -0 -c 'ACGTTTCCCCTTTTTCA' *.fastq > count/B6824_Rm0.txt
agrep -0 -c 'AGGTGTCAGTTCGGACT' *.fastq > count/B6826_Rm0.txt
agrep -0 -c 'GGATGTGTTACGGCCTG' *.fastq > count/B6828_Rm0.txt
agrep -0 -c 'TGGCGCCAATTATGGAC' *.fastq > count/B6830_Rm0.txt
agrep -0 -c 'CCGTTAGAATAGCGGCT' *.fastq > count/B6831_Rm0.txt
agrep -0 -c 'ACTCGACTCCGAGCTGT' *.fastq > count/B6832_Rm0.txt
agrep -0 -c 'CCACAGGTCATTTCGTA' *.fastq > count/B6833_Rm0.txt
agrep -0 -c 'AGACCTGAATGGGCGTG' *.fastq > count/B6835_Rm0.txt
agrep -0 -c 'GTGGCGTAGTAGGATTG' *.fastq > count/B6837_Rm0.txt
agrep -0 -c 'TCATGCTCGTACTGCGG' *.fastq > count/B6838_Rm0.txt
agrep -0 -c 'GGCGCCCTAAACTATCC' *.fastq > count/B6839_Rm0.txt
agrep -0 -c 'CCCAGTCTCGCACATAG' *.fastq > count/B6841_Rm0.txt
agrep -0 -c 'CGGTCCGTGAAAACACT' *.fastq > count/B6842_Rm0.txt
agrep -0 -c 'GGATGTTTCGAGCAACG' *.fastq > count/B6843_Rm0.txt
agrep -0 -c 'ACGGCAATTTTCGATCT' *.fastq > count/B6844_Rm0.txt
agrep -0 -c 'TACAGCGTTTTGCATCA' *.fastq > count/B6845_Rm0.txt
agrep -0 -c 'TGCAGATCGCTTATTGC' *.fastq > count/B6846_Rm0.txt
agrep -0 -c 'TTCGAGGTCAGAACGCG' *.fastq > count/B6847_Rm0.txt
agrep -0 -c 'CTTCGGACTACTCCTGT' *.fastq > count/B6848_Rm0.txt
agrep -0 -c 'GAATTCGAGCCATTGTT' *.fastq > count/B6849_Rm0.txt
agrep -0 -c 'TGACGCGTTATGGGGAC' *.fastq > count/B6851_Rm0.txt
agrep -0 -c 'TTACATTGTTCCACCAC' *.fastq > count/B6853_Rm0.txt
agrep -0 -c 'TGATGGATCTAAGCGTA' *.fastq > count/B6854_Rm0.txt
agrep -0 -c 'GGCTATTGCCTAAGGTA' *.fastq > count/B6855_Rm0.txt
agrep -0 -c 'GACGGATTTTATTCCCT' *.fastq > count/B6856_Rm0.txt
agrep -0 -c 'TAGTCTGCGTGCACGTG' *.fastq > count/B6857_Rm0.txt
agrep -0 -c 'CTCGCAAGTTCAACGTC' *.fastq > count/B6858_Rm0.txt
agrep -0 -c 'ACGTGCTGTTGGTCAAG' *.fastq > count/B6859_Rm0.txt
agrep -0 -c 'AACGTCGATATGGCTGT' *.fastq > count/B6861_Rm0.txt
agrep -0 -c 'ATCAGGGACTAATCCAG' *.fastq > count/B6862_Rm0.txt
agrep -0 -c 'TCCGGGCTGATTATACT' *.fastq > count/B6863_Rm0.txt
agrep -0 -c 'GCTCGACTCCATGGTGT' *.fastq > count/B6865_Rm0.txt
agrep -0 -c 'GCGGGGTAATTAATGTT' *.fastq > count/B6866_Rm0.txt
agrep -0 -c 'CAACGCCAGTCAGTATA' *.fastq > count/B6867_Rm0.txt
agrep -0 -c 'GTAGCTGCGAAAGATGG' *.fastq > count/B6868_Rm0.txt
agrep -0 -c 'CGTCACAATCCATGTTG' *.fastq > count/B6869_Rm0.txt
agrep -0 -c 'CATAGTATGTCCAAGCG' *.fastq > count/B6871_Rm0.txt
agrep -0 -c 'TTGGCCCATTCAGTGAT' *.fastq > count/B6872_Rm0.txt
agrep -0 -c 'TTTGGCCCTCTAATCCC' *.fastq > count/B6873_Rm0.txt
agrep -0 -c 'TGCAAACCCTCTTTCAT' *.fastq > count/B6874_Rm0.txt
agrep -0 -c 'CCTCTATATGTGCGAGA' *.fastq > count/B6875_Rm0.txt
agrep -0 -c 'CATGTGTTCTCCTCGAA' *.fastq > count/B6876_Rm0.txt
agrep -0 -c 'TTGGAGGTCAAAAGCCA' *.fastq > count/B6878_Rm0.txt
agrep -0 -c 'CGTCCGGGTAGTAACAT' *.fastq > count/B6880_Rm0.txt
agrep -0 -c 'TACTGCACAAGTGGAAT' *.fastq > count/B6881_Rm0.txt
agrep -0 -c 'TTAAAGCGTAGCGGACC' *.fastq > count/B6883_Rm0.txt
agrep -0 -c 'CACATTCGCGATCGGAG' *.fastq > count/B6884_Rm0.txt
agrep -0 -c 'ACTTAGATCGCCAGTCC' *.fastq > count/B6886_Rm0.txt
agrep -0 -c 'CTCCCTCGGATCAAGTG' *.fastq > count/B6887_Rm0.txt
agrep -0 -c 'CCTTCATTAGTCTCAAG' *.fastq > count/B6888_Rm0.txt
agrep -0 -c 'ACAAACCTGAAGTCGTA' *.fastq > count/B6889_Rm0.txt
agrep -0 -c 'CGATGGGCATAACACGA' *.fastq > count/B6890_Rm0.txt
agrep -0 -c 'TGGCATGTGAGAACTCT' *.fastq > count/B6891_Rm0.txt
agrep -0 -c 'CTCTTTCGTCTACCTTA' *.fastq > count/B6893_Rm0.txt
agrep -0 -c 'CCACATAGAATCCGTGA' *.fastq > count/B6894_Rm0.txt
agrep -0 -c 'TTACAATTGTCTCTGCG' *.fastq > count/B6896_Rm0.txt
agrep -0 -c 'TAGTATATCGTCAGACG' *.fastq > count/B6898_Rm0.txt
agrep -0 -c 'GCTAGTGGTACTATAAC' *.fastq > count/B6899_Rm0.txt
agrep -0 -c 'ACTTCGCCAGGAGTGTC' *.fastq > count/B6900_Rm0.txt
agrep -0 -c 'ACCAGGTTCAACGCGCT' *.fastq > count/B6902_Rm0.txt
agrep -0 -c 'CAGTCGCGAATGTGCAA' *.fastq > count/B6903_Rm0.txt
agrep -0 -c 'GCATTACCGAGCGTAGA' *.fastq > count/B6905_Rm0.txt
agrep -0 -c 'TCAGGTCGAGCGTTCGA' *.fastq > count/B6907_Rm0.txt
agrep -0 -c 'CGGAAGGTTTAACAGAA' *.fastq > count/B6908_Rm0.txt
agrep -0 -c 'CAGGTTTACGAAGTCTC' *.fastq > count/B6909_Rm0.txt
agrep -0 -c 'TGCATTCTGCGACGGAC' *.fastq > count/B6910_Rm0.txt
agrep -0 -c 'CTCTAGACCAAAGGAAT' *.fastq > count/B6911_Rm0.txt
agrep -0 -c 'GAACAAGCCCATAGTTG' *.fastq > count/B6912_Rm0.txt
agrep -0 -c 'GAAACGACCCGGTACAT' *.fastq > count/B6913_Rm0.txt
agrep -0 -c 'CGCGGATGTCCGTTTTA' *.fastq > count/B6914_Rm0.txt
agrep -0 -c 'GTGTGTCCGCAATCCAT' *.fastq > count/B6915_Rm0.txt
agrep -0 -c 'CACAATATCCACGGACC' *.fastq > count/B6916_Rm0.txt
agrep -0 -c 'AAGCAACCCACCGTTCT' *.fastq > count/B6917_Rm0.txt
agrep -0 -c 'GAGTATGGCCCACAACC' *.fastq > count/B6918_Rm0.txt
agrep -0 -c 'CTGCAAATTTGCCACGC' *.fastq > count/B6919_Rm0.txt
agrep -0 -c 'TCGAACTCTAGCAGCTT' *.fastq > count/B6920_Rm0.txt
agrep -0 -c 'TAAAATCGGCCGATTCT' *.fastq > count/B6921_Rm0.txt
agrep -0 -c 'TATACCAGCTCCAGGAT' *.fastq > count/B6922_Rm0.txt
agrep -0 -c 'ACGGACTTAGGAAATCG' *.fastq > count/B6923_Rm0.txt
agrep -0 -c 'CGTACAGAAAGGGGTTA' *.fastq > count/B6924_Rm0.txt
agrep -0 -c 'TGCAATGGGTCTTAAGG' *.fastq > count/B6925_Rm0.txt
agrep -0 -c 'TCCACTTGGTACTCGTG' *.fastq > count/B6926_Rm0.txt
agrep -0 -c 'TCTAGATCTGAAGCACC' *.fastq > count/B6927_Rm0.txt
agrep -0 -c 'AGCGATTGTGGCAGATG' *.fastq > count/B6928_Rm0.txt
agrep -0 -c 'GATTCATGCGATTGGTG' *.fastq > count/B6929_Rm0.txt
agrep -0 -c 'ACGTTGTGAGATTGGCC' *.fastq > count/B6930_Rm0.txt
agrep -0 -c 'ATTGTTGTCCGATTGAC' *.fastq > count/B6931_Rm0.txt
agrep -0 -c 'AATCCTGAGCCGTATAT' *.fastq > count/B6932_Rm0.txt
agrep -0 -c 'CAAGCCTAAGTATCGCA' *.fastq > count/B6933_Rm0.txt
agrep -0 -c 'AACTTGGGTCAGTTCAT' *.fastq > count/B6934_Rm0.txt
agrep -0 -c 'CGATTGCACAATGGGAG' *.fastq > count/B6938_Rm0.txt
agrep -0 -c 'GTAGTCAACTCATCTCC' *.fastq > count/B6939_Rm0.txt
agrep -0 -c 'AGACATAGGCCTCGCAT' *.fastq > count/B6942_Rm0.txt
agrep -0 -c 'GCCGTGACAAGCATCTG' *.fastq > count/B6943_Rm0.txt
agrep -0 -c 'GTACAGTGAGACGAGGC' *.fastq > count/B6944_Rm0.txt
agrep -0 -c 'ATTCGTGACCAGACTAC' *.fastq > count/B6946_Rm0.txt
agrep -0 -c 'TGCAGAGCGTTGAGTGA' *.fastq > count/B6947_Rm0.txt
agrep -0 -c 'TCATGTTCGAGCCACTG' *.fastq > count/B6948_Rm0.txt
agrep -0 -c 'GTTCAGTTCGTCGGTAC' *.fastq > count/B6950_Rm0.txt
agrep -0 -c 'AAACATTTCGGAGCCAC' *.fastq > count/B6951_Rm0.txt
agrep -0 -c 'TTCGCTCATAGCGTGAG' *.fastq > count/B6952_Rm0.txt
agrep -0 -c 'GGGTGAGTGGAACTTCC' *.fastq > count/B6953_Rm0.txt
agrep -0 -c 'TACCATTACCCCCGTAT' *.fastq > count/B6954_Rm0.txt
agrep -0 -c 'CGAAGAGCAGGTTCTAT' *.fastq > count/B6955_Rm0.txt
agrep -0 -c 'GAACTTCTTCGAATCTC' *.fastq > count/B6957_Rm0.txt
agrep -0 -c 'GACTCCTAGACGCATTA' *.fastq > count/B6958_Rm0.txt
agrep -0 -c 'TGTTTAGATACTCCGAG' *.fastq > count/B6959_Rm0.txt
agrep -0 -c 'CCTACTGGGTAAGGGAG' *.fastq > count/B6960_Rm0.txt
agrep -0 -c 'GAACCTAAAAAGCAGCA' *.fastq > count/B6961_Rm0.txt
agrep -0 -c 'TACAGCATCGTCTACAT' *.fastq > count/B6962_Rm0.txt
agrep -0 -c 'GCCGGTTGTGCAACCTA' *.fastq > count/B6963_Rm0.txt
agrep -0 -c 'CGGCACTGTTACATACA' *.fastq > count/B6964_Rm0.txt
agrep -0 -c 'GTGCTCCAGGGTTCACA' *.fastq > count/B6967_Rm0.txt
agrep -0 -c 'GTTCAAAGTGCGGGATT' *.fastq > count/B6968_Rm0.txt
agrep -0 -c 'TAGTTGGCTGGTGGCAG' *.fastq > count/B6969_Rm0.txt
agrep -0 -c 'ACATCCAGGCGTGATTG' *.fastq > count/B6970_Rm0.txt
agrep -0 -c 'TCCTAGGATCACCCCAG' *.fastq > count/B6971_Rm0.txt
agrep -0 -c 'GTCTCGAAAAGACCTGC' *.fastq > count/B6972_Rm0.txt
agrep -0 -c 'GTTACATCGGTAAGCAG' *.fastq > count/B6974_Rm0.txt
agrep -0 -c 'CGTGGCTCTATGGAACC' *.fastq > count/B6975_Rm0.txt
agrep -0 -c 'TCGAAGGTCGAAGTGTA' *.fastq > count/B6976_Rm0.txt
agrep -0 -c 'CAAATCTGCTGCACGGC' *.fastq > count/B6977_Rm0.txt
agrep -0 -c 'GGTTTGCTGACGTGCGA' *.fastq > count/B6979_Rm0.txt
agrep -0 -c 'ATTAAGCCTGCCATGCC' *.fastq > count/B6980_Rm0.txt
agrep -0 -c 'GTACTCGACGCTGTATC' *.fastq > count/B6981_Rm0.txt
agrep -0 -c 'CTCATCCTAGAGTTCGC' *.fastq > count/B6982_Rm0.txt
agrep -0 -c 'GACACGGTGCCGTAATC' *.fastq > count/B6983_Rm0.txt
agrep -0 -c 'TCGACTGTAACAAGATC' *.fastq > count/B6984_Rm0.txt
agrep -0 -c 'AGAAAGCCACTTCGACT' *.fastq > count/B6985_Rm0.txt
agrep -0 -c 'GACCGTATGCTGATATC' *.fastq > count/B6986_Rm0.txt
agrep -0 -c 'CCACTTCTACCAGGACT' *.fastq > count/B6989_Rm0.txt
agrep -0 -c 'AGTCCAGAGGTTAAACG' *.fastq > count/B6991_Rm0.txt
agrep -0 -c 'TCTAGTAGAAGAAGTCG' *.fastq > count/B6992_Rm0.txt
agrep -0 -c 'TATTCGTGTGTACGTTG' *.fastq > count/B6993_Rm0.txt
agrep -0 -c 'ACCGGGTAACCTCTTAA' *.fastq > count/B6994_Rm0.txt
agrep -0 -c 'GTATCACAACCAGGGCA' *.fastq > count/B6996_Rm0.txt
agrep -0 -c 'GAAGTCGCTGACCTAAT' *.fastq > count/B6997_Rm0.txt
agrep -0 -c 'AAGTTCAGGGGTCTCGG' *.fastq > count/B7000_Rm0.txt
agrep -0 -c 'AAGTTTGATGGGGGTGC' *.fastq > count/B7001_Rm0.txt
agrep -0 -c 'TTGCAAACGCGGCACCT' *.fastq > count/B7002_Rm0.txt
agrep -0 -c 'CGACTACGTATACGATA' *.fastq > count/B7003_Rm0.txt
agrep -0 -c 'CCAGGATTTCTGTGTCA' *.fastq > count/B7004_Rm0.txt
agrep -0 -c 'GCTAGAGCTAGCGATAT' *.fastq > count/B7007_Rm0.txt
agrep -0 -c 'TGTTGCTCTCATCGGCA' *.fastq > count/B7011_Rm0.txt
agrep -0 -c 'ATAGGCCTAGAGCATTG' *.fastq > count/B7012_Rm0.txt
agrep -0 -c 'GCAAATCGCCATTGGTC' *.fastq > count/B7013_Rm0.txt
agrep -0 -c 'TGGAACATTGCTGGCGG' *.fastq > count/B7014_Rm0.txt
agrep -0 -c 'TTAGGACTCTAGGATAG' *.fastq > count/B7015_Rm0.txt
agrep -0 -c 'CGATTCCCCTGATACTG' *.fastq > count/B7016_Rm0.txt
agrep -0 -c 'CTGGTCTCGGAGGCTAA' *.fastq > count/B7017_Rm0.txt
agrep -0 -c 'CGGAATGTTCCGCCGAT' *.fastq > count/B7018_Rm0.txt
agrep -0 -c 'TGTATACTCCGGTAGCC' *.fastq > count/B7020_Rm0.txt
agrep -0 -c 'CACTTCACTGATTGGGC' *.fastq > count/B7021_Rm0.txt
agrep -0 -c 'TTGGATGTGCTCGACCC' *.fastq > count/B7022_Rm0.txt
agrep -0 -c 'TTGAAGGAGGCTTGACT' *.fastq > count/B7023_Rm0.txt
agrep -0 -c 'GTGGGCTTAAAACGACC' *.fastq > count/B7024_Rm0.txt
agrep -0 -c 'GCACAAGCCTTCTACGT' *.fastq > count/B7026_Rm0.txt
agrep -0 -c 'CAAAGTACAAGCATGGT' *.fastq > count/B7027_Rm0.txt
agrep -0 -c 'GAGATCGATTAAAGCCC' *.fastq > count/B7029_Rm0.txt
agrep -0 -c 'CACGTTGTCGTCGGGAT' *.fastq > count/B7031_Rm0.txt
agrep -0 -c 'CGGCATTTGGTCTCACG' *.fastq > count/B7032_Rm0.txt
agrep -0 -c 'GGACGCTTCAGACTACT' *.fastq > count/B7034_Rm0.txt
agrep -0 -c 'GCCTGCGCCGATATTAG' *.fastq > count/B7035_Rm0.txt
agrep -0 -c 'AGAATCTGGGGCTCGTT' *.fastq > count/B7036_Rm0.txt
agrep -0 -c 'ATTGACGATAACTTCGC' *.fastq > count/B7037_Rm0.txt
agrep -0 -c 'AAGGTTATCATGCTTCC' *.fastq > count/B7038_Rm0.txt
agrep -0 -c 'CACGACCTGAGATTACC' *.fastq > count/B7039_Rm0.txt
agrep -0 -c 'CCGACACAATCTCCTCC' *.fastq > count/B7040_Rm0.txt
agrep -0 -c 'TCAGCATGCTTCTCTGA' *.fastq > count/B7041_Rm0.txt
agrep -0 -c 'TCCTCCTAATTCGCAGG' *.fastq > count/B7042_Rm0.txt
agrep -0 -c 'ACTTTTCTCTTCACTCG' *.fastq > count/B7043_Rm0.txt
agrep -0 -c 'TCTTCCGTCTGGTAGAA' *.fastq > count/B7044_Rm0.txt
agrep -0 -c 'GAGTAGCACCGGTCCAA' *.fastq > count/B7046_Rm0.txt
agrep -0 -c 'ACTGGTGATGGTCGCTC' *.fastq > count/B7048_Rm0.txt
agrep -0 -c 'CTCCCAGTCTTGTTGCG' *.fastq > count/B7049_Rm0.txt
agrep -0 -c 'CCAGTCGTTTCTCCAAT' *.fastq > count/B7050_Rm0.txt
agrep -0 -c 'ATATCGAACGCTTGAAC' *.fastq > count/B7051_Rm0.txt
agrep -0 -c 'GCGTGTATAGTGTGACC' *.fastq > count/B7052_Rm0.txt
agrep -0 -c 'ATCGGCCGTTATCCCTT' *.fastq > count/B7053_Rm0.txt
agrep -0 -c 'GGGGACACGTCATCATT' *.fastq > count/B7054_Rm0.txt
agrep -0 -c 'GGTTGTCAGGTGAGACA' *.fastq > count/B7055_Rm0.txt
agrep -0 -c 'ACACTTAGTCAAGCCCT' *.fastq > count/B7056_Rm0.txt
agrep -0 -c 'TATTACATCCGAGACGG' *.fastq > count/B7057_Rm0.txt
agrep -0 -c 'GGGAGTGTCCTGTCTAT' *.fastq > count/B7059_Rm0.txt
agrep -0 -c 'GTCGGTTTAGCATGATG' *.fastq > count/B7061_Rm0.txt
agrep -0 -c 'ACTAACTTGGGCTCTAT' *.fastq > count/B7062_Rm0.txt
agrep -0 -c 'GACGATGAGAGCTGTTG' *.fastq > count/B7063_Rm0.txt
agrep -0 -c 'GCATCCTTACTCGTACC' *.fastq > count/B7064_Rm0.txt
agrep -0 -c 'ACGTGTATCCCCCTCTC' *.fastq > count/B7065_Rm0.txt
agrep -0 -c 'ATTCTCAAGCCCTAGGT' *.fastq > count/B7066_Rm0.txt
agrep -0 -c 'GATTAACACCGAAGTGC' *.fastq > count/B7067_Rm0.txt
agrep -0 -c 'TGTGAATTCTACCCGAC' *.fastq > count/B7068_Rm0.txt
agrep -0 -c 'GAGGTCAAGGTAGTGCC' *.fastq > count/B7070_Rm0.txt
agrep -0 -c 'CTATCGAAAATGTCGCG' *.fastq > count/B7071_Rm0.txt
agrep -0 -c 'GTCTGTCAATACTCACT' *.fastq > count/B7072_Rm0.txt
agrep -0 -c 'AAAGAGGTAATAGTGCC' *.fastq > count/B7075_Rm0.txt
agrep -0 -c 'AAACTCGCGTTCTCGTG' *.fastq > count/B7076_Rm0.txt
agrep -0 -c 'TAGCATGCCCCCTAAGT' *.fastq > count/B7077_Rm0.txt
agrep -0 -c 'GACACGCGGTTTGTAAG' *.fastq > count/B7078_Rm0.txt
agrep -0 -c 'CTATCGTACCTTCCATT' *.fastq > count/B7079_Rm0.txt
agrep -0 -c 'CCCGCACTGATTACCTT' *.fastq > count/B7080_Rm0.txt
agrep -0 -c 'TAGCAATCCGCTGAATT' *.fastq > count/B7081_Rm0.txt
agrep -0 -c 'CACGAAGGGCCATACAA' *.fastq > count/B7082_Rm0.txt
agrep -0 -c 'TTTTGAGTTGCTCGTCG' *.fastq > count/B7083_Rm0.txt
agrep -0 -c 'GGCTACCTATGGCTCTT' *.fastq > count/B7085_Rm0.txt
agrep -0 -c 'CCCTCAGATTAGGCAAG' *.fastq > count/B7086_Rm0.txt
agrep -0 -c 'GTCTACGGACTATAACC' *.fastq > count/B7087_Rm0.txt
agrep -0 -c 'TAAGTCCATAGCTGCCG' *.fastq > count/B7088_Rm0.txt
agrep -0 -c 'CTCAAACACTCTAGCGT' *.fastq > count/B7089_Rm0.txt
agrep -0 -c 'TAATAGCAACCGGCGGC' *.fastq > count/B7090_Rm0.txt
agrep -0 -c 'GTTGTGCCAGTCTCTTA' *.fastq > count/B7091_Rm0.txt
agrep -0 -c 'CAAGTGGTTCGAGTGTG' *.fastq > count/B7092_Rm0.txt
agrep -0 -c 'TGATATCGGGCAGGCGT' *.fastq > count/B7093_Rm0.txt
agrep -0 -c 'TTCCCAGTGGTTGACAC' *.fastq > count/B7094_Rm0.txt
agrep -0 -c 'GCGACTAGTACTATTAC' *.fastq > count/B7095_Rm0.txt
agrep -0 -c 'TCACTGGTAAGGTGCTA' *.fastq > count/B7097_Rm0.txt
agrep -0 -c 'TCGGCACAATGTAGTAA' *.fastq > count/B7098_Rm0.txt
agrep -0 -c 'CAACCGCACCTGACATA' *.fastq > count/B7099_Rm0.txt
agrep -0 -c 'TAGGTCTTGGAGTACGA' *.fastq > count/B7100_Rm0.txt
agrep -0 -c 'CGAGTGTAGCCGACTGT' *.fastq > count/B7101_Rm0.txt
agrep -0 -c 'AGACTTTCACCATGCAA' *.fastq > count/B7103_Rm0.txt
agrep -0 -c 'ACTAGGGTAACGTGTGG' *.fastq > count/B7104_Rm0.txt
agrep -0 -c 'TGGCGTGAAAGAACTAG' *.fastq > count/B7105_Rm0.txt
agrep -0 -c 'AGTGACCCGATACCTGC' *.fastq > count/B7106_Rm0.txt
agrep -0 -c 'CTGTACTGCTCGCCACT' *.fastq > count/B7107_Rm0.txt
agrep -0 -c 'ACGATACCGACAATGGT' *.fastq > count/B7108_Rm0.txt
agrep -0 -c 'CATAAGTGCGCCGCTCT' *.fastq > count/B7109_Rm0.txt
agrep -0 -c 'GGTTACACCTTTCTCCC' *.fastq > count/B7110_Rm0.txt
agrep -0 -c 'AGGAGTTCCAGCTTCGT' *.fastq > count/B7111_Rm0.txt
agrep -0 -c 'CCTCAGATGCTGATTAA' *.fastq > count/B7112_Rm0.txt
agrep -0 -c 'CTCACCTTAATGAGTCA' *.fastq > count/B7113_Rm0.txt
agrep -0 -c 'TGGCGTTCCAATCTATG' *.fastq > count/B7114_Rm0.txt
agrep -0 -c 'AGCAGTGATACACGTTG' *.fastq > count/B7115_Rm0.txt
agrep -0 -c 'CCTAGTTATTAGCCTCG' *.fastq > count/B7116_Rm0.txt
agrep -0 -c 'ACTCCCCTCTTTGTCGA' *.fastq > count/B7117_Rm0.txt
agrep -0 -c 'GAACGCCATAGTATCAC' *.fastq > count/B7118_Rm0.txt
agrep -0 -c 'TAGGAGTCAGTCTTCGG' *.fastq > count/B7119_Rm0.txt
agrep -0 -c 'CCTTCTGAACTATCGCA' *.fastq > count/B7120_Rm0.txt
agrep -0 -c 'TTTTGATCCCACGAGCC' *.fastq > count/B7121_Rm0.txt
agrep -0 -c 'TGGAATTGGAGATCGGT' *.fastq > count/B7122_Rm0.txt
agrep -0 -c 'GAACCCATATCTTACCC' *.fastq > count/B7123_Rm0.txt
agrep -0 -c 'GGGTAGTTACAAAGGTG' *.fastq > count/B7124_Rm0.txt
agrep -0 -c 'CGAGTCTATAGACTATG' *.fastq > count/B7125_Rm0.txt
agrep -0 -c 'CATCGGTACGCTGAGAG' *.fastq > count/B7126_Rm0.txt
agrep -0 -c 'CTAGTACGGCCAAGCGT' *.fastq > count/B7127_Rm0.txt
agrep -0 -c 'GATCGCACAAGGAGTAA' *.fastq > count/B7128_Rm0.txt
agrep -0 -c 'TCTGAATAGACCTCTAC' *.fastq > count/B7131_Rm0.txt
agrep -0 -c 'AATGAAATGGCCCAGGT' *.fastq > count/B7132_Rm0.txt
agrep -0 -c 'GGTTGTCCACTTGTGCT' *.fastq > count/B7133_Rm0.txt
agrep -0 -c 'AGGTTAAGAGCCCACAT' *.fastq > count/B7134_Rm0.txt
agrep -0 -c 'GGATCATGGTGAGATGG' *.fastq > count/B7135_Rm0.txt
agrep -0 -c 'TGGTGGGTCTCGATAAT' *.fastq > count/B7136_Rm0.txt
agrep -0 -c 'TCAGCATGTCAAGGAAT' *.fastq > count/B7137_Rm0.txt
agrep -0 -c 'GTGATTGCATTAGGAGG' *.fastq > count/B7138_Rm0.txt
agrep -0 -c 'GGCGCAAGTGTGGATCA' *.fastq > count/B7140_Rm0.txt
agrep -0 -c 'GGGAATATACGCCAGCC' *.fastq > count/B7141_Rm0.txt
agrep -0 -c 'ACTTCAGTACGTGTACC' *.fastq > count/B7142_Rm0.txt
agrep -0 -c 'CAGTATGTAGTTGGCAG' *.fastq > count/B7143_Rm0.txt
agrep -0 -c 'CACCATACGTTACCGCG' *.fastq > count/B7144_Rm0.txt
agrep -0 -c 'ACACGAACGAAGTGTAC' *.fastq > count/B7145_Rm0.txt
agrep -0 -c 'CGTTCGTACATGGTCGC' *.fastq > count/B7146_Rm0.txt
agrep -0 -c 'CCGGCCACATTCCATTG' *.fastq > count/B7148_Rm0.txt
agrep -0 -c 'GTCAAGTCTTAACGGAG' *.fastq > count/B7149_Rm0.txt
agrep -0 -c 'TCCCCTGATGTGATGAC' *.fastq > count/B7150_Rm0.txt
agrep -0 -c 'GTGTAAGCTTTCACCCT' *.fastq > count/B7151_Rm0.txt
agrep -0 -c 'TAGGCATCAGCGATTCT' *.fastq > count/B7153_Rm0.txt
agrep -0 -c 'GCGAAAAAGTAGCGTTA' *.fastq > count/B7154_Rm0.txt
agrep -0 -c 'AGGGTTACGGTCCTGTA' *.fastq > count/B7155_Rm0.txt
agrep -0 -c 'AGTTAGGATTACCAGCG' *.fastq > count/B7156_Rm0.txt
agrep -0 -c 'AATTCTGTCCACCGCTG' *.fastq > count/B7158_Rm0.txt
agrep -0 -c 'GGTGACTACGGAACACT' *.fastq > count/B7159_Rm0.txt
agrep -0 -c 'GTGGTACGGTATGTAGT' *.fastq > count/B7160_Rm0.txt
agrep -0 -c 'ACTTCTGGACGGTGTGG' *.fastq > count/B7161_Rm0.txt
agrep -0 -c 'CTCCATAAACGGTGATA' *.fastq > count/B7162_Rm0.txt
agrep -0 -c 'AGTCTTCTGAGAGTAGA' *.fastq > count/B7163_Rm0.txt
agrep -0 -c 'ACTATACCCTGTGAGAG' *.fastq > count/B7164_Rm0.txt
agrep -0 -c 'TGTAGGAAGGGTTGAAT' *.fastq > count/B7165_Rm0.txt
agrep -0 -c 'AAGTATACCCTGGGCGC' *.fastq > count/B7167_Rm0.txt
agrep -0 -c 'AGTCTAGCGTTGAGTCC' *.fastq > count/B7169_Rm0.txt
agrep -0 -c 'CTCGTTGACCTAAAAGA' *.fastq > count/B7170_Rm0.txt
agrep -0 -c 'TATTAGGTGACGCTCGA' *.fastq > count/B7171_Rm0.txt
agrep -0 -c 'CCTCGGAAGTTTTCTAA' *.fastq > count/B7173_Rm0.txt
agrep -0 -c 'TCTCAACGCGACGGCAT' *.fastq > count/B7175_Rm0.txt
agrep -0 -c 'CCTCCAGCCCTGAACAA' *.fastq > count/B7176_Rm0.txt
agrep -0 -c 'ACCGAGCGTAGACATAT' *.fastq > count/B7177_Rm0.txt
agrep -0 -c 'GAAGAGTAACCTTCCCG' *.fastq > count/B7178_Rm0.txt
agrep -0 -c 'CCTGGATATGCGCGACA' *.fastq > count/B7180_Rm0.txt
agrep -0 -c 'GCTAGAAAGGACCCGAT' *.fastq > count/B7181_Rm0.txt
agrep -0 -c 'TGACTGCGTCACTTATT' *.fastq > count/B7183_Rm0.txt
agrep -0 -c 'CGAACAGGACTTTACAC' *.fastq > count/B7185_Rm0.txt
agrep -0 -c 'TTTAGGGTACGTCATGC' *.fastq > count/B7186_Rm0.txt
agrep -0 -c 'CCGCTTGCCTTGTGTTG' *.fastq > count/B7187_Rm0.txt
agrep -0 -c 'TGCTTGACATCGGGAAC' *.fastq > count/B7188_Rm0.txt
agrep -0 -c 'AGGATTTCCGAGCTGGC' *.fastq > count/B7189_Rm0.txt
agrep -0 -c 'GAACAATTCGCACGTAT' *.fastq > count/B7190_Rm0.txt
agrep -0 -c 'TGTCAGAGGGTCCTCTG' *.fastq > count/B7191_Rm0.txt
agrep -0 -c 'TCCGTAGACTTTGAGTC' *.fastq > count/B7193_Rm0.txt
agrep -0 -c 'AGGGCATGAGCTAGTTG' *.fastq > count/B7194_Rm0.txt
agrep -0 -c 'TAATTAGGGGCTGTGGC' *.fastq > count/B7195_Rm0.txt
agrep -0 -c 'GTCGTGTTCAGACCATA' *.fastq > count/B7196_Rm0.txt
agrep -0 -c 'TCGGGCTAGCCGGTAAT' *.fastq > count/B7197_Rm0.txt
agrep -0 -c 'TCTGGTTAAAGACCTGT' *.fastq > count/B7200_Rm0.txt
agrep -0 -c 'CAGTGCACATGTATCCC' *.fastq > count/B7201_Rm0.txt
agrep -0 -c 'CCCAATGTGGTCAAAGA' *.fastq > count/B7202_Rm0.txt
agrep -0 -c 'TGGCTGCGATAAGTCCT' *.fastq > count/B7203_Rm0.txt
agrep -0 -c 'AGTTGTAGCCCTGTATG' *.fastq > count/B7204_Rm0.txt
agrep -0 -c 'CTGACTTAGCCCACGCT' *.fastq > count/B7205_Rm0.txt
agrep -0 -c 'ATCAGCCAGCTCGATCG' *.fastq > count/B7207_Rm0.txt
agrep -0 -c 'CTGGTTGGGGTTTTAAT' *.fastq > count/B7208_Rm0.txt
agrep -0 -c 'TCAACGTGGTGGAGTAT' *.fastq > count/B7210_Rm0.txt
agrep -0 -c 'AACGCTCGCTGGATCAG' *.fastq > count/B7211_Rm0.txt
agrep -0 -c 'GGGCCACAATATCTGGC' *.fastq > count/B7214_Rm0.txt
agrep -0 -c 'TCCTGCAACTGAACGCT' *.fastq > count/B7215_Rm0.txt
agrep -0 -c 'GTAATGTATAGGGGCGG' *.fastq > count/B7217_Rm0.txt
agrep -0 -c 'GACTGCTTATCGATCGA' *.fastq > count/B7218_Rm0.txt
agrep -0 -c 'CGGTGAAAGACGTTCGA' *.fastq > count/B7219_Rm0.txt
agrep -0 -c 'AGCACATTTCAGATGGT' *.fastq > count/B7220_Rm0.txt
agrep -0 -c 'TATGTCGATACGACAGC' *.fastq > count/B7222_Rm0.txt
agrep -0 -c 'GGTATTCACAGTTCGAG' *.fastq > count/B7223_Rm0.txt
agrep -0 -c 'GCTGGGTTAAGTCAGAC' *.fastq > count/B7224_Rm0.txt
agrep -0 -c 'CAATAGCACAACAGCCA' *.fastq > count/B7226_Rm0.txt
agrep -0 -c 'GCAACCCTTCAATGACG' *.fastq > count/B7228_Rm0.txt
agrep -0 -c 'AAACGCCGGCGTAGTAA' *.fastq > count/B7229_Rm0.txt
agrep -0 -c 'GGGGAACTAGCTTACCG' *.fastq > count/B7230_Rm0.txt
agrep -0 -c 'TCAGTATCTGCCGTGAG' *.fastq > count/B7232_Rm0.txt
agrep -0 -c 'ACTTGATCGTTCTGGTT' *.fastq > count/B7233_Rm0.txt
agrep -0 -c 'TCATTGCAATCGCCTCG' *.fastq > count/B7234_Rm0.txt
agrep -0 -c 'CGGACTTGCTCCTCTAC' *.fastq > count/B7236_Rm0.txt
agrep -0 -c 'GAATAGCCTGGGAGGGT' *.fastq > count/B7237_Rm0.txt
agrep -0 -c 'AAAATCCCGTAGCCTGT' *.fastq > count/B7239_Rm0.txt
agrep -0 -c 'CATTCACATCCGCCAGG' *.fastq > count/B7240_Rm0.txt
agrep -0 -c 'CACCTATCGGTCACGCA' *.fastq > count/B7241_Rm0.txt
agrep -0 -c 'GAATTCCGACGCCGGTA' *.fastq > count/B7242_Rm0.txt
agrep -0 -c 'CGTGGTAGTGTAGAGTC' *.fastq > count/B7243_Rm0.txt
agrep -0 -c 'TGGGGCTAAGCCCAAAT' *.fastq > count/B7244_Rm0.txt
agrep -0 -c 'TGGGTTCACCGCACGAA' *.fastq > count/B7245_Rm0.txt
agrep -0 -c 'GTCCTAGCGTCTAGGGT' *.fastq > count/B7246_Rm0.txt
agrep -0 -c 'TGTTGCCAAGCATAAGC' *.fastq > count/B7247_Rm0.txt
agrep -0 -c 'CCGGCCAAAGCAACTCA' *.fastq > count/B7248_Rm0.txt
agrep -0 -c 'TGAGTACTCCGTACCGC' *.fastq > count/B7249_Rm0.txt
agrep -0 -c 'TCTGCCACTCATGAACA' *.fastq > count/B7250_Rm0.txt
agrep -0 -c 'TGTAGGCGTTCTGACGC' *.fastq > count/B7251_Rm0.txt
agrep -0 -c 'TGAGGTTACAATGTCCT' *.fastq > count/B7252_Rm0.txt
agrep -0 -c 'GACCCGAGACATAATAG' *.fastq > count/B7253_Rm0.txt
agrep -0 -c 'TTGATCTTCTCCGCTTA' *.fastq > count/B7255_Rm0.txt
agrep -0 -c 'TCTCATCTCACCGTCCT' *.fastq > count/B7256_Rm0.txt
agrep -0 -c 'CTGAGTGCATTCACCGT' *.fastq > count/B7257_Rm0.txt
agrep -0 -c 'AATTGCGCCTACCTAAC' *.fastq > count/B7258_Rm0.txt
agrep -0 -c 'TTTAGGAAGACGGCACA' *.fastq > count/B7259_Rm0.txt
agrep -0 -c 'TCGGTCCAGTAGAGGCA' *.fastq > count/B7260_Rm0.txt
agrep -0 -c 'ACTGCTGAAGTAATTCG' *.fastq > count/B7261_Rm0.txt
agrep -0 -c 'GATTCGGCACGCTAATA' *.fastq > count/B7262_Rm0.txt
agrep -0 -c 'AATCAGCGGTAGCACCT' *.fastq > count/B7263_Rm0.txt
agrep -0 -c 'TTCGTACCTAGTCCCTC' *.fastq > count/B7264_Rm0.txt
agrep -0 -c 'ATGGATCAGTAGTGATC' *.fastq > count/B7265_Rm0.txt
agrep -0 -c 'GTTTGGAAAAGGTCGAG' *.fastq > count/B7266_Rm0.txt
agrep -0 -c 'CATCGATACTCGATTAC' *.fastq > count/B7267_Rm0.txt
agrep -0 -c 'TTGCGGCTTTTAGGCGA' *.fastq > count/B7268_Rm0.txt
agrep -0 -c 'CATTTCGAGCCCTTCTT' *.fastq > count/B7269_Rm0.txt
agrep -0 -c 'GCTTGGCCTCGCTTACT' *.fastq > count/B7270_Rm0.txt
agrep -0 -c 'GCAGTTAATTCCCTCAA' *.fastq > count/B7271_Rm0.txt
agrep -0 -c 'CTTCCAGCGTTCAGATC' *.fastq > count/B7272_Rm0.txt
agrep -0 -c 'GCTTGTTGGGACCGTAT' *.fastq > count/B7273_Rm0.txt
agrep -0 -c 'AGGTCTTTAAGACCGTG' *.fastq > count/B7274_Rm0.txt
agrep -0 -c 'TTGAAAGGCGATCAATC' *.fastq > count/B7275_Rm0.txt
agrep -0 -c 'CTCCTCTAGTAGTCCTA' *.fastq > count/B7276_Rm0.txt
agrep -0 -c 'CACGACAGCTCCGGTAA' *.fastq > count/B7277_Rm0.txt
agrep -0 -c 'CAGTCCTTGGTGTATCA' *.fastq > count/B7278_Rm0.txt
agrep -0 -c 'TCCAGACGCGATGCTGA' *.fastq > count/B7279_Rm0.txt
agrep -0 -c 'CATAATTCACCCCGCCT' *.fastq > count/B7280_Rm0.txt
agrep -0 -c 'CCATACCTTGTGCAAGG' *.fastq > count/B7281_Rm0.txt
agrep -0 -c 'TGGACTATCGCAGGCAC' *.fastq > count/B7282_Rm0.txt
agrep -0 -c 'AGCCCCAACCGTCTAAC' *.fastq > count/B7283_Rm0.txt
agrep -0 -c 'TCGCTGCTTAGCAGTAC' *.fastq > count/B7284_Rm0.txt
agrep -0 -c 'TAACTACAACCTCCGTC' *.fastq > count/B7285_Rm0.txt
agrep -0 -c 'AGCAAAAGGGTTCTCCT' *.fastq > count/B7286_Rm0.txt
agrep -0 -c 'TACGTATTGCCGCCCCT' *.fastq > count/B7287_Rm0.txt
agrep -0 -c 'TAACGGTAAGGGCTTCT' *.fastq > count/B7288_Rm0.txt
agrep -0 -c 'CGACGCTAACTAGAACC' *.fastq > count/B7289_Rm0.txt
agrep -0 -c 'CCTTCATGTTCAACTCA' *.fastq > count/B7291_Rm0.txt
agrep -0 -c 'GATTCCATGTTAGTCCA' *.fastq > count/B7292_Rm0.txt
agrep -0 -c 'ACATCCTAATTCCCTGC' *.fastq > count/B7293_Rm0.txt
agrep -0 -c 'ATGGCTTCCGACGGCAA' *.fastq > count/B7295_Rm0.txt
agrep -0 -c 'GATAGAAGCCACAATAG' *.fastq > count/B7296_Rm0.txt
agrep -0 -c 'TAAGATCAGTTGGGGAT' *.fastq > count/B7299_Rm0.txt
agrep -0 -c 'ACCCCGCCATATACGAT' *.fastq > count/B7300_Rm0.txt
agrep -0 -c 'CTATGCCAAGAAGTCCA' *.fastq > count/B7302_Rm0.txt
agrep -0 -c 'GATTCTGAGCACAGTAA' *.fastq > count/B7303_Rm0.txt
agrep -0 -c 'AGGTTCTAGCCAACCCC' *.fastq > count/B7304_Rm0.txt
agrep -0 -c 'CTAGGACTGCTGGGAGT' *.fastq > count/B7305_Rm0.txt
agrep -0 -c 'ACACGTCACTCGATCCT' *.fastq > count/B7306_Rm0.txt
agrep -0 -c 'CTCGACGGAGATCAGAA' *.fastq > count/B7309_Rm0.txt
agrep -0 -c 'ATTGCTAGATTACCGGC' *.fastq > count/B7311_Rm0.txt
agrep -0 -c 'AGCCTGATTCTAGTCGA' *.fastq > count/B7312_Rm0.txt
agrep -0 -c 'CCCCACATCTGGTGTAC' *.fastq > count/B7313_Rm0.txt
agrep -0 -c 'GTCAGCAAACAGGTCCA' *.fastq > count/B7314_Rm0.txt
agrep -0 -c 'AGGCTCTTTTTCAAGAC' *.fastq > count/B7315_Rm0.txt
agrep -0 -c 'GCGCTCGCACTCGAAAT' *.fastq > count/B7318_Rm0.txt
agrep -0 -c 'TCTTGGGTCGCTCTTCT' *.fastq > count/B7319_Rm0.txt
agrep -0 -c 'GGACTACTCTGAACGAC' *.fastq > count/B7320_Rm0.txt
agrep -0 -c 'TTGCATGCGTATCGAGC' *.fastq > count/B7321_Rm0.txt
agrep -0 -c 'CGTCCCCATAGCCTTAC' *.fastq > count/B7322_Rm0.txt
agrep -0 -c 'TCCGCAGTTCACGCTAG' *.fastq > count/B7323_Rm0.txt
agrep -0 -c 'CACGAGTCGAAATCCTG' *.fastq > count/B7324_Rm0.txt
agrep -0 -c 'GCATACTACTAGGCTGG' *.fastq > count/B7325_Rm0.txt
agrep -0 -c 'GGGATAGGCTCAATTCC' *.fastq > count/B7326_Rm0.txt
agrep -0 -c 'CTAACAGTTTATCCCCT' *.fastq > count/B7328_Rm0.txt
agrep -0 -c 'ACCTACCCTTCGTGCAC' *.fastq > count/B7329_Rm0.txt
agrep -0 -c 'TGGTTCGGACTGCTAGC' *.fastq > count/B7330_Rm0.txt
agrep -0 -c 'AGACACCGACGTAGCAA' *.fastq > count/B7333_Rm0.txt
agrep -0 -c 'ACGACCCTGCTTGGACT' *.fastq > count/B7334_Rm0.txt
agrep -0 -c 'GCCATACCGCGAAAGCT' *.fastq > count/B7335_Rm0.txt
agrep -0 -c 'AGCGCGCGATTAGCTGA' *.fastq > count/B7337_Rm0.txt
agrep -0 -c 'CGGCTTGTTACGACCTT' *.fastq > count/B7338_Rm0.txt
agrep -0 -c 'AGTACGCCGATCCGTAT' *.fastq > count/B7339_Rm0.txt
agrep -0 -c 'TGGCCCGTCCAATTTGG' *.fastq > count/B7340_Rm0.txt
agrep -0 -c 'AGCGCCCAATTTCTTCC' *.fastq > count/B7341_Rm0.txt
agrep -0 -c 'TGTCGGTTCTGGAATAC' *.fastq > count/B7343_Rm0.txt
agrep -0 -c 'TTCGCCAACAGGTTTAT' *.fastq > count/B7346_Rm0.txt
agrep -0 -c 'CCTAGCGCTACAAACAT' *.fastq > count/B7347_Rm0.txt
agrep -0 -c 'CGGGCGATTACATTCAA' *.fastq > count/B7348_Rm0.txt
agrep -0 -c 'ACTTCCTTATATAGCGC' *.fastq > count/B7350_Rm0.txt
agrep -0 -c 'ACACGGATCTTCGGGTA' *.fastq > count/B7351_Rm0.txt
agrep -0 -c 'CTAGTACGATGAGCATG' *.fastq > count/B7352_Rm0.txt
agrep -0 -c 'GGGATCTCACCTGATGA' *.fastq > count/B7353_Rm0.txt
agrep -0 -c 'GCGGGGTGACTACAGAA' *.fastq > count/B7354_Rm0.txt
agrep -0 -c 'GGAAACGACATTGCGAA' *.fastq > count/B7355_Rm0.txt
agrep -0 -c 'TCCTTACTACCCTATCC' *.fastq > count/B7356_Rm0.txt
agrep -0 -c 'CCGAACGAATTACTCCA' *.fastq > count/B7357_Rm0.txt
agrep -0 -c 'TGCCCCCTAACTTCTAT' *.fastq > count/B7358_Rm0.txt
agrep -0 -c 'ACCTTTCAAGGGCTTCG' *.fastq > count/B7359_Rm0.txt
agrep -0 -c 'ATTCAGGTAGAGAACGC' *.fastq > count/B7360_Rm0.txt
agrep -0 -c 'GTAGTGCTAACGGCCAT' *.fastq > count/B7361_Rm0.txt
agrep -0 -c 'GGCCCTCAGTAAATTCT' *.fastq > count/B7362_Rm0.txt
agrep -0 -c 'ATTCCCTAGGCGTACTA' *.fastq > count/B7363_Rm0.txt
agrep -0 -c 'CTTGAAATCGTTGCGAT' *.fastq > count/B7364_Rm0.txt
agrep -0 -c 'ACCTGAACACAGAAGTA' *.fastq > count/B7365_Rm0.txt
agrep -0 -c 'TGTCGATGTGGGCGCTA' *.fastq > count/B7368_Rm0.txt
agrep -0 -c 'GACTCCGTACTGCCTCA' *.fastq > count/B7369_Rm0.txt
agrep -0 -c 'GAGTGGTACACCTGATG' *.fastq > count/B7370_Rm0.txt
agrep -0 -c 'GCGACTTTTTGATCCAA' *.fastq > count/B7371_Rm0.txt
agrep -0 -c 'TCGGTCTATTGACGTGA' *.fastq > count/B7373_Rm0.txt
agrep -0 -c 'TAGCCGCAAGCCACTCA' *.fastq > count/B7374_Rm0.txt
agrep -0 -c 'CACCACTACACCATGCT' *.fastq > count/B7375_Rm0.txt
agrep -0 -c 'CGAGATTTCTGACAATC' *.fastq > count/B7378_Rm0.txt
agrep -0 -c 'GTCGGCTATCAACTATG' *.fastq > count/B7379_Rm0.txt
agrep -0 -c 'CACTGCGAATCTGATGC' *.fastq > count/B7380_Rm0.txt
agrep -0 -c 'TGTGCTAAGGGCGATCA' *.fastq > count/B7381_Rm0.txt
agrep -0 -c 'CAGCGAAAATTGCATCA' *.fastq > count/B7382_Rm0.txt
agrep -0 -c 'TCGGTGAAGCAGAGTAG' *.fastq > count/B7383_Rm0.txt
agrep -0 -c 'TAGGGTTTACAGCGCTC' *.fastq > count/B7384_Rm0.txt
agrep -0 -c 'GGACAAAAACCTTCGAG' *.fastq > count/B7385_Rm0.txt
agrep -0 -c 'GTCGAGACTATCGTGCG' *.fastq > count/B7386_Rm0.txt
agrep -0 -c 'TCTCCGTATAGACCAAG' *.fastq > count/B7387_Rm0.txt
agrep -0 -c 'CTACAACTCGAATCCGG' *.fastq > count/B7388_Rm0.txt
agrep -0 -c 'TAACGTGCTACTGTCGT' *.fastq > count/B7389_Rm0.txt
agrep -0 -c 'TATCGTAAATAACGGCG' *.fastq > count/B7390_Rm0.txt
agrep -0 -c 'GTCTTGTCACTTGACAC' *.fastq > count/B7391_Rm0.txt
agrep -0 -c 'GATTCCCGTGTGCATGG' *.fastq > count/B7392_Rm0.txt
agrep -0 -c 'ATTGTGCACGCTTCTCG' *.fastq > count/B7393_Rm0.txt
agrep -0 -c 'GTGACTTTCGAAACCAC' *.fastq > count/B7394_Rm0.txt
agrep -0 -c 'GCGATTACTTAGAAGTG' *.fastq > count/B7395_Rm0.txt
agrep -0 -c 'TCCGGAGATGGCAAAGT' *.fastq > count/B7397_Rm0.txt
agrep -0 -c 'CTATGGAATGGACCCTC' *.fastq > count/B7399_Rm0.txt
agrep -0 -c 'ATAAGTCCCTGGGAGTG' *.fastq > count/B7402_Rm0.txt
agrep -0 -c 'TATGTGGCTCCCTCTGA' *.fastq > count/B7403_Rm0.txt
agrep -0 -c 'CTCCTGGAAAAGACGTC' *.fastq > count/B7404_Rm0.txt
agrep -0 -c 'GGCCATAGGGTGTCTCA' *.fastq > count/B7406_Rm0.txt
agrep -0 -c 'CGGTATGCTGACGTTTA' *.fastq > count/B7407_Rm0.txt
agrep -0 -c 'GAGTAGCGTAGTAGCGA' *.fastq > count/B7408_Rm0.txt
agrep -0 -c 'AGTAACGCGGTTAACCC' *.fastq > count/B7409_Rm0.txt
agrep -0 -c 'ATGGGAGCGTGTAGTTG' *.fastq > count/B7410_Rm0.txt
agrep -0 -c 'CAGAGTCGTGGATCGAT' *.fastq > count/B7411_Rm0.txt
agrep -0 -c 'TTGAAGACTTACCACAC' *.fastq > count/B7412_Rm0.txt
agrep -0 -c 'CGGGTAACTCTGATTCG' *.fastq > count/B7413_Rm0.txt
agrep -0 -c 'TAAAGACCGATCTGGCG' *.fastq > count/B7415_Rm0.txt
agrep -0 -c 'AAGTCAAAAGACCACGA' *.fastq > count/B7416_Rm0.txt
agrep -0 -c 'TCCTTTCCCATGGAGTG' *.fastq > count/B7417_Rm0.txt
agrep -0 -c 'GGCATTCAGAGATTCAG' *.fastq > count/B7418_Rm0.txt
agrep -0 -c 'GCAGTTGAGCCTTTGTC' *.fastq > count/B7419_Rm0.txt
agrep -0 -c 'AATACCGTACACAAGTG' *.fastq > count/B7420_Rm0.txt
agrep -0 -c 'TAGGTGGCCGATGACTA' *.fastq > count/B7422_Rm0.txt
agrep -0 -c 'GCGCGTTGATTTGCTAA' *.fastq > count/B7423_Rm0.txt
agrep -0 -c 'CACGACAAGTGAGGACC' *.fastq > count/B7424_Rm0.txt
agrep -0 -c 'CAGTAGTTGTATAGCTC' *.fastq > count/B7426_Rm0.txt
agrep -0 -c 'GGGACATCAAAAAGACA' *.fastq > count/B7427_Rm0.txt
agrep -0 -c 'TAGATGAGACCTGTGAG' *.fastq > count/B7428_Rm0.txt
agrep -0 -c 'GCTCGGCTATTAACATT' *.fastq > count/B7429_Rm0.txt
agrep -0 -c 'CGTACCCATACAGTGAA' *.fastq > count/B7430_Rm0.txt
agrep -0 -c 'TACCACTCGTAAGCCGC' *.fastq > count/B7431_Rm0.txt
agrep -0 -c 'AAAGGACCTTCGGCAAT' *.fastq > count/B7432_Rm0.txt
agrep -0 -c 'GGAACGAAGCGGCTACT' *.fastq > count/B7433_Rm0.txt
agrep -0 -c 'AACCGCGACACCTCTAC' *.fastq > count/B7434_Rm0.txt
agrep -0 -c 'CTGAAAAAGCGAGAGCG' *.fastq > count/B7435_Rm0.txt
agrep -0 -c 'CTCTGAACGCCTCCCTA' *.fastq > count/B7437_Rm0.txt
agrep -0 -c 'GTCGGAGATCGCTACAA' *.fastq > count/B7438_Rm0.txt
agrep -0 -c 'ACGGTCAATCTCAAGAG' *.fastq > count/B7439_Rm0.txt
agrep -0 -c 'CGAATACTGGCCCCAAG' *.fastq > count/B7443_Rm0.txt
agrep -0 -c 'CGGAGTATACCACTGGC' *.fastq > count/B7444_Rm0.txt
agrep -0 -c 'GCGAGTTGGATCGTCAC' *.fastq > count/B7445_Rm0.txt
agrep -0 -c 'ACTCCGCGGGATTGGAT' *.fastq > count/B7447_Rm0.txt
agrep -0 -c 'TTTGCAAGCCCGAGAAC' *.fastq > count/B7448_Rm0.txt
agrep -0 -c 'ACGAATAGAGTATTGCC' *.fastq > count/B7449_Rm0.txt
agrep -0 -c 'AACGACCCCAGCTATCC' *.fastq > count/B7450_Rm0.txt
agrep -0 -c 'ATGTCATGACTGGCTAA' *.fastq > count/B7451_Rm0.txt
agrep -0 -c 'GCCCAGGTTAACAGTGA' *.fastq > count/B7452_Rm0.txt
agrep -0 -c 'TGCATCGAAAAACACCT' *.fastq > count/B7453_Rm0.txt
agrep -0 -c 'GTGTCACTACTGCAGCT' *.fastq > count/B7454_Rm0.txt
agrep -0 -c 'GTGTAGCAACGTCGGAC' *.fastq > count/B7455_Rm0.txt
agrep -0 -c 'TGCAAGTAGCTTGCATT' *.fastq > count/B7456_Rm0.txt
agrep -0 -c 'GTATGTCAACGACTGAA' *.fastq > count/B7457_Rm0.txt
agrep -0 -c 'CAGTAGAGCCATTTAGT' *.fastq > count/B7458_Rm0.txt
agrep -0 -c 'GATAGCGCTACCGACAA' *.fastq > count/B7459_Rm0.txt
agrep -0 -c 'AACTATCTGGATAGGTG' *.fastq > count/B7460_Rm0.txt
agrep -0 -c 'ATGCGATATATGTGCCA' *.fastq > count/B7461_Rm0.txt
agrep -0 -c 'AGTTCGACGAACTCTCT' *.fastq > count/B7462_Rm0.txt
agrep -0 -c 'CCTCCTAACCGGTGAAG' *.fastq > count/B7463_Rm0.txt
agrep -0 -c 'TTTAGAGCGACAGCCAT' *.fastq > count/B7464_Rm0.txt
agrep -0 -c 'CATGCCAACCGTTCGAT' *.fastq > count/B7466_Rm0.txt
agrep -0 -c 'AAAAGCACGGTGTCGTT' *.fastq > count/B7467_Rm0.txt
agrep -0 -c 'GCCAGTCTATCTTCGTC' *.fastq > count/B7468_Rm0.txt
agrep -0 -c 'TAAAAACGTCGACACCC' *.fastq > count/B7469_Rm0.txt
agrep -0 -c 'TTGTGGCCTTAGGCCCT' *.fastq > count/B7470_Rm0.txt
agrep -0 -c 'GCCACGTTGGTCTAATG' *.fastq > count/B7471_Rm0.txt
agrep -0 -c 'CGCTAACACACGTGTGG' *.fastq > count/B7472_Rm0.txt
agrep -0 -c 'TAGTCAGGAAGTATCGT' *.fastq > count/B7473_Rm0.txt
agrep -0 -c 'ACAGTCATATGGGTCTA' *.fastq > count/B7474_Rm0.txt
agrep -0 -c 'CTCGTCGGCCAGATCTT' *.fastq > count/B7475_Rm0.txt
agrep -0 -c 'GGCTAAGAGTAAGGTAG' *.fastq > count/B7476_Rm0.txt
agrep -0 -c 'TAGAACGGTTGTCCAGG' *.fastq > count/B7477_Rm0.txt
agrep -0 -c 'CAAAAGCAGAGTACCCC' *.fastq > count/B7478_Rm0.txt
agrep -0 -c 'ATCAGTGTTTGTCTGAC' *.fastq > count/B7479_Rm0.txt
agrep -0 -c 'GTGTGCCTTCGTATCCC' *.fastq > count/B7480_Rm0.txt
agrep -0 -c 'ATGCGACCAAGCTTCCT' *.fastq > count/B7481_Rm0.txt
agrep -0 -c 'CACTGACCGCTTACCAC' *.fastq > count/B7482_Rm0.txt
agrep -0 -c 'CAGATTGTTATCAACGG' *.fastq > count/B7483_Rm0.txt
agrep -0 -c 'CAAGAGTTATTAGCGCT' *.fastq > count/B7484_Rm0.txt
agrep -0 -c 'CATGTTACAGTTATCGC' *.fastq > count/B7485_Rm0.txt
agrep -0 -c 'AGATTGCATTAAGACGG' *.fastq > count/B7487_Rm0.txt
agrep -0 -c 'GGTTTGAACTAAAGCGC' *.fastq > count/B7488_Rm0.txt
agrep -0 -c 'TATCAGTCGCTGCTATG' *.fastq > count/B7489_Rm0.txt
agrep -0 -c 'CTTTTAATTCCTCGACC' *.fastq > count/B7490_Rm0.txt
agrep -0 -c 'GTAATCGGACACCATTG' *.fastq > count/B7491_Rm0.txt
agrep -0 -c 'TTTCGGTCTCGCGAGCA' *.fastq > count/B7492_Rm0.txt
agrep -0 -c 'GACTCGTCCTGTTGGCA' *.fastq > count/B7493_Rm0.txt
agrep -0 -c 'CCCCATCGATGCTTTAG' *.fastq > count/B7496_Rm0.txt
agrep -0 -c 'TCGTCATAGGAGCTCTT' *.fastq > count/B7497_Rm0.txt
agrep -0 -c 'GCCCGAAAGAATGCTCC' *.fastq > count/B7498_Rm0.txt
agrep -0 -c 'CGTAGGGCAATGGGATG' *.fastq > count/B7501_Rm0.txt
agrep -0 -c 'CCAATACAGTCGCCCAT' *.fastq > count/B7502_Rm0.txt
agrep -0 -c 'GACGTAATGGCGCGCTA' *.fastq > count/B7503_Rm0.txt
agrep -0 -c 'TCTCGCATCTCTGTCGA' *.fastq > count/B7504_Rm0.txt
agrep -0 -c 'CCATTGTACGTAAACGG' *.fastq > count/B7507_Rm0.txt
agrep -0 -c 'GGTTACGTTCCCTATTA' *.fastq > count/B7508_Rm0.txt
agrep -0 -c 'GCACTTGTTATAGACGA' *.fastq > count/B7509_Rm0.txt
agrep -0 -c 'ATTAACAGATTCCCTCC' *.fastq > count/B7510_Rm0.txt
agrep -0 -c 'ATTCTGACCACAGCGGT' *.fastq > count/B7511_Rm0.txt
agrep -0 -c 'CATAAGGTTCCCAAAGG' *.fastq > count/B7512_Rm0.txt
agrep -0 -c 'AAGACCCGATCTCTTGT' *.fastq > count/B7513_Rm0.txt
agrep -0 -c 'GTCGAAGGGCCCACATT' *.fastq > count/B7514_Rm0.txt
agrep -0 -c 'CAAGCAAAGATCGCAAC' *.fastq > count/B7515_Rm0.txt
agrep -0 -c 'AGGGTCCTAGAACTATA' *.fastq > count/B7516_Rm0.txt
agrep -0 -c 'CTACTCCAATGTTTCCA' *.fastq > count/B7517_Rm0.txt
agrep -0 -c 'GTATAGGCCGTCATCGA' *.fastq > count/B7518_Rm0.txt
agrep -0 -c 'GTTTTACCGTCTGAATC' *.fastq > count/B7519_Rm0.txt
agrep -0 -c 'CCCTAGTGAATACAGAC' *.fastq > count/B7521_Rm0.txt
agrep -0 -c 'TTAAGATGGCCGAGTAA' *.fastq > count/B7522_Rm0.txt
agrep -0 -c 'AAGTGTCAAACCATAGC' *.fastq > count/B7523_Rm0.txt
agrep -0 -c 'GGCAATTAAGGGTTTGA' *.fastq > count/B7524_Rm0.txt
agrep -0 -c 'GTGTTCTACGTATGAGC' *.fastq > count/B7525_Rm0.txt
agrep -0 -c 'GAACTTCGATTCGGAAC' *.fastq > count/B7526_Rm0.txt
agrep -0 -c 'ACTACCCGCTATTAGGC' *.fastq > count/B7527_Rm0.txt
agrep -0 -c 'TCATGCCTAAAAGTGAC' *.fastq > count/B7528_Rm0.txt
agrep -0 -c 'TCACTTTAGCTCCGCGT' *.fastq > count/B7529_Rm0.txt
agrep -0 -c 'AGGTTAGCGATGAGTAT' *.fastq > count/B7531_Rm0.txt
agrep -0 -c 'AGGAGGAGGTACCCTCT' *.fastq > count/B7532_Rm0.txt
agrep -0 -c 'TTCTGCGTGAGTCAGTA' *.fastq > count/B7533_Rm0.txt
agrep -0 -c 'GCATCGCTGGTTACTCT' *.fastq > count/B7534_Rm0.txt
agrep -0 -c 'TCCGGCAATTTGTCAGG' *.fastq > count/B7536_Rm0.txt
agrep -0 -c 'TCGCTTGCTCGGTACAA' *.fastq > count/B7537_Rm0.txt
agrep -0 -c 'TGCGCTTACCCCTCGAT' *.fastq > count/B7538_Rm0.txt
agrep -0 -c 'TAAGTGTACCGATAACG' *.fastq > count/B7539_Rm0.txt
agrep -0 -c 'TGATGCCTCCCGTTAGT' *.fastq > count/B7540_Rm0.txt
agrep -0 -c 'AGTGGGCACTGACTAGC' *.fastq > count/B7541_Rm0.txt
agrep -0 -c 'CCCGGGGTAAAACTCTC' *.fastq > count/B7542_Rm0.txt
agrep -0 -c 'GGCAATTCAACCCGCTG' *.fastq > count/B7543_Rm0.txt
agrep -0 -c 'TAGAGTGTCACTCTGAA' *.fastq > count/B7544_Rm0.txt
agrep -0 -c 'AAGGAACGATTGCCTGA' *.fastq > count/B7546_Rm0.txt
agrep -0 -c 'AGCGTGTGATACGCCAG' *.fastq > count/B7547_Rm0.txt
agrep -0 -c 'AAGACTGTATGGTCCGT' *.fastq > count/B7548_Rm0.txt
agrep -0 -c 'AACCTCCGTTTTCGCAT' *.fastq > count/B7550_Rm0.txt
agrep -0 -c 'CGAATGTTAGGCGGTCA' *.fastq > count/B7551_Rm0.txt
agrep -0 -c 'GTGTGTCCGGCTTTTTG' *.fastq > count/B7552_Rm0.txt
agrep -0 -c 'ACCCACCTCCGCGATAT' *.fastq > count/B7553_Rm0.txt
agrep -0 -c 'AGGTTGATCGCCCCAGT' *.fastq > count/B7555_Rm0.txt
agrep -0 -c 'GGGTGCGCCTGTAAATA' *.fastq > count/B7556_Rm0.txt
agrep -0 -c 'GTGATCTCCGTTTGGTC' *.fastq > count/B7561_Rm0.txt
agrep -0 -c 'TCTAACGACTACGGGAA' *.fastq > count/B7562_Rm0.txt
agrep -0 -c 'CTGAGTTCCCTTTGAGT' *.fastq > count/B7563_Rm0.txt
agrep -0 -c 'CATTCTAAACGCTCAGG' *.fastq > count/B7565_Rm0.txt
agrep -0 -c 'ACATAAGTTCGCTGCTT' *.fastq > count/B7566_Rm0.txt
agrep -0 -c 'AATACGAGCCCAATCGG' *.fastq > count/B7568_Rm0.txt
agrep -0 -c 'TATCTTGACGGCTTAAC' *.fastq > count/B7569_Rm0.txt
agrep -0 -c 'GAAGGAAGAGAACGAAT' *.fastq > count/B7570_Rm0.txt
agrep -0 -c 'GTCCTAGATGAGTACCC' *.fastq > count/B7571_Rm0.txt
agrep -0 -c 'TCGTGGCCGTCGTTGAT' *.fastq > count/B7572_Rm0.txt
agrep -0 -c 'CAAACGCATGTTCTTAG' *.fastq > count/B7573_Rm0.txt
agrep -0 -c 'GTATGCATGGACCTAAC' *.fastq > count/B7574_Rm0.txt
agrep -0 -c 'TATGGCGTCAGAATGTT' *.fastq > count/B7576_Rm0.txt
agrep -0 -c 'CTTACCTCAGGGGCTAA' *.fastq > count/B7578_Rm0.txt
agrep -0 -c 'GGTAAGTCCTGAATTCG' *.fastq > count/B7579_Rm0.txt
agrep -0 -c 'GAGATTCCGCTGGAGAC' *.fastq > count/B7580_Rm0.txt
agrep -0 -c 'TAGAGTCATACACTCCA' *.fastq > count/B7582_Rm0.txt
agrep -0 -c 'GGGTGACAAATCGCGTC' *.fastq > count/B7583_Rm0.txt
agrep -0 -c 'CTTCCGCCGGTTTAGTA' *.fastq > count/B7585_Rm0.txt
agrep -0 -c 'TCTTCGGCAGTCGCATA' *.fastq > count/B7586_Rm0.txt
agrep -0 -c 'TTTCAGATAGTAAGGCC' *.fastq > count/B7588_Rm0.txt
agrep -0 -c 'CCGGCATTGTTGTGACG' *.fastq > count/B7589_Rm0.txt
agrep -0 -c 'TTAACGAGGGCGCTGGT' *.fastq > count/B7590_Rm0.txt
agrep -0 -c 'AAGAGCACGCTTCGGTT' *.fastq > count/B7591_Rm0.txt
agrep -0 -c 'CGAAGGGTCTGAGCCAT' *.fastq > count/B7592_Rm0.txt
agrep -0 -c 'GAATCAAAGTGGCGACA' *.fastq > count/B7593_Rm0.txt
agrep -0 -c 'CTCATGTCGACTTTATG' *.fastq > count/B7594_Rm0.txt
agrep -0 -c 'GGATCATCATTCAGTCG' *.fastq > count/B7595_Rm0.txt
agrep -0 -c 'ACAGCCCTGCTATAATT' *.fastq > count/B7596_Rm0.txt
agrep -0 -c 'GATACCACAGGGTATAC' *.fastq > count/B7597_Rm0.txt
agrep -0 -c 'ACCGAGACAGTTAGGGC' *.fastq > count/B7598_Rm0.txt
agrep -0 -c 'GCTTCAACTACAGCTCG' *.fastq > count/B7599_Rm0.txt
agrep -0 -c 'GCTGACCTTCTCAGGGT' *.fastq > count/B7600_Rm0.txt
agrep -0 -c 'GTACGTGACGTAATTAC' *.fastq > count/B7601_Rm0.txt
agrep -0 -c 'GATTAGAGAGGCGTCGA' *.fastq > count/B7602_Rm0.txt
agrep -0 -c 'AACGGGTCAGTCACATC' *.fastq > count/B7605_Rm0.txt
agrep -0 -c 'CTTGGGTAATCCTTTGG' *.fastq > count/B7606_Rm0.txt
agrep -0 -c 'AGGGGCACACAACTCAC' *.fastq > count/B7607_Rm0.txt
agrep -0 -c 'CCAATCGTAATCCGGCA' *.fastq > count/B7608_Rm0.txt
agrep -0 -c 'CTTCAAGTTGCAGGACC' *.fastq > count/B7609_Rm0.txt
agrep -0 -c 'GCGTATTGTTGATGCCA' *.fastq > count/B7610_Rm0.txt
agrep -0 -c 'CCTGAAATGGCGCGTAA' *.fastq > count/B7611_Rm0.txt
agrep -0 -c 'GTCACTTCTCGTCGTGA' *.fastq > count/B7612_Rm0.txt
agrep -0 -c 'ATGATGCCAGCCACACC' *.fastq > count/B7613_Rm0.txt
agrep -0 -c 'TTATATGGCCCATCTGC' *.fastq > count/B7614_Rm0.txt
agrep -0 -c 'GATTCGGGCCGTGAATC' *.fastq > count/B7616_Rm0.txt
agrep -0 -c 'AGCGATAGCAACTTCGG' *.fastq > count/B7619_Rm0.txt
agrep -0 -c 'CACGGATCCGAAACTCA' *.fastq > count/B7620_Rm0.txt
agrep -0 -c 'CTATTCGGTTGTCCATG' *.fastq > count/B7621_Rm0.txt
agrep -0 -c 'CAACTTGGTTGCAACGT' *.fastq > count/B7622_Rm0.txt
agrep -0 -c 'ACACTCCGGGACTTACT' *.fastq > count/B7623_Rm0.txt
agrep -0 -c 'ATTGATCCTCTGACCGA' *.fastq > count/B7625_Rm0.txt
agrep -0 -c 'GACGCATGAACAGTCTA' *.fastq > count/B7626_Rm0.txt
agrep -0 -c 'CGTGATTCCCGACTGCA' *.fastq > count/B7627_Rm0.txt
agrep -0 -c 'TGTATTTGTCTCACCGG' *.fastq > count/B7628_Rm0.txt
agrep -0 -c 'TCGCTTTGCGACGAGGT' *.fastq > count/B7629_Rm0.txt
agrep -0 -c 'CACGCAGATGTTTGGCC' *.fastq > count/B7630_Rm0.txt
agrep -0 -c 'AGTGGGATCGAAACTAG' *.fastq > count/B7631_Rm0.txt
agrep -0 -c 'GAATCTCCCATACGTGA' *.fastq > count/B7632_Rm0.txt
agrep -0 -c 'CTTTTCGGTCAGCAGAG' *.fastq > count/B7634_Rm0.txt
agrep -0 -c 'AAGGGTAAGGCATGCGA' *.fastq > count/B7635_Rm0.txt
agrep -0 -c 'TCATCGATCCTATGCTA' *.fastq > count/B7636_Rm0.txt
agrep -0 -c 'AGTCAATTGCCGCCTTA' *.fastq > count/B7637_Rm0.txt
agrep -0 -c 'ATGTCACAAACCGTCAT' *.fastq > count/B7638_Rm0.txt
agrep -0 -c 'GCCCGTTCTGATATTAG' *.fastq > count/B7640_Rm0.txt
agrep -0 -c 'TCCTAATCCCTACTAAC' *.fastq > count/B7641_Rm0.txt
agrep -0 -c 'CAAGACATAGGTACTGC' *.fastq > count/B7643_Rm0.txt
agrep -0 -c 'TGCCTATACCCACCTAA' *.fastq > count/B7644_Rm0.txt
agrep -0 -c 'TAAAAATCACCGGTGTC' *.fastq > count/B7647_Rm0.txt
agrep -0 -c 'CTCACCAAAGGATTGTT' *.fastq > count/B7648_Rm0.txt
agrep -0 -c 'CAGGTAGTAAGACGTGT' *.fastq > count/B7649_Rm0.txt
agrep -0 -c 'TCCATGAACTAACCCAC' *.fastq > count/B7650_Rm0.txt
agrep -0 -c 'TACATTAAACGAGGCGC' *.fastq > count/B7652_Rm0.txt
agrep -0 -c 'TGGCCATTGGGCATTGG' *.fastq > count/B7653_Rm0.txt
agrep -0 -c 'TCCGTAAGCCTCTTCTG' *.fastq > count/B7654_Rm0.txt
agrep -0 -c 'TCATCCTGATTTCCCCG' *.fastq > count/B7655_Rm0.txt
agrep -0 -c 'AACCGGGGTAATACCAA' *.fastq > count/B7656_Rm0.txt
agrep -0 -c 'CGCCCAGTGAACAAAGG' *.fastq > count/B7657_Rm0.txt
agrep -0 -c 'AACGGGTGCGGAACTAA' *.fastq > count/B7658_Rm0.txt
agrep -0 -c 'TATTGGGTAGATCTAGC' *.fastq > count/B7659_Rm0.txt
agrep -0 -c 'AACAGCTTACTAGCGTG' *.fastq > count/B7660_Rm0.txt
agrep -0 -c 'TAGCTGCCATATCCGGT' *.fastq > count/B7661_Rm0.txt
agrep -0 -c 'GCACGAGTATGCAACTT' *.fastq > count/B7662_Rm0.txt
agrep -0 -c 'TGATCCAGAGGCGGTCA' *.fastq > count/B7663_Rm0.txt
agrep -0 -c 'CTATTTCCGCCGCTTCC' *.fastq > count/B7664_Rm0.txt
agrep -0 -c 'CCAGTTGATCTCATTCA' *.fastq > count/B7665_Rm0.txt
agrep -0 -c 'TTCGCCCTGCAGGAATC' *.fastq > count/B7666_Rm0.txt
agrep -0 -c 'ATTTCAGTACCTGCCGG' *.fastq > count/B7667_Rm0.txt
agrep -0 -c 'GCTTACCCAAATCGATG' *.fastq > count/B7668_Rm0.txt
agrep -0 -c 'CGCAGGTACATCATTAT' *.fastq > count/B7669_Rm0.txt
agrep -0 -c 'ATTTCAGGGCCACGACC' *.fastq > count/B7671_Rm0.txt
agrep -0 -c 'GTTGGCCTAAAACGATA' *.fastq > count/B7673_Rm0.txt
agrep -0 -c 'CGTTACTGGACCACCGT' *.fastq > count/B7674_Rm0.txt
agrep -0 -c 'ACATCCGCCTTTCCTGC' *.fastq > count/B7676_Rm0.txt
agrep -0 -c 'AACGAACAGGCCAGTAT' *.fastq > count/B7677_Rm0.txt
agrep -0 -c 'TTCGATCCTTACGACGT' *.fastq > count/B7678_Rm0.txt
agrep -0 -c 'CCAATCGACATCGCAGT' *.fastq > count/B7679_Rm0.txt
agrep -0 -c 'AATCGGAATGTGGTGAG' *.fastq > count/B7680_Rm0.txt
agrep -0 -c 'GTCCATGAATCGCGGTC' *.fastq > count/B7681_Rm0.txt
agrep -0 -c 'AGACCCTCTGAATTGCG' *.fastq > count/B7682_Rm0.txt
agrep -0 -c 'GCGAACATGGGAGCAAG' *.fastq > count/B7683_Rm0.txt
agrep -0 -c 'ACATCCGCAAATCTGCG' *.fastq > count/B7684_Rm0.txt
agrep -0 -c 'CTAGACTCTGCAAAGAC' *.fastq > count/B7685_Rm0.txt
agrep -0 -c 'GGCCGTCCGTTAACTAA' *.fastq > count/B7687_Rm0.txt
agrep -0 -c 'AGTTGCGCCCTAACCGT' *.fastq > count/B7688_Rm0.txt
agrep -0 -c 'TCATGAAGATGGCCGCT' *.fastq > count/B7689_Rm0.txt
agrep -0 -c 'CGCCGTTGGAACTCGAT' *.fastq > count/B7690_Rm0.txt
agrep -0 -c 'TCCGCGGACACGTTGTA' *.fastq > count/B7692_Rm0.txt
agrep -0 -c 'CGTGGTATTAGGGCATT' *.fastq > count/B7693_Rm0.txt
agrep -0 -c 'CGTTATCAAGTTGCAGG' *.fastq > count/B7694_Rm0.txt
agrep -0 -c 'TTACCTAACGTGTTCGA' *.fastq > count/B7695_Rm0.txt
agrep -0 -c 'GCATTATGCCTGGACCC' *.fastq > count/B7696_Rm0.txt
agrep -0 -c 'AACCGGCAAGTCTCGTG' *.fastq > count/B7698_Rm0.txt
agrep -0 -c 'CGAGTTCCCTGACGTAG' *.fastq > count/B7699_Rm0.txt
agrep -0 -c 'AGTCAGAACCCAAGTGT' *.fastq > count/B7701_Rm0.txt
agrep -0 -c 'AACTGGTTAAGCCCTAC' *.fastq > count/B7702_Rm0.txt
agrep -0 -c 'TCGCCAAAGATGAAGCT' *.fastq > count/B7703_Rm0.txt
agrep -0 -c 'CCCAAGGGACGTTAACT' *.fastq > count/B7704_Rm0.txt
agrep -0 -c 'TCCCACACGTATCTTCT' *.fastq > count/B7706_Rm0.txt
agrep -0 -c 'GCTCATTGCCAGACCTA' *.fastq > count/B7707_Rm0.txt
agrep -0 -c 'ACGTTCCCTGCTAAGCG' *.fastq > count/B7708_Rm0.txt
agrep -0 -c 'TGAAGGTTTTCCTACCC' *.fastq > count/B7711_Rm0.txt
agrep -0 -c 'AAGTCGTTAGTTACTCC' *.fastq > count/B7712_Rm0.txt
agrep -0 -c 'AGCTACGACCGCCATCA' *.fastq > count/B7713_Rm0.txt
agrep -0 -c 'TACAAACTGGACCTTCT' *.fastq > count/B7714_Rm0.txt
agrep -0 -c 'TAGCTAGCCCCCTAATG' *.fastq > count/B7715_Rm0.txt
agrep -0 -c 'CCGACCATGTTCATAAT' *.fastq > count/B7716_Rm0.txt
agrep -0 -c 'ATGGGCGAAATGCAATG' *.fastq > count/B7717_Rm0.txt
agrep -0 -c 'CTCGACTGTGAACGATC' *.fastq > count/B7718_Rm0.txt
agrep -0 -c 'ATATACGGGGTTACGAG' *.fastq > count/B7719_Rm0.txt
agrep -0 -c 'TAGTTCGATGCTCCAGA' *.fastq > count/B7720_Rm0.txt
agrep -0 -c 'GACCGTTACGGCGACAT' *.fastq > count/B7721_Rm0.txt
agrep -0 -c 'TCCAGTAGATGATGAGC' *.fastq > count/B7723_Rm0.txt
agrep -0 -c 'GTCACCTACCGGTAAGA' *.fastq > count/B7724_Rm0.txt
agrep -0 -c 'GCTCTGACTTAGCATCA' *.fastq > count/B7725_Rm0.txt
agrep -0 -c 'AACGGCTTCTATTAACC' *.fastq > count/B7728_Rm0.txt
agrep -0 -c 'TGACTTCTTGAGCAGAT' *.fastq > count/B7730_Rm0.txt
agrep -0 -c 'GGCTTAGAACAATCCTC' *.fastq > count/B7731_Rm0.txt
agrep -0 -c 'AAATGCGTGTCCCGCGT' *.fastq > count/B7732_Rm0.txt
agrep -0 -c 'GGCAATCTCCTCTAGGC' *.fastq > count/B7733_Rm0.txt
agrep -0 -c 'TTCCCCACATTTGATGG' *.fastq > count/B7734_Rm0.txt
agrep -0 -c 'AAAGATTCCACCCGCAC' *.fastq > count/B7736_Rm0.txt
agrep -0 -c 'TAATCTTGTGTGGCGTG' *.fastq > count/B7737_Rm0.txt
agrep -0 -c 'ATTAAGCCATTCTGGAC' *.fastq > count/B7738_Rm0.txt
agrep -0 -c 'TCTCCCCTTAGCATTGA' *.fastq > count/B7739_Rm0.txt
agrep -0 -c 'CGTCGGGACAAAAACTT' *.fastq > count/B7740_Rm0.txt
agrep -0 -c 'AACTATGGAATAGCGGC' *.fastq > count/B7741_Rm0.txt
agrep -0 -c 'AGCTCCGGAAGACACTT' *.fastq > count/B7742_Rm0.txt
agrep -0 -c 'CAGTCAGGTTATCCACC' *.fastq > count/B7743_Rm0.txt
agrep -0 -c 'TTAACGTACCGTTTCCT' *.fastq > count/B7744_Rm0.txt
agrep -0 -c 'AGTCATCAGTGTCGCAG' *.fastq > count/B7745_Rm0.txt
agrep -0 -c 'AGACGGAAAAATCCGCG' *.fastq > count/B7746_Rm0.txt
agrep -0 -c 'GCCGTATCCTGAAATCC' *.fastq > count/B7747_Rm0.txt
agrep -0 -c 'GGCTCATCATTACGGGT' *.fastq > count/B7748_Rm0.txt
agrep -0 -c 'CCTTTATCTGCCCGCTC' *.fastq > count/B7749_Rm0.txt
agrep -0 -c 'ACATAGGCCGTTGACTG' *.fastq > count/B7750_Rm0.txt
agrep -0 -c 'TTCCTCTCACCTGCGAG' *.fastq > count/B7751_Rm0.txt
agrep -0 -c 'ACGTAAGGCAACATTGA' *.fastq > count/B7752_Rm0.txt
agrep -0 -c 'TCGAACGGCTGACAACG' *.fastq > count/B7753_Rm0.txt
agrep -0 -c 'ATAAAGCCCTTCCATCT' *.fastq > count/B7754_Rm0.txt
agrep -0 -c 'CATCAAGCCTTATCCGT' *.fastq > count/B7755_Rm0.txt
agrep -0 -c 'ACTCCATATGAGGCGTG' *.fastq > count/B7758_Rm0.txt
agrep -0 -c 'CAACCCCGGGTGCAATA' *.fastq > count/B7759_Rm0.txt
agrep -0 -c 'CAGAGATACTACTTGGT' *.fastq > count/B7760_Rm0.txt
agrep -0 -c 'CAGGTAGCAAGAACTTG' *.fastq > count/B7761_Rm0.txt
agrep -0 -c 'CCCCCAATATGCAACCC' *.fastq > count/B7762_Rm0.txt
agrep -0 -c 'CCGTAAACGTTGTTCGA' *.fastq > count/B7763_Rm0.txt
agrep -0 -c 'TCGTATACGCTCCCAGG' *.fastq > count/B7764_Rm0.txt
agrep -0 -c 'CGTGTAAACCCTGTCTG' *.fastq > count/B7765_Rm0.txt
agrep -0 -c 'ATAGTGCGACTCCGTGA' *.fastq > count/B7766_Rm0.txt
agrep -0 -c 'CCACGCGCTACAAATGT' *.fastq > count/B7767_Rm0.txt
agrep -0 -c 'CGCGACCTGAACAAGTT' *.fastq > count/B7768_Rm0.txt
agrep -0 -c 'TACTTGGTTAGGATTCC' *.fastq > count/B7769_Rm0.txt
agrep -0 -c 'GGCAAGAACTAGCTCGT' *.fastq > count/B7770_Rm0.txt
agrep -0 -c 'GTAGTAAAGCACGTTGC' *.fastq > count/B7771_Rm0.txt
agrep -0 -c 'AGTCAACCGCGTGCGAT' *.fastq > count/B7772_Rm0.txt
agrep -0 -c 'TAACAGACGGGGACCAG' *.fastq > count/B7773_Rm0.txt
agrep -0 -c 'ACCCGCAAAGATCGTAT' *.fastq > count/B7774_Rm0.txt
agrep -0 -c 'GAAAAATAGCCGACAGG' *.fastq > count/B7775_Rm0.txt
agrep -0 -c 'GAGATCGTAGATAACGT' *.fastq > count/B7778_Rm0.txt
agrep -0 -c 'TAGTTCCGACGGTCCAC' *.fastq > count/B7779_Rm0.txt
agrep -0 -c 'CTTTGCTACGTGTCCGG' *.fastq > count/B7780_Rm0.txt
agrep -0 -c 'AGTGTGTACCCGACGCA' *.fastq > count/B7781_Rm0.txt
agrep -0 -c 'CGCTTCGTGCACTGTTA' *.fastq > count/B7784_Rm0.txt
agrep -0 -c 'CCATGTGCAATCCACTT' *.fastq > count/B7785_Rm0.txt
agrep -0 -c 'ACGGTACCTTAGCAAGA' *.fastq > count/B7786_Rm0.txt
agrep -0 -c 'TAATTGCCGGTGTATCC' *.fastq > count/B7787_Rm0.txt
agrep -0 -c 'AGTAGTCGAGAGGATAA' *.fastq > count/B7788_Rm0.txt
agrep -0 -c 'AGACCGCTCTTAGGTCG' *.fastq > count/B7789_Rm0.txt
agrep -0 -c 'CACCGGAGAATCTAATA' *.fastq > count/B7790_Rm0.txt
agrep -0 -c 'CGTGTAATTTTCAGCCG' *.fastq > count/B7791_Rm0.txt
agrep -0 -c 'GTTCACGTGAGCGTGTC' *.fastq > count/B7792_Rm0.txt
agrep -0 -c 'TCAAAAATCAGTAGCGC' *.fastq > count/B7794_Rm0.txt
agrep -0 -c 'CTTCGATGGAGAACCTT' *.fastq > count/B7796_Rm0.txt
agrep -0 -c 'TAGGTCGGGAGAACCTT' *.fastq > count/B7797_Rm0.txt
agrep -0 -c 'ATACCCCACCAATCATG' *.fastq > count/B7799_Rm0.txt
agrep -0 -c 'GGCAGAAAACATTTTGC' *.fastq > count/B7800_Rm0.txt
agrep -0 -c 'GTCTGACGTCATTACGG' *.fastq > count/B7801_Rm0.txt
agrep -0 -c 'AGAATGGCGGTTGTTCC' *.fastq > count/B7802_Rm0.txt
agrep -0 -c 'CCTAGTCACGTAATCGC' *.fastq > count/B7803_Rm0.txt
agrep -0 -c 'CGAATCTCCACTAATAC' *.fastq > count/B7804_Rm0.txt
agrep -0 -c 'AATCGACCATCAACCGA' *.fastq > count/B7805_Rm0.txt
agrep -0 -c 'CTGCTTGTGCCACAAGA' *.fastq > count/B7806_Rm0.txt
agrep -0 -c 'CTCTAACGAGCACCACA' *.fastq > count/B7807_Rm0.txt
agrep -0 -c 'AAGGTCGAGGTGGGTTA' *.fastq > count/B7808_Rm0.txt
agrep -0 -c 'GTAGTGACCCGATGAGG' *.fastq > count/B7809_Rm0.txt
agrep -0 -c 'TACGAATGGACGGGCCA' *.fastq > count/B7810_Rm0.txt
agrep -0 -c 'GATAATCCCAGTAACCC' *.fastq > count/B7811_Rm0.txt
agrep -0 -c 'GAACAACTCTTGCGCCT' *.fastq > count/B7812_Rm0.txt
agrep -0 -c 'TACGCCTTACGCTATCA' *.fastq > count/B7813_Rm0.txt
agrep -0 -c 'GCTCAGCAATTTTTGCC' *.fastq > count/B7814_Rm0.txt
agrep -0 -c 'CAATGCTGAGCCTCTCC' *.fastq > count/B7815_Rm0.txt
agrep -0 -c 'CGTTAGTCACCTTCTAA' *.fastq > count/B7816_Rm0.txt
agrep -0 -c 'TTGCGGGCGACTTCACA' *.fastq > count/B7817_Rm0.txt
agrep -0 -c 'CGTTAGCATAGAACTGT' *.fastq > count/B7818_Rm0.txt
agrep -0 -c 'ATCAATTCTCCAAACCC' *.fastq > count/B7819_Rm0.txt
agrep -0 -c 'AGCGTAGAGCGCGATGA' *.fastq > count/B7820_Rm0.txt
agrep -0 -c 'AGACTCCACGTAACGCG' *.fastq > count/B7821_Rm0.txt
agrep -0 -c 'CCTGAAGTGCGAAATTA' *.fastq > count/B7822_Rm0.txt
agrep -0 -c 'ATTGGAACCTGGAGGAC' *.fastq > count/B7823_Rm0.txt
agrep -0 -c 'TGAGAGCGCTCAATCGC' *.fastq > count/B7824_Rm0.txt
agrep -0 -c 'CCCTAAAGCTTGGATGA' *.fastq > count/B7825_Rm0.txt
agrep -0 -c 'GAAATAAGCTCTCCTGG' *.fastq > count/B7826_Rm0.txt
agrep -0 -c 'CCTTGTTGCTTAACATC' *.fastq > count/B7827_Rm0.txt
agrep -0 -c 'TTGCGGAGATAGTGAAG' *.fastq > count/B7828_Rm0.txt
agrep -0 -c 'CGGCAAAGCTTGTATCT' *.fastq > count/B7829_Rm0.txt
agrep -0 -c 'AATGGTTACCGTGCCTG' *.fastq > count/B7830_Rm0.txt
agrep -0 -c 'TAGACCCTCCACATCGG' *.fastq > count/B7831_Rm0.txt
agrep -0 -c 'GGATTGTCTTGATACGC' *.fastq > count/B7832_Rm0.txt
agrep -0 -c 'TGACAAGGCCCTCACAA' *.fastq > count/B7834_Rm0.txt
agrep -0 -c 'TGTGTCGTGGCTGATGT' *.fastq > count/B7835_Rm0.txt
agrep -0 -c 'CAGGGGAGGAACTAACT' *.fastq > count/B7836_Rm0.txt
agrep -0 -c 'GAGCCTGAATTGGAGCC' *.fastq > count/B7837_Rm0.txt
agrep -0 -c 'CTCTATGGACGTGCCAC' *.fastq > count/B7838_Rm0.txt
agrep -0 -c 'TAGTGTCCCAGTCCCCT' *.fastq > count/B7839_Rm0.txt
agrep -0 -c 'CCCCGGGACAAAGGAAT' *.fastq > count/B7840_Rm0.txt
agrep -0 -c 'GGAGTGTGATTCAATGA' *.fastq > count/B7841_Rm0.txt
agrep -0 -c 'CGATGATCATTATGCCC' *.fastq > count/B7843_Rm0.txt
agrep -0 -c 'AACTGGTGTCTCTCGAG' *.fastq > count/B7844_Rm0.txt
agrep -0 -c 'AGGATCGCTCCATCACA' *.fastq > count/B7845_Rm0.txt
agrep -0 -c 'TCCCCTTCTTGAGCTCC' *.fastq > count/B7846_Rm0.txt
agrep -0 -c 'AAAGCTTCTTGTAAGCG' *.fastq > count/B7847_Rm0.txt
agrep -0 -c 'AAACTAGCTGGCCACTT' *.fastq > count/B7850_Rm0.txt
agrep -0 -c 'ATGCTCTGGTAGGGGTC' *.fastq > count/B7851_Rm0.txt
agrep -0 -c 'GTTTACAGTCCTACTAG' *.fastq > count/B7852_Rm0.txt
agrep -0 -c 'TAATTAGTGGGACGGAA' *.fastq > count/B7853_Rm0.txt
agrep -0 -c 'TTAGCATTATCGGATGC' *.fastq > count/B7854_Rm0.txt
agrep -0 -c 'TTTATTCCTGGTCCCGT' *.fastq > count/B7855_Rm0.txt
agrep -0 -c 'CGGGTATCACCAAAACT' *.fastq > count/B7858_Rm0.txt
agrep -0 -c 'CTGTACTCGTGCGATGT' *.fastq > count/B7859_Rm0.txt
agrep -0 -c 'GCGTAATTTTCGCTGCT' *.fastq > count/B7860_Rm0.txt
agrep -0 -c 'GTCACATGTCACACCGA' *.fastq > count/B7861_Rm0.txt
agrep -0 -c 'CGAGAGAAAGTTTCTAG' *.fastq > count/B7862_Rm0.txt
agrep -0 -c 'GACTTTACGAGCGCATT' *.fastq > count/B7863_Rm0.txt
agrep -0 -c 'GAGATGACCAACTATCC' *.fastq > count/B7864_Rm0.txt
agrep -0 -c 'GATCCCTGAGACCATAC' *.fastq > count/B7865_Rm0.txt
agrep -0 -c 'CGTGGAGACAGGAATTG' *.fastq > count/B7866_Rm0.txt
agrep -0 -c 'GTAAGGTCGTAAGTTTG' *.fastq > count/B7867_Rm0.txt
agrep -0 -c 'GGGCTTCGCCAATGACA' *.fastq > count/B7868_Rm0.txt
agrep -0 -c 'CGTCGTCCATCATTCGT' *.fastq > count/B7869_Rm0.txt
agrep -0 -c 'ATTGCTGTCTCGCCTGT' *.fastq > count/B7870_Rm0.txt
agrep -0 -c 'GCCACTTACAAGCCTGG' *.fastq > count/B7871_Rm0.txt
agrep -0 -c 'GTCATCCCGATTCGCTT' *.fastq > count/B7872_Rm0.txt
agrep -0 -c 'AAGACCTCCTACCACAT' *.fastq > count/B7873_Rm0.txt
agrep -0 -c 'CAAAGCCTAACTCTTCA' *.fastq > count/B7875_Rm0.txt
agrep -0 -c 'GACTACTCAAGCGTATA' *.fastq > count/B7876_Rm0.txt
agrep -0 -c 'TAACAGCCGGACGAAGT' *.fastq > count/B7877_Rm0.txt
agrep -0 -c 'AGCAGTGGTTTCGATTG' *.fastq > count/B7878_Rm0.txt
agrep -0 -c 'GACCAGAGAACCCAATT' *.fastq > count/B7879_Rm0.txt
agrep -0 -c 'TGACTGGTAGTTCCGCG' *.fastq > count/B7880_Rm0.txt
agrep -0 -c 'GACACTTGCCCTTCGTC' *.fastq > count/B7882_Rm0.txt
agrep -0 -c 'TATAGATCTTGACGCCC' *.fastq > count/B7883_Rm0.txt
agrep -0 -c 'CAACCTCCCGGAACATA' *.fastq > count/B7884_Rm0.txt
agrep -0 -c 'ACGCCATGAATCAAGTC' *.fastq > count/B7885_Rm0.txt
agrep -0 -c 'GTCTGACGGAATCAAGT' *.fastq > count/B7887_Rm0.txt
agrep -0 -c 'CCACATCTTGGGAAGAG' *.fastq > count/B7888_Rm0.txt
agrep -0 -c 'AAACGCAGAGTAGGCAC' *.fastq > count/B7889_Rm0.txt
agrep -0 -c 'GCGTTGCCTTCTTGGGT' *.fastq > count/B7891_Rm0.txt
agrep -0 -c 'TAGTTAACCGCAGCCTG' *.fastq > count/B7893_Rm0.txt
agrep -0 -c 'GCCGTTCAGCTTTGGTT' *.fastq > count/B7894_Rm0.txt
agrep -0 -c 'ACCGCAGGATATGACCC' *.fastq > count/B7895_Rm0.txt
agrep -0 -c 'AGGCTCCATGTATGTAT' *.fastq > count/B7896_Rm0.txt
agrep -0 -c 'GGAGTTAGGAAATTCGG' *.fastq > count/B7897_Rm0.txt
agrep -0 -c 'GTAGATTAGAGGTCGTA' *.fastq > count/B7898_Rm0.txt
agrep -0 -c 'TGCGTATCTTAAGTGCA' *.fastq > count/B7899_Rm0.txt
agrep -0 -c 'TCAGGAAGGCCGTTTAA' *.fastq > count/B7900_Rm0.txt
agrep -0 -c 'CCTCAATGGGTCTGCTC' *.fastq > count/B7902_Rm0.txt
agrep -0 -c 'ATCGTATACACTAGTGC' *.fastq > count/B7903_Rm0.txt
agrep -0 -c 'CTCCAAGATCCTTAGTA' *.fastq > count/B7904_Rm0.txt
agrep -0 -c 'TTTTGATGATCGGACGA' *.fastq > count/B7905_Rm0.txt
agrep -0 -c 'TCTGCTCGACATGTTAT' *.fastq > count/B7907_Rm0.txt
agrep -0 -c 'GATGCCAACAGAGGTAC' *.fastq > count/B7911_Rm0.txt
agrep -0 -c 'GGAGCTTAGGTTTCATC' *.fastq > count/B7912_Rm0.txt
agrep -0 -c 'ATGCGAACCGTGCGCAA' *.fastq > count/B7913_Rm0.txt
agrep -0 -c 'ATTGCCGGTTGTCTGGC' *.fastq > count/B7914_Rm0.txt
agrep -0 -c 'CGTAGTGCCCCTATACG' *.fastq > count/B7915_Rm0.txt
agrep -0 -c 'CTAAAACTAGACGCAGC' *.fastq > count/B7916_Rm0.txt
agrep -0 -c 'CGATTTGGTATCTGCCA' *.fastq > count/B7918_Rm0.txt
agrep -0 -c 'TTTCGCGGTCACGTACA' *.fastq > count/B7920_Rm0.txt
agrep -0 -c 'GTGCCGTATGCAGTCCA' *.fastq > count/B7921_Rm0.txt
agrep -0 -c 'GAAACAGCGCTATCACG' *.fastq > count/B7924_Rm0.txt
agrep -0 -c 'AACGTGCTGAGCTTCTA' *.fastq > count/B7925_Rm0.txt
agrep -0 -c 'CCAGACTATACCGTAAT' *.fastq > count/B7926_Rm0.txt
agrep -0 -c 'ATCAGTACACCTGTCCC' *.fastq > count/B7928_Rm0.txt
agrep -0 -c 'AGACGGCAGTTACGGCT' *.fastq > count/B7929_Rm0.txt
agrep -0 -c 'GCCAGCACTCAGGTCTA' *.fastq > count/B7930_Rm0.txt
agrep -0 -c 'CGGGTAGGTTCAGGTAT' *.fastq > count/B7932_Rm0.txt
agrep -0 -c 'AGGGAATCGCAAGCCAG' *.fastq > count/B7934_Rm0.txt
agrep -0 -c 'GGCGGTGATTAAGAATG' *.fastq > count/B7935_Rm0.txt
agrep -0 -c 'CTGTGCTTAGCCGATCC' *.fastq > count/B7936_Rm0.txt
agrep -0 -c 'CCAACCAAGATTGATGT' *.fastq > count/B7937_Rm0.txt
agrep -0 -c 'AGTCCAGCGATCACTAA' *.fastq > count/B7938_Rm0.txt
agrep -0 -c 'ACGGGAATTGCGCTAAT' *.fastq > count/B7939_Rm0.txt
agrep -0 -c 'TACCCGAGTGACTGGTG' *.fastq > count/B7940_Rm0.txt
agrep -0 -c 'CTTGGTACATTGAGTCG' *.fastq > count/B7941_Rm0.txt
agrep -0 -c 'GCCAATTTACCGTAACC' *.fastq > count/B7942_Rm0.txt
agrep -0 -c 'GGGATACATCTGGGGAC' *.fastq > count/B7943_Rm0.txt
agrep -0 -c 'CTGCATCATGGGGGGTT' *.fastq > count/B7944_Rm0.txt
agrep -0 -c 'GGTTATGTCGTTGGTAT' *.fastq > count/B7945_Rm0.txt
agrep -0 -c 'ATCTATCGTACCGGCCT' *.fastq > count/B7946_Rm0.txt
agrep -0 -c 'ACATTCGTGGAGAGCGT' *.fastq > count/B7947_Rm0.txt
agrep -0 -c 'CGTGTACAATAACCTCT' *.fastq > count/B7948_Rm0.txt
agrep -0 -c 'TGTCAAATCTGTCGATG' *.fastq > count/B7950_Rm0.txt
agrep -0 -c 'TGTCTATCACTCGCACA' *.fastq > count/B7951_Rm0.txt
agrep -0 -c 'TGCGTGATCTACCTTCC' *.fastq > count/B7952_Rm0.txt
agrep -0 -c 'GGTACTTCACCACCTCA' *.fastq > count/B7953_Rm0.txt
agrep -0 -c 'AAGCGCCGTCTACATAC' *.fastq > count/B7955_Rm0.txt
agrep -0 -c 'TGTAGGCTATCCCCGTA' *.fastq > count/B7956_Rm0.txt
agrep -0 -c 'CATTCGGGCGTTACAGT' *.fastq > count/B7957_Rm0.txt
agrep -0 -c 'GCACCGATTTCACTATC' *.fastq > count/B7958_Rm0.txt
agrep -0 -c 'AGGTTTCGGGTCAGCAT' *.fastq > count/B7959_Rm0.txt
agrep -0 -c 'GCCGTAAAATCTCACGG' *.fastq > count/B7960_Rm0.txt
agrep -0 -c 'AACCTTAAGCGTCAGCC' *.fastq > count/B7961_Rm0.txt
agrep -0 -c 'CGTAGCACCCCTTTAAC' *.fastq > count/B7967_Rm0.txt
agrep -0 -c 'ATACCGCTGATAAGATG' *.fastq > count/B7968_Rm0.txt
agrep -0 -c 'CAGAACATCGCACATGA' *.fastq > count/B7969_Rm0.txt
agrep -0 -c 'CTCTAAATGGCAAGTTG' *.fastq > count/B7970_Rm0.txt
agrep -0 -c 'TCAAGCTAACAAGCGCT' *.fastq > count/B7971_Rm0.txt
agrep -0 -c 'GGGATGTAGTTCAAATC' *.fastq > count/B7972_Rm0.txt
agrep -0 -c 'ACACCTTGTCACATGTA' *.fastq > count/B7973_Rm0.txt
agrep -0 -c 'TCCTACGTTACCTCAGA' *.fastq > count/B7974_Rm0.txt
agrep -0 -c 'TGACTACCAGGGCAATC' *.fastq > count/B7975_Rm0.txt
agrep -0 -c 'CGGTATCTTTACTGCTA' *.fastq > count/B7976_Rm0.txt
agrep -0 -c 'CCGCTAGGCAACTATAC' *.fastq > count/B7977_Rm0.txt
agrep -0 -c 'CAAGGTGCGGGTTAGAC' *.fastq > count/B7978_Rm0.txt
agrep -0 -c 'CTGTCGTGGCAACGAAG' *.fastq > count/B7979_Rm0.txt
agrep -0 -c 'TTGTAGGTACCCTAGAT' *.fastq > count/B7980_Rm0.txt
agrep -0 -c 'TATGACTGTTATGGCAG' *.fastq > count/B7981_Rm0.txt
agrep -0 -c 'AGCGGTTACAGTAACGC' *.fastq > count/B7982_Rm0.txt
agrep -0 -c 'GACTTTACGGGACAGGT' *.fastq > count/B7983_Rm0.txt
agrep -0 -c 'GTTCGAAGATTCAGAGA' *.fastq > count/B7984_Rm0.txt
agrep -0 -c 'TGGCTTGAATATAGCAG' *.fastq > count/B7985_Rm0.txt
agrep -0 -c 'TAGTATCGGTAGGAGCA' *.fastq > count/B7986_Rm0.txt
agrep -0 -c 'TTAGACTCCGGTGTCCG' *.fastq > count/B7987_Rm0.txt
agrep -0 -c 'CCTCTTGAAATACTCGT' *.fastq > count/B7989_Rm0.txt
agrep -0 -c 'CCCGAAAGACCTATAAG' *.fastq > count/B7990_Rm0.txt
agrep -0 -c 'AGCGCAAGCGCTTCTTG' *.fastq > count/B7991_Rm0.txt
agrep -0 -c 'TAGTTACCCACTACCAG' *.fastq > count/B7992_Rm0.txt
agrep -0 -c 'TGGCTCGAGTATTATCT' *.fastq > count/B7993_Rm0.txt
agrep -0 -c 'CGCAATCGATAATCATC' *.fastq > count/B7994_Rm0.txt
agrep -0 -c 'CCAAGTAGGGAAACCGC' *.fastq > count/B7995_Rm0.txt
agrep -0 -c 'TACTACGCGCACAACGC' *.fastq > count/B7997_Rm0.txt
agrep -0 -c 'TAAAGTACCACGGTACG' *.fastq > count/B7998_Rm0.txt
agrep -0 -c 'GTCCTTTAGCGTGGTCG' *.fastq > count/B7999_Rm0.txt
agrep -0 -c 'AAGGAGATGCGCCAAGT' *.fastq > count/B8000_Rm0.txt
agrep -0 -c 'GCGTCATCGAGGTTTTG' *.fastq > count/B8001_Rm0.txt
agrep -0 -c 'TTTCTCAGGGTTCGCTA' *.fastq > count/B8002_Rm0.txt
agrep -0 -c 'TCAGTACTACGTTCCAG' *.fastq > count/B8003_Rm0.txt
agrep -0 -c 'ATGATCTATCGGGAGTT' *.fastq > count/B8004_Rm0.txt
agrep -0 -c 'ATTGGGAATCACATCGA' *.fastq > count/B8005_Rm0.txt
agrep -0 -c 'CTCAACACGCTGAAACA' *.fastq > count/B8006_Rm0.txt
agrep -0 -c 'CGACACGGGTACCAAAT' *.fastq > count/B8007_Rm0.txt
agrep -0 -c 'AGTCTGCTGTTCACTAG' *.fastq > count/B8008_Rm0.txt
agrep -0 -c 'CTTTTCCGGTCAAAGTT' *.fastq > count/B8009_Rm0.txt
agrep -0 -c 'AAGGAGAGGTGAACGCA' *.fastq > count/B8010_Rm0.txt
agrep -0 -c 'GGTGAGAACTCAATCAT' *.fastq > count/B8011_Rm0.txt
agrep -0 -c 'TCAGATCGCAGTACTCA' *.fastq > count/B8012_Rm0.txt
agrep -0 -c 'TGTTAATGCCGCACCCC' *.fastq > count/B8013_Rm0.txt
agrep -0 -c 'ACCGTTTGCCCATATCG' *.fastq > count/B8014_Rm0.txt
agrep -0 -c 'GATACCAGGTCCGTTAC' *.fastq > count/B8015_Rm0.txt
agrep -0 -c 'ACAGCGAAAGTCTAACG' *.fastq > count/B8016_Rm0.txt
agrep -0 -c 'CTGGCTAACACGGGTCT' *.fastq > count/B8017_Rm0.txt
agrep -0 -c 'AGCTTAGTACCTGCATG' *.fastq > count/B8018_Rm0.txt
agrep -0 -c 'AGCTGGTTAGTCTGATA' *.fastq > count/B8019_Rm0.txt
agrep -0 -c 'CGTCTCTTGACTCCTAG' *.fastq > count/B8020_Rm0.txt
agrep -0 -c 'CCACTATCCGAGCATTA' *.fastq > count/B8023_Rm0.txt
agrep -0 -c 'CCGAGCTGTTAGTTCGC' *.fastq > count/B8025_Rm0.txt
agrep -0 -c 'GCCTACCGCGGAAATGT' *.fastq > count/B8026_Rm0.txt
agrep -0 -c 'CATTCCAGTCTCGCTTG' *.fastq > count/B8027_Rm0.txt
agrep -0 -c 'GTACTGTCTTCGTATAC' *.fastq > count/B8028_Rm0.txt
agrep -0 -c 'CGGTCTGCCTCTAGGTA' *.fastq > count/B8030_Rm0.txt
agrep -0 -c 'GGACTTCTGCATACTCT' *.fastq > count/B8031_Rm0.txt
agrep -0 -c 'GCTGTTCGTTCGGATCA' *.fastq > count/B8032_Rm0.txt
agrep -0 -c 'ATCGCGGACCCGTAACT' *.fastq > count/B8033_Rm0.txt
agrep -0 -c 'AACGTTCCTACCCCGTC' *.fastq > count/B8034_Rm0.txt
agrep -0 -c 'AACGCCATCTTCTGAAG' *.fastq > count/B8035_Rm0.txt
agrep -0 -c 'TGGTGTTTGAGACCGAG' *.fastq > count/B8036_Rm0.txt
agrep -0 -c 'GTAGTAAGTAAAAGGGC' *.fastq > count/B8037_Rm0.txt
agrep -0 -c 'TTACTGAATTCGATGCG' *.fastq > count/B8038_Rm0.txt
agrep -0 -c 'TACCGCACTCATTGTCC' *.fastq > count/B8039_Rm0.txt
agrep -0 -c 'ACTACTATTTGGCGACG' *.fastq > count/B8040_Rm0.txt
agrep -0 -c 'GAGCTTGCAGGCTATGT' *.fastq > count/B8041_Rm0.txt
agrep -0 -c 'ATACGTAGAATCCCGCC' *.fastq > count/B8045_Rm0.txt
agrep -0 -c 'TATCGTGCTCGCTCAAC' *.fastq > count/B8046_Rm0.txt
agrep -0 -c 'GGTGGCATCACGAATTG' *.fastq > count/B8048_Rm0.txt
agrep -0 -c 'GGTCTCGACGTAACAGT' *.fastq > count/B8049_Rm0.txt
agrep -0 -c 'GGTGCTCTGGCGAAATT' *.fastq > count/B8050_Rm0.txt
agrep -0 -c 'TCTTCCAACAGGTCGTT' *.fastq > count/B8051_Rm0.txt
agrep -0 -c 'AAGGCTCGTACTAGCTT' *.fastq > count/B8053_Rm0.txt
agrep -0 -c 'ACCTCACTATATCCCCT' *.fastq > count/B8055_Rm0.txt
agrep -0 -c 'TCTGAGCCGGCACAACA' *.fastq > count/B8056_Rm0.txt
agrep -0 -c 'CCTGGTTTCTTCTCGAC' *.fastq > count/B8057_Rm0.txt
agrep -0 -c 'GTTCCTTATGACCTTAG' *.fastq > count/B8058_Rm0.txt
agrep -0 -c 'CCATCCTGCGTTGTATG' *.fastq > count/B8059_Rm0.txt
agrep -0 -c 'GTCCACAGTTGGTTCAA' *.fastq > count/B8060_Rm0.txt
agrep -0 -c 'TGTAGCTCTTGCCGACG' *.fastq > count/B8061_Rm0.txt
agrep -0 -c 'TTGTCTAGGCATAGCAG' *.fastq > count/B8062_Rm0.txt
agrep -0 -c 'CCGAGGTGTCACATACA' *.fastq > count/B8065_Rm0.txt
agrep -0 -c 'GAAGATGTCTACTAGTC' *.fastq > count/B8066_Rm0.txt
agrep -0 -c 'AGTGATTTTCACACGCG' *.fastq > count/B8067_Rm0.txt
agrep -0 -c 'CTGACACTAGGAGTATC' *.fastq > count/B8068_Rm0.txt
agrep -0 -c 'TTTGCAAGGTAGTGACC' *.fastq > count/B8069_Rm0.txt
agrep -0 -c 'TTAGATAGAGCGCCACC' *.fastq > count/B8070_Rm0.txt
agrep -0 -c 'TGGCTGCTAGACCTAAT' *.fastq > count/B8072_Rm0.txt
agrep -0 -c 'CTGGGATTACAGTCGCC' *.fastq > count/B8073_Rm0.txt
agrep -0 -c 'GGAGACCGAGTACGACA' *.fastq > count/B8074_Rm0.txt
agrep -0 -c 'GCATGGGATTAGGTCCG' *.fastq > count/B8075_Rm0.txt
agrep -0 -c 'GGAAATGAGGCCAACAC' *.fastq > count/B8076_Rm0.txt
agrep -0 -c 'TTTAAGATGAGCAGGCC' *.fastq > count/B8077_Rm0.txt
agrep -0 -c 'GCATATGGACTCTAACC' *.fastq > count/B8078_Rm0.txt
agrep -0 -c 'TGTACGCTTAGTTTGAC' *.fastq > count/B8079_Rm0.txt
agrep -0 -c 'GTAGCTTCTAAAGCGGC' *.fastq > count/B8080_Rm0.txt
agrep -0 -c 'ACGTTATTGCGCCTAGA' *.fastq > count/B8082_Rm0.txt
agrep -0 -c 'CCGTAACGAACTAGGGC' *.fastq > count/B8083_Rm0.txt
agrep -0 -c 'TCATAACGCCGTCTGCA' *.fastq > count/B8084_Rm0.txt
agrep -0 -c 'ACGGCCTGCATCTTATG' *.fastq > count/B8085_Rm0.txt
agrep -0 -c 'GCAGGCTTTTATATGCC' *.fastq > count/B8087_Rm0.txt
agrep -0 -c 'TAAGGGTCTGCAGCATT' *.fastq > count/B8088_Rm0.txt
agrep -0 -c 'ACAGGACTTCGCGAAGT' *.fastq > count/B8089_Rm0.txt
agrep -0 -c 'ATCCCCTAAATGGAGCA' *.fastq > count/B8090_Rm0.txt
agrep -0 -c 'CTGTTTGCGGTCATGAC' *.fastq > count/B8091_Rm0.txt
agrep -0 -c 'AAATCTAACGTCGTGAG' *.fastq > count/B8092_Rm0.txt
agrep -0 -c 'ACTGACTTGATCTAGGT' *.fastq > count/B8093_Rm0.txt
agrep -0 -c 'GATACCATACCTACCGC' *.fastq > count/B8094_Rm0.txt
agrep -0 -c 'AGTGGCCAAGTAGGGTG' *.fastq > count/B8095_Rm0.txt
agrep -0 -c 'GCCAGGATCTGAATAGC' *.fastq > count/B8096_Rm0.txt
agrep -0 -c 'GTGTTGAGGTCTGTCGG' *.fastq > count/B8098_Rm0.txt
agrep -0 -c 'TGTCGATTAGATCGCGA' *.fastq > count/B8099_Rm0.txt
agrep -0 -c 'GGGCAGACTAAGTAGAT' *.fastq > count/B8100_Rm0.txt
agrep -0 -c 'GCAGACTAATGGGGGAT' *.fastq > count/B8101_Rm0.txt
agrep -0 -c 'TTGGATACGGCACAAGA' *.fastq > count/B8103_Rm0.txt
agrep -0 -c 'AACCTGGATTATCCTTG' *.fastq > count/B8104_Rm0.txt
agrep -0 -c 'CTAAAATTGTACGTGGC' *.fastq > count/B8105_Rm0.txt
agrep -0 -c 'CCCTTACGGTTCTCAGC' *.fastq > count/B8107_Rm0.txt
agrep -0 -c 'CTACAGCTTCCTCGAAC' *.fastq > count/B8108_Rm0.txt
agrep -0 -c 'CGATAGCACAAGCTCTA' *.fastq > count/B8109_Rm0.txt
agrep -0 -c 'ACGAATAAGGCAAGCAG' *.fastq > count/B8110_Rm0.txt
agrep -0 -c 'CTGATTTACGTGCTATC' *.fastq > count/B8112_Rm0.txt
agrep -0 -c 'CACTACAAGCTCTCAAC' *.fastq > count/B8113_Rm0.txt
agrep -0 -c 'CCGGAGGATATAAATCG' *.fastq > count/B8114_Rm0.txt
agrep -0 -c 'GACAGCGTTTGACGAAC' *.fastq > count/B8115_Rm0.txt
agrep -0 -c 'TCATCAGGTGCGAACGG' *.fastq > count/B8116_Rm0.txt
agrep -0 -c 'TCGTTAGTACGTAGGGT' *.fastq > count/B8117_Rm0.txt
agrep -0 -c 'GTGGTTAGTACGCAGCA' *.fastq > count/B8118_Rm0.txt
agrep -0 -c 'ACGTGCGTTAGCGAGAT' *.fastq > count/B8120_Rm0.txt
agrep -0 -c 'TAAGTGCGGAAGTAGTT' *.fastq > count/B8121_Rm0.txt
agrep -0 -c 'GCGAAGGAACTCCCAAC' *.fastq > count/B8122_Rm0.txt
agrep -0 -c 'TAGACGCAGGCATTTTG' *.fastq > count/B8123_Rm0.txt
agrep -0 -c 'TCCGTAGACTACTAGTC' *.fastq > count/B8124_Rm0.txt
agrep -0 -c 'CAATGATCGAGAAAACG' *.fastq > count/B8126_Rm0.txt
agrep -0 -c 'ACTTCGCGAAACACCGC' *.fastq > count/B8127_Rm0.txt
agrep -0 -c 'TTCTGACCCCCTAATAT' *.fastq > count/B8128_Rm0.txt
agrep -0 -c 'TATAAGATTCGAGCTCC' *.fastq > count/B8129_Rm0.txt
agrep -0 -c 'CGTCGAGTGTTCGCACA' *.fastq > count/B8130_Rm0.txt
agrep -0 -c 'CGATCTCATCGATAGCG' *.fastq > count/B8131_Rm0.txt
agrep -0 -c 'TCTAAGGGGCTGCCAAC' *.fastq > count/B8133_Rm0.txt
agrep -0 -c 'CATCCTCCGTGTGCGAA' *.fastq > count/B8134_Rm0.txt
agrep -0 -c 'CTGCTGAAAGCGTACAC' *.fastq > count/B8135_Rm0.txt
agrep -0 -c 'TGATCCCGATGAAGAAG' *.fastq > count/B8137_Rm0.txt
agrep -0 -c 'CGGCTTTAGTGATAATC' *.fastq > count/B8138_Rm0.txt
agrep -0 -c 'GTCCAGTGTGAACTAAT' *.fastq > count/B8139_Rm0.txt
agrep -0 -c 'TACCGATAGGGTTGAGG' *.fastq > count/B8140_Rm0.txt
agrep -0 -c 'TCTCAGGAGCGTGGTCT' *.fastq > count/B8141_Rm0.txt
agrep -0 -c 'GCCGAGTATACGAGTAA' *.fastq > count/B8142_Rm0.txt
agrep -0 -c 'GTACGAGTCAAGTATAC' *.fastq > count/B8144_Rm0.txt
agrep -0 -c 'CCTTTAATGCTGCCTTG' *.fastq > count/B8145_Rm0.txt
agrep -0 -c 'TGCAGAAGGACGGTCAA' *.fastq > count/B8146_Rm0.txt
agrep -0 -c 'TGAAGATGCGGACCGCA' *.fastq > count/B8147_Rm0.txt
agrep -0 -c 'GATTGCTTTTGATCTGG' *.fastq > count/B8148_Rm0.txt
agrep -0 -c 'TTGTTGTCGGGTTTCTG' *.fastq > count/B8149_Rm0.txt
agrep -0 -c 'CTGAGTTAATTCCTACG' *.fastq > count/B8151_Rm0.txt
agrep -0 -c 'CGCGCCTGGCATAATAG' *.fastq > count/B8152_Rm0.txt
agrep -0 -c 'ACTTAGCTGATCCACAG' *.fastq > count/B8154_Rm0.txt
agrep -0 -c 'GCTAGAATTTCGATTGC' *.fastq > count/B8155_Rm0.txt
agrep -0 -c 'TCACGAGCCATAATGGT' *.fastq > count/B8156_Rm0.txt
agrep -0 -c 'CAACGTTCCAGCGTCGT' *.fastq > count/B8157_Rm0.txt
agrep -0 -c 'GGTATTAGTCTGCTCCG' *.fastq > count/B8159_Rm0.txt
agrep -0 -c 'TAGCAGCCATTAAACGT' *.fastq > count/B8160_Rm0.txt
agrep -0 -c 'TCAGAAGTGCGCACACC' *.fastq > count/B8161_Rm0.txt
agrep -0 -c 'GGTGTTCGAGGGGAGTT' *.fastq > count/B8162_Rm0.txt
agrep -0 -c 'GTCCAAGAGTTAAACAC' *.fastq > count/B8163_Rm0.txt
agrep -0 -c 'GGTAATCAGTTTCGTCT' *.fastq > count/B8164_Rm0.txt
agrep -0 -c 'GCGCTTTGTCTATGAGC' *.fastq > count/B8165_Rm0.txt
agrep -0 -c 'CCAGCACAACCTGAAAT' *.fastq > count/B8167_Rm0.txt
agrep -0 -c 'GGGTTGCTCGCGCATTA' *.fastq > count/B8168_Rm0.txt
agrep -0 -c 'TGAGAATACGGTTCGAA' *.fastq > count/B8169_Rm0.txt
agrep -0 -c 'ACCATCCCTAGTACCTT' *.fastq > count/B8170_Rm0.txt
agrep -0 -c 'CCATTAGTGCACGCGGT' *.fastq > count/B8171_Rm0.txt
agrep -0 -c 'TTAATACGCGGGCGTCT' *.fastq > count/B8172_Rm0.txt
agrep -0 -c 'AAGTCTTTTGTGCGTGA' *.fastq > count/B8173_Rm0.txt
agrep -0 -c 'CATCCGTTCCATCTTAC' *.fastq > count/B8177_Rm0.txt
agrep -0 -c 'CGGGTTGAGTCTATCGA' *.fastq > count/B8178_Rm0.txt
agrep -0 -c 'CGGACGTCAACCGATTA' *.fastq > count/B8180_Rm0.txt
agrep -0 -c 'AGTTCGCCAACTAGATC' *.fastq > count/B8181_Rm0.txt
agrep -0 -c 'TCGGTGATAGTGTACGG' *.fastq > count/B8182_Rm0.txt
agrep -0 -c 'CTCTCGTTTCAAACATC' *.fastq > count/B8183_Rm0.txt
agrep -0 -c 'TAGCACATGCGTGTTCG' *.fastq > count/B8184_Rm0.txt
agrep -0 -c 'ATGGAAAACGAAGGTCG' *.fastq > count/B8185_Rm0.txt
agrep -0 -c 'GAGATTGAGCATTATCC' *.fastq > count/B8186_Rm0.txt
agrep -0 -c 'TTTGGGGCGGAACCTAA' *.fastq > count/B8187_Rm0.txt
agrep -0 -c 'TGGAAATCGACTTGGCA' *.fastq > count/B8188_Rm0.txt
agrep -0 -c 'TTAAACGATTGGGAGCC' *.fastq > count/B8189_Rm0.txt
agrep -0 -c 'CATATGGGGCGAGTACA' *.fastq > count/B8190_Rm0.txt
agrep -0 -c 'GAAGAAAGCGAACGCTC' *.fastq > count/B8191_Rm0.txt
agrep -0 -c 'GCTTGTATTGGGCGCAA' *.fastq > count/B8192_Rm0.txt
agrep -0 -c 'TAGCTCTGGAATCTAGC' *.fastq > count/B8193_Rm0.txt
agrep -0 -c 'CTTCGCGCTATTCTAGC' *.fastq > count/B8194_Rm0.txt
agrep -0 -c 'CAATACGCTGGATTGAA' *.fastq > count/B8195_Rm0.txt
agrep -0 -c 'GCCGAAGTCAAACCCTT' *.fastq > count/B8196_Rm0.txt
agrep -0 -c 'AGATAGCCGCTCTTGTC' *.fastq > count/B8197_Rm0.txt
agrep -0 -c 'TCCTAGATGCCTGACGG' *.fastq > count/B8198_Rm0.txt
agrep -0 -c 'TACCCCTATCACATCTT' *.fastq > count/B8199_Rm0.txt
agrep -0 -c 'AATCTCAACACGCAAGA' *.fastq > count/B8200_Rm0.txt
agrep -0 -c 'GAAGTCCGTAGGGCATT' *.fastq > count/B8201_Rm0.txt
agrep -0 -c 'ACACGGTGCTACATGTT' *.fastq > count/B8202_Rm0.txt
agrep -0 -c 'TGCCTTCACAACACCGC' *.fastq > count/B8203_Rm0.txt
agrep -0 -c 'TTAACGCAGCTCACTAC' *.fastq > count/B8205_Rm0.txt
agrep -0 -c 'ACGAGTTCCAACTCCCC' *.fastq > count/B8206_Rm0.txt
agrep -0 -c 'TTATGGCGCCTCATAAG' *.fastq > count/B8208_Rm0.txt
agrep -0 -c 'CCTTGGATACAGTAACA' *.fastq > count/B8209_Rm0.txt
agrep -0 -c 'ATATGCATTTGGCCGGC' *.fastq > count/B8210_Rm0.txt
agrep -0 -c 'CGGCAATCCATGTTATT' *.fastq > count/B8212_Rm0.txt
agrep -0 -c 'CCGATCATTGGTCGTCG' *.fastq > count/B8213_Rm0.txt
agrep -0 -c 'TGAAACAACGCTCGACA' *.fastq > count/B8214_Rm0.txt
agrep -0 -c 'TCACTTAGTCTACAGAG' *.fastq > count/B8216_Rm0.txt
agrep -0 -c 'CCCTTACATGACCAGCT' *.fastq > count/B8217_Rm0.txt
agrep -0 -c 'TGGAACTCGCCATGCGA' *.fastq > count/B8218_Rm0.txt
agrep -0 -c 'GGTCCATGACTTCGCGA' *.fastq > count/B8219_Rm0.txt
agrep -0 -c 'CTAGGCTACCGTTATTG' *.fastq > count/B8220_Rm0.txt
agrep -0 -c 'AGTTAGTCCGCTGACAT' *.fastq > count/B8221_Rm0.txt
agrep -0 -c 'AAGCACTAAAACCCCAG' *.fastq > count/B8222_Rm0.txt
agrep -0 -c 'ATGAACACGTATCAAGG' *.fastq > count/B8223_Rm0.txt
agrep -0 -c 'TGACACGGATAGTGTAT' *.fastq > count/B8224_Rm0.txt
agrep -0 -c 'CGATGCCAGTATTGCGT' *.fastq > count/B8226_Rm0.txt
agrep -0 -c 'TGACATGCAACGAGTTG' *.fastq > count/B8227_Rm0.txt
agrep -0 -c 'TATCAGATAAACCCCGA' *.fastq > count/B8228_Rm0.txt
agrep -0 -c 'TAACACTAGTGGAAGTC' *.fastq > count/B8229_Rm0.txt
agrep -0 -c 'GGGATGTGTTTGATCTA' *.fastq > count/B8231_Rm0.txt
agrep -0 -c 'GGTTTCTTGGAGAGGAT' *.fastq > count/B8233_Rm0.txt
agrep -0 -c 'AACCCGACCGTAACTAC' *.fastq > count/B8234_Rm0.txt
agrep -0 -c 'CGAGACTACCGTGTAAC' *.fastq > count/B8235_Rm0.txt
agrep -0 -c 'TAAGGCTGTTGGGATAC' *.fastq > count/B8236_Rm0.txt
agrep -0 -c 'GACGCAGCAGTAATTTG' *.fastq > count/B8238_Rm0.txt
agrep -0 -c 'AGTTACTAGTACCCTCT' *.fastq > count/B8239_Rm0.txt
agrep -0 -c 'TCAGGGCTAACTATTCC' *.fastq > count/B8240_Rm0.txt
agrep -0 -c 'GCTGAAGACGATATAGA' *.fastq > count/B8241_Rm0.txt
agrep -0 -c 'TTATCATATTGCTCGCC' *.fastq > count/B8242_Rm0.txt
agrep -0 -c 'TGCTACTAAGCAGAGAA' *.fastq > count/B8243_Rm0.txt
agrep -0 -c 'CTTCTGGCGGACTGACT' *.fastq > count/B8244_Rm0.txt
agrep -0 -c 'TAAACACGCATCGTGAT' *.fastq > count/B8246_Rm0.txt
agrep -0 -c 'GCCCTGCGGAGAATTGA' *.fastq > count/B8248_Rm0.txt
agrep -0 -c 'ACATACTAACTACCGGT' *.fastq > count/B8250_Rm0.txt
agrep -0 -c 'GTATAGTGACCAGCCAG' *.fastq > count/B8251_Rm0.txt
agrep -0 -c 'CAAGACACTGACGATTA' *.fastq > count/B8252_Rm0.txt
agrep -0 -c 'TACTCAAGCAAATGGTC' *.fastq > count/B8253_Rm0.txt
agrep -0 -c 'TCTGCTGAACCTTACGA' *.fastq > count/B8254_Rm0.txt
agrep -0 -c 'CGTCAATCTTCCACTCC' *.fastq > count/B8255_Rm0.txt
agrep -0 -c 'AGCTGATCACATTGACC' *.fastq > count/B8256_Rm0.txt
agrep -0 -c 'CAATCCTCTTATTACCG' *.fastq > count/B8257_Rm0.txt
agrep -0 -c 'CTAGGCGTCCCGTTAGA' *.fastq > count/B8258_Rm0.txt
agrep -0 -c 'TACCACCATGCTTCCAC' *.fastq > count/B8259_Rm0.txt
agrep -0 -c 'GGTTCGAGTTTGGGCAC' *.fastq > count/B8260_Rm0.txt
agrep -0 -c 'CATCGATAGAGCAAGCG' *.fastq > count/B8261_Rm0.txt
agrep -0 -c 'TGATTGGACAGTGGTGA' *.fastq > count/B8262_Rm0.txt
agrep -0 -c 'AGTTACGCCTAACTCTT' *.fastq > count/B8263_Rm0.txt
agrep -0 -c 'CTCATTGCTCTTACACG' *.fastq > count/B8264_Rm0.txt
agrep -0 -c 'GGTATTAGCACAGCCCT' *.fastq > count/B8265_Rm0.txt
agrep -0 -c 'ACGTTTTTGATGTTGGC' *.fastq > count/B8266_Rm0.txt
agrep -0 -c 'CGTGACTTCGATTTGAG' *.fastq > count/B8267_Rm0.txt
agrep -0 -c 'CGCGCATCAGCCTAATA' *.fastq > count/B8269_Rm0.txt
agrep -0 -c 'TTTCAGCAAGAAGCACC' *.fastq > count/B8270_Rm0.txt
agrep -0 -c 'GCGACAAGCGAGCATAA' *.fastq > count/B8271_Rm0.txt
agrep -0 -c 'GGAGAACATATTGGGTA' *.fastq > count/B8272_Rm0.txt
agrep -0 -c 'ATAGCAGTCCAATCTGA' *.fastq > count/B8273_Rm0.txt
agrep -0 -c 'TCTCCGCCAGTATTATC' *.fastq > count/B8274_Rm0.txt
agrep -0 -c 'GCTGGAACTGGAATCTC' *.fastq > count/B8275_Rm0.txt
agrep -0 -c 'GACTGCTCCAGATGTTG' *.fastq > count/B8276_Rm0.txt
agrep -0 -c 'ACTATGTCTGTACCAAC' *.fastq > count/B8277_Rm0.txt
agrep -0 -c 'CCAGAGGGTCAGTCGTT' *.fastq > count/B8278_Rm0.txt
agrep -0 -c 'GTCCGCAGGAGCTTCAT' *.fastq > count/B8279_Rm0.txt
agrep -0 -c 'CCGCTGAGCTTGTAAGT' *.fastq > count/B8280_Rm0.txt
agrep -0 -c 'CACGAAGTTAGCAGCCC' *.fastq > count/B8282_Rm0.txt
agrep -0 -c 'AGCCAATAGGTACACAA' *.fastq > count/B8283_Rm0.txt
agrep -0 -c 'TCTGGTTCCGGCTACAT' *.fastq > count/B8284_Rm0.txt
agrep -0 -c 'GTGCTGTTATCGCAGAT' *.fastq > count/B8285_Rm0.txt
agrep -0 -c 'GAGTCTCGTGTCGTAGT' *.fastq > count/B8287_Rm0.txt
agrep -0 -c 'AAGATCATCCCTGCGAT' *.fastq > count/B8288_Rm0.txt
agrep -0 -c 'ATGTTGCGGTTACCTAG' *.fastq > count/B8289_Rm0.txt
agrep -0 -c 'TTATTGGTCCCGTCCGA' *.fastq > count/B8290_Rm0.txt
agrep -0 -c 'GTGAAGCGAGTGTATCC' *.fastq > count/B8291_Rm0.txt
agrep -0 -c 'ATAACTCTGCATGACCG' *.fastq > count/B8292_Rm0.txt
agrep -0 -c 'TATCTGCTAGACGGCCC' *.fastq > count/B8293_Rm0.txt
agrep -0 -c 'GCTTTAAGCCAGGTCCA' *.fastq > count/B8294_Rm0.txt
agrep -0 -c 'ATTAAGCGTCGGGAGTA' *.fastq > count/B8295_Rm0.txt
agrep -0 -c 'TTTAATCCCGACTCTGT' *.fastq > count/B8296_Rm0.txt
agrep -0 -c 'GTCTGTTACACTCAGCG' *.fastq > count/B8297_Rm0.txt
agrep -0 -c 'ACCCTGTGGAAATGATT' *.fastq > count/B8298_Rm0.txt
agrep -0 -c 'GTTCGAAAGGCATACAA' *.fastq > count/B8300_Rm0.txt
agrep -0 -c 'GCAGGGACAACTACTAG' *.fastq > count/B8301_Rm0.txt
agrep -0 -c 'GGTAGAATAATCCGTCC' *.fastq > count/B8302_Rm0.txt
agrep -0 -c 'ATGCACGATCAACGTCA' *.fastq > count/B8303_Rm0.txt
agrep -0 -c 'AACCGAGCCCCTACTCT' *.fastq > count/B8304_Rm0.txt
agrep -0 -c 'CAGGCTGTAGCGGTATG' *.fastq > count/B8305_Rm0.txt
agrep -0 -c 'AACCGTCACTTTGAAGT' *.fastq > count/B8307_Rm0.txt
agrep -0 -c 'GCGAGTGGGAAGTCGAT' *.fastq > count/B8308_Rm0.txt
agrep -0 -c 'TAATGTCCTTATAGCGG' *.fastq > count/B8310_Rm0.txt
agrep -0 -c 'ATATGCCGTGCGCCTAC' *.fastq > count/B8311_Rm0.txt
agrep -0 -c 'ATGTTTCCCACGGACTC' *.fastq > count/B8314_Rm0.txt
agrep -0 -c 'TTTGTACCTACACCGTG' *.fastq > count/B8315_Rm0.txt
agrep -0 -c 'GACTTCTGTTCGGTCGC' *.fastq > count/B8316_Rm0.txt
agrep -0 -c 'ATCGATCCCAAGTGCCG' *.fastq > count/B8317_Rm0.txt
agrep -0 -c 'ACCACCTCACCGTAATG' *.fastq > count/B8318_Rm0.txt
agrep -0 -c 'AGGCCGATCTGTAAATA' *.fastq > count/B8320_Rm0.txt
agrep -0 -c 'GAACAGAGTAATCAGCG' *.fastq > count/B8321_Rm0.txt
agrep -0 -c 'AAATAGCCATCGGTTCT' *.fastq > count/B8322_Rm0.txt
agrep -0 -c 'GTATGACCGATGTATGC' *.fastq > count/B8323_Rm0.txt
agrep -0 -c 'GATCGGCCCTGGAAACA' *.fastq > count/B8324_Rm0.txt
agrep -0 -c 'GCGTAAGTTATGTCGGC' *.fastq > count/B8325_Rm0.txt
agrep -0 -c 'GAGTTTCGCATGGGTAC' *.fastq > count/B8327_Rm0.txt
agrep -0 -c 'ACCGCTCTTCACCAAAT' *.fastq > count/B8328_Rm0.txt
agrep -0 -c 'AGTATAAAGTCGGTGCA' *.fastq > count/B8329_Rm0.txt
agrep -0 -c 'GCGTTCGTATACGATAG' *.fastq > count/B8330_Rm0.txt
agrep -0 -c 'CGAGGCAAGGGATTCAC' *.fastq > count/B8331_Rm0.txt
agrep -0 -c 'TGAAGGTATGGGGAGCA' *.fastq > count/B8332_Rm0.txt
agrep -0 -c 'ATCAGAACCTAACGGCA' *.fastq > count/B8334_Rm0.txt
agrep -0 -c 'GGGAAATATAACGTAGC' *.fastq > count/B8335_Rm0.txt
agrep -0 -c 'CGATATTCGTTGTAACG' *.fastq > count/B8336_Rm0.txt
agrep -0 -c 'TGACTGCGGGATATGAA' *.fastq > count/B8337_Rm0.txt
agrep -0 -c 'ACCAACGATAGACTGAC' *.fastq > count/B8338_Rm0.txt
agrep -0 -c 'AGTTCCTAAAATCCTGC' *.fastq > count/B8339_Rm0.txt
agrep -0 -c 'AGCTCATCTCAGTTTCG' *.fastq > count/B8340_Rm0.txt
agrep -0 -c 'GCCAACCAGCTCGCTAA' *.fastq > count/B8341_Rm0.txt
agrep -0 -c 'CTCATGAATAACCGCGC' *.fastq > count/B8342_Rm0.txt
agrep -0 -c 'TTACACTGTCGTCGTGA' *.fastq > count/B8343_Rm0.txt
agrep -0 -c 'TTCTGTCAATCGTGCTA' *.fastq > count/B8345_Rm0.txt
agrep -0 -c 'TTGATAAAAGCGGATCC' *.fastq > count/B8347_Rm0.txt
agrep -0 -c 'TGTCTGACGCATACGAG' *.fastq > count/B8348_Rm0.txt
agrep -0 -c 'ATGGCCGCGTTACATCA' *.fastq > count/B8351_Rm0.txt
agrep -0 -c 'GACAGATATCGGTGTTA' *.fastq > count/B8352_Rm0.txt
agrep -0 -c 'TTCCGACTACTGGTACT' *.fastq > count/B8353_Rm0.txt
agrep -0 -c 'TGACCGACATTGACTAT' *.fastq > count/B8355_Rm0.txt
agrep -0 -c 'TTGGTAGCCCATGCAAG' *.fastq > count/B8356_Rm0.txt
agrep -0 -c 'GTCAGAGATATGCTACC' *.fastq > count/B8357_Rm0.txt
agrep -0 -c 'GACCTCGAGTTTGGGAA' *.fastq > count/B8358_Rm0.txt
agrep -0 -c 'ATCGGCGGACAAGAACG' *.fastq > count/B8359_Rm0.txt
agrep -0 -c 'GACCATTCTAGCTACGT' *.fastq > count/B8360_Rm0.txt
agrep -0 -c 'GTTCCAACCCTTCAGAG' *.fastq > count/B8361_Rm0.txt
agrep -0 -c 'TCAGCAGTCGGAGAAAT' *.fastq > count/B8362_Rm0.txt
agrep -0 -c 'CAATATGCGGTCCCGAG' *.fastq > count/B8363_Rm0.txt
agrep -0 -c 'CTCTGCACGTACCTACC' *.fastq > count/B8364_Rm0.txt
agrep -0 -c 'CCGTATTTGCAGCAATA' *.fastq > count/B8365_Rm0.txt
agrep -0 -c 'ACGACACTAGTCACGCA' *.fastq > count/B8366_Rm0.txt
agrep -0 -c 'GGCTTCGTCCCTAGATT' *.fastq > count/B8367_Rm0.txt
agrep -0 -c 'AAACTCGTGCGAAAGAT' *.fastq > count/B8368_Rm0.txt
agrep -0 -c 'CCCGAATATTTTCTGTG' *.fastq > count/B8369_Rm0.txt
agrep -0 -c 'TACTGAGCATGCCCGAT' *.fastq > count/B8370_Rm0.txt
agrep -0 -c 'GGGTGACAGAGCTTCTC' *.fastq > count/B8371_Rm0.txt
agrep -0 -c 'AGTCGCTCTTTGAGAGA' *.fastq > count/B8372_Rm0.txt
agrep -0 -c 'GCACCTGGATAATTCTA' *.fastq > count/B8373_Rm0.txt
agrep -0 -c 'TTGAGGCTAAATCGCGT' *.fastq > count/B8374_Rm0.txt
agrep -0 -c 'ACGTGGTCACTTCGATC' *.fastq > count/B8375_Rm0.txt
agrep -0 -c 'CGGGAAATAATTTGAGC' *.fastq > count/B8376_Rm0.txt
agrep -0 -c 'CAGCTTACGGGATTATG' *.fastq > count/B8377_Rm0.txt
agrep -0 -c 'CAACGAGCAAAGTGACC' *.fastq > count/B8378_Rm0.txt
agrep -0 -c 'CATCGATTCCACAATGG' *.fastq > count/B8380_Rm0.txt
agrep -0 -c 'GTACGCTGACCGAACTG' *.fastq > count/B8381_Rm0.txt
agrep -0 -c 'ACTAATAGTTCATGCCG' *.fastq > count/B8382_Rm0.txt
agrep -0 -c 'CTACACTTAAAGACTCG' *.fastq > count/B8383_Rm0.txt
agrep -0 -c 'CCCAAACACGATATCAT' *.fastq > count/B8384_Rm0.txt
agrep -0 -c 'TAAACTCTATCAGCACG' *.fastq > count/B8386_Rm0.txt
agrep -0 -c 'GCACGGTGACATATAAG' *.fastq > count/B8387_Rm0.txt
agrep -0 -c 'CGGGAAACATAACAGTC' *.fastq > count/B8388_Rm0.txt
agrep -0 -c 'AACAAACGCTTAATCGG' *.fastq > count/B8389_Rm0.txt
agrep -0 -c 'TCCGTATAGATCGAACC' *.fastq > count/B8390_Rm0.txt
agrep -0 -c 'GGTAACCGCAGACGACT' *.fastq > count/B8391_Rm0.txt
agrep -0 -c 'AGGCTGTTCCATGCGCT' *.fastq > count/B8392_Rm0.txt
agrep -0 -c 'TGTGGTTATTAAGTCGG' *.fastq > count/B8393_Rm0.txt
agrep -0 -c 'GGATCTTGAATCCGCCA' *.fastq > count/B8394_Rm0.txt
agrep -0 -c 'CTTTGTAACTCCTGTCA' *.fastq > count/B8395_Rm0.txt
agrep -0 -c 'GAGTATTGCGGTACAAC' *.fastq > count/B8396_Rm0.txt
agrep -0 -c 'CGACGCGAATTTATTCA' *.fastq > count/B8397_Rm0.txt
agrep -0 -c 'CGTGCCATCAATTAGCT' *.fastq > count/B8398_Rm0.txt
agrep -0 -c 'CCATCTCATGAGGGCTA' *.fastq > count/B8399_Rm0.txt
agrep -0 -c 'CTGGCTCTTAGCCTGAG' *.fastq > count/B8400_Rm0.txt
agrep -0 -c 'ATTACCGAACGCCTGCA' *.fastq > count/B8401_Rm0.txt
agrep -0 -c 'CTTTGTGCTCAACACAT' *.fastq > count/B8402_Rm0.txt
agrep -0 -c 'ATCAGGACTCGGAACCC' *.fastq > count/B8403_Rm0.txt
agrep -0 -c 'TTCGATGGGGTGTAGTG' *.fastq > count/B8404_Rm0.txt
agrep -0 -c 'TTCTTTTTCGCGCGATT' *.fastq > count/B8407_Rm0.txt
agrep -0 -c 'CGTACTCCTACAAGGTC' *.fastq > count/B8408_Rm0.txt
agrep -0 -c 'ATACGAGTGGTGTTGAA' *.fastq > count/B8409_Rm0.txt
agrep -0 -c 'AATCTTTTGGCACCTCT' *.fastq > count/B8411_Rm0.txt
agrep -0 -c 'ACCGTGTAGATACACGT' *.fastq > count/B8412_Rm0.txt
agrep -0 -c 'TTGGTCGATACACGGAT' *.fastq > count/B8413_Rm0.txt
agrep -0 -c 'CACCACGGAACATTAAC' *.fastq > count/B8414_Rm0.txt
agrep -0 -c 'GGCACTTGGCATATGAT' *.fastq > count/B8415_Rm0.txt
agrep -0 -c 'CCTACACTATATGCCTC' *.fastq > count/B8416_Rm0.txt
agrep -0 -c 'TTACTGCGTAATCCCAC' *.fastq > count/B8417_Rm0.txt
agrep -0 -c 'ATTCCGCACGTAAGCAC' *.fastq > count/B8418_Rm0.txt
agrep -0 -c 'CACTGTTCAATGGTGCC' *.fastq > count/B8419_Rm0.txt
agrep -0 -c 'CACCCCGATCTTGACGT' *.fastq > count/B8420_Rm0.txt
agrep -0 -c 'TAAGTCTTGCTACTGCT' *.fastq > count/B8421_Rm0.txt
agrep -0 -c 'CTCAGTAGTAGGTATGC' *.fastq > count/B8422_Rm0.txt
agrep -0 -c 'CCGCCATATGCAATGCG' *.fastq > count/B8423_Rm0.txt
agrep -0 -c 'ATAGCATAAGGGCAGAA' *.fastq > count/B8424_Rm0.txt
agrep -0 -c 'CCCAAGTAAAGGCGTCT' *.fastq > count/B8425_Rm0.txt
agrep -0 -c 'GATAGCGAATTTCCAGA' *.fastq > count/B8426_Rm0.txt
agrep -0 -c 'CCTGTTCACAACTAGTC' *.fastq > count/B8427_Rm0.txt
agrep -0 -c 'TCATGCACAGTATTCCC' *.fastq > count/B8428_Rm0.txt
agrep -0 -c 'GAGTACAGCTACGGGTT' *.fastq > count/B8430_Rm0.txt
agrep -0 -c 'TACTTACAGAGTCTCCC' *.fastq > count/B8431_Rm0.txt
agrep -0 -c 'ACGCATATAATTCCGTG' *.fastq > count/B8432_Rm0.txt
agrep -0 -c 'CGACCATGGACGTGATA' *.fastq > count/B8433_Rm0.txt
agrep -0 -c 'GCCATCACGCCAATCAC' *.fastq > count/B8434_Rm0.txt
agrep -0 -c 'CGTTCATTTGGGACGGT' *.fastq > count/B8435_Rm0.txt
agrep -0 -c 'GTGGCACCAAATGGGGT' *.fastq > count/B8437_Rm0.txt
agrep -0 -c 'CTAGACTACGGATCAAC' *.fastq > count/B8438_Rm0.txt
agrep -0 -c 'CAGAATACGCACAGCCG' *.fastq > count/B8441_Rm0.txt
agrep -0 -c 'CACACAGAAGGCGCTAA' *.fastq > count/B8442_Rm0.txt
agrep -0 -c 'TATGGCGCATCGCTTTG' *.fastq > count/B8443_Rm0.txt
agrep -0 -c 'GCACTTGACTTGTCCTA' *.fastq > count/B8444_Rm0.txt
agrep -0 -c 'AATAGGGATTTTACCCC' *.fastq > count/B8445_Rm0.txt
agrep -0 -c 'ACCCAAAACCCGAAGTC' *.fastq > count/B8446_Rm0.txt
agrep -0 -c 'CGAGACTTGGCTATTGC' *.fastq > count/B8447_Rm0.txt
agrep -0 -c 'ATCTGTCTGGTCAATGT' *.fastq > count/B8448_Rm0.txt
agrep -0 -c 'TTTGTTAATCTCCGTCG' *.fastq > count/B8449_Rm0.txt
agrep -0 -c 'GGTAGACCTCTGTACTA' *.fastq > count/B8450_Rm0.txt
agrep -0 -c 'TCATCACCAGAGACCGT' *.fastq > count/B8451_Rm0.txt
agrep -0 -c 'GCAGGTCGTTCGAACCT' *.fastq > count/B8452_Rm0.txt
agrep -0 -c 'CTATTATAGTCACCCTG' *.fastq > count/B8453_Rm0.txt
agrep -0 -c 'CCAGCTAGGACAGCTAG' *.fastq > count/B8454_Rm0.txt
agrep -0 -c 'ATATGCGCGATGAATCA' *.fastq > count/B8457_Rm0.txt
agrep -0 -c 'TTGTAGGTCCGGATCAC' *.fastq > count/B8458_Rm0.txt
agrep -0 -c 'TCGATTCGCAAGCTGCA' *.fastq > count/B8459_Rm0.txt
agrep -0 -c 'GACATACGGGGCTAATA' *.fastq > count/B8460_Rm0.txt
agrep -0 -c 'CGTGGCGTGTCTTCAAC' *.fastq > count/B8461_Rm0.txt
agrep -0 -c 'ACAGTGGCAGAAACCGT' *.fastq > count/B8462_Rm0.txt
agrep -0 -c 'TCCAGACATGTGCTGGC' *.fastq > count/B8463_Rm0.txt
agrep -0 -c 'GAACTTCAGGCGGAATA' *.fastq > count/B8465_Rm0.txt
agrep -0 -c 'GCCGCTAGACCAACTAT' *.fastq > count/B8466_Rm0.txt
agrep -0 -c 'CCCTCCCTGATGATATC' *.fastq > count/B8467_Rm0.txt
agrep -0 -c 'ATCGATGCATCATGTGT' *.fastq > count/B8468_Rm0.txt
agrep -0 -c 'GAGAGCGCGGATCCAAT' *.fastq > count/B8471_Rm0.txt
agrep -0 -c 'CGACCGTGTTAAAAAGA' *.fastq > count/B8472_Rm0.txt
agrep -0 -c 'AGCGAGACATTTAACGA' *.fastq > count/B8473_Rm0.txt
agrep -0 -c 'GTACGGGCTACGGAAAC' *.fastq > count/B8474_Rm0.txt
agrep -0 -c 'TTCATTGTAGCGGAGTT' *.fastq > count/B8475_Rm0.txt
agrep -0 -c 'AACAGCCCTCGTCGAAG' *.fastq > count/B8476_Rm0.txt
agrep -0 -c 'TCGTGTAAGGTCCTGTG' *.fastq > count/B8477_Rm0.txt
agrep -0 -c 'CAGCGACATTGTCTTAT' *.fastq > count/B8479_Rm0.txt
agrep -0 -c 'ACGTGGTTTAGGAGGAC' *.fastq > count/B8480_Rm0.txt
agrep -0 -c 'CCTCGTTTACGATCTAT' *.fastq > count/B8481_Rm0.txt
agrep -0 -c 'ACTACCGCCCCAACACA' *.fastq > count/B8482_Rm0.txt
agrep -0 -c 'TAAGGTACGTCGCTGAC' *.fastq > count/B8483_Rm0.txt
agrep -0 -c 'GATAACCCCAGCCTACA' *.fastq > count/B8484_Rm0.txt
agrep -0 -c 'TTGTTTCAGCACACGCT' *.fastq > count/B8486_Rm0.txt
agrep -0 -c 'CCCGTATGGATGACTTA' *.fastq > count/B8487_Rm0.txt
agrep -0 -c 'ACCGCTGTCGTAGTACA' *.fastq > count/B8488_Rm0.txt
agrep -0 -c 'CTAGAGGATTGGCCTGT' *.fastq > count/B8490_Rm0.txt
agrep -0 -c 'CGATCCTGCACTAATCG' *.fastq > count/B8492_Rm0.txt
agrep -0 -c 'CCATCACGACTGTAGTA' *.fastq > count/B8493_Rm0.txt
agrep -0 -c 'ACTGTCATTAATCCCCG' *.fastq > count/B8494_Rm0.txt
agrep -0 -c 'GTCTACGATAGTTGACC' *.fastq > count/B8495_Rm0.txt
agrep -0 -c 'CCTACTATCAAGTGATC' *.fastq > count/B8496_Rm0.txt
agrep -0 -c 'CGCGCACATACCATAAC' *.fastq > count/B8497_Rm0.txt
agrep -0 -c 'AACATACGGATTGTTCG' *.fastq > count/B8498_Rm0.txt
agrep -0 -c 'TAAGTATTTCGACCTGG' *.fastq > count/B8499_Rm0.txt
agrep -0 -c 'ACACCAGCGAAGTGAGT' *.fastq > count/B8501_Rm0.txt
agrep -0 -c 'TAGTGAAACACAGCCCG' *.fastq > count/B8502_Rm0.txt
agrep -0 -c 'GTAATCCTAGGGCCTTG' *.fastq > count/B8503_Rm0.txt
agrep -0 -c 'GGCACTAGAAAGGAGTG' *.fastq > count/B8505_Rm0.txt
agrep -0 -c 'CTTAAAACGGGTGGATA' *.fastq > count/B8506_Rm0.txt
agrep -0 -c 'CCGGCTAATAATAACCT' *.fastq > count/B8507_Rm0.txt
agrep -0 -c 'GAGTTGGGACCATCCGT' *.fastq > count/B8508_Rm0.txt
agrep -0 -c 'GTCCTCTTATTACGCAG' *.fastq > count/B8509_Rm0.txt
agrep -0 -c 'GGTCGGATGCTTCGACT' *.fastq > count/B8510_Rm0.txt
agrep -0 -c 'GAACCAGATTGCGCACT' *.fastq > count/B8511_Rm0.txt
agrep -0 -c 'AGAACACATTAACCGCT' *.fastq > count/B8514_Rm0.txt
agrep -0 -c 'AGTTTCAGGAAGCGTAA' *.fastq > count/B8515_Rm0.txt
agrep -0 -c 'GGTAGTCTTAGCGCTAC' *.fastq > count/B8516_Rm0.txt
agrep -0 -c 'TAAAACCACCGCGATTG' *.fastq > count/B8518_Rm0.txt
agrep -0 -c 'AACAGATCGTTGCGTGC' *.fastq > count/B8519_Rm0.txt
agrep -0 -c 'GCCCCCATTTGTAAAGA' *.fastq > count/B8521_Rm0.txt
agrep -0 -c 'GAAGTAACGTTTGCTTG' *.fastq > count/B8522_Rm0.txt
agrep -0 -c 'GAAGTGAGGTTATCAAC' *.fastq > count/B8523_Rm0.txt
agrep -0 -c 'AACTTCAAACTGAGGGC' *.fastq > count/B8524_Rm0.txt
agrep -0 -c 'CGTACAAAATGCTGAAG' *.fastq > count/B8525_Rm0.txt
agrep -0 -c 'GTTTATTTTGGCTCGAC' *.fastq > count/B8526_Rm0.txt
agrep -0 -c 'TGGAAGGATGACCGTGC' *.fastq > count/B8527_Rm0.txt
agrep -0 -c 'GGTAGGATACGGTAGAG' *.fastq > count/B8528_Rm0.txt
agrep -0 -c 'AAGGGTAGTGATCTCAT' *.fastq > count/B8529_Rm0.txt
agrep -0 -c 'ACAGAGGTATGTATCGT' *.fastq > count/B8530_Rm0.txt
agrep -0 -c 'TAAATCTCAGTCGCCCG' *.fastq > count/B8531_Rm0.txt
agrep -0 -c 'GGTTCTTCCCACTCCTT' *.fastq > count/B8533_Rm0.txt
agrep -0 -c 'GATCGGATGAATAACCG' *.fastq > count/B8535_Rm0.txt
agrep -0 -c 'AAGGTCTCTGTCCGACA' *.fastq > count/B8536_Rm0.txt
agrep -0 -c 'GTACCACTACGATCGAC' *.fastq > count/B8537_Rm0.txt
agrep -0 -c 'ATCCTTCCTGTACCAGA' *.fastq > count/B8538_Rm0.txt
agrep -0 -c 'ACCTTGCACAAGTAATG' *.fastq > count/B8539_Rm0.txt
agrep -0 -c 'CTTGGCGCACAAACCCT' *.fastq > count/B8540_Rm0.txt
agrep -0 -c 'CATTCGTCGCACTACGC' *.fastq > count/B8541_Rm0.txt
agrep -0 -c 'TAGCCACGAGTAGGACG' *.fastq > count/B8542_Rm0.txt
agrep -0 -c 'CTCTGGTCCGACGAATT' *.fastq > count/B8543_Rm0.txt
agrep -0 -c 'CATTGCTCATCATCTCG' *.fastq > count/B8544_Rm0.txt
agrep -0 -c 'TACTTTCCGTTCTCACT' *.fastq > count/B8546_Rm0.txt
agrep -0 -c 'GTTGTCCCCTTTCGAGT' *.fastq > count/B8547_Rm0.txt
agrep -0 -c 'CTATTCACATGCGGCTC' *.fastq > count/B8548_Rm0.txt
agrep -0 -c 'AGTATTGGCACCACATT' *.fastq > count/B8550_Rm0.txt
agrep -0 -c 'GCGCAAGGAGAAAAGAC' *.fastq > count/B8552_Rm0.txt
agrep -0 -c 'CGATCTTACGTCTTGAC' *.fastq > count/B8553_Rm0.txt
agrep -0 -c 'CGTTCATGGCATTAAGT' *.fastq > count/B8554_Rm0.txt
agrep -0 -c 'GTGTGGCTTCGTAGTTG' *.fastq > count/B8555_Rm0.txt
agrep -0 -c 'CTTTGTATAGGGAGCCA' *.fastq > count/B8556_Rm0.txt
agrep -0 -c 'TAGCCTAGTCTTAGGTC' *.fastq > count/B8557_Rm0.txt
agrep -0 -c 'ATTAATACTGCGACACC' *.fastq > count/B8558_Rm0.txt
agrep -0 -c 'AGGCCAAGCTGTGGTAA' *.fastq > count/B8559_Rm0.txt
agrep -0 -c 'CCAAAAGGAGTGTAAGC' *.fastq > count/B8561_Rm0.txt
agrep -0 -c 'ATCGTTGGTGTGGCTCA' *.fastq > count/B8562_Rm0.txt
agrep -0 -c 'CGAATTCTCACTGGCCG' *.fastq > count/B8563_Rm0.txt
agrep -0 -c 'GAGAGTGCATTTGTTGT' *.fastq > count/B8564_Rm0.txt
agrep -0 -c 'TTGTCTGGCAGACGACT' *.fastq > count/B8567_Rm0.txt
agrep -0 -c 'GTTCTGAACGCGGAAAC' *.fastq > count/B8568_Rm0.txt
agrep -0 -c 'TCGAACCCGCTTAATCG' *.fastq > count/B8569_Rm0.txt
agrep -0 -c 'GGAGGATGGCTTTATGT' *.fastq > count/B8572_Rm0.txt
agrep -0 -c 'CCACGGAAGGGATAAAC' *.fastq > count/B8574_Rm0.txt
agrep -0 -c 'GAAGCCTGACCTATACC' *.fastq > count/B8576_Rm0.txt
agrep -0 -c 'GAAAGTAGCCGCACTGA' *.fastq > count/B8577_Rm0.txt
agrep -0 -c 'GTGGTGGCGAGGTGTAA' *.fastq > count/B8578_Rm0.txt
agrep -0 -c 'TCCGGATCAGTACTAGC' *.fastq > count/B8579_Rm0.txt
agrep -0 -c 'TGGTATCCGATTCAGAC' *.fastq > count/B8580_Rm0.txt
agrep -0 -c 'TCGGCCTGCTGTTACTG' *.fastq > count/B8581_Rm0.txt
agrep -0 -c 'GGATCACATGGGTGACT' *.fastq > count/B8583_Rm0.txt
agrep -0 -c 'CGGGCATTATCGAGGTA' *.fastq > count/B8584_Rm0.txt
agrep -0 -c 'CACTTATCTTACGCGAG' *.fastq > count/B8585_Rm0.txt
agrep -0 -c 'AAACACGCAACGATTCG' *.fastq > count/B8586_Rm0.txt
agrep -0 -c 'CAACGCGCTCTTAGGTG' *.fastq > count/B8587_Rm0.txt
agrep -0 -c 'TAACCCGTTGGCGTGAC' *.fastq > count/B8588_Rm0.txt
agrep -0 -c 'ACGGGTACACTATCGTG' *.fastq > count/B8589_Rm0.txt
agrep -0 -c 'ATTCTATAGACGACCTC' *.fastq > count/B8591_Rm0.txt
agrep -0 -c 'CCCAATGACCCTACCAT' *.fastq > count/B8592_Rm0.txt
agrep -0 -c 'GGAGCTTTGAACACCTA' *.fastq > count/B8593_Rm0.txt
agrep -0 -c 'GTAAATCGTTACGCCTG' *.fastq > count/B8594_Rm0.txt
agrep -0 -c 'TTTGCATGGAGCACCCT' *.fastq > count/B8595_Rm0.txt
agrep -0 -c 'ATTCCTGGATACAGGTC' *.fastq > count/B8596_Rm0.txt
agrep -0 -c 'GACCCGCTGTTTTAAGC' *.fastq > count/B8597_Rm0.txt
agrep -0 -c 'AGAATGACGACACGACC' *.fastq > count/B8598_Rm0.txt
agrep -0 -c 'TGATGTGTATCCCGTTA' *.fastq > count/B8599_Rm0.txt
agrep -0 -c 'ACACAGTCGAGTGTGTA' *.fastq > count/B8600_Rm0.txt
agrep -0 -c 'TACCAACCAAGGTTCGA' *.fastq > count/B8601_Rm0.txt
agrep -0 -c 'TTGCGACAAAGTCCGTG' *.fastq > count/B8602_Rm0.txt
agrep -0 -c 'CGATATCTCGCAAAATC' *.fastq > count/B8603_Rm0.txt
agrep -0 -c 'CGGGACTCGATTATGAA' *.fastq > count/B8604_Rm0.txt
agrep -0 -c 'CCACGTAAACAGTTAAC' *.fastq > count/B8605_Rm0.txt
agrep -0 -c 'TTCCGGGTCCTACTACG' *.fastq > count/B8606_Rm0.txt
agrep -0 -c 'TAGCGTGTTGGAGCTCT' *.fastq > count/B8607_Rm0.txt
agrep -0 -c 'AAGCGCGGACAGTAGGT' *.fastq > count/B8608_Rm0.txt
agrep -0 -c 'AGCTTAGTAGTGCCCAT' *.fastq > count/B8609_Rm0.txt
agrep -0 -c 'GAAACTTTGGGTATTCG' *.fastq > count/B8610_Rm0.txt
agrep -0 -c 'AAGGCCGGTACATGAGG' *.fastq > count/B8611_Rm0.txt
agrep -0 -c 'TAGATACCTTGGCGGAT' *.fastq > count/B8612_Rm0.txt
agrep -0 -c 'GGAGATCCTCAGTTCTT' *.fastq > count/B8613_Rm0.txt
agrep -0 -c 'CAAATCTCGGAAGGCGA' *.fastq > count/B8614_Rm0.txt
agrep -0 -c 'CTCGTGGCTTCTTCGAA' *.fastq > count/B8615_Rm0.txt
agrep -0 -c 'TCGAGTGAGGCTACACT' *.fastq > count/B8616_Rm0.txt
agrep -0 -c 'GGGAACTATATGGGATA' *.fastq > count/B8617_Rm0.txt
agrep -0 -c 'AGCCCTTGGTAAACCTG' *.fastq > count/B8618_Rm0.txt
agrep -0 -c 'TTTAGCACCGACCTCCA' *.fastq > count/B8620_Rm0.txt
agrep -0 -c 'CCAATAGATGCTTCCCC' *.fastq > count/B8621_Rm0.txt
agrep -0 -c 'TCACGCTAGACGGGTTG' *.fastq > count/B8622_Rm0.txt
agrep -0 -c 'CCTATGTGATAGCACGT' *.fastq > count/B8623_Rm0.txt
agrep -0 -c 'GACCGGAACGACCAAAT' *.fastq > count/B8624_Rm0.txt
agrep -0 -c 'TTCGAACAGTTTCACTC' *.fastq > count/B8625_Rm0.txt
agrep -0 -c 'AAGACACGGCTAATTCT' *.fastq > count/B8627_Rm0.txt
agrep -0 -c 'CTATCGCCTATAGGACG' *.fastq > count/B8628_Rm0.txt
agrep -0 -c 'TATCGGTAGTAGCTTAG' *.fastq > count/B8629_Rm0.txt
agrep -0 -c 'CACGGACTGGTTTCAAC' *.fastq > count/B8630_Rm0.txt
agrep -0 -c 'CGAAACGACTGGTTTTG' *.fastq > count/B8631_Rm0.txt
agrep -0 -c 'AATGCTATCCGAATGAC' *.fastq > count/B8632_Rm0.txt
agrep -0 -c 'GCCTCACGAATGACAAT' *.fastq > count/B8633_Rm0.txt
agrep -0 -c 'GGACTCGCTGACAATGA' *.fastq > count/B8634_Rm0.txt
agrep -0 -c 'TCAACTCTTCGTCATCC' *.fastq > count/B8635_Rm0.txt
agrep -0 -c 'CCTCCTACCACGAGATA' *.fastq > count/B8636_Rm0.txt
agrep -0 -c 'TTGCAAGGCCAAGACGG' *.fastq > count/B8637_Rm0.txt
agrep -0 -c 'GGATAGCTAGACGAGAC' *.fastq > count/B8638_Rm0.txt
agrep -0 -c 'TTCGCTTGATTCTGGTA' *.fastq > count/B8641_Rm0.txt
agrep -0 -c 'CTTGACAGAGCATACGA' *.fastq > count/B8642_Rm0.txt
agrep -0 -c 'GTCTACAACCAACGAGG' *.fastq > count/B8643_Rm0.txt
agrep -0 -c 'TTGGAGTGACGCGGATG' *.fastq > count/B8644_Rm0.txt
agrep -0 -c 'TCGTGCAGTTAGAGAAG' *.fastq > count/B8645_Rm0.txt
agrep -0 -c 'GGGCGCAGGGTAAATTG' *.fastq > count/B8646_Rm0.txt
agrep -0 -c 'TGATGCGCTTAAGACTG' *.fastq > count/B8647_Rm0.txt
agrep -0 -c 'CGAGAGGTATCACGGAA' *.fastq > count/B8648_Rm0.txt
agrep -0 -c 'AACATTATTGTCCGGCT' *.fastq > count/B8649_Rm0.txt
agrep -0 -c 'TAGAGTCTTCACCACTG' *.fastq > count/B8650_Rm0.txt
agrep -0 -c 'TGTTGGACCATCTAGGT' *.fastq > count/B8651_Rm0.txt
agrep -0 -c 'GCTGGAATTACTACTGT' *.fastq > count/B8652_Rm0.txt
agrep -0 -c 'TGTTGCCATGCTCTACC' *.fastq > count/B8653_Rm0.txt
agrep -0 -c 'CCATGATAGGAGGCATA' *.fastq > count/B8654_Rm0.txt
agrep -0 -c 'TAACGACCTCTATTGCG' *.fastq > count/B8655_Rm0.txt
agrep -0 -c 'TCCATGTAAGACGAATG' *.fastq > count/B8656_Rm0.txt
agrep -0 -c 'GCAAGGTTTCCATTCAC' *.fastq > count/B8658_Rm0.txt
agrep -0 -c 'TGAAGGCGCAAGGACAC' *.fastq > count/B8659_Rm0.txt
agrep -0 -c 'GAAATCCGTACTGCTCG' *.fastq > count/B8660_Rm0.txt
agrep -0 -c 'GGGCCGTATTTGGAGCT' *.fastq > count/B8661_Rm0.txt
agrep -0 -c 'GGCGAGCTAAAGGATCA' *.fastq > count/B8662_Rm0.txt
agrep -0 -c 'GCAGGTGTTCGGCAGAA' *.fastq > count/B8663_Rm0.txt
agrep -0 -c 'TAGCAAGACGGAAGCTA' *.fastq > count/B8664_Rm0.txt
agrep -0 -c 'CGAATACGACGTGTATA' *.fastq > count/B8665_Rm0.txt
agrep -0 -c 'GTAGCCTCTGCCCACAA' *.fastq > count/B8666_Rm0.txt
agrep -0 -c 'GGCGAATACTTGTCTGA' *.fastq > count/B8667_Rm0.txt
agrep -0 -c 'CAACAACCCAGGTGAGT' *.fastq > count/B8668_Rm0.txt
agrep -0 -c 'ATGCACGCTAAAGTGCT' *.fastq > count/B8669_Rm0.txt
agrep -0 -c 'CGATGTCCGGTTCACGA' *.fastq > count/B8670_Rm0.txt
agrep -0 -c 'TCACTCACCCACGCTGA' *.fastq > count/B8674_Rm0.txt
agrep -0 -c 'GGAAATTCGTGTGGCGC' *.fastq > count/B8675_Rm0.txt
agrep -0 -c 'TTCTACCGTACATTGCG' *.fastq > count/B8678_Rm0.txt
agrep -0 -c 'CGAAGCCGTCTACATTA' *.fastq > count/B8679_Rm0.txt
agrep -0 -c 'GGTTAATCAACGCGTTG' *.fastq > count/B8681_Rm0.txt
agrep -0 -c 'GTTGCCCTTATTCTACG' *.fastq > count/B8682_Rm0.txt
agrep -0 -c 'GACCTGGACCAAAGATC' *.fastq > count/B8683_Rm0.txt
agrep -0 -c 'TCACCTACGGACTTGCA' *.fastq > count/B8684_Rm0.txt
agrep -0 -c 'ATACCTAGTTGATGGTG' *.fastq > count/B8685_Rm0.txt
agrep -0 -c 'CACGACTAATGAGCAAG' *.fastq > count/B8686_Rm0.txt
agrep -0 -c 'GTTACAGCTGATTAGCG' *.fastq > count/B8687_Rm0.txt
agrep -0 -c 'CATATGTTCAGGTCACG' *.fastq > count/B8688_Rm0.txt
agrep -0 -c 'CTGGAGGAGGTCTATCG' *.fastq > count/B8689_Rm0.txt
agrep -0 -c 'GAAGTACGCGAGCGCTA' *.fastq > count/B8690_Rm0.txt
agrep -0 -c 'CGTCTATAACGACGAAC' *.fastq > count/B8691_Rm0.txt
agrep -0 -c 'AAATTTACGTCCGACTG' *.fastq > count/B8692_Rm0.txt
agrep -0 -c 'TCTCCTAGTGCCTTATA' *.fastq > count/B8693_Rm0.txt
agrep -0 -c 'CGTAGCGCTGAATCACG' *.fastq > count/B8694_Rm0.txt
agrep -0 -c 'GGACGATCATATGGCGA' *.fastq > count/B8695_Rm0.txt
agrep -0 -c 'TTTGCGCGATGCTTCCG' *.fastq > count/B8696_Rm0.txt
agrep -0 -c 'TGAGCGCCAATACGTCC' *.fastq > count/B8697_Rm0.txt
agrep -0 -c 'GTCAGTTATTACTCGAG' *.fastq > count/B8698_Rm0.txt
agrep -0 -c 'GTATACGCAAGACCTTG' *.fastq > count/B8699_Rm0.txt
agrep -0 -c 'ACTGGCCCTATGGACAA' *.fastq > count/B8700_Rm0.txt
agrep -0 -c 'GGGAAAGCACGCAGTAT' *.fastq > count/B8701_Rm0.txt
agrep -0 -c 'GTCGGCTTACGCGGTAT' *.fastq > count/B8702_Rm0.txt
agrep -0 -c 'ATACGTTTACATTCCGC' *.fastq > count/B8704_Rm0.txt
agrep -0 -c 'ACAATCCGCCGATCTAC' *.fastq > count/B8705_Rm0.txt
agrep -0 -c 'TAACCGGTCTACCGTGT' *.fastq > count/B8706_Rm0.txt
agrep -0 -c 'CCGTCAGAATCGAACGT' *.fastq > count/B8707_Rm0.txt
agrep -0 -c 'TGGACGCAATTGAGGCG' *.fastq > count/B8708_Rm0.txt
agrep -0 -c 'CCGCTGGTCGTTAAACT' *.fastq > count/B8709_Rm0.txt
agrep -0 -c 'GTGTAGCTCGCACCCAA' *.fastq > count/B8710_Rm0.txt
agrep -0 -c 'TCCTAGCCGGCAGAATT' *.fastq > count/B8711_Rm0.txt
agrep -0 -c 'CGTGTGGCGTCCTTTCT' *.fastq > count/B8712_Rm0.txt
agrep -0 -c 'TGTTGAGGCATGCCTAG' *.fastq > count/B8714_Rm0.txt
agrep -0 -c 'ATTGTGGACACATTGCT' *.fastq > count/B8715_Rm0.txt
agrep -0 -c 'TACAACTAACCGGCCAA' *.fastq > count/B8717_Rm0.txt
agrep -0 -c 'ACAAGACATGTTCGCGG' *.fastq > count/B8720_Rm0.txt
agrep -0 -c 'TCGATTGGTGGGTGTAT' *.fastq > count/B8722_Rm0.txt
agrep -0 -c 'CTATCGTTACTCCCGAA' *.fastq > count/B8723_Rm0.txt
agrep -0 -c 'GCAAGTAACGTGCTGTT' *.fastq > count/B8724_Rm0.txt
agrep -0 -c 'AGCGTGGGATCATTACG' *.fastq > count/B8725_Rm0.txt
agrep -0 -c 'ATAGCCCCGTCATTGAT' *.fastq > count/B8726_Rm0.txt
agrep -0 -c 'TTATTGAGCAGCGGACA' *.fastq > count/B8727_Rm0.txt
agrep -0 -c 'TGACGTCCTTAGTCGGC' *.fastq > count/B8728_Rm0.txt
agrep -0 -c 'ATGTCTTACTGCGCTCG' *.fastq > count/B8729_Rm0.txt
agrep -0 -c 'TCTTGACAAACTCTCGA' *.fastq > count/B8730_Rm0.txt
agrep -0 -c 'CGTAGGTGAAGTCCCTA' *.fastq > count/B8731_Rm0.txt
agrep -0 -c 'GGATGCTGTGACGGTAC' *.fastq > count/B8732_Rm0.txt
agrep -0 -c 'CACTCTGCCGAAAGAAG' *.fastq > count/B8733_Rm0.txt
agrep -0 -c 'TGTCTAAGGAGGAGTTA' *.fastq > count/B8734_Rm0.txt
agrep -0 -c 'CTTTGACAATGCCGCTG' *.fastq > count/B8735_Rm0.txt
agrep -0 -c 'TCCACGCAATCCTGACA' *.fastq > count/B8736_Rm0.txt
agrep -0 -c 'ACCTGTTGACGGGCTCT' *.fastq > count/B8738_Rm0.txt
agrep -0 -c 'GGGCTCATTCGTCGTAT' *.fastq > count/B8739_Rm0.txt
agrep -0 -c 'AGGTTTCTTCTACGAAC' *.fastq > count/B8740_Rm0.txt
agrep -0 -c 'TCGCCTTCTTATAGCGC' *.fastq > count/B8741_Rm0.txt
agrep -0 -c 'AGGCGTATCGAAACCGC' *.fastq > count/B8742_Rm0.txt
agrep -0 -c 'CTTACCTATCGGGAGTT' *.fastq > count/B8743_Rm0.txt
agrep -0 -c 'GCACAGGCCGGGTAATA' *.fastq > count/B8744_Rm0.txt
agrep -0 -c 'TCATCATGTGTCATACC' *.fastq > count/B8745_Rm0.txt
agrep -0 -c 'GCGGTATACTGGGAAGA' *.fastq > count/B8746_Rm0.txt
agrep -0 -c 'TATGCTCGCTGAGTAAC' *.fastq > count/B8747_Rm0.txt
agrep -0 -c 'TGAGCTGATTCAGCGGC' *.fastq > count/B8749_Rm0.txt
agrep -0 -c 'CCTGCACGGTCCTAATA' *.fastq > count/B8750_Rm0.txt
agrep -0 -c 'GTGTTGCAATTAACGTG' *.fastq > count/B8751_Rm0.txt
agrep -0 -c 'TAGACCCGATGTGCCTG' *.fastq > count/B8752_Rm0.txt
agrep -0 -c 'CCACGCCTAGTAAAATG' *.fastq > count/B8753_Rm0.txt
agrep -0 -c 'AATAGCCAACAGCCGCC' *.fastq > count/B8754_Rm0.txt
agrep -0 -c 'TCGTTCCTACTATCGAC' *.fastq > count/B8755_Rm0.txt
agrep -0 -c 'TAACCGTCCTGAATCTT' *.fastq > count/B8756_Rm0.txt
agrep -0 -c 'TCCTGTATGCAAAAACC' *.fastq > count/B8757_Rm0.txt
agrep -0 -c 'AAAGACGGCTGAACTGT' *.fastq > count/B8758_Rm0.txt
agrep -0 -c 'GGTGATGGTTACGGAAT' *.fastq > count/B8760_Rm0.txt
agrep -0 -c 'CGACAACATCTTCTAGC' *.fastq > count/B8761_Rm0.txt
agrep -0 -c 'CAAATTTGCCTGGCCAC' *.fastq > count/B8762_Rm0.txt
agrep -0 -c 'CCCTTTCCGATTATGCA' *.fastq > count/B8763_Rm0.txt
agrep -0 -c 'GCGCGTTTGCAAATAAC' *.fastq > count/B8764_Rm0.txt
agrep -0 -c 'GATGGGCGGTTTGATCA' *.fastq > count/B8765_Rm0.txt
agrep -0 -c 'ATAGATCTCAGGTAGTG' *.fastq > count/B8766_Rm0.txt
agrep -0 -c 'GACCGATACCCGTTCTT' *.fastq > count/B8767_Rm0.txt
agrep -0 -c 'AAAGCGGACTTCGTTAC' *.fastq > count/B8768_Rm0.txt
agrep -0 -c 'TGAATCTGCACACGAGG' *.fastq > count/B8769_Rm0.txt
agrep -0 -c 'GTAGGCTCATTAGACCG' *.fastq > count/B8770_Rm0.txt
agrep -0 -c 'CTAGCGATGAAACGCGT' *.fastq > count/B8771_Rm0.txt
agrep -0 -c 'GGTGCAGTGCAAGTGTG' *.fastq > count/B8772_Rm0.txt
agrep -0 -c 'AACTTCAAAGCCCAGAG' *.fastq > count/B8774_Rm0.txt
agrep -0 -c 'ACAGCACTGGGCGTACT' *.fastq > count/B8777_Rm0.txt
agrep -0 -c 'CCTGCGTTCTCATTATG' *.fastq > count/B8778_Rm0.txt
agrep -0 -c 'CGAGGGTTCGCCTACAA' *.fastq > count/B8779_Rm0.txt
agrep -0 -c 'ACAACAGCCTAATGCGT' *.fastq > count/B8780_Rm0.txt
agrep -0 -c 'TACGCCGTCGCACTTAT' *.fastq > count/B8782_Rm0.txt
agrep -0 -c 'TTCTCAAATGTTCCGCT' *.fastq > count/B8784_Rm0.txt
agrep -0 -c 'CGATCTGACCTAATTGT' *.fastq > count/B8785_Rm0.txt
agrep -0 -c 'CCTTCCTCTAGACTCGG' *.fastq > count/B8786_Rm0.txt
agrep -0 -c 'CGAATTAACTTGCTCAC' *.fastq > count/B8787_Rm0.txt
agrep -0 -c 'TTGCGCGTAACCTTACT' *.fastq > count/B8788_Rm0.txt
agrep -0 -c 'CCCGCGGCTTTAGTATC' *.fastq > count/B8790_Rm0.txt
agrep -0 -c 'CGTGTCGTCGTAGCGTT' *.fastq > count/B8791_Rm0.txt
agrep -0 -c 'CCACGTAGTGGTTCAGA' *.fastq > count/B8792_Rm0.txt
agrep -0 -c 'TCGTGACGTTGCTTAGT' *.fastq > count/B8793_Rm0.txt
agrep -0 -c 'ACGAAAACCCTCCGGAA' *.fastq > count/B8794_Rm0.txt
agrep -0 -c 'AGTAATGACCTGAACCT' *.fastq > count/B8795_Rm0.txt
agrep -0 -c 'GGGTAGAAAGCTTGGAG' *.fastq > count/B8797_Rm0.txt
agrep -0 -c 'GGGAAACACCAATCTCT' *.fastq > count/B8798_Rm0.txt
agrep -0 -c 'GTACTTGGCGGTCTCTC' *.fastq > count/B8799_Rm0.txt
agrep -0 -c 'ATTCGTTCACATGAGTG' *.fastq > count/B8800_Rm0.txt
agrep -0 -c 'CGGCAATCGCGTATACT' *.fastq > count/B8801_Rm0.txt
agrep -0 -c 'CTTCGTCAATACTGTGC' *.fastq > count/B8802_Rm0.txt
agrep -0 -c 'ATGTTTGTACAGGTAGC' *.fastq > count/B8803_Rm0.txt
agrep -0 -c 'GGCGAATCATCTCGGCT' *.fastq > count/B8805_Rm0.txt
agrep -0 -c 'TTGACGCATGTTGACGC' *.fastq > count/B8808_Rm0.txt
agrep -0 -c 'GCATAAATTCCTCTCGT' *.fastq > count/B8809_Rm0.txt
agrep -0 -c 'CGAAACAACGTGAGCAC' *.fastq > count/B8810_Rm0.txt
agrep -0 -c 'ACCTCCATCGTTCCCAA' *.fastq > count/B8811_Rm0.txt
agrep -0 -c 'TTCTCCGCTTCGCCATT' *.fastq > count/B8813_Rm0.txt
agrep -0 -c 'AGTTGTACCCTCATTGC' *.fastq > count/B8814_Rm0.txt
agrep -0 -c 'TATCACCGCGATACACG' *.fastq > count/B8815_Rm0.txt
agrep -0 -c 'AGAATATAGGTATCCGG' *.fastq > count/B8816_Rm0.txt
agrep -0 -c 'CCAAGGCTGGTAAGACG' *.fastq > count/B8817_Rm0.txt
agrep -0 -c 'GCATGTTGATTGGTCGA' *.fastq > count/B8818_Rm0.txt
agrep -0 -c 'CTGAAGACGATCCCGTG' *.fastq > count/B8819_Rm0.txt
agrep -0 -c 'CAGTTATTCGACTGCGA' *.fastq > count/B8820_Rm0.txt
agrep -0 -c 'TTCCCTCCTAAGCGATC' *.fastq > count/B8821_Rm0.txt
agrep -0 -c 'TTGGACTATCTTGCTCG' *.fastq > count/B8822_Rm0.txt
agrep -0 -c 'CTACGAGTTTTGAGAGC' *.fastq > count/B8824_Rm0.txt
agrep -0 -c 'CGCAGCGTTGGCAATTA' *.fastq > count/B8825_Rm0.txt
agrep -0 -c 'CATTGCTACTTCAACAG' *.fastq > count/B8826_Rm0.txt
agrep -0 -c 'CACTGTCTTTTTCGAGA' *.fastq > count/B8829_Rm0.txt
agrep -0 -c 'AGGGCCTCCCACTTGTT' *.fastq > count/B8830_Rm0.txt
agrep -0 -c 'ACAACTCCAATCAGTAG' *.fastq > count/B8831_Rm0.txt
agrep -0 -c 'TAAGGGTACTACCAGCC' *.fastq > count/B8832_Rm0.txt
agrep -0 -c 'ACCGTACAGTTTGATGA' *.fastq > count/B8833_Rm0.txt
agrep -0 -c 'CTGGCAACCTAATGACT' *.fastq > count/B8834_Rm0.txt
agrep -0 -c 'GGAGCCTTAGTCTTAAG' *.fastq > count/B8835_Rm0.txt
agrep -0 -c 'TCAACTACGTCCGCTGG' *.fastq > count/B8839_Rm0.txt
agrep -0 -c 'AGGAACACCGCGTGCAT' *.fastq > count/B8840_Rm0.txt
agrep -0 -c 'CGAGCTTACGCTCCTCT' *.fastq > count/B8841_Rm0.txt
agrep -0 -c 'CAGTAGCCCGAGTCATC' *.fastq > count/B8842_Rm0.txt
agrep -0 -c 'TAGCCGCGCTTTCACAA' *.fastq > count/B8843_Rm0.txt
agrep -0 -c 'TTAATGCACGCCCCCTG' *.fastq > count/B8844_Rm0.txt
agrep -0 -c 'CAACGTGCTCTTGTAAG' *.fastq > count/B8845_Rm0.txt
agrep -0 -c 'AAGGCGAATAACGTCAC' *.fastq > count/B8846_Rm0.txt
agrep -0 -c 'AGTATCGGCTCGTCGTC' *.fastq > count/B8848_Rm0.txt
agrep -0 -c 'CATCAGCCGAGCATTCA' *.fastq > count/B8849_Rm0.txt
agrep -0 -c 'TATTAGGGCAGTATCGG' *.fastq > count/B8850_Rm0.txt
agrep -0 -c 'ATCGTGGGTATTGGGTT' *.fastq > count/B8851_Rm0.txt
agrep -0 -c 'GCAATAGGGCTTCAGGT' *.fastq > count/B8852_Rm0.txt
agrep -0 -c 'GAAATCCAGACGCCAGT' *.fastq > count/B8853_Rm0.txt
agrep -0 -c 'TAGTTGGGCATCTCGCC' *.fastq > count/B8854_Rm0.txt
agrep -0 -c 'GATGGGTCAGAAGCGTG' *.fastq > count/B8855_Rm0.txt
agrep -0 -c 'TTAGCTAGCAGTTCCTG' *.fastq > count/B8856_Rm0.txt
agrep -0 -c 'AGGAATCGATCCGATAT' *.fastq > count/B8857_Rm0.txt
agrep -0 -c 'CGGATAGACGACATACT' *.fastq > count/B8858_Rm0.txt
agrep -0 -c 'CTGAGCTCTAGAACTGA' *.fastq > count/B8859_Rm0.txt
agrep -0 -c 'TACGCGCAAATGTGGTC' *.fastq > count/B8860_Rm0.txt
agrep -0 -c 'TGAGGTCCAGCCCTTAA' *.fastq > count/B8861_Rm0.txt
agrep -0 -c 'ATAATGGGAAGCCGCTG' *.fastq > count/B8862_Rm0.txt
agrep -0 -c 'CTGTGCTTTTTAGAGCG' *.fastq > count/B8864_Rm0.txt
agrep -0 -c 'TGGAGGCAAACATCTAG' *.fastq > count/B8869_Rm0.txt
agrep -0 -c 'GGCTTGAACCCGGTTTA' *.fastq > count/B8870_Rm0.txt
agrep -0 -c 'TATTGTAGCCGAACGAC' *.fastq > count/B8871_Rm0.txt
agrep -0 -c 'TCAAAGATCCCGCGTCA' *.fastq > count/B8872_Rm0.txt
agrep -0 -c 'ACGTGTCAAACAGGTGT' *.fastq > count/B8873_Rm0.txt
agrep -0 -c 'GGCAAGTCGATAGAATT' *.fastq > count/B8874_Rm0.txt
agrep -0 -c 'GATAAATTGAGCGGCGC' *.fastq > count/B8875_Rm0.txt
agrep -0 -c 'CCTCAGCCATTTAACTG' *.fastq > count/B8876_Rm0.txt
agrep -0 -c 'CTATCACACCCAAGGAT' *.fastq > count/B8877_Rm0.txt
agrep -0 -c 'TATTGGCTACCCCTGCG' *.fastq > count/B8878_Rm0.txt
agrep -0 -c 'GCTGGGACTCGTTTCAT' *.fastq > count/B8879_Rm0.txt
agrep -0 -c 'GTTAGTACTCGGCATCC' *.fastq > count/B8880_Rm0.txt
agrep -0 -c 'CAGCCATTGCGCTAGTA' *.fastq > count/B8882_Rm0.txt
agrep -0 -c 'AGAGTCCCTTACGAAGG' *.fastq > count/B8883_Rm0.txt
agrep -0 -c 'GTCTCTGACTCAATCGC' *.fastq > count/B8884_Rm0.txt
agrep -0 -c 'ACCCTTGAAATGGGCTT' *.fastq > count/B8885_Rm0.txt
agrep -0 -c 'CCTGTGAAGTCTTGCCC' *.fastq > count/B8886_Rm0.txt
agrep -0 -c 'TTGTCGCAAGATGAGCT' *.fastq > count/B8887_Rm0.txt
agrep -0 -c 'TGCATACCGGTTCGATT' *.fastq > count/B8888_Rm0.txt
agrep -0 -c 'GCGTGTTTGTAGAATGG' *.fastq > count/B8889_Rm0.txt
agrep -0 -c 'AGTAAGGTCTGAACGTA' *.fastq > count/B8890_Rm0.txt
agrep -0 -c 'TACTCGATCAGCCACAC' *.fastq > count/B8891_Rm0.txt
agrep -0 -c 'CGGGGTTACCTATATGA' *.fastq > count/B8893_Rm0.txt
agrep -0 -c 'CAGTATAGCAAAACTCG' *.fastq > count/B8894_Rm0.txt
agrep -0 -c 'TGCGTGAGACAAACGGC' *.fastq > count/B8895_Rm0.txt
agrep -0 -c 'GCGAAATATGGACTTAG' *.fastq > count/B8897_Rm0.txt
agrep -0 -c 'CGAATTCCCTGGTCAGG' *.fastq > count/B8898_Rm0.txt
agrep -0 -c 'TTACAAGTTCCGAATCC' *.fastq > count/B8899_Rm0.txt
agrep -0 -c 'GACCCTTGAAATGTACA' *.fastq > count/B8900_Rm0.txt
agrep -0 -c 'CCGACGATAGACCATGA' *.fastq > count/B8901_Rm0.txt
agrep -0 -c 'AGGAGTATCGCCATTTG' *.fastq > count/B8902_Rm0.txt
agrep -0 -c 'TAATCCCGGGAATATGG' *.fastq > count/B8903_Rm0.txt
agrep -0 -c 'AAGGGTGCACTCCCCTA' *.fastq > count/B8904_Rm0.txt
agrep -0 -c 'CAGGCAAAAGCCGTGTG' *.fastq > count/B8905_Rm0.txt
agrep -0 -c 'TGGCGATATGGTGTCGG' *.fastq > count/B8906_Rm0.txt
agrep -0 -c 'AATATCGTAGGTGGGAG' *.fastq > count/B8907_Rm0.txt
agrep -0 -c 'CCACGGTATGCGTACGT' *.fastq > count/B8908_Rm0.txt
agrep -0 -c 'CGATTTAGGGCATGGAA' *.fastq > count/B8909_Rm0.txt
agrep -0 -c 'CCGTGGCGAGTGAAATC' *.fastq > count/B8910_Rm0.txt
agrep -0 -c 'TGACTGCAACTTCGGAG' *.fastq > count/B8911_Rm0.txt
agrep -0 -c 'GGCAATGTCCAACAAGA' *.fastq > count/B8912_Rm0.txt
agrep -0 -c 'GGGGATGGAAGGACAAG' *.fastq > count/B8913_Rm0.txt
agrep -0 -c 'GTTTTCGATACAACCCG' *.fastq > count/B8914_Rm0.txt
agrep -0 -c 'GAGTACACTCACTGGTA' *.fastq > count/B8915_Rm0.txt
agrep -0 -c 'CGGTGTGGAGTATTGCG' *.fastq > count/B8916_Rm0.txt
agrep -0 -c 'ATCTCCGTGACTGCATA' *.fastq > count/B8917_Rm0.txt
agrep -0 -c 'GAAACGGCACAGATTTA' *.fastq > count/B8918_Rm0.txt
agrep -0 -c 'GAAAGCGCATACGACTG' *.fastq > count/B8919_Rm0.txt
agrep -0 -c 'CTGTATAACGAGTTAGG' *.fastq > count/B8920_Rm0.txt
agrep -0 -c 'GAGCCACGTTATTAGGC' *.fastq > count/B8921_Rm0.txt
agrep -0 -c 'CCCATTCGATCAAACCC' *.fastq > count/B8922_Rm0.txt
agrep -0 -c 'TGCCGTCTTTAGAAATG' *.fastq > count/B8923_Rm0.txt
agrep -0 -c 'GCGGGCATAAGTGACTG' *.fastq > count/B8924_Rm0.txt
agrep -0 -c 'CGGTAGCGCGTGTTGTT' *.fastq > count/B8925_Rm0.txt
agrep -0 -c 'TATCGTGGCACTCGATT' *.fastq > count/B8926_Rm0.txt
agrep -0 -c 'CCCGTGATTAACTTGTT' *.fastq > count/B8927_Rm0.txt
agrep -0 -c 'AGCCGATTAATGCTAAG' *.fastq > count/B8928_Rm0.txt
agrep -0 -c 'CTTTTCGCCCCTGACAA' *.fastq > count/B8929_Rm0.txt
agrep -0 -c 'GTGGTTAACATGCCCTT' *.fastq > count/B8930_Rm0.txt
agrep -0 -c 'TATCTGGAAGACGGAGA' *.fastq > count/B8932_Rm0.txt
agrep -0 -c 'ACCAACTTCCCAGAGCG' *.fastq > count/B8933_Rm0.txt
agrep -0 -c 'GACGCATGGGTTGTCAA' *.fastq > count/B8934_Rm0.txt
agrep -0 -c 'GTCATAAGCGGGTTTCG' *.fastq > count/B8935_Rm0.txt
agrep -0 -c 'AGACCGAGTTGATACAA' *.fastq > count/B8938_Rm0.txt
agrep -0 -c 'CGGTTTATCTGAGCTAC' *.fastq > count/B8939_Rm0.txt
agrep -0 -c 'TTCCGTCACTGACTCAG' *.fastq > count/B8940_Rm0.txt
agrep -0 -c 'GAGCGACCTAAAATCGA' *.fastq > count/B8941_Rm0.txt
agrep -0 -c 'GGCTCAAAGACCCTACG' *.fastq > count/B8943_Rm0.txt
agrep -0 -c 'AATGGATCACAGCTCAC' *.fastq > count/B8944_Rm0.txt
agrep -0 -c 'CAAACCGATCGTGTTCC' *.fastq > count/B8945_Rm0.txt
agrep -0 -c 'GCCGTAATATGCCGTCT' *.fastq > count/B8946_Rm0.txt
agrep -0 -c 'AAAGGACAGAACTCGCC' *.fastq > count/B8947_Rm0.txt
agrep -0 -c 'GACGGTCTAGGAAACGG' *.fastq > count/B8948_Rm0.txt
agrep -0 -c 'ACATGTATGACGGCATA' *.fastq > count/B8949_Rm0.txt
agrep -0 -c 'TATAGGAACAAGGCAGC' *.fastq > count/B8950_Rm0.txt
agrep -0 -c 'CCTAATGGTTCCGGCAC' *.fastq > count/B8951_Rm0.txt
agrep -0 -c 'TATTGAGCGAGGGGGGT' *.fastq > count/B8952_Rm0.txt
agrep -0 -c 'TGGGCGCAGAGTAGATG' *.fastq > count/B8953_Rm0.txt
agrep -0 -c 'GTTGAGGCTCAGCTATA' *.fastq > count/B8954_Rm0.txt
agrep -0 -c 'GTGAAGACGATAGTTGC' *.fastq > count/B8956_Rm0.txt
agrep -0 -c 'TGCCCTGTACCACATAA' *.fastq > count/B8957_Rm0.txt
agrep -0 -c 'GCAAAAACGCTCTCTGG' *.fastq > count/B8958_Rm0.txt
agrep -0 -c 'AGCCTTAACGAGGGAGA' *.fastq > count/B8959_Rm0.txt
agrep -0 -c 'CAGTCCCGACTAGCGTT' *.fastq > count/B8960_Rm0.txt
agrep -0 -c 'CATCACACTAGACTTAC' *.fastq > count/B8961_Rm0.txt
agrep -0 -c 'TCTTACGTTTGGTTACC' *.fastq > count/B8962_Rm0.txt
agrep -0 -c 'ACAGAGTTAATCACCCT' *.fastq > count/B8963_Rm0.txt
agrep -0 -c 'TCACTGAGGACCCAAAT' *.fastq > count/B8964_Rm0.txt
agrep -0 -c 'CATAGCGCAATCAGACA' *.fastq > count/B8965_Rm0.txt
agrep -0 -c 'TGGATACACACCAGTAG' *.fastq > count/B8966_Rm0.txt
agrep -0 -c 'CACCCGATAAGGTGACC' *.fastq > count/B8967_Rm0.txt
agrep -0 -c 'ATTTGACTGCGGCATCT' *.fastq > count/B8968_Rm0.txt
agrep -0 -c 'AAGCTCTCTGAGTTACG' *.fastq > count/B8969_Rm0.txt
agrep -0 -c 'GAACACGGGGTCGTATA' *.fastq > count/B8970_Rm0.txt
agrep -0 -c 'TGATCAATGTGTGCTCG' *.fastq > count/B8971_Rm0.txt
agrep -0 -c 'CCCTGAAAACCGTATGT' *.fastq > count/B8972_Rm0.txt
agrep -0 -c 'CGTGCCAAAAGACGTCG' *.fastq > count/B8973_Rm0.txt
agrep -0 -c 'CGCCAAGCTTACGTGTG' *.fastq > count/B8974_Rm0.txt
agrep -0 -c 'TATCAGAGCTACCGTAC' *.fastq > count/B8975_Rm0.txt
agrep -0 -c 'CGGCCGCAGACAAAAAC' *.fastq > count/B8976_Rm0.txt
agrep -0 -c 'CTACTACGGGATCGACT' *.fastq > count/B8977_Rm0.txt
agrep -0 -c 'GTTTATCACACACGCCC' *.fastq > count/B8978_Rm0.txt
agrep -0 -c 'CGCTTCCCTAAGCTAGA' *.fastq > count/B8979_Rm0.txt
agrep -0 -c 'TGGGTTGACCCTTAGAT' *.fastq > count/B8980_Rm0.txt
agrep -0 -c 'CCAATCGCCCCTATTCA' *.fastq > count/B8981_Rm0.txt
agrep -0 -c 'ACTAGATCGAAGTAAGC' *.fastq > count/B8982_Rm0.txt
agrep -0 -c 'CAACTCTGTCAGCAGTC' *.fastq > count/B8983_Rm0.txt
agrep -0 -c 'CTCTGTTAAACGTGCCA' *.fastq > count/B8984_Rm0.txt
agrep -0 -c 'TCTGCATCGGTAAGAGT' *.fastq > count/B8985_Rm0.txt
agrep -0 -c 'ATCCAGGTACACATCTA' *.fastq > count/B8986_Rm0.txt
agrep -0 -c 'TGGCCCACATAACCACG' *.fastq > count/B8987_Rm0.txt
agrep -0 -c 'AATGCGAGTTCCGACCC' *.fastq > count/B8988_Rm0.txt
agrep -0 -c 'TCCTACGCATCACCATC' *.fastq > count/B8989_Rm0.txt
agrep -0 -c 'ACGGCCAAACATTGTGA' *.fastq > count/B8992_Rm0.txt
agrep -0 -c 'GTTCCGGTTTGTGTCAT' *.fastq > count/B8993_Rm0.txt
agrep -0 -c 'CGCCTGACTGAGTGACT' *.fastq > count/B8994_Rm0.txt
agrep -0 -c 'TCCAATACCAGCTAAGG' *.fastq > count/B8995_Rm0.txt
agrep -0 -c 'CACTTAGTACGTACGCT' *.fastq > count/B8996_Rm0.txt
agrep -0 -c 'ATCGCCTCCACCTAAGA' *.fastq > count/B8997_Rm0.txt
agrep -0 -c 'CCTGCCTAGCATGGTCT' *.fastq > count/B8998_Rm0.txt
agrep -0 -c 'TACCGCGAAACGAACTT' *.fastq > count/B9000_Rm0.txt
agrep -0 -c 'GAACTGTGTGCGGTTTG' *.fastq > count/B9001_Rm0.txt
agrep -0 -c 'TCCTCACTAACTGAGTA' *.fastq > count/B9002_Rm0.txt
agrep -0 -c 'GGTTTTATGGGTCGGGT' *.fastq > count/B9003_Rm0.txt
agrep -0 -c 'AATCCGAATACCCCACG' *.fastq > count/B9004_Rm0.txt
agrep -0 -c 'ATATCACCCTCCTGTCC' *.fastq > count/B9005_Rm0.txt
agrep -0 -c 'AACGTGTGGACAGATGC' *.fastq > count/B9006_Rm0.txt
agrep -0 -c 'TAGGTTACATCACGCTT' *.fastq > count/B9007_Rm0.txt
agrep -0 -c 'CAAGACTGGTGGTATGG' *.fastq > count/B9009_Rm0.txt
agrep -0 -c 'CTATCCGGATGCGATGA' *.fastq > count/B9010_Rm0.txt
agrep -0 -c 'TTACAACGCGGTCGATA' *.fastq > count/B9011_Rm0.txt
agrep -0 -c 'TGAGATCAGCGTTCACG' *.fastq > count/B9012_Rm0.txt
agrep -0 -c 'ACGTAAGCCCTTGAATA' *.fastq > count/B9014_Rm0.txt
agrep -0 -c 'GCGCGATAGATTGATCG' *.fastq > count/B9015_Rm0.txt
agrep -0 -c 'TCAAGGTGTACGCCAAG' *.fastq > count/B9016_Rm0.txt
agrep -0 -c 'CTCTCTAGACAGTGGCG' *.fastq > count/B9017_Rm0.txt
agrep -0 -c 'TTGCGTCTTGTGAATGA' *.fastq > count/B9019_Rm0.txt
agrep -0 -c 'ACGCCTTAGCCAACTAC' *.fastq > count/B9020_Rm0.txt
agrep -0 -c 'AGAGACATAGGATTGGT' *.fastq > count/B9022_Rm0.txt
agrep -0 -c 'TAACAAAGTAGGTGACC' *.fastq > count/B9023_Rm0.txt
agrep -0 -c 'TGCTTTGAACGGATAGG' *.fastq > count/B9024_Rm0.txt
agrep -0 -c 'TCTAACGCTTCCCACCT' *.fastq > count/B9025_Rm0.txt
agrep -0 -c 'CTACAATAGTCAGACGT' *.fastq > count/B9026_Rm0.txt
agrep -0 -c 'GTGCGTTACCTCTGGAG' *.fastq > count/B9028_Rm0.txt
agrep -0 -c 'GCTTAACGAGTCTAGTA' *.fastq > count/B9029_Rm0.txt
agrep -0 -c 'GGCTCTAAGCGGATCAC' *.fastq > count/B9030_Rm0.txt
agrep -0 -c 'CGTTTTGGGCGCGTATG' *.fastq > count/B9031_Rm0.txt
agrep -0 -c 'TGATATTCCATTCCACG' *.fastq > count/B9032_Rm0.txt
agrep -0 -c 'AACGTTTGACCATCCTC' *.fastq > count/B9033_Rm0.txt
agrep -0 -c 'CTCCTTGCCCTAGAGAG' *.fastq > count/B9034_Rm0.txt
agrep -0 -c 'CTTAGCCGACTCAGCCA' *.fastq > count/B9035_Rm0.txt
agrep -0 -c 'TCGAGCTGTCGGTTGTC' *.fastq > count/B9036_Rm0.txt
agrep -0 -c 'GGGGGACTTCACGTTTG' *.fastq > count/B9037_Rm0.txt
agrep -0 -c 'TCCCGCAAGGATACGTG' *.fastq > count/B9039_Rm0.txt
agrep -0 -c 'CATGATCTCCGCCTCTT' *.fastq > count/B9040_Rm0.txt
agrep -0 -c 'CACAAACAAGCGGGCTA' *.fastq > count/B9041_Rm0.txt
agrep -0 -c 'CCGATTCGTCGACCTGT' *.fastq > count/B9042_Rm0.txt
agrep -0 -c 'TCGAGGAAGCATCAATG' *.fastq > count/B9043_Rm0.txt
agrep -0 -c 'GGTCGCGCTTACTCAGA' *.fastq > count/B9044_Rm0.txt
agrep -0 -c 'TGTCGTGCTCCAATCGA' *.fastq > count/B9045_Rm0.txt
agrep -0 -c 'CCCCGGGAATGTAATTA' *.fastq > count/B9047_Rm0.txt
agrep -0 -c 'AGTATGAATAGGGGTGC' *.fastq > count/B9048_Rm0.txt
agrep -0 -c 'ATGGCCTACTGAAGATT' *.fastq > count/B9049_Rm0.txt
agrep -0 -c 'AACGGCTCCATTCGTAC' *.fastq > count/B9050_Rm0.txt
agrep -0 -c 'ATCTACTAAAGTCCGCG' *.fastq > count/B9051_Rm0.txt
agrep -0 -c 'ATGTCCGAAATCTGTAC' *.fastq > count/B9052_Rm0.txt
agrep -0 -c 'ACCTTGTTGTGGGGCAT' *.fastq > count/B9053_Rm0.txt
agrep -0 -c 'GTGCACTACAAGATATG' *.fastq > count/B9056_Rm0.txt
agrep -0 -c 'AGTAGACCCACAGATAG' *.fastq > count/B9058_Rm0.txt
agrep -0 -c 'TGCGAGCCAAATTGGTG' *.fastq > count/B9059_Rm0.txt
agrep -0 -c 'ACCACGCGCTAATGAGC' *.fastq > count/B9060_Rm0.txt
agrep -0 -c 'CGGAATAACGACAGACA' *.fastq > count/B9061_Rm0.txt
agrep -0 -c 'CTCAGGGCGTATCAGCA' *.fastq > count/B9062_Rm0.txt
agrep -0 -c 'TCTCATATAGAGCGACA' *.fastq > count/B9063_Rm0.txt
agrep -0 -c 'TTGGTGGTCCCGCAAAT' *.fastq > count/B9064_Rm0.txt
agrep -0 -c 'CTACCTGTAGTGTCGGT' *.fastq > count/B9065_Rm0.txt
agrep -0 -c 'CTTTCTCTGGTTACGTG' *.fastq > count/B9066_Rm0.txt
agrep -0 -c 'CATGACGATTACGTTCC' *.fastq > count/B9067_Rm0.txt
agrep -0 -c 'CTCATTAGCTGTTCCCG' *.fastq > count/B9068_Rm0.txt
agrep -0 -c 'GTTCGACCTACTTCCTT' *.fastq > count/B9069_Rm0.txt
agrep -0 -c 'CTAGCAGACGATCCACG' *.fastq > count/B9070_Rm0.txt
agrep -0 -c 'AACGTCCAGTGAACGCC' *.fastq > count/B9072_Rm0.txt
agrep -0 -c 'CGAAAAGCTAGGAGACG' *.fastq > count/B9073_Rm0.txt
agrep -0 -c 'TCAGACACGCTTAGAGT' *.fastq > count/B9074_Rm0.txt
agrep -0 -c 'AGCAACGTCATAGCGGT' *.fastq > count/B9077_Rm0.txt
agrep -0 -c 'TCCGCGCTAGGATTACT' *.fastq > count/B9078_Rm0.txt
agrep -0 -c 'TATGCATAAGACCGGCG' *.fastq > count/B9079_Rm0.txt
agrep -0 -c 'TCATAACGGCGTTGCAG' *.fastq > count/B9080_Rm0.txt
agrep -0 -c 'TAGTACCGGTTGACCGC' *.fastq > count/B9081_Rm0.txt
agrep -0 -c 'CGCACAACGTAAACCTG' *.fastq > count/B9082_Rm0.txt
agrep -0 -c 'CCCTTGCAAGCTGTTAA' *.fastq > count/B9083_Rm0.txt
agrep -0 -c 'CGTACATGTCGCGTATA' *.fastq > count/B9084_Rm0.txt
agrep -0 -c 'GATTCCCTGTTTCGTAT' *.fastq > count/B9085_Rm0.txt
agrep -0 -c 'TAAGTAGGGTTACCGTT' *.fastq > count/B9086_Rm0.txt
agrep -0 -c 'CTTTCACCTTCACCCGT' *.fastq > count/B9088_Rm0.txt
agrep -0 -c 'ACTAGTTCTGTTCCCCC' *.fastq > count/B9089_Rm0.txt
agrep -0 -c 'TCAGACGTACCACCTAC' *.fastq > count/B9090_Rm0.txt
agrep -0 -c 'CGAAGAGCAAATGCAAT' *.fastq > count/B9091_Rm0.txt
agrep -0 -c 'TGTCGGTTCCCTCCGAA' *.fastq > count/B9092_Rm0.txt
agrep -0 -c 'GCTAACCCAGACTATAC' *.fastq > count/B9093_Rm0.txt
agrep -0 -c 'AGACGTAGAGGAATCAT' *.fastq > count/B9094_Rm0.txt
agrep -0 -c 'ACCATCAAGGTGCCGAG' *.fastq > count/B9096_Rm0.txt
agrep -0 -c 'GCGCCGTTCGGCAATAT' *.fastq > count/B9097_Rm0.txt
agrep -0 -c 'CAGCCTCGAGAACTATA' *.fastq > count/B9099_Rm0.txt
agrep -0 -c 'CGGCCATAAGTTTGACC' *.fastq > count/B9102_Rm0.txt
agrep -0 -c 'GGTGTCCCGCTGTTTAT' *.fastq > count/B9103_Rm0.txt
agrep -0 -c 'GGACCAAGTTGTCAAGA' *.fastq > count/B9105_Rm0.txt
agrep -0 -c 'CTTATTTGTTGGCGAGG' *.fastq > count/B9106_Rm0.txt
agrep -0 -c 'CAACCGGCGGAATCTAC' *.fastq > count/B9107_Rm0.txt
agrep -0 -c 'TCATATCGACCTAGGCT' *.fastq > count/B9108_Rm0.txt
agrep -0 -c 'CACGCAAACGAGGAAAC' *.fastq > count/B9109_Rm0.txt
agrep -0 -c 'GGGTTAGCAAGTCCTGG' *.fastq > count/B9110_Rm0.txt
agrep -0 -c 'TCCCTAAGGCAGCTCAA' *.fastq > count/B9111_Rm0.txt
agrep -0 -c 'GGTGTCGGCGACAACTT' *.fastq > count/B9112_Rm0.txt
agrep -0 -c 'TTGCACAGTACGAAATC' *.fastq > count/B9113_Rm0.txt
agrep -0 -c 'AACGCCATGTATCGAGA' *.fastq > count/B9114_Rm0.txt
agrep -0 -c 'AGCCACATCCCACCAAG' *.fastq > count/B9116_Rm0.txt
agrep -0 -c 'TCCATGGTCGTGTTCGA' *.fastq > count/B9117_Rm0.txt
agrep -0 -c 'AAGTTGATACTGTGCGT' *.fastq > count/B9118_Rm0.txt
agrep -0 -c 'CATGGGGTTGGTTTTGC' *.fastq > count/B9119_Rm0.txt
agrep -0 -c 'ATCTAATGGCACAACAG' *.fastq > count/B9120_Rm0.txt
agrep -0 -c 'AACGCACACCATACGAA' *.fastq > count/B9121_Rm0.txt
agrep -0 -c 'TAGGGCAATGTGGACTG' *.fastq > count/B9122_Rm0.txt
agrep -0 -c 'GAGCAAAAGGTGACATC' *.fastq > count/B9123_Rm0.txt
agrep -0 -c 'CGTGTCCGAAGGTACAT' *.fastq > count/B9124_Rm0.txt
agrep -0 -c 'ATGGCCTAGGCGCGATA' *.fastq > count/B9125_Rm0.txt
agrep -0 -c 'GACAGGGTCCTACGCTT' *.fastq > count/B9126_Rm0.txt
agrep -0 -c 'GCCCATGTCTCTATAGC' *.fastq > count/B9127_Rm0.txt
agrep -0 -c 'TTGAAACCCGGCTTTGC' *.fastq > count/B9128_Rm0.txt
agrep -0 -c 'AGGGTGTAACTGACGCT' *.fastq > count/B9129_Rm0.txt
agrep -0 -c 'GACAGATCCGAATGCTT' *.fastq > count/B9131_Rm0.txt
agrep -0 -c 'ACCGCAATGAACGAAGG' *.fastq > count/B9132_Rm0.txt
agrep -0 -c 'CTAATTGTGTCGTATCC' *.fastq > count/B9134_Rm0.txt
agrep -0 -c 'AAGATGTCCTGTCCATA' *.fastq > count/B9135_Rm0.txt
agrep -0 -c 'CCATCTCAGAACAGAAT' *.fastq > count/B9137_Rm0.txt
agrep -0 -c 'TCCTTGCGGTTTGGCAG' *.fastq > count/B9138_Rm0.txt
agrep -0 -c 'CGTGACTTTCTGCAGCA' *.fastq > count/B9139_Rm0.txt
agrep -0 -c 'GGTTCTACGGACTGTCT' *.fastq > count/B9140_Rm0.txt
agrep -0 -c 'ACAAGACAACTCGGGCT' *.fastq > count/B9141_Rm0.txt
agrep -0 -c 'CTTCGAAACCGCTTGAC' *.fastq > count/B9142_Rm0.txt
agrep -0 -c 'ATCCGTTAGCCACCAGT' *.fastq > count/B9144_Rm0.txt
agrep -0 -c 'CGTCGACATGTTACAGT' *.fastq > count/B9145_Rm0.txt
agrep -0 -c 'TCCTTCCCGGATGAAGT' *.fastq > count/B9146_Rm0.txt
agrep -0 -c 'CTGGCCGGCAGTTTACT' *.fastq > count/B9147_Rm0.txt
agrep -0 -c 'AATGTTCTGACGGGCTT' *.fastq > count/B9148_Rm0.txt
agrep -0 -c 'TCCCCAGATGTCTGATG' *.fastq > count/B9149_Rm0.txt
agrep -0 -c 'TAAGAACGTGTGGGGGT' *.fastq > count/B9150_Rm0.txt
agrep -0 -c 'GGTAGCTACATCCACAA' *.fastq > count/B9151_Rm0.txt
agrep -0 -c 'GCCCGACTAGTAAAGAG' *.fastq > count/B9152_Rm0.txt
agrep -0 -c 'AAGGCATCTGACCGTGC' *.fastq > count/B9153_Rm0.txt
agrep -0 -c 'TTAAGTCGTTCCTTTCG' *.fastq > count/B9154_Rm0.txt
agrep -0 -c 'GATACACTGACCAAGCC' *.fastq > count/B9156_Rm0.txt
agrep -0 -c 'AACTACGCCAACAAATC' *.fastq > count/B9157_Rm0.txt
agrep -0 -c 'GACAGAAGACAATACAC' *.fastq > count/B9159_Rm0.txt
agrep -0 -c 'CCGACTAAGTCCTGCAT' *.fastq > count/B9160_Rm0.txt
agrep -0 -c 'GGTAGATCCATCTAACC' *.fastq > count/B9161_Rm0.txt
agrep -0 -c 'GACTTCGTTGCATAAAC' *.fastq > count/B9162_Rm0.txt
agrep -0 -c 'AGAGCAATTAGGGCGTA' *.fastq > count/B9163_Rm0.txt
agrep -0 -c 'AAGGGCGGATACAACCC' *.fastq > count/B9165_Rm0.txt
agrep -0 -c 'AAGGTCGACTAACAGCT' *.fastq > count/B9166_Rm0.txt
agrep -0 -c 'GCACCAGTACAGAACCT' *.fastq > count/B9167_Rm0.txt
agrep -0 -c 'CATAGTAGTGTTCGACC' *.fastq > count/B9168_Rm0.txt
agrep -0 -c 'GGTGGTTGATAGCCTTA' *.fastq > count/B9169_Rm0.txt
agrep -0 -c 'CTATAAAGCCTCCGGTA' *.fastq > count/B9170_Rm0.txt
agrep -0 -c 'TCGGACGTTTCACCGTA' *.fastq > count/B9171_Rm0.txt
agrep -0 -c 'GTTTCAGTCGGGTTAGT' *.fastq > count/B9172_Rm0.txt
agrep -0 -c 'AGCGCCCACAGTAGATT' *.fastq > count/B9173_Rm0.txt
agrep -0 -c 'ACGCAGGTCCTATGAGG' *.fastq > count/B9174_Rm0.txt
agrep -0 -c 'CCCTTTGGTCAATACGT' *.fastq > count/B9176_Rm0.txt
agrep -0 -c 'GACTCCTCATACCGCTA' *.fastq > count/B9177_Rm0.txt
agrep -0 -c 'ACCTAGGGTAGTACTAA' *.fastq > count/B9178_Rm0.txt
agrep -0 -c 'AGAGCTGGCGTATTATC' *.fastq > count/B9179_Rm0.txt
agrep -0 -c 'TCTCAAACCCAAAAGTG' *.fastq > count/B9180_Rm0.txt
agrep -0 -c 'GCGTTTTTTCTAGTTGC' *.fastq > count/B9181_Rm0.txt
agrep -0 -c 'TTCACTATCGGAAGACG' *.fastq > count/B9183_Rm0.txt
agrep -0 -c 'ACGCCGTAAGCTGTGAT' *.fastq > count/B9184_Rm0.txt
agrep -0 -c 'CAGTTGTTTGACAGACT' *.fastq > count/B9186_Rm0.txt
agrep -0 -c 'TGGCACTTTTTGAGTGA' *.fastq > count/B9187_Rm0.txt
agrep -0 -c 'GCGTATCCTTCAGTTAC' *.fastq > count/B9188_Rm0.txt
agrep -0 -c 'CCGAACACCGCTGCTAA' *.fastq > count/B9190_Rm0.txt
agrep -0 -c 'ATCTCTGAGCCGGTCGT' *.fastq > count/B9191_Rm0.txt
agrep -0 -c 'AATAAAGCCTGGGCGCG' *.fastq > count/B9194_Rm0.txt
agrep -0 -c 'ACGCGCTATCGACGCAT' *.fastq > count/B9196_Rm0.txt
agrep -0 -c 'TATTGCAGTTGTATCCG' *.fastq > count/B9197_Rm0.txt
agrep -0 -c 'GTCCTGCTACATCAGTA' *.fastq > count/B9199_Rm0.txt
agrep -0 -c 'CGCATTCTCGAGACTTG' *.fastq > count/B9200_Rm0.txt
agrep -0 -c 'AGACCGGGTCCTAAGAG' *.fastq > count/B9201_Rm0.txt
agrep -0 -c 'ACTCCGGACCTACGATG' *.fastq > count/B9202_Rm0.txt
agrep -0 -c 'ATTGCTGTCATAGCCCT' *.fastq > count/B9203_Rm0.txt
agrep -0 -c 'TTGAACCTGCACGCTGA' *.fastq > count/B9204_Rm0.txt
agrep -0 -c 'TAGATTAACGTCGGGTG' *.fastq > count/B9205_Rm0.txt
agrep -0 -c 'GTATAACAATCCGGTAC' *.fastq > count/B9206_Rm0.txt
agrep -0 -c 'CCGCCTCCCATAGTTCT' *.fastq > count/B9207_Rm0.txt
agrep -0 -c 'TCAGATTTCGCGGACAC' *.fastq > count/B9208_Rm0.txt
agrep -0 -c 'CTGGATATGGATCAACC' *.fastq > count/B9209_Rm0.txt
agrep -0 -c 'AGGTCAGACTGTGTGCG' *.fastq > count/B9210_Rm0.txt
agrep -0 -c 'TAGGCTACCTAGAGCGC' *.fastq > count/B9212_Rm0.txt
agrep -0 -c 'CTTCTGGCTTTAGAACC' *.fastq > count/B9213_Rm0.txt
agrep -0 -c 'CATCCACCGAGCGAGAA' *.fastq > count/B9214_Rm0.txt
agrep -0 -c 'GGGTCTACGTCACAGCA' *.fastq > count/B9216_Rm0.txt
agrep -0 -c 'TTTTGCCTTAATAGGGC' *.fastq > count/B9217_Rm0.txt
agrep -0 -c 'CTCTTAGCGTCCGGTCT' *.fastq > count/B9218_Rm0.txt
agrep -0 -c 'CCTGCAATCATAATGGT' *.fastq > count/B9219_Rm0.txt
agrep -0 -c 'TCACCTGGCCGTCAGAA' *.fastq > count/B9220_Rm0.txt
agrep -0 -c 'GGCCGGACTTTACACAA' *.fastq > count/B9221_Rm0.txt
agrep -0 -c 'CGGAAGAAATTACGCAC' *.fastq > count/B9223_Rm0.txt
agrep -0 -c 'GATAGTGCTCTCGACCT' *.fastq > count/B9225_Rm0.txt
agrep -0 -c 'GCGGTCTCCGCACTAAT' *.fastq > count/B9227_Rm0.txt
agrep -0 -c 'GTTCACCGTGTTCTACG' *.fastq > count/B9228_Rm0.txt
agrep -0 -c 'AGTTCAGTATCCTGGTC' *.fastq > count/B9229_Rm0.txt
agrep -0 -c 'GGCAACACAGCTAACAT' *.fastq > count/B9230_Rm0.txt
agrep -0 -c 'GTCGGCTGTTTGTTGCA' *.fastq > count/B9231_Rm0.txt
agrep -0 -c 'GGCATTTAGGCCTTGCT' *.fastq > count/B9233_Rm0.txt
agrep -0 -c 'ATCAGTACAGAGGAAGG' *.fastq > count/B9234_Rm0.txt
agrep -0 -c 'GAGTTTCACGGTGGCCA' *.fastq > count/B9235_Rm0.txt
agrep -0 -c 'CTTGCGGAAGTACCCGT' *.fastq > count/B9236_Rm0.txt
agrep -0 -c 'GTGGGTGTCTCCTGCAA' *.fastq > count/B9237_Rm0.txt
agrep -0 -c 'GCACTACCCACATAATA' *.fastq > count/B9238_Rm0.txt
agrep -0 -c 'ATCGTGCCCCATAGAAT' *.fastq > count/B9239_Rm0.txt
agrep -0 -c 'TTTTAAGACGTTCACCG' *.fastq > count/B9240_Rm0.txt
agrep -0 -c 'GACGCTGGGTGCTTTTG' *.fastq > count/B9241_Rm0.txt
agrep -0 -c 'TTGGACCACGTACTGCG' *.fastq > count/B9242_Rm0.txt
agrep -0 -c 'AGTGGGTACCACCGATA' *.fastq > count/B9244_Rm0.txt
agrep -0 -c 'AATTGTGATGGCTGATC' *.fastq > count/B9246_Rm0.txt
agrep -0 -c 'GTCTTAATCGGCGTTCG' *.fastq > count/B9247_Rm0.txt
agrep -0 -c 'GTGCAGTCTATATACCT' *.fastq > count/B9248_Rm0.txt
agrep -0 -c 'CACTCATTCCAACGGCC' *.fastq > count/B9249_Rm0.txt
agrep -0 -c 'GCTTTCGTTCATTTCGT' *.fastq > count/B9250_Rm0.txt
agrep -0 -c 'AGCCAGACCGGATAGTT' *.fastq > count/B9251_Rm0.txt
agrep -0 -c 'GGTCCGTGGTAGATTAG' *.fastq > count/B9252_Rm0.txt
agrep -0 -c 'CCCATGCCTCAGATATG' *.fastq > count/B9253_Rm0.txt
agrep -0 -c 'AGTGTCCCGCCAATGAC' *.fastq > count/B9254_Rm0.txt
agrep -0 -c 'CTTGTTTAGCCGGACAC' *.fastq > count/B9255_Rm0.txt
agrep -0 -c 'GTTGCAACGGTCGTCGA' *.fastq > count/B9256_Rm0.txt
agrep -0 -c 'CTGGGACCTGCCTTATT' *.fastq > count/B9257_Rm0.txt
agrep -0 -c 'TAAGTGCCCTGGCTTGG' *.fastq > count/B9258_Rm0.txt
agrep -0 -c 'CCCCTGCCTGTCGTATA' *.fastq > count/B9260_Rm0.txt
agrep -0 -c 'CAGCAGACTCATGAGGC' *.fastq > count/B9261_Rm0.txt
agrep -0 -c 'TGTTGGAGCGAAAAAAC' *.fastq > count/B9262_Rm0.txt
agrep -0 -c 'ATCAGCGGAGAAGGAAG' *.fastq > count/B9263_Rm0.txt
agrep -0 -c 'CACCTTCCATGTTTGTA' *.fastq > count/B9265_Rm0.txt
agrep -0 -c 'AGAGGTCTATGCCGATA' *.fastq > count/B9266_Rm0.txt
agrep -0 -c 'ATCGTGCCTTGGAGCGT' *.fastq > count/B9267_Rm0.txt
agrep -0 -c 'GTGCCTGAAGTGGTATT' *.fastq > count/B9268_Rm0.txt
agrep -0 -c 'TGTAAAACGTCCGCCAC' *.fastq > count/B9269_Rm0.txt
agrep -0 -c 'CCGAAAACGAGATTGCT' *.fastq > count/B9271_Rm0.txt
agrep -0 -c 'AGTCGGGAACAAAACTC' *.fastq > count/B9272_Rm0.txt
agrep -0 -c 'GGTTGAGCGTCAGAGGT' *.fastq > count/B9273_Rm0.txt
agrep -0 -c 'TTCTCCGCAGTAATCCG' *.fastq > count/B9274_Rm0.txt
agrep -0 -c 'CGCTCACGTAAATAACG' *.fastq > count/B9275_Rm0.txt
agrep -0 -c 'ACCTGATGTGCGCAGTA' *.fastq > count/B9276_Rm0.txt
agrep -0 -c 'AAGGATTGTGCGATAGT' *.fastq > count/B9277_Rm0.txt
agrep -0 -c 'TCCCGCCAAACCTAGTC' *.fastq > count/B9278_Rm0.txt
agrep -0 -c 'GTGCGATGATCGATCTG' *.fastq > count/B9281_Rm0.txt
agrep -0 -c 'AAGTAGACTGCGCGTGA' *.fastq > count/B9282_Rm0.txt
agrep -0 -c 'GACCTATAAGAGGATCC' *.fastq > count/B9283_Rm0.txt
agrep -0 -c 'TTACTCAGGTAGTCGGC' *.fastq > count/B9284_Rm0.txt
agrep -0 -c 'TATGCAAACTTCGTGAC' *.fastq > count/B9285_Rm0.txt
agrep -0 -c 'CGACTTAGGTGGTTACG' *.fastq > count/B9286_Rm0.txt
agrep -0 -c 'ACATATCTACCGCGTCT' *.fastq > count/B9287_Rm0.txt
agrep -0 -c 'AAAGCCACGCATGTCCG' *.fastq > count/B9288_Rm0.txt
agrep -0 -c 'GCAATTTAGGTCAGTCG' *.fastq > count/B9289_Rm0.txt
agrep -0 -c 'TCGGAAAGGCGTCCATT' *.fastq > count/B9290_Rm0.txt
agrep -0 -c 'TATCCGGTTACAATCGG' *.fastq > count/B9291_Rm0.txt
agrep -0 -c 'AGTACGCTCCAAGTAGA' *.fastq > count/B9292_Rm0.txt
agrep -0 -c 'ACCTATTGGATACGCTG' *.fastq > count/B9293_Rm0.txt
agrep -0 -c 'ACGGCCAATTTATGCTC' *.fastq > count/B9294_Rm0.txt
agrep -0 -c 'TACGACACAGGTCCATG' *.fastq > count/B9297_Rm0.txt
agrep -0 -c 'AATATCGTTGACGCTAG' *.fastq > count/B9298_Rm0.txt
agrep -0 -c 'AACGCGTAGCGCATGAC' *.fastq > count/B9300_Rm0.txt
agrep -0 -c 'CCCTCTGTAATCAGCGC' *.fastq > count/B9301_Rm0.txt
agrep -0 -c 'CAGAGGCGAATGTGATG' *.fastq > count/B9302_Rm0.txt
agrep -0 -c 'ACAAAATGCGGAGAGAG' *.fastq > count/B9303_Rm0.txt
agrep -0 -c 'CTCGCTGTTCTATGCCC' *.fastq > count/B9304_Rm0.txt
agrep -0 -c 'GTCCATCGAACTGCTCT' *.fastq > count/B9305_Rm0.txt
agrep -0 -c 'AATGATACCGCTGAACT' *.fastq > count/B9307_Rm0.txt
agrep -0 -c 'CACGCTGCGTCTATATC' *.fastq > count/B9308_Rm0.txt
agrep -0 -c 'TTGCATTATTAGTCGCG' *.fastq > count/B9309_Rm0.txt
agrep -0 -c 'GAGTTCCGCACACTTAC' *.fastq > count/B9310_Rm0.txt
agrep -0 -c 'GGTGTGGTAACCGAACC' *.fastq > count/B9311_Rm0.txt
agrep -0 -c 'GCGACGAACGCTTAGTG' *.fastq > count/B9312_Rm0.txt
agrep -0 -c 'CACCATCATGGTTTTCT' *.fastq > count/B9314_Rm0.txt
agrep -0 -c 'ATCTGAGGCACTATCGC' *.fastq > count/B9315_Rm0.txt
agrep -0 -c 'AGCGTGGTAAGTGTACT' *.fastq > count/B9316_Rm0.txt
agrep -0 -c 'TCTTAGGGGAGACTACG' *.fastq > count/B9318_Rm0.txt
agrep -0 -c 'TCGGGCTATACTGGCGT' *.fastq > count/B9319_Rm0.txt
agrep -0 -c 'TATGGGTATTCTAGCCC' *.fastq > count/B9320_Rm0.txt
agrep -0 -c 'GTCTTATCTCTCCGGGT' *.fastq > count/B9322_Rm0.txt
agrep -0 -c 'TTGGCCTTTTCGATTAG' *.fastq > count/B9323_Rm0.txt
agrep -0 -c 'CGGAACGCCAATTGATT' *.fastq > count/B9324_Rm0.txt
agrep -0 -c 'TAACTCCACTATGTGAC' *.fastq > count/B9326_Rm0.txt
agrep -0 -c 'ACGTTCTGTTCCGTTAC' *.fastq > count/B9327_Rm0.txt
agrep -0 -c 'CGTCTGGGACAATGCTC' *.fastq > count/B9329_Rm0.txt
agrep -0 -c 'TCATCAGAAGTTTCTGG' *.fastq > count/B9330_Rm0.txt
agrep -0 -c 'TCTGCGGCTACCAAGAT' *.fastq > count/B9331_Rm0.txt
agrep -0 -c 'GGGTATTGCGTATCGTC' *.fastq > count/B9332_Rm0.txt
agrep -0 -c 'TGTCGCGGTACAACCCT' *.fastq > count/B9333_Rm0.txt
agrep -0 -c 'TCTGCACGAAGCAACGA' *.fastq > count/B9334_Rm0.txt
agrep -0 -c 'AGTGCTATATATTGGGC' *.fastq > count/B9335_Rm0.txt
agrep -0 -c 'TCGCTAGGCATGCTTCA' *.fastq > count/B9336_Rm0.txt
agrep -0 -c 'TCAGCACCCCTTTCTAT' *.fastq > count/B9339_Rm0.txt
agrep -0 -c 'GTTTACGTGCGGCTCTG' *.fastq > count/B9340_Rm0.txt
agrep -0 -c 'AGCTGGGTGCAGTTACG' *.fastq > count/B9342_Rm0.txt
agrep -0 -c 'GAGGATATCCAGCTCTA' *.fastq > count/B9344_Rm0.txt
agrep -0 -c 'CGTGCTTATCAGCGTCT' *.fastq > count/B9345_Rm0.txt
agrep -0 -c 'GTGCCGTGAAACCATTG' *.fastq > count/B9347_Rm0.txt
agrep -0 -c 'TTATATCTGTGGTGCAC' *.fastq > count/B9348_Rm0.txt
agrep -0 -c 'CCCAACGGCTTACCAAT' *.fastq > count/B9350_Rm0.txt
agrep -0 -c 'GATCTTGTCACGAAAGT' *.fastq > count/B9351_Rm0.txt
agrep -0 -c 'CAATCACTTCCTATGCG' *.fastq > count/B9352_Rm0.txt
agrep -0 -c 'AAGAGACAGGAAGGTTA' *.fastq > count/B9353_Rm0.txt
agrep -0 -c 'TCGTGCGTGGAGATTAT' *.fastq > count/B9354_Rm0.txt
agrep -0 -c 'ACTTCGGCGGCTCTAAC' *.fastq > count/B9355_Rm0.txt
agrep -0 -c 'ACAACCCTTACACCCTA' *.fastq > count/B9357_Rm0.txt
agrep -0 -c 'CGGAGCTTCACTTGGAC' *.fastq > count/B9359_Rm0.txt
agrep -0 -c 'CTAAATTCCACCGCCTA' *.fastq > count/B9361_Rm0.txt
agrep -0 -c 'ATGACGTGTCTATATGC' *.fastq > count/B9362_Rm0.txt
agrep -0 -c 'TTCGGGGAGCCTTGATT' *.fastq > count/B9363_Rm0.txt
agrep -0 -c 'CATAGTACGTTGGTCCC' *.fastq > count/B9365_Rm0.txt
agrep -0 -c 'GACACTAGTTGCTTACA' *.fastq > count/B9367_Rm0.txt
agrep -0 -c 'CTAGTCGTATGCCCTAA' *.fastq > count/B9369_Rm0.txt
agrep -0 -c 'CTGTAAACCAGTCGCCT' *.fastq > count/B9370_Rm0.txt
agrep -0 -c 'ACGCTAAGACTATCGGC' *.fastq > count/B9371_Rm0.txt
agrep -0 -c 'ATTCCCCCACGAAATTG' *.fastq > count/B9372_Rm0.txt
agrep -0 -c 'TAACCGACTTATCAAGG' *.fastq > count/B9373_Rm0.txt
agrep -0 -c 'TCCCCACATGCCAATAG' *.fastq > count/B9375_Rm0.txt
agrep -0 -c 'AGTGTGCTAGGCTGGAT' *.fastq > count/B9376_Rm0.txt
agrep -0 -c 'CGTGTGTTATGGTAATC' *.fastq > count/B9377_Rm0.txt
agrep -0 -c 'GAAGGTATTGACGGCTG' *.fastq > count/B9379_Rm0.txt
agrep -0 -c 'AGAGTGCGTGTGCTGCT' *.fastq > count/B9380_Rm0.txt
agrep -0 -c 'ATCCTAAACCCTCCCAC' *.fastq > count/B9381_Rm0.txt
agrep -0 -c 'CTGTCAACTGGTTACAC' *.fastq > count/B9382_Rm0.txt
agrep -0 -c 'TCTGCAAGTTGGCCTTG' *.fastq > count/B9383_Rm0.txt
agrep -0 -c 'AGCGTCAACTGTAGGAA' *.fastq > count/B9384_Rm0.txt
agrep -0 -c 'ACTCTCCACTTGACAAC' *.fastq > count/B9385_Rm0.txt
agrep -0 -c 'AACTGCCGCGATACAAT' *.fastq > count/B9386_Rm0.txt
agrep -0 -c 'TTAGGTGTTCCCCCGAT' *.fastq > count/B9387_Rm0.txt
agrep -0 -c 'CTAATAGTGTGTCCGGC' *.fastq > count/B9389_Rm0.txt
agrep -0 -c 'TTCTTAACAGTCTACGG' *.fastq > count/B9390_Rm0.txt
agrep -0 -c 'GTGCTCATTCGGTGTCG' *.fastq > count/B9392_Rm0.txt
agrep -0 -c 'TAGTATGAGGGTTGCAC' *.fastq > count/B9393_Rm0.txt
agrep -0 -c 'TCATCAGAGGATAAGGT' *.fastq > count/B9394_Rm0.txt
agrep -0 -c 'TTGAGGAAGATAGGTAG' *.fastq > count/B9395_Rm0.txt
agrep -0 -c 'ATGCCAAAGTACTGGGC' *.fastq > count/B9396_Rm0.txt
agrep -0 -c 'ACAGTGTCTCTTCGATA' *.fastq > count/B9397_Rm0.txt
agrep -0 -c 'ACTTGTCGTTACACGCA' *.fastq > count/B9400_Rm0.txt
agrep -0 -c 'ACATTTGGGCTCCATAC' *.fastq > count/B9401_Rm0.txt
agrep -0 -c 'CTGCACATTGATGACAC' *.fastq > count/B9402_Rm0.txt
agrep -0 -c 'CGGCTATCTTAGCAATA' *.fastq > count/B9405_Rm0.txt
agrep -0 -c 'GTAGATATCAATCTCCG' *.fastq > count/B9406_Rm0.txt
agrep -0 -c 'ACTCCTACGCGGGTAAG' *.fastq > count/B9408_Rm0.txt
agrep -0 -c 'AAACCCCTCTCCCAATA' *.fastq > count/B9409_Rm0.txt
agrep -0 -c 'TTGTGGTTGTTCCCATC' *.fastq > count/B9410_Rm0.txt
agrep -0 -c 'CCACGGAATGGTCACGT' *.fastq > count/B9411_Rm0.txt
agrep -0 -c 'TCAGTCCAGAGCGTCAA' *.fastq > count/B9412_Rm0.txt
agrep -0 -c 'GAAGTCCAATTTAGCTG' *.fastq > count/B9413_Rm0.txt
agrep -0 -c 'TGGGGCCACCGATTTTA' *.fastq > count/B9414_Rm0.txt
agrep -0 -c 'GTCACCAGTCAAAAGCC' *.fastq > count/B9415_Rm0.txt
agrep -0 -c 'GCCGGATAAGGTATCGT' *.fastq > count/B9418_Rm0.txt
agrep -0 -c 'CCACCTACGCCAATCAA' *.fastq > count/B9420_Rm0.txt
agrep -0 -c 'TAGCAAAGGATGAGTCG' *.fastq > count/B9421_Rm0.txt
agrep -0 -c 'TCAAAGCCCGGACAGTC' *.fastq > count/B9422_Rm0.txt
agrep -0 -c 'GCACCGACAACACACTT' *.fastq > count/B9424_Rm0.txt
agrep -0 -c 'TTACTCCCGCTGAACCT' *.fastq > count/B9426_Rm0.txt
agrep -0 -c 'CCGAAAAGACACCTCTG' *.fastq > count/B9428_Rm0.txt
agrep -0 -c 'CTACAGACGTTTGCGGT' *.fastq > count/B9429_Rm0.txt
agrep -0 -c 'AGGTGTACTGCCAGTCG' *.fastq > count/B9430_Rm0.txt
agrep -0 -c 'GTAGGCATTGTCCGAGC' *.fastq > count/B9431_Rm0.txt
agrep -0 -c 'TCGCACGCGAATCTAGC' *.fastq > count/B9433_Rm0.txt
agrep -0 -c 'GAGGGTTTCTCCTGCTA' *.fastq > count/B9434_Rm0.txt
agrep -0 -c 'GGTTTGAGATACTGACG' *.fastq > count/B9435_Rm0.txt
agrep -0 -c 'TTGAGTTAAAGGCGAAG' *.fastq > count/B9436_Rm0.txt
agrep -0 -c 'TTGCCCTCGGATAATGC' *.fastq > count/B9437_Rm0.txt
agrep -0 -c 'AGGATAGCGTACAGCGG' *.fastq > count/B9438_Rm0.txt
agrep -0 -c 'CTTTTCACGTCCATTCG' *.fastq > count/B9440_Rm0.txt
agrep -0 -c 'GAAGCATAAGCTGTAGC' *.fastq > count/B9441_Rm0.txt
agrep -0 -c 'GGTCGTCGCAAACCGTT' *.fastq > count/B9442_Rm0.txt
agrep -0 -c 'GATCATCGGAGCATGAC' *.fastq > count/B9443_Rm0.txt
agrep -0 -c 'CAACCGATACGGTCTAG' *.fastq > count/B9444_Rm0.txt
agrep -0 -c 'TAGCGTATTCTCACTAC' *.fastq > count/B9445_Rm0.txt
agrep -0 -c 'CCTGCCGCTTATAGTGT' *.fastq > count/B9446_Rm0.txt
agrep -0 -c 'TTCGCATGTGCGTTACA' *.fastq > count/B9447_Rm0.txt
agrep -0 -c 'CTTAAGGCGGGATTGCC' *.fastq > count/B9448_Rm0.txt
agrep -0 -c 'GATCCTTGCATGTGGCT' *.fastq > count/B9449_Rm0.txt
agrep -0 -c 'CTTCCAACTTTGTGCGG' *.fastq > count/B9450_Rm0.txt
agrep -0 -c 'CGCGTTTCGTGGTTCTC' *.fastq > count/B9453_Rm0.txt
agrep -0 -c 'CAACGGCCTCCTACATG' *.fastq > count/B9454_Rm0.txt
agrep -0 -c 'AGACAACGGAACAGATA' *.fastq > count/B9455_Rm0.txt
agrep -0 -c 'AATGCAAGTACGCCCGG' *.fastq > count/B9459_Rm0.txt
agrep -0 -c 'GGGTCACCCCTCATGTA' *.fastq > count/B9460_Rm0.txt
agrep -0 -c 'CAGTACAGGCCCGTAAG' *.fastq > count/B9461_Rm0.txt
agrep -0 -c 'ATCAGTCTGTTCCGTGC' *.fastq > count/B9462_Rm0.txt
agrep -0 -c 'AACAAGAGTAAGTCTCG' *.fastq > count/B9463_Rm0.txt
agrep -0 -c 'TCACGACTATGGTCGCC' *.fastq > count/B9464_Rm0.txt
agrep -0 -c 'CCGTCTTATTCGTCGCA' *.fastq > count/B9465_Rm0.txt
agrep -0 -c 'AGTACCAAGCCCGCATA' *.fastq > count/B9466_Rm0.txt
agrep -0 -c 'TCAACATTTACGGATCC' *.fastq > count/B9467_Rm0.txt
agrep -0 -c 'CATGAGTTGACGGGCTG' *.fastq > count/B9468_Rm0.txt
agrep -0 -c 'TACCAATACCTCATTCG' *.fastq > count/B9469_Rm0.txt
agrep -0 -c 'CACTAAGAGGCTGGTTA' *.fastq > count/B9472_Rm0.txt
agrep -0 -c 'GCGGGTCCATGGAATCA' *.fastq > count/B9473_Rm0.txt
agrep -0 -c 'TATCTCCCACACTCACT' *.fastq > count/B9474_Rm0.txt
agrep -0 -c 'ATCGTTGTGAGTGGTAG' *.fastq > count/B9475_Rm0.txt
agrep -0 -c 'TATGTGGAGGGCTCATT' *.fastq > count/B9476_Rm0.txt
agrep -0 -c 'AGATCGCTGTCTATCAC' *.fastq > count/B9477_Rm0.txt
agrep -0 -c 'GCTGATACGTTGATGTG' *.fastq > count/B9478_Rm0.txt
agrep -0 -c 'ACTCAACTCGATCCGAA' *.fastq > count/B9479_Rm0.txt
agrep -0 -c 'CTCATACATTTCGGTCA' *.fastq > count/B9480_Rm0.txt
agrep -0 -c 'TTCAGGTACACTTAACC' *.fastq > count/B9481_Rm0.txt
agrep -0 -c 'TTACCCATTAGGTCTAC' *.fastq > count/B9482_Rm0.txt
agrep -0 -c 'GATAAGCCAATACTGCT' *.fastq > count/B9483_Rm0.txt
agrep -0 -c 'GAATGAACACGGCTCAA' *.fastq > count/B9484_Rm0.txt
agrep -0 -c 'AAAAGAACGGAGCCGCT' *.fastq > count/B9485_Rm0.txt
agrep -0 -c 'TCATGTACTTTTCGCCA' *.fastq > count/B9486_Rm0.txt
agrep -0 -c 'TCTTCGAGAGTCAGTCT' *.fastq > count/B9487_Rm0.txt
agrep -0 -c 'CGTGACTGATCTATCGT' *.fastq > count/B9488_Rm0.txt
agrep -0 -c 'GTGCAAGATACTAATCC' *.fastq > count/B9489_Rm0.txt
agrep -0 -c 'TCGACTCCTGCAGCTAC' *.fastq > count/B9491_Rm0.txt
agrep -0 -c 'GTGCGTGTGGAGAATAA' *.fastq > count/B9492_Rm0.txt
agrep -0 -c 'GAGCTACGGCGTTTATA' *.fastq > count/B9494_Rm0.txt
agrep -0 -c 'CATCCGGGATCAATTCC' *.fastq > count/B9495_Rm0.txt
agrep -0 -c 'GCCGATCGGTGTAACGT' *.fastq > count/B9496_Rm0.txt
agrep -0 -c 'TGATTATAGCGGTGCCC' *.fastq > count/B9497_Rm0.txt
agrep -0 -c 'TGGAAATCCGATCCCGC' *.fastq > count/B9498_Rm0.txt
agrep -0 -c 'CTAAGTCCTTACGATGC' *.fastq > count/B9499_Rm0.txt
agrep -0 -c 'GGTGGTATAGCCAAACT' *.fastq > count/B9500_Rm0.txt
agrep -0 -c 'GGCCGGGAAGATCTTAG' *.fastq > count/B9501_Rm0.txt
agrep -0 -c 'GCGGTCAATCTATCAAC' *.fastq > count/B9502_Rm0.txt
agrep -0 -c 'GTCGTTAGCGGCCAATT' *.fastq > count/B9503_Rm0.txt
agrep -0 -c 'CCCGGGACGTTAAATAC' *.fastq > count/B9504_Rm0.txt
agrep -0 -c 'GTTAGGGATCTCAAACG' *.fastq > count/B9505_Rm0.txt
agrep -0 -c 'GTCCGGTGAGGTATCAA' *.fastq > count/B9506_Rm0.txt
agrep -0 -c 'TGTAGCGTTGCCGACTT' *.fastq > count/B9507_Rm0.txt
agrep -0 -c 'TGCGCCATTAAGTGGGC' *.fastq > count/B9508_Rm0.txt
agrep -0 -c 'GAACTGACTACATATGG' *.fastq > count/B9509_Rm0.txt
agrep -0 -c 'GGTAGTTGGACGTAGCC' *.fastq > count/B9510_Rm0.txt
agrep -0 -c 'CTAGCAGGAGTCTCGTA' *.fastq > count/B9511_Rm0.txt
agrep -0 -c 'GGCAGATTTTCAATAGC' *.fastq > count/B9513_Rm0.txt
agrep -0 -c 'CTTGCTGTACCGAGCCA' *.fastq > count/B9514_Rm0.txt
agrep -0 -c 'TTCCCTTGCGAAGTAAC' *.fastq > count/B9515_Rm0.txt
agrep -0 -c 'ACCTTTGATGGTAGCGT' *.fastq > count/B9517_Rm0.txt
agrep -0 -c 'AGCCGAAACCCTAGCCA' *.fastq > count/B9518_Rm0.txt
agrep -0 -c 'GGAGTATTCGGTTGCGC' *.fastq > count/B9519_Rm0.txt
agrep -0 -c 'CGTGGTAATCGTTGCTG' *.fastq > count/B9520_Rm0.txt
agrep -0 -c 'GAGCATTATACCTGGTG' *.fastq > count/B9521_Rm0.txt
agrep -0 -c 'CCACGCTTAATGAGCAC' *.fastq > count/B9522_Rm0.txt
agrep -0 -c 'GCGGCTATCAGCATACT' *.fastq > count/B9523_Rm0.txt
agrep -0 -c 'GAGCGAGCAGGTACTTA' *.fastq > count/B9524_Rm0.txt
agrep -0 -c 'CACTACGCACTCAGCAG' *.fastq > count/B9525_Rm0.txt
agrep -0 -c 'TGCCTGTTTCGTTTACT' *.fastq > count/B9527_Rm0.txt
agrep -0 -c 'CGTCAAAGCGCCAAAGG' *.fastq > count/B9528_Rm0.txt
agrep -0 -c 'TTAGCGCGATTGGGTAT' *.fastq > count/B9530_Rm0.txt
agrep -0 -c 'GCCGGTATGCCTCTGAT' *.fastq > count/B9531_Rm0.txt
agrep -0 -c 'CAGCCTAACTACATCGG' *.fastq > count/B9532_Rm0.txt
agrep -0 -c 'GATCCTTGCCGTACTCC' *.fastq > count/B9533_Rm0.txt
agrep -0 -c 'GCGAGGCCATATCAGCT' *.fastq > count/B9535_Rm0.txt
agrep -0 -c 'GAATAAGCAGGGACGCA' *.fastq > count/B9536_Rm0.txt
agrep -0 -c 'AAGCCCAGCATTCCTCT' *.fastq > count/B9537_Rm0.txt
agrep -0 -c 'TATACGCTGGCCTCGAC' *.fastq > count/B9538_Rm0.txt
agrep -0 -c 'TGAGACACACTAGTTGC' *.fastq > count/B9539_Rm0.txt
agrep -0 -c 'CTCCTATTAGATGCGAT' *.fastq > count/B9541_Rm0.txt
agrep -0 -c 'TAACAGAAAGGGGGTCC' *.fastq > count/B9542_Rm0.txt
agrep -0 -c 'TACAGGCAATGCATCGT' *.fastq > count/B9543_Rm0.txt
agrep -0 -c 'GCCACCAGTTAGGAACT' *.fastq > count/B9544_Rm0.txt
agrep -0 -c 'GACAAGACCTCGGCGTT' *.fastq > count/B9545_Rm0.txt
agrep -0 -c 'AGGGCTCTTACTCACGT' *.fastq > count/B9546_Rm0.txt
agrep -0 -c 'ATTATGAAACGTGGTGC' *.fastq > count/B9547_Rm0.txt
agrep -0 -c 'TGTAGCGCATTCGCGTC' *.fastq > count/B9548_Rm0.txt
agrep -0 -c 'GTTCAAGCGACACATGA' *.fastq > count/B9549_Rm0.txt
agrep -0 -c 'CGATCCGTTAAATACTC' *.fastq > count/B9550_Rm0.txt
agrep -0 -c 'TTGTCTCATGCGGGCGA' *.fastq > count/B9551_Rm0.txt
agrep -0 -c 'AATGCGTTTAAGAGGGC' *.fastq > count/B9552_Rm0.txt
agrep -0 -c 'GTTTTTAATGCTGCCGG' *.fastq > count/B9553_Rm0.txt
agrep -0 -c 'TTGGAGATTCCCCTTCT' *.fastq > count/B9554_Rm0.txt
agrep -0 -c 'GATCTCGTAATGACTCT' *.fastq > count/B9555_Rm0.txt
agrep -0 -c 'TCTGAATCGGGAACCAT' *.fastq > count/B9556_Rm0.txt
agrep -0 -c 'TAGCATGGATCGGCTGT' *.fastq > count/B9558_Rm0.txt
agrep -0 -c 'TGAACGGAACGTACGAC' *.fastq > count/B9559_Rm0.txt
agrep -0 -c 'GATAATCAGCAACAACC' *.fastq > count/B9560_Rm0.txt
agrep -0 -c 'AGACTCGAACAACATCG' *.fastq > count/B9561_Rm0.txt
agrep -0 -c 'GAGACCGCCAATAGATT' *.fastq > count/B9562_Rm0.txt
agrep -0 -c 'ACGGGATGAAACTAGCT' *.fastq > count/B9564_Rm0.txt
agrep -0 -c 'GCCAAAGGTCGTTGTCT' *.fastq > count/B9565_Rm0.txt
agrep -0 -c 'TATCCCGTTGGCAACGG' *.fastq > count/B9566_Rm0.txt
agrep -0 -c 'AGTCGAACTCTATTGCT' *.fastq > count/B9567_Rm0.txt
agrep -0 -c 'AAGCTAGATGTGCACGG' *.fastq > count/B9568_Rm0.txt
agrep -0 -c 'ATGTGTGTCGTTTGAGC' *.fastq > count/B9569_Rm0.txt
agrep -0 -c 'AGTCACTTCCCGGCGTT' *.fastq > count/B9570_Rm0.txt
agrep -0 -c 'TGCACCTCGCACTACTG' *.fastq > count/B9571_Rm0.txt
agrep -0 -c 'AATTTTCTGCGGCCACC' *.fastq > count/B9572_Rm0.txt
agrep -0 -c 'TTCAGGGACTTCAAATC' *.fastq > count/B9573_Rm0.txt
agrep -0 -c 'GGCTGAATAAGGTTATC' *.fastq > count/B9575_Rm0.txt
agrep -0 -c 'TGTCGGTAGGAAGGGTC' *.fastq > count/B9576_Rm0.txt
agrep -0 -c 'AGTGCGTAGCTGCTTAA' *.fastq > count/B9577_Rm0.txt
agrep -0 -c 'ACTGACCGTATCGGGTG' *.fastq > count/B9579_Rm0.txt
agrep -0 -c 'GCTACAGTCCTCAGATA' *.fastq > count/B9580_Rm0.txt
agrep -0 -c 'GTGTCGTAACGCTATGT' *.fastq > count/B9581_Rm0.txt
agrep -0 -c 'GTTGCGAGTAGATACTG' *.fastq > count/B9582_Rm0.txt
agrep -0 -c 'GATGGGAGCATTTTACG' *.fastq > count/B9583_Rm0.txt
agrep -0 -c 'CTACGCCTTTTCCAATC' *.fastq > count/B9584_Rm0.txt
agrep -0 -c 'TCGGAATCGGTTCTCCC' *.fastq > count/B9585_Rm0.txt
agrep -0 -c 'GCGGCTACTTTCCACGA' *.fastq > count/B9587_Rm0.txt
agrep -0 -c 'CGAATGTGACCCGAACT' *.fastq > count/B9588_Rm0.txt
agrep -0 -c 'ATACGCGCGTCTGGCAA' *.fastq > count/B9589_Rm0.txt
agrep -0 -c 'GCGAAGGACTTGGCGAA' *.fastq > count/B9590_Rm0.txt
agrep -0 -c 'CAGCATTTTTTCAGTCG' *.fastq > count/B9591_Rm0.txt
agrep -0 -c 'CGCTCATCCGTAGAGTA' *.fastq > count/B9592_Rm0.txt
agrep -0 -c 'AAGGTAAGCTGCGACAG' *.fastq > count/B9593_Rm0.txt
agrep -0 -c 'GCGGGAAGTGGCTAATC' *.fastq > count/B9594_Rm0.txt
agrep -0 -c 'GATGTTTCGCGATATTG' *.fastq > count/B9595_Rm0.txt
agrep -0 -c 'TTAAAGGCGCAGTGCCG' *.fastq > count/B9597_Rm0.txt
agrep -0 -c 'TATCGGCCGAACGAGAA' *.fastq > count/B9598_Rm0.txt
agrep -0 -c 'CGCCTTTCAGGTGCTAC' *.fastq > count/B9600_Rm0.txt
agrep -0 -c 'AGTGAGGTTCCCACAGA' *.fastq > count/B9601_Rm0.txt
agrep -0 -c 'CTGGATTAGATCCGAAT' *.fastq > count/B9602_Rm0.txt
agrep -0 -c 'CATGAACGAGCTATCGT' *.fastq > count/B9603_Rm0.txt
agrep -0 -c 'CTTCGTCGTATAAGCGA' *.fastq > count/B9606_Rm0.txt
agrep -0 -c 'CTTGTTACATGATCACC' *.fastq > count/B9607_Rm0.txt
agrep -0 -c 'TCAAGCGAGCACATGAA' *.fastq > count/B9609_Rm0.txt
agrep -0 -c 'TAGCGGTCTATCCCGAT' *.fastq > count/B9611_Rm0.txt
agrep -0 -c 'CTTCGTCTTAGCTTTGG' *.fastq > count/B9613_Rm0.txt
agrep -0 -c 'AAATCACCGCTGAGATA' *.fastq > count/B9615_Rm0.txt
agrep -0 -c 'GCACCGCATTGTCACCT' *.fastq > count/B9616_Rm0.txt
agrep -0 -c 'GCTATAAAGGACGTTGC' *.fastq > count/B9617_Rm0.txt
agrep -0 -c 'GCCACAATTAGTTGCGA' *.fastq > count/B9618_Rm0.txt
agrep -0 -c 'GTAGGGCACTTGAGATA' *.fastq > count/B9619_Rm0.txt
agrep -0 -c 'AAACATCGTCCGAAGCA' *.fastq > count/B9620_Rm0.txt
agrep -0 -c 'ACCCGAGATTGGCGATT' *.fastq > count/B9622_Rm0.txt
agrep -0 -c 'CTTTTGAGGTCCGCTAC' *.fastq > count/B9623_Rm0.txt
agrep -0 -c 'TAGCTGATTCTTCTGAG' *.fastq > count/B9624_Rm0.txt
agrep -0 -c 'GCCGAACACCATAATAT' *.fastq > count/B9626_Rm0.txt
agrep -0 -c 'TTGTCACTCGACGCAGT' *.fastq > count/B9628_Rm0.txt
agrep -0 -c 'CGTCTGTCTTCATATCC' *.fastq > count/B9629_Rm0.txt
agrep -0 -c 'CGTAGTGCTCTACTCTT' *.fastq > count/B9633_Rm0.txt
agrep -0 -c 'TCACTGATGCCAATGTT' *.fastq > count/B9635_Rm0.txt
agrep -0 -c 'TGACTGATTGCATAAGG' *.fastq > count/B9636_Rm0.txt
agrep -0 -c 'TAACAGACGAGGTCCTA' *.fastq > count/B9637_Rm0.txt
agrep -0 -c 'GCAACTGCTGTTGCGAA' *.fastq > count/B9638_Rm0.txt
agrep -0 -c 'GGCATTCTTAACTTGTC' *.fastq > count/B9639_Rm0.txt
agrep -0 -c 'TAGTTCTACGCCGCGCT' *.fastq > count/B9642_Rm0.txt
agrep -0 -c 'CGATAGTGAGCCCTCAA' *.fastq > count/B9643_Rm0.txt
agrep -0 -c 'GTTACAGATCGACTAGA' *.fastq > count/B9644_Rm0.txt
agrep -0 -c 'TGCGCGATATCAAAGAC' *.fastq > count/B9645_Rm0.txt
agrep -0 -c 'AGTGTATCTCGCCAGTT' *.fastq > count/B9646_Rm0.txt
agrep -0 -c 'TGACCTAAACGCAATGT' *.fastq > count/B9647_Rm0.txt
agrep -0 -c 'TCCCGAAGATATTCGGC' *.fastq > count/B9648_Rm0.txt
agrep -0 -c 'CCCAGTTCATTCCAACT' *.fastq > count/B9649_Rm0.txt
agrep -0 -c 'ATCTCTAGTGGTTACGG' *.fastq > count/B9650_Rm0.txt
agrep -0 -c 'CACGGGACCTGATTACA' *.fastq > count/B9652_Rm0.txt
agrep -0 -c 'CCAATTCGAACTCAGCA' *.fastq > count/B9653_Rm0.txt
agrep -0 -c 'AACCGGCATCATGTCCA' *.fastq > count/B9654_Rm0.txt
agrep -0 -c 'CGAGTAGACTCTCCCAG' *.fastq > count/B9655_Rm0.txt
agrep -0 -c 'TCATTCATCCGGGGAAC' *.fastq > count/B9656_Rm0.txt
agrep -0 -c 'AAGTGACACAAGCAAGG' *.fastq > count/B9657_Rm0.txt
agrep -0 -c 'GATAGGGCTAATGTCCC' *.fastq > count/B9658_Rm0.txt
agrep -0 -c 'TCTAACGGCAAGATAGC' *.fastq > count/B9659_Rm0.txt
agrep -0 -c 'CACGATTCCCCTCCGAT' *.fastq > count/B9660_Rm0.txt
agrep -0 -c 'AGCTACGCCACCCTCTA' *.fastq > count/B9661_Rm0.txt
agrep -0 -c 'TTGGTGGTGAACTCGAG' *.fastq > count/B9662_Rm0.txt
agrep -0 -c 'AGAATTGGTGTCCGCGA' *.fastq > count/B9664_Rm0.txt
agrep -0 -c 'GGTAGTACTATAGTCGA' *.fastq > count/B9665_Rm0.txt
agrep -0 -c 'TCATGTCCGAAGACACG' *.fastq > count/B9667_Rm0.txt
agrep -0 -c 'GCCGAAGCTTGCTATCA' *.fastq > count/B9668_Rm0.txt
agrep -0 -c 'TAGTCTTCCATAGGTGG' *.fastq > count/B9669_Rm0.txt
agrep -0 -c 'ATGTACTCGGTGACGAA' *.fastq > count/B9670_Rm0.txt
agrep -0 -c 'TCACTCAAACCGCGGAG' *.fastq > count/B9671_Rm0.txt
agrep -0 -c 'ATCGAAAGAACCTTGAC' *.fastq > count/B9673_Rm0.txt
agrep -0 -c 'GAGCCCTTGACTCTTTG' *.fastq > count/B9674_Rm0.txt
agrep -0 -c 'AGGGGGCGCTTAACACT' *.fastq > count/B9675_Rm0.txt
agrep -0 -c 'CTCAATTGGTCTCTAGA' *.fastq > count/B9676_Rm0.txt
agrep -0 -c 'CCAGTTATTCGGAACGC' *.fastq > count/B9677_Rm0.txt
agrep -0 -c 'CCTATGACGCGTCGACA' *.fastq > count/B9678_Rm0.txt
agrep -0 -c 'GGGCGCCATTATATCAT' *.fastq > count/B9679_Rm0.txt
agrep -0 -c 'AACAACGTAAGTGGCAC' *.fastq > count/B9680_Rm0.txt
agrep -0 -c 'GAGTTGTATACCCAAGG' *.fastq > count/B9681_Rm0.txt
agrep -0 -c 'TCTTGGGATAAACGGAG' *.fastq > count/B9682_Rm0.txt
agrep -0 -c 'CGATCATTGGTGAACAC' *.fastq > count/B9684_Rm0.txt
agrep -0 -c 'CCTACACTCGTTCAGTG' *.fastq > count/B9685_Rm0.txt
agrep -0 -c 'GACTTAACGCGAGACGC' *.fastq > count/B9686_Rm0.txt
agrep -0 -c 'AAAGTGGGCCGTAACCG' *.fastq > count/B9687_Rm0.txt
agrep -0 -c 'CGTAGAAAATTGCGGGC' *.fastq > count/B9688_Rm0.txt
agrep -0 -c 'CTGACGGGAAACGTACA' *.fastq > count/B9689_Rm0.txt
agrep -0 -c 'TCTGCCACAATGAGACG' *.fastq > count/B9690_Rm0.txt
agrep -0 -c 'AACCTTCGGAATTGCAG' *.fastq > count/B9691_Rm0.txt
agrep -0 -c 'ACGCCTTGGCTAGACAC' *.fastq > count/B9692_Rm0.txt
agrep -0 -c 'GGGTTTGACCGCAAGTT' *.fastq > count/B9693_Rm0.txt
agrep -0 -c 'AACGAAGAGCCACGACG' *.fastq > count/B9694_Rm0.txt
agrep -0 -c 'ACTGGGCACGGATAACC' *.fastq > count/B9695_Rm0.txt
agrep -0 -c 'CATATGGGCCAGATGAA' *.fastq > count/B9696_Rm0.txt
agrep -0 -c 'AGGCCGTAAGATGGATC' *.fastq > count/B9698_Rm0.txt
agrep -0 -c 'TTGCCCAGCGCAAAGCA' *.fastq > count/B9699_Rm0.txt
agrep -0 -c 'AATAGGCCTGGTGAACT' *.fastq > count/B9700_Rm0.txt
agrep -0 -c 'TTCGACACCTTCACACG' *.fastq > count/B9701_Rm0.txt
agrep -0 -c 'TGTATTAGCTTCCTAGC' *.fastq > count/B9702_Rm0.txt
agrep -0 -c 'GTTAAGTCCTCAGCTAG' *.fastq > count/B9703_Rm0.txt
agrep -0 -c 'CGAAGGCGTTGTCCGTT' *.fastq > count/B9704_Rm0.txt
agrep -0 -c 'TCCAGGGTTAGTTCCCT' *.fastq > count/B9705_Rm0.txt
agrep -0 -c 'GATTGACCTATGATCCG' *.fastq > count/B9706_Rm0.txt
agrep -0 -c 'GGCTTTACAATCAGGAG' *.fastq > count/B9707_Rm0.txt
agrep -0 -c 'ATGACTTCGTGTTCGTC' *.fastq > count/B9708_Rm0.txt
agrep -0 -c 'TCCTGCATATCACGATG' *.fastq > count/B9709_Rm0.txt
agrep -0 -c 'GAGTACTATTCGCATGC' *.fastq > count/B9710_Rm0.txt
agrep -0 -c 'ATATGTCCGCCCCTCCA' *.fastq > count/B9713_Rm0.txt
agrep -0 -c 'GGCACTTTTACTTGCGC' *.fastq > count/B9714_Rm0.txt
agrep -0 -c 'TCCCGTGTTGACCGACA' *.fastq > count/B9716_Rm0.txt
agrep -0 -c 'GTATCGGATCACCTAAT' *.fastq > count/B9717_Rm0.txt
agrep -0 -c 'TCAAGACGGGGGGGAAT' *.fastq > count/B9718_Rm0.txt
agrep -0 -c 'TCTCGCTAGTTATGCTA' *.fastq > count/B9721_Rm0.txt
agrep -0 -c 'TGGAGAGGATTCTCTAC' *.fastq > count/B9722_Rm0.txt
agrep -0 -c 'CCCGTGTGAAAGAACGT' *.fastq > count/B9723_Rm0.txt
agrep -0 -c 'GAACGTCGATGTCTAGG' *.fastq > count/B9724_Rm0.txt
agrep -0 -c 'GGCATTAGATTCCGCCT' *.fastq > count/B9725_Rm0.txt
agrep -0 -c 'GGTACCAGTGGCTATCT' *.fastq > count/B9727_Rm0.txt
agrep -0 -c 'CGCTTACCCATCCAATT' *.fastq > count/B9728_Rm0.txt
agrep -0 -c 'TCCCCGGAGGTGAATAC' *.fastq > count/B9729_Rm0.txt
agrep -0 -c 'TAAAGTCTGCCCGGTCA' *.fastq > count/B9730_Rm0.txt
agrep -0 -c 'TTGATAGTACGGCGACA' *.fastq > count/B9731_Rm0.txt
agrep -0 -c 'ACCCTCGACAAATAGAT' *.fastq > count/B9732_Rm0.txt
agrep -0 -c 'AAACTATCGCTGCTCAT' *.fastq > count/B9735_Rm0.txt
agrep -0 -c 'AGCTTGAAACGCTGGCG' *.fastq > count/B9736_Rm0.txt
agrep -0 -c 'CGTTTGTGTATGGCGCG' *.fastq > count/B9737_Rm0.txt
agrep -0 -c 'TAGCTTTTTAGGGCCAG' *.fastq > count/B9738_Rm0.txt
agrep -0 -c 'TGACGTAATGTAGCCCC' *.fastq > count/B9739_Rm0.txt
agrep -0 -c 'CGACTGTTACTATTCCT' *.fastq > count/B9740_Rm0.txt
agrep -0 -c 'CCAGAAGGACATGGGAT' *.fastq > count/B9741_Rm0.txt
agrep -0 -c 'CCGCTGAAAGCCGACTT' *.fastq > count/B9744_Rm0.txt
agrep -0 -c 'GCTCATACGGGGTTAAG' *.fastq > count/B9745_Rm0.txt
agrep -0 -c 'AGTTAATGACTCTCCGA' *.fastq > count/B9746_Rm0.txt
agrep -0 -c 'AGATCCTGAGGTCGACG' *.fastq > count/B9747_Rm0.txt
agrep -0 -c 'AGCCGTGTCGATCTCAA' *.fastq > count/B9748_Rm0.txt
agrep -0 -c 'CCAGAAAATGGGCAACA' *.fastq > count/B9750_Rm0.txt
agrep -0 -c 'GCGTTACGTGTGTAACG' *.fastq > count/B9751_Rm0.txt
agrep -0 -c 'TGAGCATCGGCCCTCTT' *.fastq > count/B9752_Rm0.txt
agrep -0 -c 'TGGACTCTACCTATATG' *.fastq > count/B9753_Rm0.txt
agrep -0 -c 'TCCGTGCCTGATTGTAT' *.fastq > count/B9754_Rm0.txt
agrep -0 -c 'TACGGCTTACCTCAGGT' *.fastq > count/B9755_Rm0.txt
agrep -0 -c 'TATAGACCCTGTTGGAA' *.fastq > count/B9756_Rm0.txt
agrep -0 -c 'ATGCAACATATGCAGTG' *.fastq > count/B9757_Rm0.txt
agrep -0 -c 'GGTAAAGAGACGGGAGT' *.fastq > count/B9758_Rm0.txt
agrep -0 -c 'CTGCAATGTGGTTATCG' *.fastq > count/B9759_Rm0.txt
agrep -0 -c 'TTCACTCATAGCCGCAA' *.fastq > count/B9760_Rm0.txt
agrep -0 -c 'CCATTCAGCGCTCCTAA' *.fastq > count/B9761_Rm0.txt
agrep -0 -c 'TGTCGAGGTTCCAACTG' *.fastq > count/B9762_Rm0.txt
agrep -0 -c 'AGTCGCCTATACGTCGA' *.fastq > count/B9763_Rm0.txt
agrep -0 -c 'AACGACAATCCCAGCGT' *.fastq > count/B9764_Rm0.txt
agrep -0 -c 'ATTGGAGCAACCCCGCT' *.fastq > count/B9767_Rm0.txt
agrep -0 -c 'CTTGCGTGTGTTGCCGA' *.fastq > count/B9768_Rm0.txt
agrep -0 -c 'GGGGCTGTCCATTTATT' *.fastq > count/B9769_Rm0.txt
agrep -0 -c 'ATGATTACGCCCGCACC' *.fastq > count/B9770_Rm0.txt
agrep -0 -c 'GTTGGTGAGGCGCTGAA' *.fastq > count/B9771_Rm0.txt
agrep -0 -c 'GGAGCCGAAAACTGCGT' *.fastq > count/B9772_Rm0.txt
agrep -0 -c 'CCCTGACGTGATGGGTT' *.fastq > count/B9773_Rm0.txt
agrep -0 -c 'CTTTTGTCCGCGTGGTC' *.fastq > count/B9774_Rm0.txt
agrep -0 -c 'GACGTGACCACCTGGTA' *.fastq > count/B9775_Rm0.txt
agrep -0 -c 'GTTGCGCGATGACTAGA' *.fastq > count/B9776_Rm0.txt
agrep -0 -c 'CTTCAATCTGATCGCCC' *.fastq > count/B9778_Rm0.txt
agrep -0 -c 'ACCGCTTCGAGTCCGAA' *.fastq > count/B9779_Rm0.txt
agrep -0 -c 'TACCAGCTCCGAAACGC' *.fastq > count/B9782_Rm0.txt
agrep -0 -c 'TCCCAGTATCGCTTGTC' *.fastq > count/B9784_Rm0.txt
agrep -0 -c 'TTTGCCGTGCATTCCAA' *.fastq > count/B9785_Rm0.txt
agrep -0 -c 'TAAGCCGCTTCGCGCAT' *.fastq > count/B9786_Rm0.txt
agrep -0 -c 'TCTATCCCCATGACTTG' *.fastq > count/B9790_Rm0.txt
agrep -0 -c 'TACTTGGAAGAGGTCTC' *.fastq > count/B9791_Rm0.txt
agrep -0 -c 'CAGAACACCTCCTCCTG' *.fastq > count/B9792_Rm0.txt
agrep -0 -c 'ACGAACCCAAGCATCAT' *.fastq > count/B9793_Rm0.txt
agrep -0 -c 'GTTCATCAGAGCAGAGT' *.fastq > count/B9794_Rm0.txt
agrep -0 -c 'GTTTATCGCCCAAGTCC' *.fastq > count/B9795_Rm0.txt
agrep -0 -c 'CCCCCACAAAGATACCT' *.fastq > count/B9796_Rm0.txt
agrep -0 -c 'TAATGACACCGCTATCG' *.fastq > count/B9800_Rm0.txt
agrep -0 -c 'CTACATTCTGGTAGCTT' *.fastq > count/B9801_Rm0.txt
agrep -0 -c 'AACCCAGTAAACTTCAG' *.fastq > count/B9802_Rm0.txt
agrep -0 -c 'ATCGCCACTCTCAAACC' *.fastq > count/B9803_Rm0.txt
agrep -0 -c 'AAAGCTCTGTCTCGTAT' *.fastq > count/B9804_Rm0.txt
agrep -0 -c 'CAATGTCTGGTACTGCT' *.fastq > count/B9805_Rm0.txt
agrep -0 -c 'TTTAGTGCATACCGGCA' *.fastq > count/B9806_Rm0.txt
agrep -0 -c 'GAGATTAGTTTCGCTGT' *.fastq > count/B9807_Rm0.txt
agrep -0 -c 'ACAATACTATTGTCGCC' *.fastq > count/B9808_Rm0.txt
agrep -0 -c 'CCGTAGTCATGATCTAG' *.fastq > count/B9809_Rm0.txt
agrep -0 -c 'TGAGTATGGGACGCTCC' *.fastq > count/B9810_Rm0.txt
agrep -0 -c 'TTTATATTGGAGCCCGG' *.fastq > count/B9811_Rm0.txt
agrep -0 -c 'CACACGGTGCTCTTCAA' *.fastq > count/B9812_Rm0.txt
agrep -0 -c 'TAGATTCCCGGATAGTT' *.fastq > count/B9813_Rm0.txt
agrep -0 -c 'CCTATACAGTTATCGTG' *.fastq > count/B9814_Rm0.txt
agrep -0 -c 'TAATGTGGGTCGCTACA' *.fastq > count/B9815_Rm0.txt
agrep -0 -c 'CTAGTTACTATCGACCC' *.fastq > count/B9816_Rm0.txt
agrep -0 -c 'TCCGTTGTGTTCGACTG' *.fastq > count/B9818_Rm0.txt
agrep -0 -c 'TAATGGGGCGGACCTAT' *.fastq > count/B9820_Rm0.txt
agrep -0 -c 'GCGTTACGGACCAGGAA' *.fastq > count/B9822_Rm0.txt
agrep -0 -c 'GGCCTGTACAAACCCAA' *.fastq > count/B9823_Rm0.txt
agrep -0 -c 'CCCAGCCTATCCTACAG' *.fastq > count/B9824_Rm0.txt
agrep -0 -c 'AGACTAATCTCCGCAAG' *.fastq > count/B9826_Rm0.txt
agrep -0 -c 'TAACTGTGCTTCCCCCG' *.fastq > count/B9827_Rm0.txt
agrep -0 -c 'CACCCGAACTCGTATGA' *.fastq > count/B9828_Rm0.txt
agrep -0 -c 'AAGTAAGAGGAGACTAC' *.fastq > count/B9829_Rm0.txt
agrep -0 -c 'ACTGGAACCGGGCTACA' *.fastq > count/B9830_Rm0.txt
agrep -0 -c 'GCAAAATGAGCAACCAG' *.fastq > count/B9831_Rm0.txt
agrep -0 -c 'CGAATAGCTATTACTCG' *.fastq > count/B9832_Rm0.txt
agrep -0 -c 'ATTCAACGATTTGGGCG' *.fastq > count/B9834_Rm0.txt
agrep -0 -c 'AACCCGATTGGACAGTG' *.fastq > count/B9835_Rm0.txt
agrep -0 -c 'AAACACCGCTTGACTAA' *.fastq > count/B9836_Rm0.txt
agrep -0 -c 'GGACTAATCATGAACCT' *.fastq > count/B9837_Rm0.txt
agrep -0 -c 'ACCGTCTGACCCTTAAC' *.fastq > count/B9838_Rm0.txt
agrep -0 -c 'TAGATTTATCGGGGAGA' *.fastq > count/B9839_Rm0.txt
agrep -0 -c 'TTCGTGAGGTCCATGCG' *.fastq > count/B9840_Rm0.txt
agrep -0 -c 'CACCTCTTCCTACGCAT' *.fastq > count/B9842_Rm0.txt
agrep -0 -c 'CTATTGAACAGCCCTGT' *.fastq > count/B9843_Rm0.txt
agrep -0 -c 'TCAGCTCCTATTAAACG' *.fastq > count/B9844_Rm0.txt
agrep -0 -c 'AATCCGAAATGCCATTG' *.fastq > count/B9845_Rm0.txt
agrep -0 -c 'GTCGGGGAAAGTATGTG' *.fastq > count/B9846_Rm0.txt
agrep -0 -c 'GAGCCAACTGTGTGACA' *.fastq > count/B9847_Rm0.txt
agrep -0 -c 'ATCATATAGATACCCGC' *.fastq > count/B9848_Rm0.txt
agrep -0 -c 'TTCACAGAGTGGAGACC' *.fastq > count/B9849_Rm0.txt
agrep -0 -c 'TTCGCGTCAAATGAGCG' *.fastq > count/B9850_Rm0.txt
agrep -0 -c 'GTCCTTGTTATATTCCG' *.fastq > count/B9851_Rm0.txt
agrep -0 -c 'GAACAGTCTTCGACGCG' *.fastq > count/B9852_Rm0.txt
agrep -0 -c 'GGACTACCTTTTGAGAC' *.fastq > count/B9854_Rm0.txt
agrep -0 -c 'TAGTTTGCCATTCGCTC' *.fastq > count/B9856_Rm0.txt
agrep -0 -c 'CGTTGTCGTTACCTACG' *.fastq > count/B9858_Rm0.txt
agrep -0 -c 'CGGTCAGCAAGTAAATT' *.fastq > count/B9859_Rm0.txt
agrep -0 -c 'ATCCTGGACCGAGTCAC' *.fastq > count/B9860_Rm0.txt
agrep -0 -c 'AAGCCGAACCTGGGGAA' *.fastq > count/B9861_Rm0.txt
agrep -0 -c 'AGAAAGTGCGTGACAAC' *.fastq > count/B9862_Rm0.txt
agrep -0 -c 'GCGTGAAGATTCCTAAG' *.fastq > count/B9863_Rm0.txt
agrep -0 -c 'GTCTTTGCAGTCCACTG' *.fastq > count/B9864_Rm0.txt
agrep -0 -c 'TCGGACTAAACCGAGCC' *.fastq > count/B9865_Rm0.txt
agrep -0 -c 'GGTTTTTGCACCCATAC' *.fastq > count/B9866_Rm0.txt
agrep -0 -c 'CTCAAGTGCGAATAACT' *.fastq > count/B9867_Rm0.txt
agrep -0 -c 'CGCTAATTGACGTTATG' *.fastq > count/B9868_Rm0.txt
agrep -0 -c 'CCCCAAAAAATTATCGC' *.fastq > count/B9869_Rm0.txt
agrep -0 -c 'CGAGCTCCTACCAGTGT' *.fastq > count/B9871_Rm0.txt
agrep -0 -c 'AAAAACTCACTCCGTCT' *.fastq > count/B9872_Rm0.txt
agrep -0 -c 'AGAGACAAGGCGGATAG' *.fastq > count/B9873_Rm0.txt
agrep -0 -c 'AGTCCCTACATTTGTGC' *.fastq > count/B9874_Rm0.txt
agrep -0 -c 'GGCCTCCTATACTAACG' *.fastq > count/B9876_Rm0.txt
agrep -0 -c 'ATATAGCCGTATCGCTA' *.fastq > count/B9877_Rm0.txt
agrep -0 -c 'CTGGATCCCGCCATACA' *.fastq > count/B9879_Rm0.txt
agrep -0 -c 'CGCTAACAGCTTCGGAC' *.fastq > count/B9882_Rm0.txt
agrep -0 -c 'ATTTGGCAATAAGACCG' *.fastq > count/B9883_Rm0.txt
agrep -0 -c 'TTCTTCCGCGCGTAATA' *.fastq > count/B9884_Rm0.txt
agrep -0 -c 'CTCTTCCCGATTCGAAT' *.fastq > count/B9885_Rm0.txt
agrep -0 -c 'ACCGAATCGGTGAGTGG' *.fastq > count/B9886_Rm0.txt
agrep -0 -c 'GATATTCAGCAACCGGC' *.fastq > count/B9887_Rm0.txt
agrep -0 -c 'TCTAGACCCTATGATAC' *.fastq > count/B9888_Rm0.txt
agrep -0 -c 'GTTTTACTCTCCACGGC' *.fastq > count/B9892_Rm0.txt
agrep -0 -c 'GCTCCTCTATAGCGGCT' *.fastq > count/B9894_Rm0.txt
agrep -0 -c 'GAGAGTAGAGGTCGGAG' *.fastq > count/B9896_Rm0.txt
agrep -0 -c 'CAATGTGTAAAGCGACT' *.fastq > count/B9897_Rm0.txt
agrep -0 -c 'AGCCCGAACACTTGGAA' *.fastq > count/B9898_Rm0.txt
agrep -0 -c 'GTACGCTATTCCGCGCA' *.fastq > count/B9899_Rm0.txt
agrep -0 -c 'CGATCAGCGTCTGCTTG' *.fastq > count/B9900_Rm0.txt
agrep -0 -c 'TAAGCAGATCCGACCGG' *.fastq > count/B9901_Rm0.txt
agrep -0 -c 'TCAGTGGATCACCAACC' *.fastq > count/B9902_Rm0.txt
agrep -0 -c 'ACCCTTCTTTATTGTCC' *.fastq > count/B9903_Rm0.txt
agrep -0 -c 'TATTGACCGGCCAACGT' *.fastq > count/B9905_Rm0.txt
agrep -0 -c 'TCTCTGACCCGTTACTC' *.fastq > count/B9906_Rm0.txt
agrep -0 -c 'AGGACCATTCCTATCCG' *.fastq > count/B9907_Rm0.txt
agrep -0 -c 'GGGTGAATACGAGGGCA' *.fastq > count/B9908_Rm0.txt
agrep -0 -c 'GGTTGTTGAATAGGCCT' *.fastq > count/B9909_Rm0.txt
agrep -0 -c 'CTGGAACGTCCCTACGA' *.fastq > count/B9910_Rm0.txt
agrep -0 -c 'ATAGGGCGTCAACGAAG' *.fastq > count/B9911_Rm0.txt
agrep -0 -c 'GGTTGACGCAGACTGTT' *.fastq > count/B9912_Rm0.txt
agrep -0 -c 'TCTAGATGTAGCAAGCG' *.fastq > count/B9914_Rm0.txt
agrep -0 -c 'CTCCGATCTTCTACGCC' *.fastq > count/B9915_Rm0.txt
agrep -0 -c 'TTGCGTCTTGCGCTGAT' *.fastq > count/B9916_Rm0.txt
agrep -0 -c 'TATGACGCCTCAGCGTG' *.fastq > count/B9917_Rm0.txt
agrep -0 -c 'CCAGTTCCAAACCAGTC' *.fastq > count/B9918_Rm0.txt
agrep -0 -c 'ACTAAGGTCGTTCGCGA' *.fastq > count/B9919_Rm0.txt
agrep -0 -c 'ATACACGGATGAGGTGC' *.fastq > count/B9922_Rm0.txt
agrep -0 -c 'TGTTCTCAAGCAGGGGT' *.fastq > count/B9923_Rm0.txt
agrep -0 -c 'TATCCGGGTGAGGTTGT' *.fastq > count/B9924_Rm0.txt
agrep -0 -c 'AGGCTCAGCTTCGTCTA' *.fastq > count/B9925_Rm0.txt
agrep -0 -c 'AGGGAAGATATGACTCA' *.fastq > count/B9926_Rm0.txt
agrep -0 -c 'TGAAGTAAGATACGGAC' *.fastq > count/B9927_Rm0.txt
agrep -0 -c 'CGATCTCGACAACTGGC' *.fastq > count/B9928_Rm0.txt
agrep -0 -c 'TCCGTAGGTCCTATGCA' *.fastq > count/B9929_Rm0.txt
agrep -0 -c 'GGTAACTATATCATCCC' *.fastq > count/B9930_Rm0.txt
agrep -0 -c 'CACGGCCTACTGCACTA' *.fastq > count/B9931_Rm0.txt
agrep -0 -c 'ATTTACCAGTCGTCGAG' *.fastq > count/B9932_Rm0.txt
agrep -0 -c 'CGGTAGCGTATGTTAGG' *.fastq > count/B9933_Rm0.txt
agrep -0 -c 'CGCAAGCCTGAGCTCTA' *.fastq > count/B9934_Rm0.txt
agrep -0 -c 'TGTATCTTGCGTCCGAG' *.fastq > count/B9935_Rm0.txt
agrep -0 -c 'TGCCAACTTGACCAATA' *.fastq > count/B9936_Rm0.txt
agrep -0 -c 'CGGAACCAGCTACAAAT' *.fastq > count/B9937_Rm0.txt
agrep -0 -c 'CGCTGAGTCGAGATCGT' *.fastq > count/B9939_Rm0.txt
agrep -0 -c 'GTGCTGTTTAGAACAGT' *.fastq > count/B9940_Rm0.txt
agrep -0 -c 'CAATATGACGTCGTGGC' *.fastq > count/B9941_Rm0.txt
agrep -0 -c 'GATTTCCGCTTAGGTTA' *.fastq > count/B9942_Rm0.txt
agrep -0 -c 'ATACCACGTCACTACCC' *.fastq > count/B9943_Rm0.txt
agrep -0 -c 'CCCCCTCAGTATGTTAT' *.fastq > count/B9944_Rm0.txt
agrep -0 -c 'GTCGGCTCATCAAACTG' *.fastq > count/B9945_Rm0.txt
agrep -0 -c 'CCCACAGCAATAGCGAC' *.fastq > count/B9946_Rm0.txt
agrep -0 -c 'TCAGTGTTCACCACTGG' *.fastq > count/B9947_Rm0.txt
agrep -0 -c 'GACAAGAGGCTCCTCCA' *.fastq > count/B9948_Rm0.txt
agrep -0 -c 'CGTCGCATAGGAACTCC' *.fastq > count/B9949_Rm0.txt
agrep -0 -c 'CTCCGAAAATCGGCCTT' *.fastq > count/B9950_Rm0.txt
agrep -0 -c 'AACCCACCGCTACCTGA' *.fastq > count/B9951_Rm0.txt
agrep -0 -c 'AACGTGCGGTCAATACG' *.fastq > count/B9952_Rm0.txt
agrep -0 -c 'CTTAGCCGCATATTTGT' *.fastq > count/B9953_Rm0.txt
agrep -0 -c 'TAGAGTTCGGGATCTCA' *.fastq > count/B9954_Rm0.txt
agrep -0 -c 'GAATGCCTCACAGATGA' *.fastq > count/B9955_Rm0.txt
agrep -0 -c 'TTGAGGCGACATATCAA' *.fastq > count/B9956_Rm0.txt
agrep -0 -c 'TTTTCCGAACACAGACG' *.fastq > count/B9957_Rm0.txt
agrep -0 -c 'ATGTTCTAGTCGGCCCT' *.fastq > count/B9958_Rm0.txt
agrep -0 -c 'ACCGGACCTTGCTATGG' *.fastq > count/B9959_Rm0.txt
agrep -0 -c 'TACAAATCGGATGCTCC' *.fastq > count/B9960_Rm0.txt
agrep -0 -c 'CACGTATGCCCTTCTAC' *.fastq > count/B9961_Rm0.txt
agrep -0 -c 'ACTCTTCTTGTGACGCG' *.fastq > count/B9963_Rm0.txt
agrep -0 -c 'AAATACGATAGTGGTGG' *.fastq > count/B9965_Rm0.txt
agrep -0 -c 'TCATCCTTCTGGTCATT' *.fastq > count/B9966_Rm0.txt
agrep -0 -c 'TGACGCTCCCAATGACA' *.fastq > count/B9967_Rm0.txt
agrep -0 -c 'TCGATATTCCTGGCATG' *.fastq > count/B9970_Rm0.txt
agrep -0 -c 'TTATACCTGTAACGTCC' *.fastq > count/B9972_Rm0.txt
agrep -0 -c 'GATTAGACCTGGTTAGA' *.fastq > count/B9973_Rm0.txt
agrep -0 -c 'GCACTGCGTTAGCGTTG' *.fastq > count/B9974_Rm0.txt
agrep -0 -c 'CAAACAATTGGCGCACT' *.fastq > count/B9975_Rm0.txt
agrep -0 -c 'CGGAAATGATCTCGTGC' *.fastq > count/B9976_Rm0.txt
agrep -0 -c 'TCGGTCTCTTCCTTGAG' *.fastq > count/B9977_Rm0.txt
agrep -0 -c 'GGTCATACGCAGGACTG' *.fastq > count/B9980_Rm0.txt
agrep -0 -c 'TTGTTAACAATGGCGTG' *.fastq > count/B9982_Rm0.txt
agrep -0 -c 'TATCAGGGGTGCCAATC' *.fastq > count/B9984_Rm0.txt
agrep -0 -c 'AGTTAGTGGCTCAGCTC' *.fastq > count/B9985_Rm0.txt
agrep -0 -c 'CGCCTAACACTTTATGT' *.fastq > count/B9986_Rm0.txt
agrep -0 -c 'ACGTCAGTTGAAATTGG' *.fastq > count/B9987_Rm0.txt
agrep -0 -c 'AGATTCCGCGTGAGGCT' *.fastq > count/B9988_Rm0.txt
agrep -0 -c 'ATTGTTCACGAGACCCG' *.fastq > count/B9990_Rm0.txt
agrep -0 -c 'TGGGCGATTTTTTTCGT' *.fastq > count/B9991_Rm0.txt
agrep -0 -c 'TGTAGATCGGACTTCGG' *.fastq > count/B9993_Rm0.txt
agrep -0 -c 'CCAGTGGATACCTTCCT' *.fastq > count/B9994_Rm0.txt
agrep -0 -c 'CCTCTACGGATAGACTG' *.fastq > count/B9996_Rm0.txt
agrep -0 -c 'CGTGGTATTCAGAGGAG' *.fastq > count/B9997_Rm0.txt
agrep -0 -c 'TGGACTGCATCGTCTTG' *.fastq > count/B9998_Rm0.txt
agrep -0 -c 'AGCTTCCTTGGATGCCG' *.fastq > count/B10001_Rm0.txt
agrep -0 -c 'GCTGGGGCTTCGTTAGA' *.fastq > count/B10002_Rm0.txt
agrep -0 -c 'TGACGGCTGACTATCGT' *.fastq > count/B10003_Rm0.txt
agrep -0 -c 'ACTACTCAGGTTAAGCG' *.fastq > count/B10004_Rm0.txt
agrep -0 -c 'GTGTGGTTCCGAGTAAC' *.fastq > count/B10005_Rm0.txt
agrep -0 -c 'GCCAAACATTGCTTCCC' *.fastq > count/B10006_Rm0.txt
agrep -0 -c 'TGCTCTATCAAGCACAA' *.fastq > count/B10007_Rm0.txt
agrep -0 -c 'CGCATAGTCGCACAGAT' *.fastq > count/B10008_Rm0.txt
agrep -0 -c 'AAGTATACGATCTGCGC' *.fastq > count/B10009_Rm0.txt
agrep -0 -c 'AACAACTGCTTCATCGC' *.fastq > count/B10010_Rm0.txt
agrep -0 -c 'AGACCGAGGGGTAGATC' *.fastq > count/B10011_Rm0.txt
agrep -0 -c 'ATCCCAACCGTAGACAC' *.fastq > count/B10012_Rm0.txt
agrep -0 -c 'CACTACAGCTCCTTAAG' *.fastq > count/B10013_Rm0.txt
agrep -0 -c 'TCTTCGCTTAACACGTG' *.fastq > count/B10015_Rm0.txt
agrep -0 -c 'CCGTCCATGAGTGCACA' *.fastq > count/B10016_Rm0.txt
agrep -0 -c 'CGACCAAGACAGTGATG' *.fastq > count/B10017_Rm0.txt
agrep -0 -c 'AGCCCTAGTTGGACAAG' *.fastq > count/B10018_Rm0.txt
agrep -0 -c 'ATGCGGGCCAATTGATC' *.fastq > count/B10020_Rm0.txt
agrep -0 -c 'GGCATTGAAGTCCTATC' *.fastq > count/B10021_Rm0.txt
agrep -0 -c 'TGCTGATGCACTCAGTT' *.fastq > count/B10022_Rm0.txt
agrep -0 -c 'GAAGATTGAACCACTCC' *.fastq > count/B10023_Rm0.txt
agrep -0 -c 'TTTCTGTCGCTAAGCCA' *.fastq > count/B10024_Rm0.txt
agrep -0 -c 'TAGCCAGACGTGTGAGA' *.fastq > count/B10025_Rm0.txt
agrep -0 -c 'CGATCGTAAACAACGCT' *.fastq > count/B10028_Rm0.txt
agrep -0 -c 'ACAATATTCAGTGCCAC' *.fastq > count/B10029_Rm0.txt
agrep -0 -c 'TCCTTGTGCACTCGATG' *.fastq > count/B10031_Rm0.txt
agrep -0 -c 'TGATACCGACGGAAGCC' *.fastq > count/B10032_Rm0.txt
agrep -0 -c 'TCGGTCCGCCAATTAGA' *.fastq > count/B10033_Rm0.txt
agrep -0 -c 'CCGCAACGGTTGACCAA' *.fastq > count/B10034_Rm0.txt
agrep -0 -c 'GGTACACGTGTACCGTC' *.fastq > count/B10035_Rm0.txt
agrep -0 -c 'CAAAAGACGCACCCACG' *.fastq > count/B10036_Rm0.txt
agrep -0 -c 'TTTCGTAGACATCTACG' *.fastq > count/B10037_Rm0.txt
agrep -0 -c 'GCACACCGTCTCGTTTA' *.fastq > count/B10039_Rm0.txt
agrep -0 -c 'TTGTCGACAGTCATACT' *.fastq > count/B10040_Rm0.txt
agrep -0 -c 'GTTAGAAGGGTCTGCCA' *.fastq > count/B10041_Rm0.txt
agrep -0 -c 'AAAGAGGCGTGCTTCAG' *.fastq > count/B10044_Rm0.txt
agrep -0 -c 'GCCGTTTTTATAGCACT' *.fastq > count/B10045_Rm0.txt
agrep -0 -c 'ACGGGGGTATACCCACT' *.fastq > count/B10046_Rm0.txt
agrep -0 -c 'GGGATTGTAGTCTACGT' *.fastq > count/B10047_Rm0.txt
agrep -0 -c 'ATGTCAAGCTTATCGCC' *.fastq > count/B10048_Rm0.txt
agrep -0 -c 'ACCTGCTGTCGCAAAGG' *.fastq > count/B10049_Rm0.txt
agrep -0 -c 'GGGCATTTCCACAGTGA' *.fastq > count/B10050_Rm0.txt
agrep -0 -c 'TACCGGTTTTCTGGAAC' *.fastq > count/B10051_Rm0.txt
agrep -0 -c 'GAACAAGTCGACTCACT' *.fastq > count/B10052_Rm0.txt
agrep -0 -c 'TCGAAGTGATTTGTCCC' *.fastq > count/B10053_Rm0.txt
agrep -0 -c 'CCGAGATCGAGCCATAT' *.fastq > count/B10054_Rm0.txt
agrep -0 -c 'GAGACCCGTAATCCAAC' *.fastq > count/B10057_Rm0.txt
agrep -0 -c 'ACGTGGTGGCTTCATAG' *.fastq > count/B10058_Rm0.txt
agrep -0 -c 'GTTGACAATGACACATG' *.fastq > count/B10059_Rm0.txt
agrep -0 -c 'ACGGAAAGAACGGACAC' *.fastq > count/B10060_Rm0.txt
agrep -0 -c 'CGCATAATGCTCGTTGG' *.fastq > count/B10061_Rm0.txt
agrep -0 -c 'ACCTCGCAGGGCTAAGA' *.fastq > count/B10062_Rm0.txt
agrep -0 -c 'GGGCCAATTTATATCAC' *.fastq > count/B10063_Rm0.txt
agrep -0 -c 'GATAAGTGAGATGGTGT' *.fastq > count/B10065_Rm0.txt
agrep -0 -c 'CTCACGGGCATCTCTCT' *.fastq > count/B10067_Rm0.txt
agrep -0 -c 'AATATCGGCGCTCTTGG' *.fastq > count/B10068_Rm0.txt
agrep -0 -c 'AATTAATGCACCCGTTG' *.fastq > count/B10069_Rm0.txt
agrep -0 -c 'CCGGAGTATCCTGCATT' *.fastq > count/B10070_Rm0.txt
agrep -0 -c 'ACATTATCTGCGAACGG' *.fastq > count/B10071_Rm0.txt
agrep -0 -c 'TAATGACGCCCCAAGTT' *.fastq > count/B10072_Rm0.txt
agrep -0 -c 'AATTTTGTGATAGCCGG' *.fastq > count/B10073_Rm0.txt
agrep -0 -c 'AGCCATGGTTAGCTAGT' *.fastq > count/B10074_Rm0.txt
agrep -0 -c 'CCGACACGTGATCTCCA' *.fastq > count/B10075_Rm0.txt
agrep -0 -c 'TTAACGCTGCGAGCACC' *.fastq > count/B10076_Rm0.txt
agrep -0 -c 'ATTTCGGCTGACTGTCT' *.fastq > count/B10078_Rm0.txt
agrep -0 -c 'CCCAGCTTCAGTAGACG' *.fastq > count/B10080_Rm0.txt
agrep -0 -c 'GCTCACGATCACTTACA' *.fastq > count/B10081_Rm0.txt
agrep -0 -c 'TATGGTCACACGGAAAT' *.fastq > count/B10082_Rm0.txt
agrep -0 -c 'GGTATCTTGCGATCGAG' *.fastq > count/B10084_Rm0.txt
agrep -0 -c 'TAACAGACCTTGCGCCG' *.fastq > count/B10085_Rm0.txt
agrep -0 -c 'TCCGCCGTTGCTGTCAA' *.fastq > count/B10086_Rm0.txt
agrep -0 -c 'CTGAATCTCTCGGTTTA' *.fastq > count/B10087_Rm0.txt
agrep -0 -c 'TCAGTCCTCGTACATTA' *.fastq > count/B10088_Rm0.txt
agrep -0 -c 'CCGATTAGGCCTCATAG' *.fastq > count/B10089_Rm0.txt
agrep -0 -c 'CATTTAGTCTGGTTGTG' *.fastq > count/B10090_Rm0.txt
agrep -0 -c 'CATAGTCACCAGGATCG' *.fastq > count/B10091_Rm0.txt
agrep -0 -c 'GTTAGCTAGTACAGTGG' *.fastq > count/B10092_Rm0.txt
agrep -0 -c 'ACACTCGTTACACCACC' *.fastq > count/B10093_Rm0.txt
agrep -0 -c 'TAAACGCCTCCCTTAGG' *.fastq > count/B10094_Rm0.txt
agrep -0 -c 'GGAAGAGGGCACATTCC' *.fastq > count/B10095_Rm0.txt
agrep -0 -c 'TCAAGGTCCTGCTCGAC' *.fastq > count/B10096_Rm0.txt
agrep -0 -c 'TGCCCGTAGTCTAACTG' *.fastq > count/B10097_Rm0.txt
agrep -0 -c 'CCGAGTATGCTACCATA' *.fastq > count/B10098_Rm0.txt
agrep -0 -c 'CTAGCTAAATGGCAATG' *.fastq > count/B10100_Rm0.txt
agrep -0 -c 'ATCACCGATGGTTCGTT' *.fastq > count/B10101_Rm0.txt
agrep -0 -c 'ACAATCTGGGAGTAGAT' *.fastq > count/B10103_Rm0.txt
agrep -0 -c 'AGCATGCGGTGTTAGAG' *.fastq > count/B10104_Rm0.txt
agrep -0 -c 'AGTACAACACATTACCC' *.fastq > count/B10105_Rm0.txt
agrep -0 -c 'TAGTGAGATAACGCTGG' *.fastq > count/B10106_Rm0.txt
agrep -0 -c 'AACACGGGCGCACCTAA' *.fastq > count/B10107_Rm0.txt
agrep -0 -c 'GCTACAAAACCTAGCGA' *.fastq > count/B10108_Rm0.txt
agrep -0 -c 'TTCAGACGGCTGAACAT' *.fastq > count/B10109_Rm0.txt
agrep -0 -c 'ATATACCGTGGGACTAT' *.fastq > count/B10110_Rm0.txt
agrep -0 -c 'GTGTTAATGGAACGGTT' *.fastq > count/B10111_Rm0.txt
agrep -0 -c 'ATGAAAAGGACCACGTT' *.fastq > count/B10112_Rm0.txt
agrep -0 -c 'TAGAACACCAAGGGGAA' *.fastq > count/B10113_Rm0.txt
agrep -0 -c 'TGAGAGTTCGTGTCAGC' *.fastq > count/B10115_Rm0.txt
agrep -0 -c 'TTATTCCGTATACGCCG' *.fastq > count/B10117_Rm0.txt
agrep -0 -c 'AGCACACCTAGGCATGA' *.fastq > count/B10119_Rm0.txt
agrep -0 -c 'AGAGGGTCGATCATGTG' *.fastq > count/B10120_Rm0.txt
agrep -0 -c 'GACGAGTGGACAGTGTG' *.fastq > count/B10121_Rm0.txt
agrep -0 -c 'ACCTGAATCGTCGACAG' *.fastq > count/B10122_Rm0.txt
agrep -0 -c 'CAACACTCTCCAGTCAT' *.fastq > count/B10123_Rm0.txt
agrep -0 -c 'TCGTGTAGGGTTACTAG' *.fastq > count/B10125_Rm0.txt
agrep -0 -c 'TAAGTTACGTCCCCCAC' *.fastq > count/B10126_Rm0.txt
agrep -0 -c 'CTGGAAAATTTACGGCT' *.fastq > count/B10127_Rm0.txt
agrep -0 -c 'GATGACTTACGTAGGCC' *.fastq > count/B10128_Rm0.txt
agrep -0 -c 'GATGGGTGTCGACAGTG' *.fastq > count/B10129_Rm0.txt
agrep -0 -c 'ACGCACACAAAAACCGC' *.fastq > count/B10130_Rm0.txt
agrep -0 -c 'CGGACTAGCACCACACT' *.fastq > count/B10131_Rm0.txt
agrep -0 -c 'GCAGTGTGGAACGGTAC' *.fastq > count/B10132_Rm0.txt
agrep -0 -c 'AAATCGGGGAGTTCTGA' *.fastq > count/B10133_Rm0.txt
agrep -0 -c 'TACACACGTAACTGTGT' *.fastq > count/B10135_Rm0.txt
agrep -0 -c 'ATCGGGATGTGTTTTAC' *.fastq > count/B10136_Rm0.txt
agrep -0 -c 'GCGAAAGAAACACGAAC' *.fastq > count/B10137_Rm0.txt
agrep -0 -c 'ACCGGGTTGACTTACAA' *.fastq > count/B10140_Rm0.txt
agrep -0 -c 'TCCGTGTAGCAAGTGAT' *.fastq > count/B10141_Rm0.txt
agrep -0 -c 'TTATGTAACCACCTGTC' *.fastq > count/B10142_Rm0.txt
agrep -0 -c 'CCTCCCGTTTAGTAACT' *.fastq > count/B10143_Rm0.txt
agrep -0 -c 'TATCAGGAGGGTGCTCG' *.fastq > count/B10144_Rm0.txt
agrep -0 -c 'CACTAGGGAAGGCATCG' *.fastq > count/B10145_Rm0.txt
agrep -0 -c 'CCGGTTCCCTTATCCTG' *.fastq > count/B10146_Rm0.txt
agrep -0 -c 'CGCATGAATATAAGCGC' *.fastq > count/B10147_Rm0.txt
agrep -0 -c 'AACTTTCGTTACAGCAG' *.fastq > count/B10148_Rm0.txt
agrep -0 -c 'CGTACTGGTCCATCTCT' *.fastq > count/B10149_Rm0.txt
agrep -0 -c 'ACAAGTTCTGATGTCGA' *.fastq > count/B10150_Rm0.txt
agrep -0 -c 'ACCTGCACGATACGGTT' *.fastq > count/B10151_Rm0.txt
agrep -0 -c 'CGTCGTGGAACCATCCA' *.fastq > count/B10154_Rm0.txt
agrep -0 -c 'TCCGGATTAATAGCAGT' *.fastq > count/B10155_Rm0.txt
agrep -0 -c 'TTGATGTTTACGCACTG' *.fastq > count/B10156_Rm0.txt
agrep -0 -c 'GAAGTATCTCAGCGTGA' *.fastq > count/B10157_Rm0.txt
agrep -0 -c 'TGTTATTGCCAATGGCA' *.fastq > count/B10158_Rm0.txt
agrep -0 -c 'GGGACCAACGTCTATCC' *.fastq > count/B10159_Rm0.txt
agrep -0 -c 'TTACGGGAGAGTATACG' *.fastq > count/B10160_Rm0.txt
agrep -0 -c 'GAATGTTTGGCCTGAGG' *.fastq > count/B10162_Rm0.txt
agrep -0 -c 'GACCAGTATAGTTGGTA' *.fastq > count/B10164_Rm0.txt
agrep -0 -c 'ATACCGCTCCGCATTGG' *.fastq > count/B10165_Rm0.txt
agrep -0 -c 'TCGGTCAAAACAGTCCG' *.fastq > count/B10166_Rm0.txt
agrep -0 -c 'ACGTAGGCCACAGCATA' *.fastq > count/B10168_Rm0.txt
agrep -0 -c 'CGTCGGCCTTTTCCATC' *.fastq > count/B10169_Rm0.txt
agrep -0 -c 'CGAGCGTAAAAAGTGTT' *.fastq > count/B10170_Rm0.txt
agrep -0 -c 'TCTTAGGCTCGCGCTCA' *.fastq > count/B10171_Rm0.txt
agrep -0 -c 'GTTTGGAAAGGGAACTC' *.fastq > count/B10172_Rm0.txt
agrep -0 -c 'GAGTTGACCACGCACAC' *.fastq > count/B10173_Rm0.txt
agrep -0 -c 'GATCTGTTAGACAGACC' *.fastq > count/B10174_Rm0.txt
agrep -0 -c 'TTTGTGACCATCCGTCC' *.fastq > count/B10175_Rm0.txt
agrep -0 -c 'GATCCGAGGCACCGAAT' *.fastq > count/B10176_Rm0.txt
agrep -0 -c 'GGTAATGTGACCGTTGA' *.fastq > count/B10177_Rm0.txt
agrep -0 -c 'TTGGGATGTCTCAGTTG' *.fastq > count/B10178_Rm0.txt
agrep -0 -c 'ATGTTCACTCCTGCAGG' *.fastq > count/B10180_Rm0.txt
agrep -0 -c 'GTAAGCACTACCGGCGT' *.fastq > count/B10182_Rm0.txt
agrep -0 -c 'TGGCTGACCACTTATAA' *.fastq > count/B10183_Rm0.txt
agrep -0 -c 'CGTCGTGGTCATAAGAT' *.fastq > count/B10184_Rm0.txt
agrep -0 -c 'ACGAGATGCCTGTCGCA' *.fastq > count/B10185_Rm0.txt
agrep -0 -c 'CATGTCCCGCATTAATC' *.fastq > count/B10186_Rm0.txt
agrep -0 -c 'TACTCTCATATGGATCG' *.fastq > count/B10187_Rm0.txt
agrep -0 -c 'GTTTCCTTCAAGGGGTA' *.fastq > count/B10188_Rm0.txt
agrep -0 -c 'CTAAGCGCTTATAGTTG' *.fastq > count/B10189_Rm0.txt
agrep -0 -c 'ACGTTCACACTTGGCGT' *.fastq > count/B10191_Rm0.txt
agrep -0 -c 'GGTGTTATTACTCCAGG' *.fastq > count/B10192_Rm0.txt
agrep -0 -c 'GCCTATTGCAAGAGTAC' *.fastq > count/B10193_Rm0.txt
agrep -0 -c 'GAGTCTTGCCATGAACA' *.fastq > count/B10194_Rm0.txt
agrep -0 -c 'AGAGATCCAATGCGTAG' *.fastq > count/B10195_Rm0.txt
agrep -0 -c 'AAGCGCAGCACTGACTA' *.fastq > count/B10196_Rm0.txt
agrep -0 -c 'AGAACAAAGGTGCGCTC' *.fastq > count/B10198_Rm0.txt
agrep -0 -c 'CTCGTCAAGAACCTTCG' *.fastq > count/B10199_Rm0.txt
agrep -0 -c 'TGCGATATTGAGGATAC' *.fastq > count/B10200_Rm0.txt
agrep -0 -c 'CTAACGAGTAGCTGGAT' *.fastq > count/B10201_Rm0.txt
agrep -0 -c 'GATAGGGACGAACCTGG' *.fastq > count/B10202_Rm0.txt
agrep -0 -c 'TTACGACGAAATCTGCT' *.fastq > count/B10203_Rm0.txt
agrep -0 -c 'TGCCGCTGGTTATCCTA' *.fastq > count/B10204_Rm0.txt
agrep -0 -c 'GGCACCGCTGCTAATGA' *.fastq > count/B10205_Rm0.txt
agrep -0 -c 'CAGCAGACTACGTATAT' *.fastq > count/B10206_Rm0.txt
agrep -0 -c 'CGGTGAAATTACGATAG' *.fastq > count/B10207_Rm0.txt
agrep -0 -c 'CCATCTTCAGTGCGCTC' *.fastq > count/B10208_Rm0.txt
agrep -0 -c 'TGACACACAAACTCGCA' *.fastq > count/B10209_Rm0.txt
agrep -0 -c 'ACGCAAAGGGCATGCCT' *.fastq > count/B10210_Rm0.txt
agrep -0 -c 'TAGTCCCCTGTTGTCCT' *.fastq > count/B10213_Rm0.txt
agrep -0 -c 'ATCATGGAAGCTTATCG' *.fastq > count/B10214_Rm0.txt
agrep -0 -c 'TGAACCAATCTAGTCAC' *.fastq > count/B10215_Rm0.txt
agrep -0 -c 'GCCCCCAAACTTGAATT' *.fastq > count/B10216_Rm0.txt
agrep -0 -c 'GGGAATCGCTTGGCATA' *.fastq > count/B10217_Rm0.txt
agrep -0 -c 'TCTCAGGACACGGCTAT' *.fastq > count/B10218_Rm0.txt
agrep -0 -c 'TCGTCGTACCTAATTGC' *.fastq > count/B10220_Rm0.txt
agrep -0 -c 'GAGTAGTGTCCCCAGCT' *.fastq > count/B10221_Rm0.txt
agrep -0 -c 'TGTCCGACTAAGTTGCA' *.fastq > count/B10223_Rm0.txt
agrep -0 -c 'CACATAACCCGGAGATA' *.fastq > count/B10224_Rm0.txt
agrep -0 -c 'AGTCGCCCTATAAATGC' *.fastq > count/B10225_Rm0.txt
agrep -0 -c 'ATACTGCGAGTTAGTCC' *.fastq > count/B10226_Rm0.txt
agrep -0 -c 'TCGATGATAGAGTGTGG' *.fastq > count/B10228_Rm0.txt
agrep -0 -c 'ATCCCTTTGGGAATTTG' *.fastq > count/B10229_Rm0.txt
agrep -0 -c 'TTTCAAAGCATCGTTGC' *.fastq > count/B10230_Rm0.txt
agrep -0 -c 'CGACTGTAATGCTCCAC' *.fastq > count/B10232_Rm0.txt
agrep -0 -c 'CCTCGCCTGCTACTGAA' *.fastq > count/B10233_Rm0.txt
agrep -0 -c 'GACATAGTGCGACCCTA' *.fastq > count/B10235_Rm0.txt
agrep -0 -c 'TTAAACAATAAGGCGCG' *.fastq > count/B10236_Rm0.txt
agrep -0 -c 'AATACGTGTTCCACCCT' *.fastq > count/B10237_Rm0.txt
agrep -0 -c 'TACAGCACTTTCGCGGC' *.fastq > count/B10238_Rm0.txt
agrep -0 -c 'ACGCACCATACGGTATT' *.fastq > count/B10239_Rm0.txt
agrep -0 -c 'TGGTTAACTTGAGTCGT' *.fastq > count/B10240_Rm0.txt
agrep -0 -c 'AACCCCCGGCTCTAGAA' *.fastq > count/B10242_Rm0.txt
agrep -0 -c 'TATCACAGGACGTTCGC' *.fastq > count/B10243_Rm0.txt
agrep -0 -c 'GAGGTGACTCATTTTTG' *.fastq > count/B10244_Rm0.txt
agrep -0 -c 'ATAAGCCGCCACAATGC' *.fastq > count/B10245_Rm0.txt
agrep -0 -c 'ACGAACTCTACCGAGAA' *.fastq > count/B10246_Rm0.txt
agrep -0 -c 'GGGATAGTACACCCGAT' *.fastq > count/B10247_Rm0.txt
agrep -0 -c 'TAAGGCTTTAGGCGTGG' *.fastq > count/B10248_Rm0.txt
agrep -0 -c 'CACCGAGTGCGACTATT' *.fastq > count/B10250_Rm0.txt
agrep -0 -c 'CGTTAGCCATGTCTATC' *.fastq > count/B10251_Rm0.txt
agrep -0 -c 'ACGATGCTAGGACAACG' *.fastq > count/B10253_Rm0.txt
agrep -0 -c 'GCACGAGATAGCCAACT' *.fastq > count/B10254_Rm0.txt
agrep -0 -c 'TTGATCAGCCAGCACCC' *.fastq > count/B10255_Rm0.txt
agrep -0 -c 'GCCACTGTCGTGCTTAA' *.fastq > count/B10256_Rm0.txt
agrep -0 -c 'AAAGCGACGAGATTGCG' *.fastq > count/B10257_Rm0.txt
agrep -0 -c 'GAACCTACGCCGAGAAC' *.fastq > count/B10258_Rm0.txt
agrep -0 -c 'GGAGCGTACTTATGGCC' *.fastq > count/B10259_Rm0.txt
agrep -0 -c 'AGACAGTTTGTCGCGAG' *.fastq > count/B10260_Rm0.txt
agrep -0 -c 'TATCGGGCACCATCAAG' *.fastq > count/B10261_Rm0.txt
agrep -0 -c 'AAGCCAAGTCACTGGTA' *.fastq > count/B10263_Rm0.txt
agrep -0 -c 'TAGGCCTTAGATCGCAC' *.fastq > count/B10264_Rm0.txt
agrep -0 -c 'CCATACGCAAAGAGGAA' *.fastq > count/B10265_Rm0.txt
agrep -0 -c 'GTTTCTGCCAACTCCTA' *.fastq > count/B10266_Rm0.txt
agrep -0 -c 'TCGGGAGGACTTGTTCT' *.fastq > count/B10267_Rm0.txt
agrep -0 -c 'TCCCTATGTAGTCGGAT' *.fastq > count/B10268_Rm0.txt
agrep -0 -c 'ACTCGTGCCTGAGACAA' *.fastq > count/B10270_Rm0.txt
agrep -0 -c 'CTAAATGACTGCCGACG' *.fastq > count/B10271_Rm0.txt
agrep -0 -c 'CTTAGCTGTTCGCGTCA' *.fastq > count/B10272_Rm0.txt
agrep -0 -c 'ACCTCCTCTCGAAAACT' *.fastq > count/B10273_Rm0.txt
agrep -0 -c 'GCAACGGTTGACAATAC' *.fastq > count/B10274_Rm0.txt
agrep -0 -c 'CAACTCAGGGTTTGGGC' *.fastq > count/B10275_Rm0.txt
agrep -0 -c 'CAACTTTCTCGCGAAGA' *.fastq > count/B10276_Rm0.txt
agrep -0 -c 'TTCGAGAAATAGCCACG' *.fastq > count/B10277_Rm0.txt
agrep -0 -c 'GAGATGTCATCATACGC' *.fastq > count/B10278_Rm0.txt
agrep -0 -c 'CGGGTTCTTACGTTCTC' *.fastq > count/B10280_Rm0.txt
agrep -0 -c 'ATGGACACCACAACACT' *.fastq > count/B10281_Rm0.txt
agrep -0 -c 'ATCTTCCTCCACACGAA' *.fastq > count/B10282_Rm0.txt
agrep -0 -c 'ACTAACGACCACTGTCG' *.fastq > count/B10283_Rm0.txt
agrep -0 -c 'TCTCGACCAAGACACTT' *.fastq > count/B10284_Rm0.txt
agrep -0 -c 'AGATCGACTGGCACCTC' *.fastq > count/B10285_Rm0.txt
agrep -0 -c 'TAACATTTAGGTCGTCG' *.fastq > count/B10286_Rm0.txt
agrep -0 -c 'GCTTGCTTTGATCAGCC' *.fastq > count/B10287_Rm0.txt
agrep -0 -c 'TCGCCTATAAAAATCGG' *.fastq > count/B10288_Rm0.txt
agrep -0 -c 'CTTAACTTTAGCCGTCT' *.fastq > count/B10289_Rm0.txt
agrep -0 -c 'AACGCGAGCTGAAGAAG' *.fastq > count/B10290_Rm0.txt
agrep -0 -c 'CATCGAATCGCCAGTAC' *.fastq > count/B10291_Rm0.txt
agrep -0 -c 'GTGATATCTGCCACTAG' *.fastq > count/B10292_Rm0.txt
agrep -0 -c 'TGCCTACTACGATTACG' *.fastq > count/B10294_Rm0.txt
agrep -0 -c 'GAAGCAGCGCAATCAAC' *.fastq > count/B10295_Rm0.txt
agrep -0 -c 'CTCTAGCTTACTATCGT' *.fastq > count/B10296_Rm0.txt
agrep -0 -c 'CACGTCCTTAGTAGTAT' *.fastq > count/B10297_Rm0.txt
agrep -0 -c 'GAGGCCGTCAAACATAC' *.fastq > count/B10298_Rm0.txt
agrep -0 -c 'ACGAACTCTCCTCAGGT' *.fastq > count/B10299_Rm0.txt
agrep -0 -c 'TTGTTTAGTCCGCTCGA' *.fastq > count/B10300_Rm0.txt
agrep -0 -c 'CGCATAATCTGAGACTG' *.fastq > count/B10301_Rm0.txt
agrep -0 -c 'TTCGACAAATGCGCCCC' *.fastq > count/B10302_Rm0.txt
agrep -0 -c 'TCATAGTTGTCACTCCA' *.fastq > count/B10303_Rm0.txt
agrep -0 -c 'GTCTAGTAAGCCTACAG' *.fastq > count/B10304_Rm0.txt
agrep -0 -c 'TAGGTTCTCTCGGGCAG' *.fastq > count/B10305_Rm0.txt
agrep -0 -c 'AGACTGCCGGACGAATG' *.fastq > count/B10307_Rm0.txt
agrep -0 -c 'TAGACGACCAAATCCAT' *.fastq > count/B10308_Rm0.txt
agrep -0 -c 'GGACAAGCGCGGACTAA' *.fastq > count/B10309_Rm0.txt
agrep -0 -c 'TCCCTTTACCTGTACAG' *.fastq > count/B10310_Rm0.txt
agrep -0 -c 'CTACCCGAATTGCTGTA' *.fastq > count/B10312_Rm0.txt
agrep -0 -c 'GATCGCGTCAGACTTTA' *.fastq > count/B10314_Rm0.txt
agrep -0 -c 'TAGTCGATCCGAAGCGA' *.fastq > count/B10315_Rm0.txt
agrep -0 -c 'CCTTTTGTATACTTCCG' *.fastq > count/B10317_Rm0.txt
agrep -0 -c 'GAAACGTCTGTTCAGAG' *.fastq > count/B10318_Rm0.txt
agrep -0 -c 'TAGGAGGTTGAACGCAC' *.fastq > count/B10319_Rm0.txt
agrep -0 -c 'AAACATCTACGTCGCGC' *.fastq > count/B10320_Rm0.txt
agrep -0 -c 'CTCGATCCTAGCGATAA' *.fastq > count/B10321_Rm0.txt
agrep -0 -c 'TGAAAAGCGGTGAGACG' *.fastq > count/B10322_Rm0.txt
agrep -0 -c 'CTGATACATACTACGCG' *.fastq > count/B10323_Rm0.txt
agrep -0 -c 'TCTCCGATGGAAAGTAG' *.fastq > count/B10324_Rm0.txt
agrep -0 -c 'GTCGTAACCGCCAACTT' *.fastq > count/B10325_Rm0.txt
agrep -0 -c 'CAGGTGTGACATCTTCG' *.fastq > count/B10326_Rm0.txt
agrep -0 -c 'CAATTCCGTGTCAGTTG' *.fastq > count/B10327_Rm0.txt
agrep -0 -c 'ACTCTGGACTGTGAGAC' *.fastq > count/B10328_Rm0.txt
agrep -0 -c 'GTGTAGCGAATTTACCG' *.fastq > count/B10329_Rm0.txt
agrep -0 -c 'ACCGAAGTAAGGCGTAA' *.fastq > count/B10332_Rm0.txt
agrep -0 -c 'CGACAGTACAGATAGTA' *.fastq > count/B10333_Rm0.txt
agrep -0 -c 'GTATTCTCGGTTGGCAG' *.fastq > count/B10334_Rm0.txt
agrep -0 -c 'TGACGGTATTACGGCGC' *.fastq > count/B10335_Rm0.txt
agrep -0 -c 'CTTGTTCACCGTAGAGC' *.fastq > count/B10336_Rm0.txt
agrep -0 -c 'TTAGTGGGTATGTCATC' *.fastq > count/B10337_Rm0.txt
agrep -0 -c 'GCGGGCATTTGACTTGA' *.fastq > count/B10339_Rm0.txt
agrep -0 -c 'ACGGTAAGCGATCGCTA' *.fastq > count/B10342_Rm0.txt
agrep -0 -c 'GTCTTGCTAGCCGAAAT' *.fastq > count/B10343_Rm0.txt
agrep -0 -c 'AAGGTGTAATACCCAGG' *.fastq > count/B10344_Rm0.txt
agrep -0 -c 'TCTATGACTGCGTCTCA' *.fastq > count/B10345_Rm0.txt
agrep -0 -c 'GCGAATTCGGGGCGTAA' *.fastq > count/B10346_Rm0.txt
agrep -0 -c 'ACCTAGGAATTATCCTC' *.fastq > count/B10347_Rm0.txt
agrep -0 -c 'TTTCTGCAATTTGCACC' *.fastq > count/B10348_Rm0.txt
agrep -0 -c 'CCTGCTTACGAGTCCTC' *.fastq > count/B10350_Rm0.txt
agrep -0 -c 'TTCGGACGGGACTCAAT' *.fastq > count/B10351_Rm0.txt
agrep -0 -c 'TGGCCGGTCAACGTTAT' *.fastq > count/B10352_Rm0.txt
agrep -0 -c 'GCTGACATACTCAGAGA' *.fastq > count/B10353_Rm0.txt
agrep -0 -c 'TGAATCGGCAGGATGCA' *.fastq > count/B10354_Rm0.txt
agrep -0 -c 'ATACCGGCTAGCTACTT' *.fastq > count/B10356_Rm0.txt
agrep -0 -c 'ATGAAACCCTCCGTAGA' *.fastq > count/B10358_Rm0.txt
agrep -0 -c 'TCAATAACCGATATCGG' *.fastq > count/B10360_Rm0.txt
agrep -0 -c 'TACTGGTTCTGGTCGAC' *.fastq > count/B10361_Rm0.txt
agrep -0 -c 'ATAGTGAAACTACGAGG' *.fastq > count/B10362_Rm0.txt
agrep -0 -c 'CATTTATTGGGCCCTAT' *.fastq > count/B10363_Rm0.txt
agrep -0 -c 'CAGCTCCTAGACTCAGG' *.fastq > count/B10367_Rm0.txt
agrep -0 -c 'AGTTGCCATGGGTTCGC' *.fastq > count/B10370_Rm0.txt
agrep -0 -c 'GATCCGATTGAGTTATC' *.fastq > count/B10371_Rm0.txt
agrep -0 -c 'GTGTTGCAACTTCCGGC' *.fastq > count/B10372_Rm0.txt
agrep -0 -c 'CTCCTGTCTGTTCAACC' *.fastq > count/B10376_Rm0.txt
agrep -0 -c 'ATCTTGAAGACGACATC' *.fastq > count/B10377_Rm0.txt
agrep -0 -c 'TCTAGTGATGTCCGGAA' *.fastq > count/B10378_Rm0.txt
agrep -0 -c 'GCTAGGATACTCGGAGT' *.fastq > count/B10379_Rm0.txt
agrep -0 -c 'CCATTGCCTGACGGAAG' *.fastq > count/B10380_Rm0.txt
agrep -0 -c 'TTCACGGTTTTCGCGTG' *.fastq > count/B10381_Rm0.txt
agrep -0 -c 'GTTATTCCTAGCGTGCA' *.fastq > count/B10382_Rm0.txt
agrep -0 -c 'AAGCACGTAATCGGTTG' *.fastq > count/B10383_Rm0.txt
agrep -0 -c 'GTGTCCCGAGGAAGATA' *.fastq > count/B10384_Rm0.txt
agrep -0 -c 'CTAACTGGGAGTGTCAT' *.fastq > count/B10385_Rm0.txt
agrep -0 -c 'CCGGTATACGGGTTACT' *.fastq > count/B10388_Rm0.txt
agrep -0 -c 'GGCCACAGCAAACTATT' *.fastq > count/B10392_Rm0.txt
agrep -0 -c 'GTGAAGCCAGGTGCCAA' *.fastq > count/B10393_Rm0.txt
agrep -0 -c 'GAACTATTGTGGGACCG' *.fastq > count/B10394_Rm0.txt
agrep -0 -c 'TGTAACGGCCATTGCCA' *.fastq > count/B10396_Rm0.txt
agrep -0 -c 'ATCAGAGGCTGGAAGGC' *.fastq > count/B10397_Rm0.txt
agrep -0 -c 'TTAGGCCCGGGTTCATG' *.fastq > count/B10399_Rm0.txt
agrep -0 -c 'TTCAAGCGCAGCTGGAA' *.fastq > count/B10400_Rm0.txt
agrep -0 -c 'GGGGAAGTAAGTTGTGT' *.fastq > count/B10401_Rm0.txt
agrep -0 -c 'AGACGAGAGTATGGTAC' *.fastq > count/B10402_Rm0.txt
agrep -0 -c 'TCGTATGACTCTAGCAC' *.fastq > count/B10403_Rm0.txt
agrep -0 -c 'GAATGCCTAGCTTGTCG' *.fastq > count/B10404_Rm0.txt
agrep -0 -c 'AGTCTTAGTCGCCGAAC' *.fastq > count/B10405_Rm0.txt
agrep -0 -c 'CAAACTTAAACCCGCTG' *.fastq > count/B10406_Rm0.txt
agrep -0 -c 'CCTGGTTATCTGTCAGA' *.fastq > count/B10407_Rm0.txt
agrep -0 -c 'AAAGGTTGCGGGTGGGT' *.fastq > count/B10408_Rm0.txt
agrep -0 -c 'AGCATGCCGCATGGTCT' *.fastq > count/B10409_Rm0.txt
agrep -0 -c 'AGTACTTCGGAGTTGGT' *.fastq > count/B10410_Rm0.txt
agrep -0 -c 'CCTAGAGATGCGCTATG' *.fastq > count/B10411_Rm0.txt
agrep -0 -c 'AGCGAATCCGACAAAGA' *.fastq > count/B10412_Rm0.txt
agrep -0 -c 'CAGCATAACTGCGAATC' *.fastq > count/B10413_Rm0.txt
agrep -0 -c 'AAGGAAACCGATAGCGG' *.fastq > count/B10414_Rm0.txt
agrep -0 -c 'GCGGTAGAATCGCGATT' *.fastq > count/B10415_Rm0.txt
agrep -0 -c 'GAAGTTAAGGGCATTAG' *.fastq > count/B10416_Rm0.txt
agrep -0 -c 'TATGCCAATTGGCCGCA' *.fastq > count/B10417_Rm0.txt
agrep -0 -c 'CTAAACCGTTTAACGAG' *.fastq > count/B10418_Rm0.txt
agrep -0 -c 'CAATCTTGGGCCGTGTC' *.fastq > count/B10421_Rm0.txt
agrep -0 -c 'AGACGTATCGAGCTGGT' *.fastq > count/B10422_Rm0.txt
agrep -0 -c 'AGTGAGGACAGGTCAAG' *.fastq > count/B10424_Rm0.txt
agrep -0 -c 'TGGCATGAGCAGTCTAA' *.fastq > count/B10425_Rm0.txt
agrep -0 -c 'CTACTTATGCCGTCGTA' *.fastq > count/B10426_Rm0.txt
agrep -0 -c 'ATACGGACATCAGCCAC' *.fastq > count/B10427_Rm0.txt
agrep -0 -c 'GGCGCGCGGACTTATAA' *.fastq > count/B10428_Rm0.txt
agrep -0 -c 'GGTCCATTTTTCGGAGA' *.fastq > count/B10429_Rm0.txt
agrep -0 -c 'CGTGATGCCCAACAAGG' *.fastq > count/B10430_Rm0.txt
agrep -0 -c 'GTGCTCGCTACGTCTTG' *.fastq > count/B10431_Rm0.txt
agrep -0 -c 'GATAATGGGACGAGATG' *.fastq > count/B10432_Rm0.txt
agrep -0 -c 'ATGGCCCCTTAAGTAGG' *.fastq > count/B10433_Rm0.txt
agrep -0 -c 'GGAATACGTACAGCAGA' *.fastq > count/B10434_Rm0.txt
agrep -0 -c 'TGCTAATCTGTGTAGCG' *.fastq > count/B10435_Rm0.txt
agrep -0 -c 'ATCGCAGAAGTACCAGG' *.fastq > count/B10436_Rm0.txt
agrep -0 -c 'CTGCCAACTGAGGCCTT' *.fastq > count/B10437_Rm0.txt
agrep -0 -c 'CAGATATGTCAGTCCGA' *.fastq > count/B10438_Rm0.txt
agrep -0 -c 'GAGTATGGAGTTGGTGC' *.fastq > count/B10440_Rm0.txt
agrep -0 -c 'TAGCCGCTAACATCCTG' *.fastq > count/B10441_Rm0.txt
agrep -0 -c 'GACTCATGATAACCGCT' *.fastq > count/B10443_Rm0.txt
agrep -0 -c 'ACTAGCAATCCAGGCAC' *.fastq > count/B10444_Rm0.txt
agrep -0 -c 'CACCTCTGATCGACTCT' *.fastq > count/B10445_Rm0.txt
agrep -0 -c 'CAATTCGGATGTCCCTT' *.fastq > count/B10446_Rm0.txt
agrep -0 -c 'TGAACACACAGCCTAGG' *.fastq > count/B10447_Rm0.txt
agrep -0 -c 'TGATCCCATAGTCAGTC' *.fastq > count/B10448_Rm0.txt
agrep -0 -c 'TGCATCCGCCATAAAGA' *.fastq > count/B10449_Rm0.txt
agrep -0 -c 'AGGTCTATAACGGCTAG' *.fastq > count/B10453_Rm0.txt
agrep -0 -c 'AGAGGCGGGCTGTGTAA' *.fastq > count/B10455_Rm0.txt
agrep -0 -c 'TTACATTGCCCGAGAGC' *.fastq > count/B10456_Rm0.txt
agrep -0 -c 'CCATGATGCCGACATTG' *.fastq > count/B10457_Rm0.txt
agrep -0 -c 'CGCGTTAAAGTCGATCA' *.fastq > count/B10459_Rm0.txt
agrep -0 -c 'TAGATCCCCGTATAGCG' *.fastq > count/B10461_Rm0.txt
agrep -0 -c 'TGAGTCCGCCATCTGAC' *.fastq > count/B10462_Rm0.txt
agrep -0 -c 'TTCTCCCTTAGATACGG' *.fastq > count/B10463_Rm0.txt
agrep -0 -c 'CGACCTTCAGGTAATGC' *.fastq > count/B10464_Rm0.txt
agrep -0 -c 'CTCAGATAAGACCAATG' *.fastq > count/B10465_Rm0.txt
agrep -0 -c 'AGGCTTCTAAAGGCCGT' *.fastq > count/B10466_Rm0.txt
agrep -0 -c 'AGCATAGTGTAACAGAC' *.fastq > count/B10467_Rm0.txt
agrep -0 -c 'AGAGGTACATTCCTGGC' *.fastq > count/B10468_Rm0.txt
agrep -0 -c 'CTGTCATGCGACTAGTG' *.fastq > count/B10469_Rm0.txt
agrep -0 -c 'ATTCTGACCGAGACGAG' *.fastq > count/B10471_Rm0.txt
agrep -0 -c 'GAGCTATTAGGGCGTGA' *.fastq > count/B10472_Rm0.txt
agrep -0 -c 'TTCACTATGAGAGTCAC' *.fastq > count/B10473_Rm0.txt
agrep -0 -c 'TAAGCGGAATCTGACGG' *.fastq > count/B10474_Rm0.txt
agrep -0 -c 'CAGTTGGTCATAACGAG' *.fastq > count/B10475_Rm0.txt
agrep -0 -c 'TGCGATAAGTGGGACAG' *.fastq > count/B10476_Rm0.txt
agrep -0 -c 'GAAGTTTTCGAATGCCA' *.fastq > count/B10477_Rm0.txt
agrep -0 -c 'GTTCGTAATCGGTCACC' *.fastq > count/B10478_Rm0.txt
agrep -0 -c 'AGGTCCTTGGTCGGAAC' *.fastq > count/B10480_Rm0.txt
agrep -0 -c 'GAAAACCGCCCAACAGA' *.fastq > count/B10481_Rm0.txt
agrep -0 -c 'TCCTATTTAGACGTCCC' *.fastq > count/B10482_Rm0.txt
agrep -0 -c 'CCCAGAAGGAATAGGTA' *.fastq > count/B10483_Rm0.txt
agrep -0 -c 'GCTGAGACGACAGTTTG' *.fastq > count/B10484_Rm0.txt
agrep -0 -c 'TTCCTTGACAGGAGCAC' *.fastq > count/B10485_Rm0.txt
agrep -0 -c 'AGCGCGATCCTTTGGTC' *.fastq > count/B10486_Rm0.txt
agrep -0 -c 'GAGTGATTGATATGGCG' *.fastq > count/B10487_Rm0.txt
agrep -0 -c 'TCTTCTTTTGACGCGAC' *.fastq > count/B10488_Rm0.txt
agrep -0 -c 'AAGCATAAGGCCGAGCA' *.fastq > count/B10489_Rm0.txt
agrep -0 -c 'AATGGCTTAGGTAGACG' *.fastq > count/B10490_Rm0.txt
agrep -0 -c 'CGGGCTTATGAATCTAA' *.fastq > count/B10491_Rm0.txt
agrep -0 -c 'GTCTACTGGGGTATCAT' *.fastq > count/B10492_Rm0.txt
agrep -0 -c 'TTGAGACGTGGGGTTGA' *.fastq > count/B10493_Rm0.txt
agrep -0 -c 'GAAGCACTTGTATACGT' *.fastq > count/B10494_Rm0.txt
agrep -0 -c 'CCGCTGGATTATGGAAT' *.fastq > count/B10495_Rm0.txt
agrep -0 -c 'CATGCCATCGAAAATTG' *.fastq > count/B10496_Rm0.txt
agrep -0 -c 'GAAGTAAGAACCGACTA' *.fastq > count/B10497_Rm0.txt
agrep -0 -c 'GTAGTACCCTCAAACTA' *.fastq > count/B10499_Rm0.txt
agrep -0 -c 'ACAGGGTATGAAAACTC' *.fastq > count/B10500_Rm0.txt
agrep -0 -c 'GGTGCATCACTAACAGA' *.fastq > count/B10501_Rm0.txt
agrep -0 -c 'ATGCACGGCAAGGGTTG' *.fastq > count/B10502_Rm0.txt
agrep -0 -c 'GACAGAGTTAAGCTCTC' *.fastq > count/B10503_Rm0.txt
agrep -0 -c 'TTGCACACGGATTCGGT' *.fastq > count/B10504_Rm0.txt
agrep -0 -c 'TCGTTTCACCCGATGAC' *.fastq > count/B10506_Rm0.txt
agrep -0 -c 'GATGGAGCCTGTGGCAA' *.fastq > count/B10507_Rm0.txt
agrep -0 -c 'AGAGTGCTGCTCGTTGG' *.fastq > count/B10508_Rm0.txt
agrep -0 -c 'GAGCGAGAGTCACAAAC' *.fastq > count/B10509_Rm0.txt
agrep -0 -c 'CCATACGAACGATGATC' *.fastq > count/B10510_Rm0.txt
agrep -0 -c 'ATCGCTACTCCTAGACG' *.fastq > count/B10511_Rm0.txt
agrep -0 -c 'GACTGCCGTTCACACTA' *.fastq > count/B10512_Rm0.txt
agrep -0 -c 'CTAAACCCTATCCATCG' *.fastq > count/B10513_Rm0.txt
agrep -0 -c 'CAAGTACGTAATGACCG' *.fastq > count/B10514_Rm0.txt
agrep -0 -c 'AGACCAGCTTATCTTGC' *.fastq > count/B10515_Rm0.txt
agrep -0 -c 'AGTTGACGGGAATTCAC' *.fastq > count/B10516_Rm0.txt
agrep -0 -c 'AGGACTCGCAACAGGTG' *.fastq > count/B10517_Rm0.txt
agrep -0 -c 'CGAAGCACATCATAACG' *.fastq > count/B10518_Rm0.txt
agrep -0 -c 'TCACGCCGTTAAATCAT' *.fastq > count/B10519_Rm0.txt
agrep -0 -c 'AACGCAAAACATCGCGC' *.fastq > count/B10520_Rm0.txt
agrep -0 -c 'AGCTGTTTTAGACCGTA' *.fastq > count/B10521_Rm0.txt
agrep -0 -c 'ACCCTTACGATGGTATT' *.fastq > count/B10522_Rm0.txt
agrep -0 -c 'TTAACACCGTCTCCAAC' *.fastq > count/B10523_Rm0.txt
agrep -0 -c 'CACTCGGGCGGTTACAT' *.fastq > count/B10524_Rm0.txt
agrep -0 -c 'TAATTCCACCTAGGGTC' *.fastq > count/B10525_Rm0.txt
agrep -0 -c 'GTGTCGACGTGTTACTG' *.fastq > count/B10528_Rm0.txt
agrep -0 -c 'GTTCCTCTACTCAGGCC' *.fastq > count/B10529_Rm0.txt
agrep -0 -c 'GGTGACCTGGTGGTTAC' *.fastq > count/B10531_Rm0.txt
agrep -0 -c 'TGGCTATACACACCACG' *.fastq > count/B10533_Rm0.txt
agrep -0 -c 'TTTTGGGTTTGATTCGC' *.fastq > count/B10535_Rm0.txt
agrep -0 -c 'TCGAACGGATCAATAGC' *.fastq > count/B10537_Rm0.txt
agrep -0 -c 'GTGCGGGAGCAGCAAAT' *.fastq > count/B10538_Rm0.txt
agrep -0 -c 'AGCCGCGATACTCGACA' *.fastq > count/B10539_Rm0.txt
agrep -0 -c 'GTATTCTATGTCCTCGC' *.fastq > count/B10540_Rm0.txt
agrep -0 -c 'GCCATGGTGCATTCAGA' *.fastq > count/B10541_Rm0.txt
agrep -0 -c 'CCATAGATCATCCTCGG' *.fastq > count/B10542_Rm0.txt
agrep -0 -c 'GAGGAAACACCGTCTGG' *.fastq > count/B10543_Rm0.txt
agrep -0 -c 'TCAGAGGCCATACAATG' *.fastq > count/B10544_Rm0.txt
agrep -0 -c 'CGAGCTGACAGAACAAG' *.fastq > count/B10545_Rm0.txt
agrep -0 -c 'GAGGCACCACAATAGAG' *.fastq > count/B10546_Rm0.txt
agrep -0 -c 'GAGTCCATCGTTGCTAT' *.fastq > count/B10547_Rm0.txt
agrep -0 -c 'TATGTGTATGACCCCGT' *.fastq > count/B10548_Rm0.txt
agrep -0 -c 'TAGTTCCATGACGCGTT' *.fastq > count/B10549_Rm0.txt
agrep -0 -c 'TTGTGTGAAACACCGTG' *.fastq > count/B10550_Rm0.txt
agrep -0 -c 'TTCAGGTCCGCTAAGCA' *.fastq > count/B10551_Rm0.txt
agrep -0 -c 'GGACGTGCGAGGATGAA' *.fastq > count/B10552_Rm0.txt
agrep -0 -c 'CAGTACGATGACGGCCA' *.fastq > count/B10553_Rm0.txt
agrep -0 -c 'TCCTCTTCGAACATTGC' *.fastq > count/B10554_Rm0.txt
agrep -0 -c 'AATCGTAGCCCTCAATT' *.fastq > count/B10555_Rm0.txt
agrep -0 -c 'GCATAGTATCGGACCCG' *.fastq > count/B10557_Rm0.txt
agrep -0 -c 'GCTAAGGGTACGCGTTG' *.fastq > count/B10560_Rm0.txt
agrep -0 -c 'GTGAGGGTAGCTATACT' *.fastq > count/B10561_Rm0.txt
agrep -0 -c 'TAGTTTACTGTCGTCGA' *.fastq > count/B10562_Rm0.txt
agrep -0 -c 'ATCGAAGGTACTACAGA' *.fastq > count/B10567_Rm0.txt
agrep -0 -c 'GCGGCACGCTTTTTACA' *.fastq > count/B10568_Rm0.txt
agrep -0 -c 'AGTCTGACATATCCGAC' *.fastq > count/B10569_Rm0.txt
agrep -0 -c 'CCTTTCGTTGCATAATC' *.fastq > count/B10570_Rm0.txt
agrep -0 -c 'CTCGAGCACGTTTTTGG' *.fastq > count/B10572_Rm0.txt
agrep -0 -c 'CGAGAGATCGTGGGTTA' *.fastq > count/B10573_Rm0.txt
agrep -0 -c 'ACTGGGGCCTGTCACTT' *.fastq > count/B10574_Rm0.txt
agrep -0 -c 'GTTGTGTTTGCCGTCGT' *.fastq > count/B10575_Rm0.txt
agrep -0 -c 'TGTATAAGGCTGCCGCT' *.fastq > count/B10576_Rm0.txt
agrep -0 -c 'ACGACGCGCGCTTATCA' *.fastq > count/B10577_Rm0.txt
agrep -0 -c 'AGTAAAGCCAAACTCCC' *.fastq > count/B10578_Rm0.txt
agrep -0 -c 'AACTGCGACATACAGAC' *.fastq > count/B10579_Rm0.txt
agrep -0 -c 'CACGGATGGAGAGCGAT' *.fastq > count/B10580_Rm0.txt
agrep -0 -c 'CCTGGCTCGACTTGATT' *.fastq > count/B10581_Rm0.txt
agrep -0 -c 'AACTGCTCTACGACATC' *.fastq > count/B10582_Rm0.txt
agrep -0 -c 'TGCCATACATAGGAATG' *.fastq > count/B10583_Rm0.txt
agrep -0 -c 'TGCGAATGGATCAACAT' *.fastq > count/B10584_Rm0.txt
agrep -0 -c 'CCCCGTGTTCGGTATCT' *.fastq > count/B10585_Rm0.txt
agrep -0 -c 'CAGCATCTCCTACACGT' *.fastq > count/B10586_Rm0.txt
agrep -0 -c 'TAGTCACTCTAGGCTTA' *.fastq > count/B10587_Rm0.txt
agrep -0 -c 'CACGTGTAGCCAGTATG' *.fastq > count/B10588_Rm0.txt
agrep -0 -c 'GTGATCTAGTGGTTAGG' *.fastq > count/B10589_Rm0.txt
agrep -0 -c 'TTGTTAGACGATCCGCA' *.fastq > count/B10591_Rm0.txt
agrep -0 -c 'AGTCATTACGTAGTAGG' *.fastq > count/B10592_Rm0.txt
agrep -0 -c 'AGCCAACCTACCCTACC' *.fastq > count/B10593_Rm0.txt
agrep -0 -c 'GAACCTAAATTGCCGCA' *.fastq > count/B10594_Rm0.txt
agrep -0 -c 'GGGCTTAATGGTTTGTA' *.fastq > count/B10595_Rm0.txt
agrep -0 -c 'CTTGGGCCTACGAAGAC' *.fastq > count/B10596_Rm0.txt
agrep -0 -c 'ATCAGGAAAGTGTCGAG' *.fastq > count/B10598_Rm0.txt
agrep -0 -c 'CGATGAGCGGGATAGCA' *.fastq > count/B10600_Rm0.txt
agrep -0 -c 'TACTTTTTGATCGGACC' *.fastq > count/B10602_Rm0.txt
agrep -0 -c 'TAGTAGACTGAGCAAGA' *.fastq > count/B10603_Rm0.txt
agrep -0 -c 'TAGGAACGCTAATCCCT' *.fastq > count/B10604_Rm0.txt
agrep -0 -c 'TCACGACGGATATGGTC' *.fastq > count/B10606_Rm0.txt
agrep -0 -c 'CGAACAGACAGAGGTGA' *.fastq > count/B10607_Rm0.txt
agrep -0 -c 'AATGCGACCTTTGAGTT' *.fastq > count/B10609_Rm0.txt
agrep -0 -c 'AATGCGAAGATGCGTTG' *.fastq > count/B10610_Rm0.txt
agrep -0 -c 'TGCTGCGAGGACACTAC' *.fastq > count/B10612_Rm0.txt
agrep -0 -c 'CAGCTTGGAAAGTGGCC' *.fastq > count/B10613_Rm0.txt
agrep -0 -c 'GTTTGCCGTCATCAAGC' *.fastq > count/B10614_Rm0.txt
agrep -0 -c 'GGATTATAGCCCCGCTG' *.fastq > count/B10615_Rm0.txt
agrep -0 -c 'TTTGGATCGGGGCTTGT' *.fastq > count/B10617_Rm0.txt
agrep -0 -c 'TTAGGGTCGCATTCTAT' *.fastq > count/B10619_Rm0.txt
agrep -0 -c 'ACCACCGAGGAGGTTAG' *.fastq > count/B10620_Rm0.txt
agrep -0 -c 'CTCTCAATCGTGGCAAG' *.fastq > count/B10622_Rm0.txt
agrep -0 -c 'GACAGAAATAGGCTTGG' *.fastq > count/B10623_Rm0.txt
agrep -0 -c 'CGGAATCAAAGGAGGTC' *.fastq > count/B10624_Rm0.txt
agrep -0 -c 'TGTTTTTGCGAGTGAGA' *.fastq > count/B10625_Rm0.txt
agrep -0 -c 'TTCCCATCAGACCTAAC' *.fastq > count/B10626_Rm0.txt
agrep -0 -c 'AGAGCGTGTGATAGTGT' *.fastq > count/B10627_Rm0.txt
agrep -0 -c 'GTGCAAGACGTAATCTC' *.fastq > count/B10629_Rm0.txt
agrep -0 -c 'AGGTGAAGTAGACACAC' *.fastq > count/B10630_Rm0.txt
agrep -0 -c 'GAGTGTCGAAAGCCTTA' *.fastq > count/B10631_Rm0.txt
agrep -0 -c 'AGAGCGCATGATTCCCG' *.fastq > count/B10632_Rm0.txt
agrep -0 -c 'GAGGAATGTCATGTGTG' *.fastq > count/B10633_Rm0.txt
agrep -0 -c 'CTTTAACGTGTGGCTGG' *.fastq > count/B10635_Rm0.txt
agrep -0 -c 'TTTGGAACCGTCAGCAC' *.fastq > count/B10637_Rm0.txt
agrep -0 -c 'TGGTAACGTTAGAGCAG' *.fastq > count/B10638_Rm0.txt
agrep -0 -c 'CCATGCTAACTGGCAAG' *.fastq > count/B10641_Rm0.txt
agrep -0 -c 'CCAAAAGGTCCATCATC' *.fastq > count/B10642_Rm0.txt
agrep -0 -c 'AATCCGGCATTCACCCC' *.fastq > count/B10643_Rm0.txt
agrep -0 -c 'TCCCGCACTTCACAATA' *.fastq > count/B10644_Rm0.txt
agrep -0 -c 'TCGTCTTGCGAGAGGTA' *.fastq > count/B10645_Rm0.txt
agrep -0 -c 'CCCACTCAATGTTCCTC' *.fastq > count/B10647_Rm0.txt
agrep -0 -c 'CATAGGGCATCATCCTG' *.fastq > count/B10648_Rm0.txt
agrep -0 -c 'CGTGGCAAATAGCCTTA' *.fastq > count/B10649_Rm0.txt
agrep -0 -c 'TCACTACCGATAGCCAC' *.fastq > count/B10650_Rm0.txt
agrep -0 -c 'CGTTTAGGGGCTCAATG' *.fastq > count/B10651_Rm0.txt
agrep -0 -c 'GACCCCTTAGCTGACTG' *.fastq > count/B10652_Rm0.txt
agrep -0 -c 'AGCATCGACCACTTGAG' *.fastq > count/B10653_Rm0.txt
agrep -0 -c 'CGCAGGATACTGTAGCT' *.fastq > count/B10654_Rm0.txt
agrep -0 -c 'CGTCAAGTCTATTGTTG' *.fastq > count/B10656_Rm0.txt
agrep -0 -c 'TGGCCAATCTTCCGAAC' *.fastq > count/B10657_Rm0.txt
agrep -0 -c 'TGGGTCATACTCCGAGT' *.fastq > count/B10658_Rm0.txt
agrep -0 -c 'AAAGAAGCACATGGTCC' *.fastq > count/B10659_Rm0.txt
agrep -0 -c 'GCGAGCATAGAATGATG' *.fastq > count/B10660_Rm0.txt
agrep -0 -c 'GGTGTACCTTTTTTGCA' *.fastq > count/B10661_Rm0.txt
agrep -0 -c 'ACTGGTGGCACTGAATC' *.fastq > count/B10662_Rm0.txt
agrep -0 -c 'CCAAGTAGACGCAACCC' *.fastq > count/B10663_Rm0.txt
agrep -0 -c 'GATCACGGTGAATGCCG' *.fastq > count/B10664_Rm0.txt
agrep -0 -c 'TGCCCTCTATTACATAC' *.fastq > count/B10666_Rm0.txt
agrep -0 -c 'TTGGCGACTTCACCAGC' *.fastq > count/B10667_Rm0.txt
agrep -0 -c 'CAGCAGACTCGAGCGAT' *.fastq > count/B10668_Rm0.txt
agrep -0 -c 'CCACCCCGATCTGCTAT' *.fastq > count/B10669_Rm0.txt
agrep -0 -c 'TCGGGGGGGTATATGCA' *.fastq > count/B10670_Rm0.txt
agrep -0 -c 'ACCTCGCGTGTCTCGTT' *.fastq > count/B10671_Rm0.txt
agrep -0 -c 'CATCCGCTTAGGGTAAG' *.fastq > count/B10672_Rm0.txt
agrep -0 -c 'GGGTTATAGTACGCGGC' *.fastq > count/B10673_Rm0.txt
agrep -0 -c 'TGGAACTTAGGGAAGTT' *.fastq > count/B10674_Rm0.txt
agrep -0 -c 'TTCGAAGGCAATTCAAG' *.fastq > count/B10675_Rm0.txt
agrep -0 -c 'CTTGAAATTCCTCCTCG' *.fastq > count/B10677_Rm0.txt
agrep -0 -c 'ATCGCAACGTGATTACG' *.fastq > count/B10678_Rm0.txt
agrep -0 -c 'CACGCGGGGCATTTAGA' *.fastq > count/B10679_Rm0.txt
agrep -0 -c 'TTGTACAGGTGCCGACG' *.fastq > count/B10680_Rm0.txt
agrep -0 -c 'AAGTGCAACTCCTAGTC' *.fastq > count/B10681_Rm0.txt
agrep -0 -c 'TCTTACACTTGGAGTGG' *.fastq > count/B10682_Rm0.txt
agrep -0 -c 'CCTAGACGGATTTCCGG' *.fastq > count/B10683_Rm0.txt
agrep -0 -c 'CGAGTCGAGATAGGGAT' *.fastq > count/B10684_Rm0.txt
agrep -0 -c 'TCTTCTGGGGTGAAATG' *.fastq > count/B10686_Rm0.txt
agrep -0 -c 'AATTTAGCGTGTACCGG' *.fastq > count/B10687_Rm0.txt
agrep -0 -c 'TGTACATGACATGCTTG' *.fastq > count/B10688_Rm0.txt
agrep -0 -c 'GCTTACGGTCGTACTCA' *.fastq > count/B10689_Rm0.txt
agrep -0 -c 'CAGATTGGTGGTGTGAT' *.fastq > count/B10690_Rm0.txt
agrep -0 -c 'CGATGGGAGTGAATATA' *.fastq > count/B10691_Rm0.txt
agrep -0 -c 'AAGCAATCGAACTGGCG' *.fastq > count/B10692_Rm0.txt
agrep -0 -c 'AGCTCCCGTGATACCCT' *.fastq > count/B10694_Rm0.txt
agrep -0 -c 'CGTCGCAGGCTGTTCTA' *.fastq > count/B10695_Rm0.txt
agrep -0 -c 'GAATCCATGCCCTAGTT' *.fastq > count/B10696_Rm0.txt
agrep -0 -c 'TGCAATCGAACGGGTTG' *.fastq > count/B10697_Rm0.txt
agrep -0 -c 'AATTCGACAGACTCGAT' *.fastq > count/B10698_Rm0.txt
agrep -0 -c 'GGATAAACGCCATCGCC' *.fastq > count/B10699_Rm0.txt
agrep -0 -c 'TCTCTATGAAGGGTAGG' *.fastq > count/B10700_Rm0.txt
agrep -0 -c 'GATACCCAACTGAGTTA' *.fastq > count/B10701_Rm0.txt
agrep -0 -c 'TCAGGGCCTCGTCTTTA' *.fastq > count/B10702_Rm0.txt
agrep -0 -c 'GATGTGGTGGAATGTCG' *.fastq > count/B10703_Rm0.txt
agrep -0 -c 'TCAGGAGGGCATTTATT' *.fastq > count/B10704_Rm0.txt
agrep -0 -c 'GTCTAGTGGATGACTCT' *.fastq > count/B10705_Rm0.txt
agrep -0 -c 'GAGTAACGATCCTGCGG' *.fastq > count/B10707_Rm0.txt
agrep -0 -c 'GTATCAGGTGCTGCACG' *.fastq > count/B10708_Rm0.txt
agrep -0 -c 'TGACACTACAAGTGAGC' *.fastq > count/B10709_Rm0.txt
agrep -0 -c 'ACGTTGCAGATGCGTTG' *.fastq > count/B10711_Rm0.txt
agrep -0 -c 'TGCTCGCCGAGTGATAG' *.fastq > count/B10712_Rm0.txt
agrep -0 -c 'GGGTAACAGCATTCTCA' *.fastq > count/B10714_Rm0.txt
agrep -0 -c 'TCAACTGCACTCTGATG' *.fastq > count/B10716_Rm0.txt
agrep -0 -c 'AACCAGCACGCTGACGA' *.fastq > count/B10717_Rm0.txt
agrep -0 -c 'TAAGATCGCCGACCTCG' *.fastq > count/B10718_Rm0.txt
agrep -0 -c 'GACCGACATCGTATAGT' *.fastq > count/B10719_Rm0.txt
agrep -0 -c 'TTGTGGCAGTCCCAGAG' *.fastq > count/B10720_Rm0.txt
agrep -0 -c 'ACATCTCGCCAGAAGCG' *.fastq > count/B10721_Rm0.txt
agrep -0 -c 'AATTGGTCCACCGGTGT' *.fastq > count/B10722_Rm0.txt
agrep -0 -c 'ATTGCAAGGTCAAGTAG' *.fastq > count/B10723_Rm0.txt
agrep -0 -c 'TGCTATAACACCCCATG' *.fastq > count/B10724_Rm0.txt
agrep -0 -c 'TCAATGGCGGTCTCATA' *.fastq > count/B10725_Rm0.txt
agrep -0 -c 'ATTCACGCACACAGCAT' *.fastq > count/B10726_Rm0.txt
agrep -0 -c 'CTGCCCACTCAACGGTT' *.fastq > count/B10727_Rm0.txt
agrep -0 -c 'CCTAGTCTTTCGAATGT' *.fastq > count/B10728_Rm0.txt
agrep -0 -c 'GCCTTCTATCCGAGGTT' *.fastq > count/B10729_Rm0.txt
agrep -0 -c 'GCGTCAGGTACATACGG' *.fastq > count/B10730_Rm0.txt
agrep -0 -c 'ATCCCCCCTACGATAGT' *.fastq > count/B10731_Rm0.txt
agrep -0 -c 'TATCGACCCACTCACGA' *.fastq > count/B10732_Rm0.txt
agrep -0 -c 'GCCCATCTATACCATGC' *.fastq > count/B10733_Rm0.txt
agrep -0 -c 'CCGACTAGGCTACCTCA' *.fastq > count/B10734_Rm0.txt
agrep -0 -c 'ACCAGTATGCTCACTAG' *.fastq > count/B10735_Rm0.txt
agrep -0 -c 'AACGCCGTCTATTTCTG' *.fastq > count/B10736_Rm0.txt
agrep -0 -c 'GTCTTGCGCCATCCTTA' *.fastq > count/B10737_Rm0.txt
agrep -0 -c 'CCCAAATCATGAGCACG' *.fastq > count/B10738_Rm0.txt
agrep -0 -c 'TAGAGGGCACAGATCCA' *.fastq > count/B10739_Rm0.txt
agrep -0 -c 'AGAAGGGTAGTTATTCG' *.fastq > count/B10740_Rm0.txt
agrep -0 -c 'TCCCTGATACCCAGATA' *.fastq > count/B10741_Rm0.txt
agrep -0 -c 'CCGCAACAAATAGTGGT' *.fastq > count/B10742_Rm0.txt
agrep -0 -c 'GGATCTCGACTGCCGTA' *.fastq > count/B10743_Rm0.txt
agrep -0 -c 'GTAACCCAACGCCACAT' *.fastq > count/B10744_Rm0.txt
agrep -0 -c 'TACGAGCCCTCTGAAGA' *.fastq > count/B10745_Rm0.txt
agrep -0 -c 'ATCGCCGAATATAGCCT' *.fastq > count/B10747_Rm0.txt
agrep -0 -c 'ATTTTGCACCTCTGGAG' *.fastq > count/B10748_Rm0.txt
agrep -0 -c 'TAACAGGATTGGACACT' *.fastq > count/B10749_Rm0.txt
agrep -0 -c 'GATGCGCTTAATAGACC' *.fastq > count/B10750_Rm0.txt
agrep -0 -c 'TCTATAGTGGGGTGGGT' *.fastq > count/B10753_Rm0.txt
agrep -0 -c 'TTGACCCACAGCGAACT' *.fastq > count/B10754_Rm0.txt
agrep -0 -c 'AGGCTACGCGTGTCTAA' *.fastq > count/B10755_Rm0.txt
agrep -0 -c 'TCTACGACCGGTTTATT' *.fastq > count/B10756_Rm0.txt
agrep -0 -c 'TTGGCGAAAGTGTATAC' *.fastq > count/B10757_Rm0.txt
agrep -0 -c 'TAGACGTATAGTCGAGG' *.fastq > count/B10758_Rm0.txt
agrep -0 -c 'TCCGCGAGAAACGAACA' *.fastq > count/B10760_Rm0.txt
agrep -0 -c 'CTTTCGGATTAGTTAGG' *.fastq > count/B10761_Rm0.txt
agrep -0 -c 'AGAGAATTATCTCTGCC' *.fastq > count/B10762_Rm0.txt
agrep -0 -c 'ATAGGGTATTCTGACGC' *.fastq > count/B10763_Rm0.txt
agrep -0 -c 'TGGTGCCACATTGTGTA' *.fastq > count/B10764_Rm0.txt
agrep -0 -c 'CCGAATTTCAACACGCC' *.fastq > count/B10765_Rm0.txt
agrep -0 -c 'TAGCTTGTTGTGCCCGG' *.fastq > count/B10767_Rm0.txt
agrep -0 -c 'CGCGCTATAAACCTGAT' *.fastq > count/B10768_Rm0.txt
agrep -0 -c 'TATGGAGGCTCTGATCC' *.fastq > count/B10770_Rm0.txt
agrep -0 -c 'TATACTGAAGCGCTGAC' *.fastq > count/B10771_Rm0.txt
agrep -0 -c 'CGGGGCGTCCTATCAAT' *.fastq > count/B10772_Rm0.txt
agrep -0 -c 'GCTTCCATACTGAAAGT' *.fastq > count/B10773_Rm0.txt
agrep -0 -c 'AACGGGACTTAAGGATC' *.fastq > count/B10774_Rm0.txt
agrep -0 -c 'TATGTTCAGCGAGTATC' *.fastq > count/B10775_Rm0.txt
agrep -0 -c 'CGTTAAGAAGGCCTATC' *.fastq > count/B10776_Rm0.txt
agrep -0 -c 'AGAGATACGTGTGCCCG' *.fastq > count/B10777_Rm0.txt
agrep -0 -c 'GAACAGCTCGCGTTCTT' *.fastq > count/B10778_Rm0.txt
agrep -0 -c 'ACAGTTGAGTGGAGGAC' *.fastq > count/B10779_Rm0.txt
agrep -0 -c 'AGAGGTCGACGGTCCAT' *.fastq > count/B10781_Rm0.txt
agrep -0 -c 'AAGACGACGCCCACTAA' *.fastq > count/B10784_Rm0.txt
agrep -0 -c 'CCAAGTGGGTCGATTCC' *.fastq > count/B10785_Rm0.txt
agrep -0 -c 'CAGGTTACATTACACCG' *.fastq > count/B10787_Rm0.txt
agrep -0 -c 'AATACTAACTGCATCGG' *.fastq > count/B10788_Rm0.txt
agrep -0 -c 'AGTGACGATCCGGTTTA' *.fastq > count/B10789_Rm0.txt
agrep -0 -c 'AACGTTGGCCAACGCCT' *.fastq > count/B10790_Rm0.txt
agrep -0 -c 'TGTACCGAGTGTTGAGG' *.fastq > count/B10791_Rm0.txt
agrep -0 -c 'TCTCATGAGCCTCTGAA' *.fastq > count/B10792_Rm0.txt
agrep -0 -c 'TGGCGCTAACGCTACTA' *.fastq > count/B10793_Rm0.txt
agrep -0 -c 'CGGGCGATCTTTCCTAA' *.fastq > count/B10794_Rm0.txt
agrep -0 -c 'TTGAACCCACTAGCGTC' *.fastq > count/B10795_Rm0.txt
agrep -0 -c 'ACCGAGCAATGGTTGAC' *.fastq > count/B10796_Rm0.txt
agrep -0 -c 'GAAGTAATCACGTGGAC' *.fastq > count/B10797_Rm0.txt
agrep -0 -c 'AAGGGGAACCATGTGAC' *.fastq > count/B10798_Rm0.txt
agrep -0 -c 'GAAGATCCAGGAAGAAC' *.fastq > count/B10799_Rm0.txt
agrep -0 -c 'GTGCAGATGGTTGCACC' *.fastq > count/B10800_Rm0.txt
agrep -0 -c 'TGACTGAGCGTACGTGG' *.fastq > count/B10801_Rm0.txt
agrep -0 -c 'CCTCCGATCGTGATACA' *.fastq > count/B10802_Rm0.txt
agrep -0 -c 'TTGCCAGCTTAGGTCAT' *.fastq > count/B10803_Rm0.txt
agrep -0 -c 'TTGTTCGTATCGCCAAC' *.fastq > count/B10804_Rm0.txt
agrep -0 -c 'CGCTCTCGTCTTTAAAT' *.fastq > count/B10805_Rm0.txt
agrep -0 -c 'ATACTTTCCCGACGCTG' *.fastq > count/B10807_Rm0.txt
agrep -0 -c 'CACTAGATAATCACCCT' *.fastq > count/B10808_Rm0.txt
agrep -0 -c 'TCCTCTACCTGGACCGT' *.fastq > count/B10810_Rm0.txt
agrep -0 -c 'TCGTCCTGTGTATGTCC' *.fastq > count/B10812_Rm0.txt
agrep -0 -c 'GTTAATCGCCATTCACT' *.fastq > count/B10813_Rm0.txt
agrep -0 -c 'TAGGTGACCATGGTGTG' *.fastq > count/B10815_Rm0.txt
agrep -0 -c 'GGCAACGCATGTTCTAC' *.fastq > count/B10816_Rm0.txt
agrep -0 -c 'TTGTGCAGCGGAGAACT' *.fastq > count/B10817_Rm0.txt
agrep -0 -c 'ATGCCAGTTGTTCGTTA' *.fastq > count/B10818_Rm0.txt
agrep -0 -c 'TCGTTTCTCATAATCCG' *.fastq > count/B10820_Rm0.txt
agrep -0 -c 'CCGTCTACTGGTACGTA' *.fastq > count/B10821_Rm0.txt
agrep -0 -c 'GGCTAGCGTGACTCTGT' *.fastq > count/B10822_Rm0.txt
agrep -0 -c 'AGTGCGAGAAAGCTCTA' *.fastq > count/B10823_Rm0.txt
agrep -0 -c 'ATAGCTTGGCAGTGTAG' *.fastq > count/B10824_Rm0.txt
agrep -0 -c 'AGTCGGTAACAAGTAAC' *.fastq > count/B10825_Rm0.txt
agrep -0 -c 'CGGCATTTGCTAGATTA' *.fastq > count/B10826_Rm0.txt
agrep -0 -c 'ACGGGAAGTCTGGACTG' *.fastq > count/B10828_Rm0.txt
agrep -0 -c 'TCTGTCGCCCACCAGTA' *.fastq > count/B10829_Rm0.txt
agrep -0 -c 'ACATCGCCGTCAATACG' *.fastq > count/B10830_Rm0.txt
agrep -0 -c 'AACCTAGCAGTCGTGCC' *.fastq > count/B10831_Rm0.txt
agrep -0 -c 'CAAATGAAAGCATACCG' *.fastq > count/B10834_Rm0.txt
agrep -0 -c 'CCAAGTGCGATTCGAAG' *.fastq > count/B10836_Rm0.txt
agrep -0 -c 'CGTATAGCCAGTCGATA' *.fastq > count/B10837_Rm0.txt
agrep -0 -c 'TACTGGGCGACGTTTCA' *.fastq > count/B10839_Rm0.txt
agrep -0 -c 'GTGATCTTGCCTCGACT' *.fastq > count/B10840_Rm0.txt
agrep -0 -c 'GCGAAATAGAGCTCGAG' *.fastq > count/B10842_Rm0.txt
agrep -0 -c 'CCAGATTATTTGGCCCG' *.fastq > count/B10843_Rm0.txt
agrep -0 -c 'TGCGTCATTCATGTGAA' *.fastq > count/B10844_Rm0.txt
agrep -0 -c 'CGGTATAAAGTACCAGT' *.fastq > count/B10845_Rm0.txt
agrep -0 -c 'CATCGTAGACTTAACAC' *.fastq > count/B10847_Rm0.txt
agrep -0 -c 'ATGTCCGTCAACTGGTT' *.fastq > count/B10848_Rm0.txt
agrep -0 -c 'GTTGTGTTCTGAGTCAC' *.fastq > count/B10849_Rm0.txt
agrep -0 -c 'ATACCCCCACCGCTTAT' *.fastq > count/B10851_Rm0.txt
agrep -0 -c 'TGGCAGATACGAATACT' *.fastq > count/B10853_Rm0.txt
agrep -0 -c 'CCTTTGGTATACAACGC' *.fastq > count/B10854_Rm0.txt
agrep -0 -c 'GAGACGCCTATTAACAG' *.fastq > count/B10856_Rm0.txt
agrep -0 -c 'GTCTTAACCTCATCGTC' *.fastq > count/B10857_Rm0.txt
agrep -0 -c 'CTCAGAGAGCAGTGCGT' *.fastq > count/B10858_Rm0.txt
agrep -0 -c 'ACAGGTCTCGCGAACGT' *.fastq > count/B10859_Rm0.txt
agrep -0 -c 'GACGAAAGAGTCTGAGG' *.fastq > count/B10860_Rm0.txt
agrep -0 -c 'GCGTTTTTGGGACTCCG' *.fastq > count/B10861_Rm0.txt
agrep -0 -c 'AATCCCTAGTTGACACT' *.fastq > count/B10862_Rm0.txt
agrep -0 -c 'AGAACGTAGACTTGCAA' *.fastq > count/B10866_Rm0.txt
agrep -0 -c 'GCCCATTATGACTTACT' *.fastq > count/B10867_Rm0.txt
agrep -0 -c 'AATTGACCATCTACCAC' *.fastq > count/B10868_Rm0.txt
agrep -0 -c 'TGAGCGGTCTAGCTACC' *.fastq > count/B10870_Rm0.txt
agrep -0 -c 'AAGCCAACCAATGCGTT' *.fastq > count/B10872_Rm0.txt
agrep -0 -c 'TCATACAGAGATACCGG' *.fastq > count/B10874_Rm0.txt
agrep -0 -c 'TGAAGACTCCGCTTTAT' *.fastq > count/B10875_Rm0.txt
agrep -0 -c 'ACAAAGCTCTCGTGATG' *.fastq > count/B10876_Rm0.txt
agrep -0 -c 'CCGAATGTCAAGGTACT' *.fastq > count/B10878_Rm0.txt
agrep -0 -c 'AGTGCCACCTCCATATA' *.fastq > count/B10879_Rm0.txt
agrep -0 -c 'GTGAGAGCTTGAGAACC' *.fastq > count/B10880_Rm0.txt
agrep -0 -c 'GCGGAATTGATCCATTA' *.fastq > count/B10881_Rm0.txt
agrep -0 -c 'TAAACCAAGTCGGGCTC' *.fastq > count/B10882_Rm0.txt
agrep -0 -c 'TCTGCCTAAACCGCCTG' *.fastq > count/B10885_Rm0.txt
agrep -0 -c 'GCCTAATTATCAATCGC' *.fastq > count/B10887_Rm0.txt
agrep -0 -c 'CTGGGAGGGGTAATATG' *.fastq > count/B10888_Rm0.txt
agrep -0 -c 'GTTAACTTGTCAAGGCA' *.fastq > count/B10889_Rm0.txt
agrep -0 -c 'CTCTGATGTCGGCTCGA' *.fastq > count/B10890_Rm0.txt
agrep -0 -c 'ATTTGGAGAGGGCAAAT' *.fastq > count/B10891_Rm0.txt
agrep -0 -c 'TGAATACGGCTGACGCT' *.fastq > count/B10894_Rm0.txt
agrep -0 -c 'GGACTTCTTCACGCGGT' *.fastq > count/B10895_Rm0.txt
agrep -0 -c 'CAACTCTTTGGTCCGTT' *.fastq > count/B10896_Rm0.txt
agrep -0 -c 'GGTCGTTCTAGACCGAA' *.fastq > count/B10897_Rm0.txt
agrep -0 -c 'AGCTCCTACTCGGCTCA' *.fastq > count/B10898_Rm0.txt
agrep -0 -c 'GCCTGAAGGACTGGTAC' *.fastq > count/B10899_Rm0.txt
agrep -0 -c 'CCGGGCATACAACCATC' *.fastq > count/B10900_Rm0.txt
agrep -0 -c 'CTAGAGCCACTATATAG' *.fastq > count/B10901_Rm0.txt
agrep -0 -c 'ATCGACAGCGTTGTCTG' *.fastq > count/B10903_Rm0.txt
agrep -0 -c 'GTGCTGTTCGAAAAGCC' *.fastq > count/B10904_Rm0.txt
agrep -0 -c 'TATCGGATTACTGCGCT' *.fastq > count/B10905_Rm0.txt
agrep -0 -c 'CATGAAAGCGCCTGATA' *.fastq > count/B10906_Rm0.txt
agrep -0 -c 'GAGCTGTCCGTCGTATA' *.fastq > count/B10907_Rm0.txt
agrep -0 -c 'CGGTTACAACACGAACT' *.fastq > count/B10908_Rm0.txt
agrep -0 -c 'TTAGATGCGACCATAGT' *.fastq > count/B10910_Rm0.txt
agrep -0 -c 'GTAATGTCTCAGTAGAC' *.fastq > count/B10911_Rm0.txt
agrep -0 -c 'CATATTGCTCGCAGGAA' *.fastq > count/B10912_Rm0.txt
agrep -0 -c 'AATCCAGGTACCTGCCC' *.fastq > count/B10913_Rm0.txt
agrep -0 -c 'ATCAGGCCGACTTCCTC' *.fastq > count/B10914_Rm0.txt
agrep -0 -c 'TCAATCCGGAATGCCTG' *.fastq > count/B10915_Rm0.txt
agrep -0 -c 'CTGTAACGCGGGATTGA' *.fastq > count/B10917_Rm0.txt
agrep -0 -c 'TGATTCTGGGACGTCCC' *.fastq > count/B10918_Rm0.txt
agrep -0 -c 'ACCGATCCTTACGACCT' *.fastq > count/B10919_Rm0.txt
agrep -0 -c 'TAACCATGCAACACGGC' *.fastq > count/B10920_Rm0.txt
agrep -0 -c 'AGGCATCCTTTATCGCA' *.fastq > count/B10922_Rm0.txt
agrep -0 -c 'ACCGGATGGGAAAGACG' *.fastq > count/B10923_Rm0.txt
agrep -0 -c 'ACCGTGGTACAACCAGG' *.fastq > count/B10924_Rm0.txt
agrep -0 -c 'TACAAGTTATGTCACCC' *.fastq > count/B10925_Rm0.txt
agrep -0 -c 'ATAGAGGTCCCGAACGC' *.fastq > count/B10926_Rm0.txt
agrep -0 -c 'CTATGTAGAGAGGACCC' *.fastq > count/B10927_Rm0.txt
agrep -0 -c 'CATGAGTCTCGTGGTGA' *.fastq > count/B10928_Rm0.txt
agrep -0 -c 'CACGCCCATACCCTGTT' *.fastq > count/B10929_Rm0.txt
agrep -0 -c 'GTCGACCTTAGGGGATC' *.fastq > count/B10931_Rm0.txt
agrep -0 -c 'GGCGTTGAGTGTATGTT' *.fastq > count/B10932_Rm0.txt
agrep -0 -c 'GGGAACTTACGTGACTT' *.fastq > count/B10934_Rm0.txt
agrep -0 -c 'ATTTAGCACAGTACTCG' *.fastq > count/B10935_Rm0.txt
agrep -0 -c 'TGGGGTGTATTAACGAC' *.fastq > count/B10936_Rm0.txt
agrep -0 -c 'ATCGATCCCAGGGGGAT' *.fastq > count/B10937_Rm0.txt
agrep -0 -c 'TCCGCTCCCGCTTGATA' *.fastq > count/B10938_Rm0.txt
agrep -0 -c 'TCGCCTAGACGCTTAGG' *.fastq > count/B10939_Rm0.txt
agrep -0 -c 'TCGGCATTCCAAAAGAA' *.fastq > count/B10940_Rm0.txt
agrep -0 -c 'TTAGTCAGTTCACTGCA' *.fastq > count/B10941_Rm0.txt
agrep -0 -c 'ACTTGGATCACCGCTGC' *.fastq > count/B10942_Rm0.txt
agrep -0 -c 'CTTACGAGAGCCCTCTG' *.fastq > count/B10943_Rm0.txt
agrep -0 -c 'TAGTCGAACAAACAGTG' *.fastq > count/B10944_Rm0.txt
agrep -0 -c 'CAGTGCTTTGTGACACC' *.fastq > count/B10945_Rm0.txt
agrep -0 -c 'ACCGTAATGTGTGAACC' *.fastq > count/B10946_Rm0.txt
agrep -0 -c 'AATGACTCAGTAGCGGC' *.fastq > count/B10947_Rm0.txt
agrep -0 -c 'ACTCAAGACACGCTGGT' *.fastq > count/B10948_Rm0.txt
agrep -0 -c 'TGATACCAGTCGTGGCA' *.fastq > count/B10949_Rm0.txt
agrep -0 -c 'GTGCGGCTTCGCCTATT' *.fastq > count/B10950_Rm0.txt
agrep -0 -c 'TGATTCACGGTAGCCAC' *.fastq > count/B10951_Rm0.txt
agrep -0 -c 'TTGGACCTATATTGTCG' *.fastq > count/B10952_Rm0.txt
agrep -0 -c 'ACTGGACCGGTCGACTA' *.fastq > count/B10953_Rm0.txt
agrep -0 -c 'GGTTATAGGTGTCCAGC' *.fastq > count/B10956_Rm0.txt
agrep -0 -c 'TACTAGGGTTGGCTACC' *.fastq > count/B10957_Rm0.txt
agrep -0 -c 'ACAGGCGAAGACTGATA' *.fastq > count/B10958_Rm0.txt
agrep -0 -c 'CTTCGCCGAAAAATGCA' *.fastq > count/B10960_Rm0.txt
agrep -0 -c 'ACCTGTGGATAAGGTAG' *.fastq > count/B10963_Rm0.txt
agrep -0 -c 'GGCCGCGATAGCAAATT' *.fastq > count/B10964_Rm0.txt
agrep -0 -c 'CCCGAATGTCGAGCGTA' *.fastq > count/B10965_Rm0.txt
agrep -0 -c 'CTTTGACGAGGAGAGAT' *.fastq > count/B10966_Rm0.txt
agrep -0 -c 'CCGTTGCGGATTAAGTA' *.fastq > count/B10967_Rm0.txt
agrep -0 -c 'TTAGAACACGAGTCCCC' *.fastq > count/B10968_Rm0.txt
agrep -0 -c 'GAAACGTACAACCGATG' *.fastq > count/B10970_Rm0.txt
agrep -0 -c 'GAACCTACGTTGAACGG' *.fastq > count/B10971_Rm0.txt
agrep -0 -c 'CGGGGTAGATTGAATGC' *.fastq > count/B10972_Rm0.txt
agrep -0 -c 'GGATGGTGTACCTGGTA' *.fastq > count/B10973_Rm0.txt
agrep -0 -c 'CTGACGGCAGTTCCAGT' *.fastq > count/B10975_Rm0.txt
agrep -0 -c 'CGAGTTCGAAGTGTGGC' *.fastq > count/B10976_Rm0.txt
agrep -0 -c 'TCCGATGAGCTCCAACA' *.fastq > count/B10978_Rm0.txt
agrep -0 -c 'GAGCGACTACATGATCT' *.fastq > count/B10980_Rm0.txt
agrep -0 -c 'AGGATCAAAAGGGCACC' *.fastq > count/B10981_Rm0.txt
agrep -0 -c 'CTAGAAACCGACGCATC' *.fastq > count/B10983_Rm0.txt
agrep -0 -c 'TTGGCGGCTCAACCTAC' *.fastq > count/B10984_Rm0.txt
agrep -0 -c 'CATGAGCTTTCCTAGGT' *.fastq > count/B10985_Rm0.txt
agrep -0 -c 'AGGCGCAGGTAATGTGA' *.fastq > count/B10986_Rm0.txt
agrep -0 -c 'CCCATTAGGATACCAGG' *.fastq > count/B10987_Rm0.txt
agrep -0 -c 'CCCAACCCTAGATTGCT' *.fastq > count/B10988_Rm0.txt
agrep -0 -c 'AAAAGCGGGGCCAGCTA' *.fastq > count/B10989_Rm0.txt
agrep -0 -c 'CCCCATGTTAACGAAAT' *.fastq > count/B10990_Rm0.txt
agrep -0 -c 'CTGTCCCAAAAGCAGTG' *.fastq > count/B10991_Rm0.txt
agrep -0 -c 'TACCGCATCGATATCGA' *.fastq > count/B10992_Rm0.txt
agrep -0 -c 'TGGAGTTAGTCCTGGAA' *.fastq > count/B10993_Rm0.txt
agrep -0 -c 'CGTGCTGAACTTGGTAT' *.fastq > count/B10994_Rm0.txt
agrep -0 -c 'GACTTAGCGCACTGTGT' *.fastq > count/B10995_Rm0.txt
agrep -0 -c 'AACTTAGGATTAGTGCC' *.fastq > count/B10997_Rm0.txt
agrep -0 -c 'TCCCATAGTTTGGCACT' *.fastq > count/B10999_Rm0.txt
agrep -0 -c 'AGGACACGGGATCTAGC' *.fastq > count/B11001_Rm0.txt
agrep -0 -c 'AAATGGGGGAGTCAGGC' *.fastq > count/B11002_Rm0.txt
agrep -0 -c 'CCACCATCGGCTTATGG' *.fastq > count/B11003_Rm0.txt
agrep -0 -c 'TACCGTTGACAAGATTG' *.fastq > count/B11004_Rm0.txt
agrep -0 -c 'TCAAACCACTTGTGCGC' *.fastq > count/B11005_Rm0.txt
agrep -0 -c 'AGACGGAGTCTCGACTT' *.fastq > count/B11006_Rm0.txt
agrep -0 -c 'GGACGATTTGGCAAGTC' *.fastq > count/B11007_Rm0.txt
agrep -0 -c 'GGAGTCCACGTTACATC' *.fastq > count/B11008_Rm0.txt
agrep -0 -c 'TAAGACCACGATGGCAA' *.fastq > count/B11010_Rm0.txt
agrep -0 -c 'TGGCAACTTAGGGTGCA' *.fastq > count/B11011_Rm0.txt
agrep -0 -c 'CCCGCACGATATAAACG' *.fastq > count/B11012_Rm0.txt
agrep -0 -c 'AGATTGTGAGTTCGTGA' *.fastq > count/B11013_Rm0.txt
agrep -0 -c 'CTCAATCATGCCTGTAG' *.fastq > count/B11014_Rm0.txt
agrep -0 -c 'GGCACAATAGGAACTGA' *.fastq > count/B11015_Rm0.txt
agrep -0 -c 'TTAACCGTTTCCAGGCA' *.fastq > count/B11016_Rm0.txt
agrep -0 -c 'TTGGAGCATCTATCCGG' *.fastq > count/B11017_Rm0.txt
agrep -0 -c 'TTGCATTTAACGGGTGA' *.fastq > count/B11018_Rm0.txt
agrep -0 -c 'CATGCTCAAACTGGTAT' *.fastq > count/B11019_Rm0.txt
agrep -0 -c 'TAGACGGTCTCAGGATT' *.fastq > count/B11021_Rm0.txt
agrep -0 -c 'GCCCGGAATGCTCAATA' *.fastq > count/B11022_Rm0.txt
agrep -0 -c 'CAAGACTTATACCCCAA' *.fastq > count/B11023_Rm0.txt
agrep -0 -c 'TGAGGTAACCCTCGTAC' *.fastq > count/B11024_Rm0.txt
agrep -0 -c 'GTAATCCACGACTCAGC' *.fastq > count/B11025_Rm0.txt
agrep -0 -c 'CTCGCTGCATCTCCTCA' *.fastq > count/B11026_Rm0.txt
agrep -0 -c 'GTTGGCACGGGATTACA' *.fastq > count/B11029_Rm0.txt
agrep -0 -c 'TTGCGTGAACCGAGAAG' *.fastq > count/B11030_Rm0.txt
agrep -0 -c 'AGTACATGTTACCACGG' *.fastq > count/B11031_Rm0.txt
agrep -0 -c 'CCAACGACAAAGCACGT' *.fastq > count/B11032_Rm0.txt
agrep -0 -c 'GGGCTTAGGGTTTGATA' *.fastq > count/B11033_Rm0.txt
agrep -0 -c 'AGCCTGTACTGCAACAA' *.fastq > count/B11034_Rm0.txt
agrep -0 -c 'CCTGAAATTCCACGAGG' *.fastq > count/B11035_Rm0.txt
agrep -0 -c 'TCCATTAGTATAGTCCC' *.fastq > count/B11038_Rm0.txt
agrep -0 -c 'ATCAACGCTCATGTGCC' *.fastq > count/B11039_Rm0.txt
agrep -0 -c 'GTCCGGTAAATTGGTTG' *.fastq > count/B11040_Rm0.txt
agrep -0 -c 'CTCATTTTACACTGGCC' *.fastq > count/B11042_Rm0.txt
agrep -0 -c 'AAAGGCCTACGTTAGTT' *.fastq > count/B11043_Rm0.txt
agrep -0 -c 'GCGTCAAACCTTAAGAC' *.fastq > count/B11044_Rm0.txt
agrep -0 -c 'CCTTGTTTCTACGGATC' *.fastq > count/B11046_Rm0.txt
agrep -0 -c 'CAACTAACAAATCGCTG' *.fastq > count/B11047_Rm0.txt
agrep -0 -c 'CATTTACCTGATCGGGT' *.fastq > count/B11048_Rm0.txt
agrep -0 -c 'ATGTCTCTTGGGCGACG' *.fastq > count/B11049_Rm0.txt
agrep -0 -c 'TTAGAGCGAGCATGCCC' *.fastq > count/B11050_Rm0.txt
agrep -0 -c 'TCGGACTATCCACGACT' *.fastq > count/B11051_Rm0.txt
agrep -0 -c 'TAGCGATTAGACCGGCC' *.fastq > count/B11052_Rm0.txt
agrep -0 -c 'CCAGGTACGGGTCTAGT' *.fastq > count/B11053_Rm0.txt
agrep -0 -c 'CTACCATGACTAGAACC' *.fastq > count/B11054_Rm0.txt
agrep -0 -c 'GCTGGGTGATCCCTAAT' *.fastq > count/B11055_Rm0.txt
agrep -0 -c 'CAAGCCAGTACCCTCGT' *.fastq > count/B11056_Rm0.txt
agrep -0 -c 'CTAGAACGGATACGCAA' *.fastq > count/B11057_Rm0.txt
agrep -0 -c 'ATCTGCAGCTGGCTAGT' *.fastq > count/B11059_Rm0.txt
agrep -0 -c 'GTATTCTGACTTCGAAG' *.fastq > count/B11061_Rm0.txt
agrep -0 -c 'AGCTCCCAATATCTTAG' *.fastq > count/B11062_Rm0.txt
agrep -0 -c 'ATTCCTGATCTGGGTCT' *.fastq > count/B11064_Rm0.txt
agrep -0 -c 'AGAACGAGACTACTAGA' *.fastq > count/B11065_Rm0.txt
agrep -0 -c 'CGACTTGAGGGTCGCAA' *.fastq > count/B11066_Rm0.txt
agrep -0 -c 'TCGGTAAACCTTGAGAC' *.fastq > count/B11067_Rm0.txt
agrep -0 -c 'AGTTCTGGAGTCATGTT' *.fastq > count/B11068_Rm0.txt
agrep -0 -c 'TCAGTTTGGGCGATGAC' *.fastq > count/B11069_Rm0.txt
agrep -0 -c 'GGAGGGCATTTAGGGCT' *.fastq > count/B11070_Rm0.txt
agrep -0 -c 'TTTAGGTCTGATGAGAC' *.fastq > count/B11071_Rm0.txt
agrep -0 -c 'GCAGAAGTCCCAGACTC' *.fastq > count/B11072_Rm0.txt
agrep -0 -c 'GATAGCGCTATAAGAGT' *.fastq > count/B11073_Rm0.txt
agrep -0 -c 'CCTCCCAAACGCAACTC' *.fastq > count/B11074_Rm0.txt
agrep -0 -c 'ACCGCGAACTGTCGCTT' *.fastq > count/B11075_Rm0.txt
agrep -0 -c 'AATAACGGGCGGGTAAC' *.fastq > count/B11077_Rm0.txt
agrep -0 -c 'TGGTGCGTGTGAAACTA' *.fastq > count/B11079_Rm0.txt
agrep -0 -c 'CGTACGCATAGGGGTGT' *.fastq > count/B11080_Rm0.txt
agrep -0 -c 'CACGATGTAGGACTCAA' *.fastq > count/B11081_Rm0.txt
agrep -0 -c 'GCTGTAATGGCACTAGT' *.fastq > count/B11082_Rm0.txt
agrep -0 -c 'TGCCTAGTGCACCTCTA' *.fastq > count/B11083_Rm0.txt
agrep -0 -c 'AGCCCCCAGGGTTTAAT' *.fastq > count/B11084_Rm0.txt
agrep -0 -c 'ATCAGGGTAGGCATCAT' *.fastq > count/B11085_Rm0.txt
agrep -0 -c 'CCATCCGCAGCTAACCT' *.fastq > count/B11088_Rm0.txt
agrep -0 -c 'GCATGTTCCGTACTGCC' *.fastq > count/B11089_Rm0.txt
agrep -0 -c 'GGCGAAGAGATCTTAAG' *.fastq > count/B11090_Rm0.txt
agrep -0 -c 'CATTCTGGCATCCCCTC' *.fastq > count/B11091_Rm0.txt
agrep -0 -c 'GTCTACTACCCATGTGG' *.fastq > count/B11092_Rm0.txt
agrep -0 -c 'TCAGAACAAAACGACGC' *.fastq > count/B11093_Rm0.txt
agrep -0 -c 'ACTGATATCGTTGTGGC' *.fastq > count/B11094_Rm0.txt
agrep -0 -c 'GGGTTAACGTTAGAGTG' *.fastq > count/B11095_Rm0.txt
agrep -0 -c 'TTGCAAGGCCACGAGTA' *.fastq > count/B11096_Rm0.txt
agrep -0 -c 'GCGCATTAGCTTAAGAA' *.fastq > count/B11097_Rm0.txt
agrep -0 -c 'ACGTAAGACGAGTGCTA' *.fastq > count/B11098_Rm0.txt
agrep -0 -c 'CAACGCTTCTTGAGACA' *.fastq > count/B11099_Rm0.txt
agrep -0 -c 'CTAATCACACGCCAATC' *.fastq > count/B11100_Rm0.txt
agrep -0 -c 'TACAGTCGTTGTCTAAG' *.fastq > count/B11102_Rm0.txt
agrep -0 -c 'TGAAGTGGCTCCTCGTC' *.fastq > count/B11103_Rm0.txt
agrep -0 -c 'CAACGCCGTCGGATTCT' *.fastq > count/B11104_Rm0.txt
agrep -0 -c 'AATTGACCGTCCCTAGC' *.fastq > count/B11106_Rm0.txt
agrep -0 -c 'ACATGGGACGTCTGCTG' *.fastq > count/B11107_Rm0.txt
agrep -0 -c 'CCGGAAGTGAGGAATAG' *.fastq > count/B11108_Rm0.txt
agrep -0 -c 'AGTACGAGGTGGTCCAC' *.fastq > count/B11109_Rm0.txt
agrep -0 -c 'AGTAGACCGGATGAGTT' *.fastq > count/B11110_Rm0.txt
agrep -0 -c 'CGACTGTTATGGCGGAG' *.fastq > count/B11111_Rm0.txt
agrep -0 -c 'CAGGGTCGATTTCCACT' *.fastq > count/B11112_Rm0.txt
agrep -0 -c 'GGGCAGTTGGAAATCGG' *.fastq > count/B11113_Rm0.txt
agrep -0 -c 'GTGTCGTCTCCGATACA' *.fastq > count/B11115_Rm0.txt
agrep -0 -c 'TCACTCTGCGAACTAAT' *.fastq > count/B11116_Rm0.txt
agrep -0 -c 'AAATCGCCCTCTGACAC' *.fastq > count/B11118_Rm0.txt
agrep -0 -c 'AATGTCTATCCATGCGA' *.fastq > count/B11119_Rm0.txt
agrep -0 -c 'ATTAGTTACGATTGCCC' *.fastq > count/B11120_Rm0.txt
agrep -0 -c 'CGTTGTGGACCACTGTT' *.fastq > count/B11122_Rm0.txt
agrep -0 -c 'GTAAAAGTGTCTCCGTT' *.fastq > count/B11123_Rm0.txt
agrep -0 -c 'GCCACTAACCTTGTACG' *.fastq > count/B11124_Rm0.txt
agrep -0 -c 'AACAGCATCCGACTCAG' *.fastq > count/B11125_Rm0.txt
agrep -0 -c 'CCCGAAGTAGAAACGCT' *.fastq > count/B11126_Rm0.txt
agrep -0 -c 'TGCTGCTCGTATTCCAT' *.fastq > count/B11127_Rm0.txt
agrep -0 -c 'GAACTTATCTGTGAACG' *.fastq > count/B11128_Rm0.txt
agrep -0 -c 'AGCAAACCATCCTCTGG' *.fastq > count/B11130_Rm0.txt
agrep -0 -c 'TCGATTCTCGTCATGCA' *.fastq > count/B11132_Rm0.txt
agrep -0 -c 'CCCCTTATATAGTCGAC' *.fastq > count/B11133_Rm0.txt
agrep -0 -c 'TTACTACTGGCCTATCC' *.fastq > count/B11134_Rm0.txt
agrep -0 -c 'GGCCATAAGTCTTAGCT' *.fastq > count/B11135_Rm0.txt
agrep -0 -c 'GCTTGATCGCGATTACC' *.fastq > count/B11136_Rm0.txt
agrep -0 -c 'ACCACTAGTTTGACAGC' *.fastq > count/B11137_Rm0.txt
agrep -0 -c 'ATAAGGGGCAATCTCTA' *.fastq > count/B11139_Rm0.txt
agrep -0 -c 'ATCGAAGGCCACATAAT' *.fastq > count/B11140_Rm0.txt
agrep -0 -c 'CCGGCTTCTATATACGT' *.fastq > count/B11142_Rm0.txt
agrep -0 -c 'AGCATTCTCCGTTCAAG' *.fastq > count/B11143_Rm0.txt
agrep -0 -c 'ACGGCAAATATTTGGTG' *.fastq > count/B11144_Rm0.txt
agrep -0 -c 'GTAGGTTCGACAGCATA' *.fastq > count/B11145_Rm0.txt
agrep -0 -c 'ATTTAACAACCCAGCGC' *.fastq > count/B11147_Rm0.txt
agrep -0 -c 'GTAAAACGGGCTGTGCA' *.fastq > count/B11148_Rm0.txt
agrep -0 -c 'ATTCCAGTCGCCCCATT' *.fastq > count/B11149_Rm0.txt
agrep -0 -c 'GGTATAGCTATTAGGTC' *.fastq > count/B11150_Rm0.txt
agrep -0 -c 'CTCACAAAGAAAACCGT' *.fastq > count/B11151_Rm0.txt
agrep -0 -c 'CGTCTAAGATCAGCAAC' *.fastq > count/B11152_Rm0.txt
agrep -0 -c 'GCAATTCGATTTAGGTC' *.fastq > count/B11153_Rm0.txt
agrep -0 -c 'CTTAACGAACCTATCCC' *.fastq > count/B11154_Rm0.txt
agrep -0 -c 'CAGTACTTCGTGCGTGG' *.fastq > count/B11155_Rm0.txt
agrep -0 -c 'TCCACTTATTTAACCCC' *.fastq > count/B11156_Rm0.txt
agrep -0 -c 'TTCCCCCCTATATGGAA' *.fastq > count/B11157_Rm0.txt
agrep -0 -c 'GCCTTTAACAACGCATC' *.fastq > count/B11158_Rm0.txt
agrep -0 -c 'CAAATACGTTGGCGAAT' *.fastq > count/B11161_Rm0.txt
agrep -0 -c 'CAATACCTTGATAACGG' *.fastq > count/B11162_Rm0.txt
agrep -0 -c 'AACGTGACCGCTAGGAA' *.fastq > count/B11164_Rm0.txt
agrep -0 -c 'CAAAGCCAAAAGTTCGC' *.fastq > count/B11165_Rm0.txt
agrep -0 -c 'TGGTTCTCTCGTAGATA' *.fastq > count/B11166_Rm0.txt
agrep -0 -c 'CCCAGATAGAACCGGAT' *.fastq > count/B11167_Rm0.txt
agrep -0 -c 'GAAGGACGTAAGTGCGC' *.fastq > count/B11168_Rm0.txt
agrep -0 -c 'ATCAAGCAACCGACTGT' *.fastq > count/B11169_Rm0.txt
agrep -0 -c 'CGCCTATACGAAACATT' *.fastq > count/B11170_Rm0.txt
agrep -0 -c 'CGATTCGCTCCAGCACA' *.fastq > count/B11171_Rm0.txt
agrep -0 -c 'GTTGCCGGTAATCGGTT' *.fastq > count/B11172_Rm0.txt
agrep -0 -c 'GGCGTTTCCATACTGAC' *.fastq > count/B11173_Rm0.txt
agrep -0 -c 'CACGGGATGTCAGTGAA' *.fastq > count/B11174_Rm0.txt
agrep -0 -c 'CCTTGAGAAGCAGTGAC' *.fastq > count/B11175_Rm0.txt
agrep -0 -c 'GCTGAAGGAAATTCGAT' *.fastq > count/B11176_Rm0.txt
agrep -0 -c 'AAGCTAACAGGATCGCT' *.fastq > count/B11177_Rm0.txt
agrep -0 -c 'TGATGCCGATGTAGGCA' *.fastq > count/B11178_Rm0.txt
agrep -0 -c 'AACAACCTGATGTGGTG' *.fastq > count/B11179_Rm0.txt
agrep -0 -c 'GCCTTTCGTCCCTGTTA' *.fastq > count/B11181_Rm0.txt
agrep -0 -c 'TCAATCGCTGAACTGAT' *.fastq > count/B11182_Rm0.txt
agrep -0 -c 'GACGCGAAGTAATCACC' *.fastq > count/B11183_Rm0.txt
agrep -0 -c 'TTCCTAACACGGACGTC' *.fastq > count/B11184_Rm0.txt
agrep -0 -c 'AAACAATGAGTGCCAAC' *.fastq > count/B11185_Rm0.txt
agrep -0 -c 'ATTTGAGATTGGAGTCC' *.fastq > count/B11186_Rm0.txt
agrep -0 -c 'GATCCTCAGAGCCCGTT' *.fastq > count/B11187_Rm0.txt
agrep -0 -c 'ACGATTGAGCCAATATG' *.fastq > count/B11188_Rm0.txt
agrep -0 -c 'CTACAACAATCCAGGTG' *.fastq > count/B11189_Rm0.txt
agrep -0 -c 'ACCCCTTTGTGAGTGCT' *.fastq > count/B11190_Rm0.txt
agrep -0 -c 'AAGGTCAAACGCCAGAG' *.fastq > count/B11192_Rm0.txt
agrep -0 -c 'GTGTTTTGTGACACGAT' *.fastq > count/B11193_Rm0.txt
agrep -0 -c 'AAGGACGGATTAGTACC' *.fastq > count/B11194_Rm0.txt
agrep -0 -c 'ATCGGACACTATCCCTT' *.fastq > count/B11196_Rm0.txt
agrep -0 -c 'CCAGAGGAGTAAAGCGA' *.fastq > count/B11197_Rm0.txt
agrep -0 -c 'CTACCGAAAGACGACGC' *.fastq > count/B11198_Rm0.txt
agrep -0 -c 'TATGACCGGGTCGTTCG' *.fastq > count/B11199_Rm0.txt
agrep -0 -c 'CAGTGTAGCCAGATGCC' *.fastq > count/B11200_Rm0.txt
agrep -0 -c 'CTGACAAGTAGTTTCAG' *.fastq > count/B11201_Rm0.txt
agrep -0 -c 'TCCGGGAATTGTGCATG' *.fastq > count/B11203_Rm0.txt
agrep -0 -c 'ATCGCGGCAATAACTAA' *.fastq > count/B11204_Rm0.txt
agrep -0 -c 'CGTTAAGTCTGAGCGCG' *.fastq > count/B11205_Rm0.txt
agrep -0 -c 'TCTGCTAGAACCGCAAG' *.fastq > count/B11207_Rm0.txt
agrep -0 -c 'TCTCGCCATCTTTCTAG' *.fastq > count/B11208_Rm0.txt
agrep -0 -c 'GACTATGCAGTAGATGA' *.fastq > count/B11210_Rm0.txt
agrep -0 -c 'ACGTTTGCCGTAAACCG' *.fastq > count/B11211_Rm0.txt
agrep -0 -c 'TGCATGGTGGTTACTTG' *.fastq > count/B11212_Rm0.txt
agrep -0 -c 'AAGGTCTCAATCGGCTC' *.fastq > count/B11213_Rm0.txt
agrep -0 -c 'GCTCCTGTACCCGATAA' *.fastq > count/B11214_Rm0.txt
agrep -0 -c 'ACCAATATCGGTCGTTG' *.fastq > count/B11216_Rm0.txt
agrep -0 -c 'TGCCGGGCACAGTTCTT' *.fastq > count/B11218_Rm0.txt
agrep -0 -c 'TACGTCACAATCAAGTC' *.fastq > count/B11219_Rm0.txt
agrep -0 -c 'GTTTGAGCTTGAATGCC' *.fastq > count/B11222_Rm0.txt
agrep -0 -c 'CTTGTTGCAACGATCCT' *.fastq > count/B11223_Rm0.txt
agrep -0 -c 'TCAGGGTTAACCCAGAA' *.fastq > count/B11224_Rm0.txt
agrep -0 -c 'TTATATGGTGTCGATGC' *.fastq > count/B11225_Rm0.txt
agrep -0 -c 'GACTTCGTACATCCGAG' *.fastq > count/B11226_Rm0.txt
agrep -0 -c 'CTGCTATATGTGGGCAC' *.fastq > count/B11227_Rm0.txt
agrep -0 -c 'TTAGATTCAGGAACCTC' *.fastq > count/B11228_Rm0.txt
agrep -0 -c 'CCTTTTGATAGTATGCG' *.fastq > count/B11229_Rm0.txt
agrep -0 -c 'CTATATGGGACATCTCT' *.fastq > count/B11231_Rm0.txt
agrep -0 -c 'GGTGGTTTTTCGCCCTT' *.fastq > count/B11232_Rm0.txt
agrep -0 -c 'TCCGCACACATCAGCCT' *.fastq > count/B11233_Rm0.txt
agrep -0 -c 'TTTTTGCAGTGAGTCGG' *.fastq > count/B11234_Rm0.txt
agrep -0 -c 'CGAAAGCCCAAATCGGC' *.fastq > count/B11235_Rm0.txt
agrep -0 -c 'GCGATGAGAGAAATGAC' *.fastq > count/B11236_Rm0.txt
agrep -0 -c 'ATTAGTCAGTCGCGGAC' *.fastq > count/B11237_Rm0.txt
agrep -0 -c 'CACGTAGACCTAGCAAC' *.fastq > count/B11238_Rm0.txt
agrep -0 -c 'GTTCTTTAGACGTTGAC' *.fastq > count/B11239_Rm0.txt
agrep -0 -c 'ATGTCCCGAGGAGACCT' *.fastq > count/B11240_Rm0.txt
agrep -0 -c 'GAGAGTCAATAGCGAAC' *.fastq > count/B11242_Rm0.txt
agrep -0 -c 'CGAAGGCAAGGTAATGA' *.fastq > count/B11243_Rm0.txt
agrep -0 -c 'TTGGGCTTCGGCTAGAG' *.fastq > count/B11244_Rm0.txt
agrep -0 -c 'CCAGTTCCTTAAGGCTC' *.fastq > count/B11246_Rm0.txt
agrep -0 -c 'CGGTGGCTATGAGAACC' *.fastq > count/B11247_Rm0.txt
agrep -0 -c 'CCGAGAGGGTCACTATT' *.fastq > count/B11248_Rm0.txt
agrep -0 -c 'TGAAGTAGTCTTGGAAG' *.fastq > count/B11249_Rm0.txt
agrep -0 -c 'TCTCGTTCCAGATCGTT' *.fastq > count/B11250_Rm0.txt
agrep -0 -c 'TTCCGAAATGCTAGATC' *.fastq > count/B11251_Rm0.txt
agrep -0 -c 'GCCACCGCGTACTGATA' *.fastq > count/B11252_Rm0.txt
agrep -0 -c 'ACCCACTACTCTCAACC' *.fastq > count/B11253_Rm0.txt
agrep -0 -c 'GTGCTCCGATTACTAGC' *.fastq > count/B11254_Rm0.txt
agrep -0 -c 'CTCGCTCTAAGATACTT' *.fastq > count/B11255_Rm0.txt
agrep -0 -c 'TCACACCCTTGTTAGTC' *.fastq > count/B11256_Rm0.txt
agrep -0 -c 'GATAGGAGGGCGTAATT' *.fastq > count/B11257_Rm0.txt
agrep -0 -c 'ATTACTAGACCGTGCGA' *.fastq > count/B11258_Rm0.txt
agrep -0 -c 'ATTACTTCTTGCCTGCC' *.fastq > count/B11259_Rm0.txt
agrep -0 -c 'TCTGAATCTTGTGGCTA' *.fastq > count/B11260_Rm0.txt
agrep -0 -c 'CATCTCACCCTGTAAGA' *.fastq > count/B11261_Rm0.txt
agrep -0 -c 'CTAAAACCAAGGTCGCT' *.fastq > count/B11262_Rm0.txt
agrep -0 -c 'ACAGCCCGCCTATGCAT' *.fastq > count/B11264_Rm0.txt
agrep -0 -c 'ATGAGGTCTGCCGACTT' *.fastq > count/B11266_Rm0.txt
agrep -0 -c 'CACGGAGGCCTTTATGC' *.fastq > count/B11267_Rm0.txt
agrep -0 -c 'TCGGCCTCATAGACGCT' *.fastq > count/B11268_Rm0.txt
agrep -0 -c 'TCGTCCCTTTTCCTGAG' *.fastq > count/B11269_Rm0.txt
agrep -0 -c 'TTCTGTCTCGTAAACCT' *.fastq > count/B11270_Rm0.txt
agrep -0 -c 'GCGACCTGGTAAGAGGT' *.fastq > count/B11271_Rm0.txt
agrep -0 -c 'TTTGTTTTGTCCGCCAT' *.fastq > count/B11272_Rm0.txt
agrep -0 -c 'CCAATCATGACGTGAGT' *.fastq > count/B11276_Rm0.txt
agrep -0 -c 'ATTAGCCCCTTGTCATG' *.fastq > count/B11278_Rm0.txt
agrep -0 -c 'CGGATAAGCAGGTACCT' *.fastq > count/B11280_Rm0.txt
agrep -0 -c 'CTAGCCGATGATGAGCC' *.fastq > count/B11282_Rm0.txt
agrep -0 -c 'GCTTCTCACGTAAGTCA' *.fastq > count/B11283_Rm0.txt
agrep -0 -c 'TCGGGACACACTATCTA' *.fastq > count/B11284_Rm0.txt
agrep -0 -c 'ACGATGAGATAACGAGT' *.fastq > count/B11285_Rm0.txt
agrep -0 -c 'TATGGATCAGGGAAGTA' *.fastq > count/B11287_Rm0.txt
agrep -0 -c 'TTAGTACGCGCTGCGCA' *.fastq > count/B11288_Rm0.txt
agrep -0 -c 'AGTCTACGAGGGCATGT' *.fastq > count/B11289_Rm0.txt
agrep -0 -c 'ATGGTGCTTTAACAGCG' *.fastq > count/B11290_Rm0.txt
agrep -0 -c 'TAGCACTTCAGCATGTT' *.fastq > count/B11291_Rm0.txt
agrep -0 -c 'GCCTGCTAGTCATTCTT' *.fastq > count/B11292_Rm0.txt
agrep -0 -c 'GTTATGGTTCGACACGT' *.fastq > count/B11293_Rm0.txt
agrep -0 -c 'TAGATCCCTCAGCTCCG' *.fastq > count/B11294_Rm0.txt
agrep -0 -c 'CTAAATATCGCCGGATA' *.fastq > count/B11295_Rm0.txt
agrep -0 -c 'TGACTTCTCATTGTGTG' *.fastq > count/B11296_Rm0.txt
agrep -0 -c 'CGCAGGTTCGATTACCT' *.fastq > count/B11298_Rm0.txt
agrep -0 -c 'CCACTCTTGGGACATAG' *.fastq > count/B11299_Rm0.txt
agrep -0 -c 'AACGCTCGTTCCAATCC' *.fastq > count/B11300_Rm0.txt
agrep -0 -c 'AAGCTTCAAACACGGTT' *.fastq > count/B11301_Rm0.txt
agrep -0 -c 'CTGCGATCTCCTGAGGT' *.fastq > count/B11302_Rm0.txt
agrep -0 -c 'GGTCTGAACTATGGAGA' *.fastq > count/B11303_Rm0.txt
agrep -0 -c 'ATTACCGATCATCATCG' *.fastq > count/B11304_Rm0.txt
agrep -0 -c 'CAACGAGTAAGACTTAG' *.fastq > count/B11305_Rm0.txt
agrep -0 -c 'TCTCCGTGTAACGTGCA' *.fastq > count/B11306_Rm0.txt
agrep -0 -c 'GGGTCAGCAAAGTGACG' *.fastq > count/B11308_Rm0.txt
agrep -0 -c 'TCCACGGCCAAATGTAT' *.fastq > count/B11309_Rm0.txt
agrep -0 -c 'ACTACTCTCTGTCTAAG' *.fastq > count/B11310_Rm0.txt
agrep -0 -c 'GGTCATGCTTTGTATCT' *.fastq > count/B11311_Rm0.txt
agrep -0 -c 'CCCCTAGACGTTAATCG' *.fastq > count/B11312_Rm0.txt
agrep -0 -c 'CGATCCCTCCCTTGTAA' *.fastq > count/B11313_Rm0.txt
agrep -0 -c 'TTTTCTGTCACGGGCAG' *.fastq > count/B11314_Rm0.txt
agrep -0 -c 'GCATAGGCGAAGAGTAT' *.fastq > count/B11315_Rm0.txt
agrep -0 -c 'GAGCAATAGCCAACCCC' *.fastq > count/B11316_Rm0.txt
agrep -0 -c 'TGGCCGGCTAATTTAGA' *.fastq > count/B11317_Rm0.txt
agrep -0 -c 'TCCTTGTGGTCGGACTG' *.fastq > count/B11318_Rm0.txt
agrep -0 -c 'TGCTTGGCGCACTCAAC' *.fastq > count/B11320_Rm0.txt
agrep -0 -c 'ATTAGGGCCGTACTGAA' *.fastq > count/B11321_Rm0.txt
agrep -0 -c 'GAAGATTGATGAACTCG' *.fastq > count/B11322_Rm0.txt
agrep -0 -c 'CCCCTACAATAGCGGAT' *.fastq > count/B11323_Rm0.txt
agrep -0 -c 'TATCGCCAAATGGAGCT' *.fastq > count/B11324_Rm0.txt
agrep -0 -c 'AGCGATCGGAGGCAGTT' *.fastq > count/B11326_Rm0.txt
agrep -0 -c 'TGCTTGCCTACTCGGTA' *.fastq > count/B11327_Rm0.txt
agrep -0 -c 'CATTCCTTACATGGTGA' *.fastq > count/B11328_Rm0.txt
agrep -0 -c 'CTTATGGATGCTCCGAA' *.fastq > count/B11329_Rm0.txt
agrep -0 -c 'GTATTGGAGGTTCGACA' *.fastq > count/B11330_Rm0.txt
agrep -0 -c 'ATACGACCGCGTGGAGT' *.fastq > count/B11331_Rm0.txt
agrep -0 -c 'ATTTGTACCGCTCCCGG' *.fastq > count/B11332_Rm0.txt
agrep -0 -c 'GATGCCATCAATGCCGG' *.fastq > count/B11334_Rm0.txt
agrep -0 -c 'GCCGCGTTTGTCTTAGT' *.fastq > count/B11335_Rm0.txt
agrep -0 -c 'CTGTATAGTGTCTGGCG' *.fastq > count/B11336_Rm0.txt
agrep -0 -c 'ACGATATCCTCTATCGA' *.fastq > count/B11339_Rm0.txt
agrep -0 -c 'ATCTAAAGTGCATGTCC' *.fastq > count/B11340_Rm0.txt
agrep -0 -c 'GACAAAACCGTGACCGG' *.fastq > count/B11341_Rm0.txt
agrep -0 -c 'CTACTATTCGCGAGGGT' *.fastq > count/B11342_Rm0.txt
agrep -0 -c 'AATAGGCATGCCCATAC' *.fastq > count/B11344_Rm0.txt
agrep -0 -c 'GCACCATTCAAGGTATG' *.fastq > count/B11345_Rm0.txt
agrep -0 -c 'CCGTCTGCTAATCCTCG' *.fastq > count/B11347_Rm0.txt
agrep -0 -c 'TAAGGTCTAAGTACGCG' *.fastq > count/B11348_Rm0.txt
agrep -0 -c 'TCGCTAACTGATTTCTC' *.fastq > count/B11349_Rm0.txt
agrep -0 -c 'CTTCTCGGGTTGCCAGT' *.fastq > count/B11350_Rm0.txt
agrep -0 -c 'GCCTCTCAGTAAACAGT' *.fastq > count/B11352_Rm0.txt
agrep -0 -c 'AGGTTCAACAACGAGTG' *.fastq > count/B11353_Rm0.txt
agrep -0 -c 'GATTGCGCGCTATAATA' *.fastq > count/B11354_Rm0.txt
agrep -0 -c 'AGGTCCCTTAACTACGT' *.fastq > count/B11355_Rm0.txt
agrep -0 -c 'TCTCTGGTCCTGTTGAA' *.fastq > count/B11356_Rm0.txt
agrep -0 -c 'CCAATATTGAACGCAGA' *.fastq > count/B11357_Rm0.txt
agrep -0 -c 'TCCACACGCAGTCCTAG' *.fastq > count/B11358_Rm0.txt
agrep -0 -c 'GACTACGCCCCTCTCAA' *.fastq > count/B11359_Rm0.txt
agrep -0 -c 'TTGTATGCCATCGGTGT' *.fastq > count/B11360_Rm0.txt
agrep -0 -c 'AACTGGCTACAGGCGCA' *.fastq > count/B11361_Rm0.txt
agrep -0 -c 'TCACGCTAAGTACTCTG' *.fastq > count/B11363_Rm0.txt
agrep -0 -c 'TGAGTCGCTACTAGTAT' *.fastq > count/B11364_Rm0.txt
agrep -0 -c 'AGGCAGTTCCAACCGTG' *.fastq > count/B11365_Rm0.txt
agrep -0 -c 'CCTCCAGGGTACCAGTT' *.fastq > count/B11366_Rm0.txt
agrep -0 -c 'GCCATCAACAGTTAGTT' *.fastq > count/B11367_Rm0.txt
agrep -0 -c 'CAGGCGAAAAATGAGAT' *.fastq > count/B11368_Rm0.txt
agrep -0 -c 'TCGATTGCGCTAAGCAG' *.fastq > count/B11369_Rm0.txt
agrep -0 -c 'CTACTTCACCGAAGACT' *.fastq > count/B11370_Rm0.txt
agrep -0 -c 'CCGCTTGATGAGCACTG' *.fastq > count/B11371_Rm0.txt
agrep -0 -c 'TGTGTCGTGCATTGTCT' *.fastq > count/B11372_Rm0.txt
agrep -0 -c 'AACCGGGTATAATATGC' *.fastq > count/B11373_Rm0.txt
agrep -0 -c 'CGTTCATGACGCCACAT' *.fastq > count/B11374_Rm0.txt
agrep -0 -c 'TGCTTTTTCGGACTCCG' *.fastq > count/B11375_Rm0.txt
agrep -0 -c 'CGATCTTTCAGAGGAAG' *.fastq > count/B11376_Rm0.txt
agrep -0 -c 'AGAATAGATTCGTGGTC' *.fastq > count/B11378_Rm0.txt
agrep -0 -c 'TTTTACCGACACCCCAA' *.fastq > count/B11379_Rm0.txt
agrep -0 -c 'GTCTTCAAGCATCCCCC' *.fastq > count/B11380_Rm0.txt
agrep -0 -c 'ACCGTGCTCTAATCCCT' *.fastq > count/B11382_Rm0.txt
agrep -0 -c 'GTCGTTCTAACTCCATA' *.fastq > count/B11383_Rm0.txt
agrep -0 -c 'AAGCGGAGCTATACACT' *.fastq > count/B11384_Rm0.txt
agrep -0 -c 'ACTTACCTCGAACTCGA' *.fastq > count/B11385_Rm0.txt
agrep -0 -c 'AGCCAGCGACAATTCGG' *.fastq > count/B11386_Rm0.txt
agrep -0 -c 'AAGAACGCAGGTCGGCA' *.fastq > count/B11388_Rm0.txt
agrep -0 -c 'TACGCGAGGCGGTTTAC' *.fastq > count/B11390_Rm0.txt
agrep -0 -c 'AGGTCTCAGTCGATGGT' *.fastq > count/B11391_Rm0.txt
agrep -0 -c 'CTGCAGCAACAAGTCTA' *.fastq > count/B11392_Rm0.txt
agrep -0 -c 'TCTTGTACTGTTAGCCG' *.fastq > count/B11393_Rm0.txt
agrep -0 -c 'GTATCGAAGTAACTTGC' *.fastq > count/B11394_Rm0.txt
agrep -0 -c 'GTAGAGTGGTTTAGAAC' *.fastq > count/B11395_Rm0.txt
agrep -0 -c 'GTAGTATGACGTCAAGA' *.fastq > count/B11396_Rm0.txt
agrep -0 -c 'CGTGATTGGGTTTCATT' *.fastq > count/B11397_Rm0.txt
agrep -0 -c 'GTTGGCGGATGTATCCT' *.fastq > count/B11399_Rm0.txt
agrep -0 -c 'CGTGCTTCTGAATCCAA' *.fastq > count/B11400_Rm0.txt
agrep -0 -c 'CATAGTGTCGTAAACGC' *.fastq > count/B11401_Rm0.txt
agrep -0 -c 'CAGAGGAAGCGAAAATA' *.fastq > count/B11402_Rm0.txt
agrep -0 -c 'TGTCATTAGCTGTTGCA' *.fastq > count/B11405_Rm0.txt
agrep -0 -c 'TGACTTAGACGGTAGTG' *.fastq > count/B11406_Rm0.txt
agrep -0 -c 'GCGAATGTGACTGAGTC' *.fastq > count/B11409_Rm0.txt
agrep -0 -c 'TTGCATGGGCCTCCGTT' *.fastq > count/B11410_Rm0.txt
agrep -0 -c 'GCGGGCGTTAATGACGA' *.fastq > count/B11411_Rm0.txt
agrep -0 -c 'AACCTGCAACGAAGCCC' *.fastq > count/B11412_Rm0.txt
agrep -0 -c 'ACGTTGAAGGGCTATCA' *.fastq > count/B11414_Rm0.txt
agrep -0 -c 'GGGTGTCTCTAGTTCCA' *.fastq > count/B11415_Rm0.txt
agrep -0 -c 'TAATTGGTCAGGGCAAT' *.fastq > count/B11416_Rm0.txt
agrep -0 -c 'AGAGGGCACAAACTCGG' *.fastq > count/B11417_Rm0.txt
agrep -0 -c 'CCTTAAAATCTTGCGCA' *.fastq > count/B11418_Rm0.txt
agrep -0 -c 'AAGGGTTACAACGAACC' *.fastq > count/B11419_Rm0.txt
agrep -0 -c 'AAGTAAGCGATACCACG' *.fastq > count/B11422_Rm0.txt
agrep -0 -c 'GCGCTACCGTCAGTTAG' *.fastq > count/B11423_Rm0.txt
agrep -0 -c 'GGAATCGGATTCGAGTC' *.fastq > count/B11424_Rm0.txt
agrep -0 -c 'GTATGCTGGCTTCCGGT' *.fastq > count/B11425_Rm0.txt
agrep -0 -c 'ACTGAGGGGTAGTCTAT' *.fastq > count/B11426_Rm0.txt
agrep -0 -c 'TAAGGCGTAACAGGCGA' *.fastq > count/B11427_Rm0.txt
agrep -0 -c 'GAACAGAGCGGATGCAC' *.fastq > count/B11428_Rm0.txt
agrep -0 -c 'GATCGAGGTACGTGTTG' *.fastq > count/B11429_Rm0.txt
agrep -0 -c 'TAAGACCAAACCGGGAT' *.fastq > count/B11430_Rm0.txt
agrep -0 -c 'GCAGCTGGCTTGAGTAC' *.fastq > count/B11431_Rm0.txt
agrep -0 -c 'TGCATGGGTTGTAACAC' *.fastq > count/B11432_Rm0.txt
agrep -0 -c 'TCGATATCTTTGAGGGT' *.fastq > count/B11433_Rm0.txt
agrep -0 -c 'ATAGATGCGAACTCGTT' *.fastq > count/B11434_Rm0.txt
agrep -0 -c 'TAACGTCCACTTCGATC' *.fastq > count/B11435_Rm0.txt
agrep -0 -c 'GTAGGAAGCCTACCTTA' *.fastq > count/B11436_Rm0.txt
agrep -0 -c 'AGCGGGCATACCGTTTA' *.fastq > count/B11437_Rm0.txt
agrep -0 -c 'AACGTAAGCAGTAAGCT' *.fastq > count/B11440_Rm0.txt
agrep -0 -c 'TTGTATTTGGCAACGCG' *.fastq > count/B11442_Rm0.txt
agrep -0 -c 'TAAGCAGAACGATACAC' *.fastq > count/B11443_Rm0.txt
agrep -0 -c 'CCCAATCAATGGTCTGC' *.fastq > count/B11445_Rm0.txt
agrep -0 -c 'AGTAGTCACGACCCTGT' *.fastq > count/B11448_Rm0.txt
agrep -0 -c 'GACGTTACTACAGTGCG' *.fastq > count/B11449_Rm0.txt
agrep -0 -c 'GGCGTGCTCTGCTTAGA' *.fastq > count/B11451_Rm0.txt
agrep -0 -c 'AGCTATTTGCAGTCGTT' *.fastq > count/B11452_Rm0.txt
agrep -0 -c 'AGTGAAAGGGCACCCCT' *.fastq > count/B11453_Rm0.txt
agrep -0 -c 'GTTACGACATCAGACGT' *.fastq > count/B11454_Rm0.txt
agrep -0 -c 'CACTGACCCGTCTAACG' *.fastq > count/B11455_Rm0.txt
agrep -0 -c 'AAGTAACGTACACAACG' *.fastq > count/B11456_Rm0.txt
agrep -0 -c 'GAACTTTAATCACGCGT' *.fastq > count/B11457_Rm0.txt
agrep -0 -c 'CTCCTACACACACGTCG' *.fastq > count/B11458_Rm0.txt
agrep -0 -c 'CGATGGCCAGATACAAC' *.fastq > count/B11459_Rm0.txt
agrep -0 -c 'CGAGGATGGACAGCATA' *.fastq > count/B11460_Rm0.txt
agrep -0 -c 'ATTGCCGACATCCGATA' *.fastq > count/B11461_Rm0.txt
agrep -0 -c 'CTCGACTGGATGGTGTG' *.fastq > count/B11462_Rm0.txt
agrep -0 -c 'GTCGTTCCGCCTTCAGT' *.fastq > count/B11463_Rm0.txt
agrep -0 -c 'TAACCGTTACCCGGGGT' *.fastq > count/B11465_Rm0.txt
agrep -0 -c 'GAGGGAACGCAAAGGCA' *.fastq > count/B11466_Rm0.txt
agrep -0 -c 'GCTGCCCTGCTTGGATA' *.fastq > count/B11467_Rm0.txt
agrep -0 -c 'TCTATTCCGCTCAGTAT' *.fastq > count/B11468_Rm0.txt
agrep -0 -c 'GGCAAACAGATGGTACC' *.fastq > count/B11470_Rm0.txt
agrep -0 -c 'CGGTTTGCTTCCAAGTC' *.fastq > count/B11471_Rm0.txt
agrep -0 -c 'CTGAACCGCGGTAGTAT' *.fastq > count/B11472_Rm0.txt
agrep -0 -c 'TACAATTGTCCGCTCGC' *.fastq > count/B11474_Rm0.txt
agrep -0 -c 'CAATACATTCCATACGG' *.fastq > count/B11475_Rm0.txt
agrep -0 -c 'TCGCTGACCCTTCGTAT' *.fastq > count/B11476_Rm0.txt
agrep -0 -c 'ATTTGGCGTGTAAGAGA' *.fastq > count/B11478_Rm0.txt
agrep -0 -c 'CGAACCGTTAACGTAAG' *.fastq > count/B11479_Rm0.txt
agrep -0 -c 'GCATAAGCCTCTGTAGA' *.fastq > count/B11480_Rm0.txt
agrep -0 -c 'TGGGTCGATGTATCTAA' *.fastq > count/B11481_Rm0.txt
agrep -0 -c 'TGATCGTTCATCCATGC' *.fastq > count/B11482_Rm0.txt
agrep -0 -c 'CCCATGCTAGTTCACGC' *.fastq > count/B11483_Rm0.txt
agrep -0 -c 'TTGGTTGCCGAATCAGT' *.fastq > count/B11484_Rm0.txt
agrep -0 -c 'AAAGCCTTGACCCAGAC' *.fastq > count/B11485_Rm0.txt
agrep -0 -c 'GGTGTGTCGGTTTCACA' *.fastq > count/B11486_Rm0.txt
agrep -0 -c 'CAGATCGTCTAAGCTGT' *.fastq > count/B11487_Rm0.txt
agrep -0 -c 'TAAGTCGAACAGTAACC' *.fastq > count/B11489_Rm0.txt
agrep -0 -c 'TAGCCTTCTTGACTCAC' *.fastq > count/B11493_Rm0.txt
agrep -0 -c 'TGGTGAGAGCGTTATAT' *.fastq > count/B11494_Rm0.txt
agrep -0 -c 'CTTGAGTATGCGCGGAG' *.fastq > count/B11496_Rm0.txt
agrep -0 -c 'CTGATTAGGTCGCAGCA' *.fastq > count/B11497_Rm0.txt
agrep -0 -c 'CCCATTGACCACGAAGA' *.fastq > count/B11498_Rm0.txt
agrep -0 -c 'ACACCGAGATTTTGCCG' *.fastq > count/B11499_Rm0.txt
agrep -0 -c 'CACGATGTCGGGTCTCT' *.fastq > count/B11500_Rm0.txt
agrep -0 -c 'GTCTACGTGAACACTGG' *.fastq > count/B11501_Rm0.txt
agrep -0 -c 'GTTAGGATACCCGCAGC' *.fastq > count/B11502_Rm0.txt
agrep -0 -c 'GTAAAGGGTTTTTGAGC' *.fastq > count/B11503_Rm0.txt
agrep -0 -c 'GATTTACTGCACTAAGC' *.fastq > count/B11504_Rm0.txt
agrep -0 -c 'TTTAGCGATCTACGTCA' *.fastq > count/B11505_Rm0.txt
agrep -0 -c 'AACGGCTCTTGAGTCTC' *.fastq > count/B11506_Rm0.txt
agrep -0 -c 'ACCCTACGATCATGAGG' *.fastq > count/B11507_Rm0.txt
agrep -0 -c 'TAAACAACTCGCTATGC' *.fastq > count/B11508_Rm0.txt
agrep -0 -c 'CAACCCCGTTGGTTTAC' *.fastq > count/B11511_Rm0.txt
agrep -0 -c 'GCCCGCAGACATGATTG' *.fastq > count/B11512_Rm0.txt
agrep -0 -c 'AGCATAGGGCACATTGG' *.fastq > count/B11513_Rm0.txt
agrep -0 -c 'GGAATGTCTAACTCGGT' *.fastq > count/B11514_Rm0.txt
agrep -0 -c 'CGAAGTTCGTTTAGGCC' *.fastq > count/B11515_Rm0.txt
agrep -0 -c 'ACAGACAAACAACCAGC' *.fastq > count/B11517_Rm0.txt
agrep -0 -c 'TGTCGAGGTCTCCTGAA' *.fastq > count/B11520_Rm0.txt
agrep -0 -c 'AATTTGACTGCCCTGTG' *.fastq > count/B11521_Rm0.txt
agrep -0 -c 'TTAGTCATCCCCAGCAT' *.fastq > count/B11522_Rm0.txt
agrep -0 -c 'AAAGAGTCCACTGCTAA' *.fastq > count/B11524_Rm0.txt
agrep -0 -c 'GTGGAACATGGGTTGAT' *.fastq > count/B11525_Rm0.txt
agrep -0 -c 'AGACCATATCTAGTGCT' *.fastq > count/B11526_Rm0.txt
agrep -0 -c 'CGCTGCAAAAGGACCTC' *.fastq > count/B11527_Rm0.txt
agrep -0 -c 'GAGGATTAGTCAGGCAT' *.fastq > count/B11528_Rm0.txt
agrep -0 -c 'AGTCGCTAGTCTTCCTG' *.fastq > count/B11529_Rm0.txt
agrep -0 -c 'GTTGACCATACGTCTAG' *.fastq > count/B11530_Rm0.txt
agrep -0 -c 'CACCTGCTTTGGTACGT' *.fastq > count/B11531_Rm0.txt
agrep -0 -c 'TCTAATAGCGAGCCCTT' *.fastq > count/B11532_Rm0.txt
agrep -0 -c 'AGCAGAATCGCACGTGG' *.fastq > count/B11533_Rm0.txt
agrep -0 -c 'GTTCAACCTGGTATGAA' *.fastq > count/B11534_Rm0.txt
agrep -0 -c 'GAAACACATCAGAATCG' *.fastq > count/B11535_Rm0.txt
agrep -0 -c 'ATGAGTTAAGCGTCTTG' *.fastq > count/B11536_Rm0.txt
agrep -0 -c 'TGGAAGCACGGCTTGGT' *.fastq > count/B11537_Rm0.txt
agrep -0 -c 'TGTCTGCCTCGGTTACT' *.fastq > count/B11539_Rm0.txt
agrep -0 -c 'GTACCTGATGCAACTAA' *.fastq > count/B11541_Rm0.txt
agrep -0 -c 'CGCGATGTAATACAGAC' *.fastq > count/B11542_Rm0.txt
agrep -0 -c 'TGTGGGGCTAAGAAGTT' *.fastq > count/B11543_Rm0.txt
agrep -0 -c 'CAAAGACCCACGCGTTG' *.fastq > count/B11544_Rm0.txt
agrep -0 -c 'GAGAACCATTGATAGGT' *.fastq > count/B11545_Rm0.txt
agrep -0 -c 'GTCAACGCGTTCTATCA' *.fastq > count/B11546_Rm0.txt
agrep -0 -c 'TTTCACTTAGCACGCAG' *.fastq > count/B11548_Rm0.txt
agrep -0 -c 'AGGTCTAAACTGCGCTA' *.fastq > count/B11549_Rm0.txt
agrep -0 -c 'TCAATATGTTACCGCGG' *.fastq > count/B11550_Rm0.txt
agrep -0 -c 'AATCGAGTGCGAATCCT' *.fastq > count/B11551_Rm0.txt
agrep -0 -c 'TTACGAACCCCTGCCAG' *.fastq > count/B11552_Rm0.txt
agrep -0 -c 'TCAGGCTAAAGCTCCGT' *.fastq > count/B11553_Rm0.txt
agrep -0 -c 'TAGGCAGAGGCCCTTTA' *.fastq > count/B11554_Rm0.txt
agrep -0 -c 'CTACTAGACTGACCATT' *.fastq > count/B11555_Rm0.txt
agrep -0 -c 'GGGGCGCCATCACATAT' *.fastq > count/B11556_Rm0.txt
agrep -0 -c 'GTCCAAACTACGGTAAG' *.fastq > count/B11557_Rm0.txt
agrep -0 -c 'GGGGAAACTAAACGCGC' *.fastq > count/B11558_Rm0.txt
agrep -0 -c 'TGCCATTCCTTTGTCAG' *.fastq > count/B11559_Rm0.txt
agrep -0 -c 'CGAATGAAGCTGCAGGC' *.fastq > count/B11560_Rm0.txt
agrep -0 -c 'TCTTCACGCGCAAATAT' *.fastq > count/B11561_Rm0.txt
agrep -0 -c 'ATTTAGTCCGCACCATC' *.fastq > count/B11562_Rm0.txt
agrep -0 -c 'TCCAATCAACACGACCT' *.fastq > count/B11563_Rm0.txt
agrep -0 -c 'CAACAACGACCAATGCT' *.fastq > count/B11564_Rm0.txt
agrep -0 -c 'CTCCAGCATATAACGGC' *.fastq > count/B11565_Rm0.txt
agrep -0 -c 'GCAAGGCGTGTAGACAA' *.fastq > count/B11566_Rm0.txt
agrep -0 -c 'CCTCGGATGAACAAATC' *.fastq > count/B11567_Rm0.txt
agrep -0 -c 'GCGCCAACTACAAGACC' *.fastq > count/B11568_Rm0.txt
agrep -0 -c 'CGCGCCTGCTAAAGAAT' *.fastq > count/B11571_Rm0.txt
agrep -0 -c 'ACCCTCGTATCTCAGTC' *.fastq > count/B11572_Rm0.txt
agrep -0 -c 'TTACGCGAGAGTAAATC' *.fastq > count/B11575_Rm0.txt
agrep -0 -c 'GGGACGATACTAGAACA' *.fastq > count/B11576_Rm0.txt
agrep -0 -c 'TGAACAACTAGCCTCTC' *.fastq > count/B11578_Rm0.txt
agrep -0 -c 'CGGGGCTGCACTAAAAT' *.fastq > count/B11579_Rm0.txt
agrep -0 -c 'ATTGCGATCAAGTGCTT' *.fastq > count/B11580_Rm0.txt
agrep -0 -c 'GTTGATGAGTCCGCTCT' *.fastq > count/B11581_Rm0.txt
agrep -0 -c 'TCTCGAACTGCTCGTCC' *.fastq > count/B11582_Rm0.txt
agrep -0 -c 'GATGCCGACATAAACGG' *.fastq > count/B11583_Rm0.txt
agrep -0 -c 'CGTCGTCATCTTGGAAT' *.fastq > count/B11585_Rm0.txt
agrep -0 -c 'TACGAATTGGTGAGAAG' *.fastq > count/B11586_Rm0.txt
agrep -0 -c 'CGCGACTAATTATCGTA' *.fastq > count/B11587_Rm0.txt
agrep -0 -c 'CAGTAACGGTTAACACG' *.fastq > count/B11588_Rm0.txt
agrep -0 -c 'AGAGCACCATCGTGTCG' *.fastq > count/B11589_Rm0.txt
agrep -0 -c 'CTCACCGTAGTTGGTCG' *.fastq > count/B11590_Rm0.txt
agrep -0 -c 'TTCGAGTTTGGGGCCTC' *.fastq > count/B11591_Rm0.txt
agrep -0 -c 'GCTTAATACTCTGACGT' *.fastq > count/B11592_Rm0.txt
agrep -0 -c 'ATGTAAACTTTGCGGTC' *.fastq > count/B11593_Rm0.txt
agrep -0 -c 'GTTTGTATAGCCCAACG' *.fastq > count/B11594_Rm0.txt
agrep -0 -c 'TCGTTGTCGTCTAGTGA' *.fastq > count/B11595_Rm0.txt
agrep -0 -c 'AGCCGTATTCTACCATG' *.fastq > count/B11596_Rm0.txt
agrep -0 -c 'TGGGACCTAGCTGAGAA' *.fastq > count/B11598_Rm0.txt
agrep -0 -c 'GCTAAAGCGATCCTCCC' *.fastq > count/B11599_Rm0.txt
agrep -0 -c 'TTAGTTTGCACCCACTC' *.fastq > count/B11601_Rm0.txt
agrep -0 -c 'ATGCGTTGAGTAGTCAG' *.fastq > count/B11602_Rm0.txt
agrep -0 -c 'CTAATACATCTTCCGTG' *.fastq > count/B11603_Rm0.txt
agrep -0 -c 'GCTTCGCCAGAACGACT' *.fastq > count/B11604_Rm0.txt
agrep -0 -c 'TATTACGGAACCCGTAC' *.fastq > count/B11605_Rm0.txt
agrep -0 -c 'GGAAGGTATTAGGGTGC' *.fastq > count/B11606_Rm0.txt
agrep -0 -c 'GCGAATGTAGCCCACTC' *.fastq > count/B11608_Rm0.txt
agrep -0 -c 'GAGTTGCGGTGTAGTAG' *.fastq > count/B11611_Rm0.txt
agrep -0 -c 'TCCACGGCTTGAGAGTG' *.fastq > count/B11613_Rm0.txt
agrep -0 -c 'CACACGTCCTAGCCCTA' *.fastq > count/B11614_Rm0.txt
agrep -0 -c 'TTACCAGAGTGCGGCCT' *.fastq > count/B11615_Rm0.txt
agrep -0 -c 'TACGTAACGCGAGCTTA' *.fastq > count/B11616_Rm0.txt
agrep -0 -c 'AACTGAACTACTGGGAA' *.fastq > count/B11618_Rm0.txt
agrep -0 -c 'GCCGCACTTCGCATTCT' *.fastq > count/B11619_Rm0.txt
agrep -0 -c 'ATTCTGTGACCACGTTG' *.fastq > count/B11620_Rm0.txt
agrep -0 -c 'CGTACGAGTCCGCAATG' *.fastq > count/B11621_Rm0.txt
agrep -0 -c 'GTAATGTCGTGGATGCG' *.fastq > count/B11622_Rm0.txt
agrep -0 -c 'GCTATAATGGCTAGGAA' *.fastq > count/B11623_Rm0.txt
agrep -0 -c 'GTTAAGGCCGGACTGTC' *.fastq > count/B11624_Rm0.txt
agrep -0 -c 'ACGATTGGCTTGTCCAA' *.fastq > count/B11625_Rm0.txt
agrep -0 -c 'TAAGTGTGCGTGACGTG' *.fastq > count/B11626_Rm0.txt
agrep -0 -c 'GCAAACATAGCTACTCG' *.fastq > count/B11627_Rm0.txt
agrep -0 -c 'CTAGTAGAGTGGCACGG' *.fastq > count/B11628_Rm0.txt
agrep -0 -c 'ATACCGACTGGGATTTG' *.fastq > count/B11630_Rm0.txt
agrep -0 -c 'AAAACTCGGGCCATTGC' *.fastq > count/B11631_Rm0.txt
agrep -0 -c 'CACTAACTAATGGGATC' *.fastq > count/B11632_Rm0.txt
agrep -0 -c 'GATTCTAAGCGATCCGG' *.fastq > count/B11633_Rm0.txt
agrep -0 -c 'TCCTGAGTATCAATTCC' *.fastq > count/B11634_Rm0.txt
agrep -0 -c 'TACGTCCAAGACCTACC' *.fastq > count/B11635_Rm0.txt
agrep -0 -c 'CTGAGAAGTGGATAGAA' *.fastq > count/B11636_Rm0.txt
agrep -0 -c 'GCAGCCCAATGACCAAG' *.fastq > count/B11637_Rm0.txt
agrep -0 -c 'TGCTACGTGCGGACCAT' *.fastq > count/B11639_Rm0.txt
agrep -0 -c 'GCCTCCCGACTTTTGAT' *.fastq > count/B11640_Rm0.txt
agrep -0 -c 'GCTGAGTCACGTTAAGG' *.fastq > count/B11642_Rm0.txt
agrep -0 -c 'GCTATGGCAGTCGTGTA' *.fastq > count/B11643_Rm0.txt
agrep -0 -c 'CAAAATATCGGTGTGCA' *.fastq > count/B11645_Rm0.txt
agrep -0 -c 'GCTGAGAGTGTACGAGA' *.fastq > count/B11648_Rm0.txt
agrep -0 -c 'GTTGACTGCAGTTGAGA' *.fastq > count/B11649_Rm0.txt
agrep -0 -c 'AGGGTCGAATGCCTTCA' *.fastq > count/B11650_Rm0.txt
agrep -0 -c 'TAACGTTTGAATGCCTC' *.fastq > count/B11651_Rm0.txt
agrep -0 -c 'TATTGGTAAAGCGAGGC' *.fastq > count/B11652_Rm0.txt
agrep -0 -c 'GTTCTGACATAGCTCCG' *.fastq > count/B11653_Rm0.txt
agrep -0 -c 'ACGGAGAGATTAGGTGT' *.fastq > count/B11654_Rm0.txt
agrep -0 -c 'GTCCGTATGACCTATCA' *.fastq > count/B11655_Rm0.txt
agrep -0 -c 'CATGTCTCGTATTCCTG' *.fastq > count/B11656_Rm0.txt
agrep -0 -c 'GTAGCTCAATTAGGCAA' *.fastq > count/B11657_Rm0.txt
agrep -0 -c 'TTGCCAATAAGAAGTGG' *.fastq > count/B11659_Rm0.txt
agrep -0 -c 'AGAACTCTACCAAGGCT' *.fastq > count/B11660_Rm0.txt
agrep -0 -c 'CTCATCAAGGAGCGCGT' *.fastq > count/B11661_Rm0.txt
agrep -0 -c 'TCTACGAGTTAGGGGGC' *.fastq > count/B11662_Rm0.txt
agrep -0 -c 'GGACGAACTGTTACTAA' *.fastq > count/B11663_Rm0.txt
agrep -0 -c 'CTCTATTGGTTCGGTGA' *.fastq > count/B11664_Rm0.txt
agrep -0 -c 'TAAAGATGGGGGTGATT' *.fastq > count/B11665_Rm0.txt
agrep -0 -c 'GACATCGTCAGGTCTCA' *.fastq > count/B11667_Rm0.txt
agrep -0 -c 'ATGGGGCGAATGCTCTT' *.fastq > count/B11668_Rm0.txt
agrep -0 -c 'CCCCAACGAATTGGGCA' *.fastq > count/B11669_Rm0.txt
agrep -0 -c 'TAAGGAACGGCCGCTCT' *.fastq > count/B11671_Rm0.txt
agrep -0 -c 'CATTAGACCGTATGTCT' *.fastq > count/B11672_Rm0.txt
agrep -0 -c 'TCATTGTTCCGCCTGCC' *.fastq > count/B11673_Rm0.txt
agrep -0 -c 'CATTCGGCTACGAATCT' *.fastq > count/B11674_Rm0.txt
agrep -0 -c 'CGATAGGTAATCGGTCG' *.fastq > count/B11675_Rm0.txt
agrep -0 -c 'ATCGACAGCTTTCCCCT' *.fastq > count/B11676_Rm0.txt
agrep -0 -c 'TAGCATGGATGTCGATG' *.fastq > count/B11677_Rm0.txt
agrep -0 -c 'GCGGAGAGCTCAAGTAA' *.fastq > count/B11678_Rm0.txt
agrep -0 -c 'AAATTCACTACCCACAG' *.fastq > count/B11681_Rm0.txt
agrep -0 -c 'GTCTATCGTGAGCAATT' *.fastq > count/B11682_Rm0.txt
agrep -0 -c 'GACTGATTCGCTCGATT' *.fastq > count/B11683_Rm0.txt
agrep -0 -c 'CCCTATCTACACTACGC' *.fastq > count/B11684_Rm0.txt
agrep -0 -c 'GTGCACAAATGTAGGCC' *.fastq > count/B11686_Rm0.txt
agrep -0 -c 'ACTCCCATAGGAAACCT' *.fastq > count/B11687_Rm0.txt
agrep -0 -c 'AAAAGGCCCCTAGATGT' *.fastq > count/B11689_Rm0.txt
agrep -0 -c 'GCGTTCGAAACTAAGCT' *.fastq > count/B11690_Rm0.txt
agrep -0 -c 'CCGCTTATGGTGAAGAA' *.fastq > count/B11692_Rm0.txt
agrep -0 -c 'GTCTGCGTTGTGTCGAG' *.fastq > count/B11693_Rm0.txt
agrep -0 -c 'CCTCCTGTTAGACTAAC' *.fastq > count/B11694_Rm0.txt
agrep -0 -c 'GTTACCACCGAAAGTCG' *.fastq > count/B11695_Rm0.txt
agrep -0 -c 'TGAGCAATTAAGCGGGC' *.fastq > count/B11697_Rm0.txt
agrep -0 -c 'TCCCTGCGGTATGTACG' *.fastq > count/B11700_Rm0.txt
agrep -0 -c 'TACCAGGAGCCAGGAAT' *.fastq > count/B11701_Rm0.txt
agrep -0 -c 'CCGAAATGCCGACCGAT' *.fastq > count/B11702_Rm0.txt
agrep -0 -c 'AAACCGGGCCTAGAAGA' *.fastq > count/B11703_Rm0.txt
agrep -0 -c 'TCTTCTCCGGCTAATAC' *.fastq > count/B11704_Rm0.txt
agrep -0 -c 'GACATACTAGCTCCCGG' *.fastq > count/B11705_Rm0.txt
agrep -0 -c 'TTATCGTAGACACTCGT' *.fastq > count/B11706_Rm0.txt
agrep -0 -c 'GGCAACTCGATCCTCGA' *.fastq > count/B11707_Rm0.txt
agrep -0 -c 'CCGGTTCCTGGTAACGT' *.fastq > count/B11710_Rm0.txt
agrep -0 -c 'CAATCCAGCGATAGTTG' *.fastq > count/B11711_Rm0.txt
agrep -0 -c 'TACGTGCCAGCCCTACA' *.fastq > count/B11712_Rm0.txt
agrep -0 -c 'AGTCGCCGATCTCATGA' *.fastq > count/B11714_Rm0.txt
agrep -0 -c 'AACGGCCTTGGGATTAG' *.fastq > count/B11715_Rm0.txt
agrep -0 -c 'TTACAACACTTTGAGCC' *.fastq > count/B11717_Rm0.txt
agrep -0 -c 'CTCAGGGTGTCACTTAA' *.fastq > count/B11719_Rm0.txt
agrep -0 -c 'AGACCTTACCCTCATGG' *.fastq > count/B11720_Rm0.txt
agrep -0 -c 'GGTACCGTAATAGTCGC' *.fastq > count/B11721_Rm0.txt
agrep -0 -c 'CGAAGTTGCTCTTTGCT' *.fastq > count/B11722_Rm0.txt
agrep -0 -c 'AAAGGGTTCCCTCGCCT' *.fastq > count/B11723_Rm0.txt
agrep -0 -c 'CATCCTGCAAGACCACG' *.fastq > count/B11724_Rm0.txt
agrep -0 -c 'TAACCTTTCAACGTCGA' *.fastq > count/B11725_Rm0.txt
agrep -0 -c 'TAATCTCTCCTTGACGC' *.fastq > count/B11726_Rm0.txt
agrep -0 -c 'GTAGACTGGTTAGATAC' *.fastq > count/B11727_Rm0.txt
agrep -0 -c 'ATCTAGTCAGGGGCATA' *.fastq > count/B11728_Rm0.txt
agrep -0 -c 'AACCGCGTAGGAGAGGT' *.fastq > count/B11729_Rm0.txt
agrep -0 -c 'GAAGTGTTCCCACTGCT' *.fastq > count/B11730_Rm0.txt
agrep -0 -c 'TTTGCGGGCTTGGTCTT' *.fastq > count/B11731_Rm0.txt
agrep -0 -c 'TCGTTCTTCAATCTCCT' *.fastq > count/B11732_Rm0.txt
agrep -0 -c 'CTGCCCACGTAAGACTT' *.fastq > count/B11733_Rm0.txt
agrep -0 -c 'CTAACATCGCTGTAACA' *.fastq > count/B11735_Rm0.txt
agrep -0 -c 'TCCGTGTATTAGCTGAG' *.fastq > count/B11736_Rm0.txt
agrep -0 -c 'CTTATGCGACGAGTAAT' *.fastq > count/B11738_Rm0.txt
agrep -0 -c 'CGACCTTTACTAACCGC' *.fastq > count/B11739_Rm0.txt
agrep -0 -c 'CGACAATCTTGAACGAT' *.fastq > count/B11740_Rm0.txt
agrep -0 -c 'CCCATGGATTTCCCGAT' *.fastq > count/B11741_Rm0.txt
agrep -0 -c 'TTATCGGGTGAGAGGCA' *.fastq > count/B11742_Rm0.txt
agrep -0 -c 'GCCTTGAGGGATCGAAC' *.fastq > count/B11743_Rm0.txt
agrep -0 -c 'TATTGCCTGGTACTTCC' *.fastq > count/B11744_Rm0.txt
agrep -0 -c 'TGATGATTGCGGCCAGG' *.fastq > count/B11745_Rm0.txt
agrep -0 -c 'AATATGCTTCTAGCTCG' *.fastq > count/B11746_Rm0.txt
agrep -0 -c 'ACGACCAAGCTCAAAGT' *.fastq > count/B11747_Rm0.txt
agrep -0 -c 'GACCTCCCATAATACTA' *.fastq > count/B11749_Rm0.txt
agrep -0 -c 'TTAACGCCAGCGGGTCA' *.fastq > count/B11750_Rm0.txt
agrep -0 -c 'CATTGCAGTGCCTTAGC' *.fastq > count/B11751_Rm0.txt
agrep -0 -c 'ATTTACACGTAACCAGC' *.fastq > count/B11752_Rm0.txt
agrep -0 -c 'GCTATGCCTGGGTACCT' *.fastq > count/B11753_Rm0.txt
agrep -0 -c 'GAACTTATGCTACGTAG' *.fastq > count/B11754_Rm0.txt
agrep -0 -c 'AATAGATAGGAGGGCGA' *.fastq > count/B11755_Rm0.txt
agrep -0 -c 'AATACCCAGTTGGCTCT' *.fastq > count/B11756_Rm0.txt
agrep -0 -c 'TCCTTGTGGCCCTAAAC' *.fastq > count/B11759_Rm0.txt
agrep -0 -c 'GACGTAGGCCGTTCATT' *.fastq > count/B11760_Rm0.txt
agrep -0 -c 'ACGAAAGATAAGGCGGC' *.fastq > count/B11761_Rm0.txt
agrep -0 -c 'GGCAATCTAATAGGGGT' *.fastq > count/B11762_Rm0.txt
agrep -0 -c 'ACCCAGTTCGACGATCA' *.fastq > count/B11764_Rm0.txt
agrep -0 -c 'GCTGAACTGTACCTGTG' *.fastq > count/B11765_Rm0.txt
agrep -0 -c 'GTGTGTTGGAACGGATA' *.fastq > count/B11766_Rm0.txt
agrep -0 -c 'AAGTACGTCGCGGAACG' *.fastq > count/B11767_Rm0.txt
agrep -0 -c 'ATTAGACCGCCCAGTGA' *.fastq > count/B11768_Rm0.txt
agrep -0 -c 'TGCCGGAAGTATTGGGC' *.fastq > count/B11771_Rm0.txt
agrep -0 -c 'TTAGAGGGGTGTCTTCA' *.fastq > count/B11773_Rm0.txt
agrep -0 -c 'AGCCACTTAGTACGAGG' *.fastq > count/B11774_Rm0.txt
agrep -0 -c 'GGAACCTGATTGTGAGC' *.fastq > count/B11775_Rm0.txt
agrep -0 -c 'TTGCCTAGTAAGGTGAG' *.fastq > count/B11776_Rm0.txt
agrep -0 -c 'GTCCTATGTGTTATGGT' *.fastq > count/B11777_Rm0.txt
agrep -0 -c 'TTCGCGCACATCATCTT' *.fastq > count/B11779_Rm0.txt
agrep -0 -c 'AGAGGGGATCCGAGGTA' *.fastq > count/B11780_Rm0.txt
agrep -0 -c 'AACGGGCTTCAGTGCCA' *.fastq > count/B11781_Rm0.txt
agrep -0 -c 'AACCTCCAGATGTTGAC' *.fastq > count/B11782_Rm0.txt
agrep -0 -c 'CGAAAGATCCCAGTCTC' *.fastq > count/B11783_Rm0.txt
agrep -0 -c 'AAACGGCTCTTGAGGGT' *.fastq > count/B11786_Rm0.txt
agrep -0 -c 'CTTCGCCATGGTTGTGT' *.fastq > count/B11787_Rm0.txt
agrep -0 -c 'CACCCGGATTTTGAACC' *.fastq > count/B11789_Rm0.txt
agrep -0 -c 'AAAACTGTGTATCGCAC' *.fastq > count/B11790_Rm0.txt
agrep -0 -c 'GTCTAGAGCATGAATAG' *.fastq > count/B11791_Rm0.txt
agrep -0 -c 'AGACTACCTTTTTCGAG' *.fastq > count/B11792_Rm0.txt
agrep -0 -c 'ATTAGATAACGATGGCG' *.fastq > count/B11793_Rm0.txt
agrep -0 -c 'TGAGGTTGTATAAGCGA' *.fastq > count/B11794_Rm0.txt
agrep -0 -c 'TCATCATCCGGGCCTAG' *.fastq > count/B11795_Rm0.txt
agrep -0 -c 'GATTGTCGCGTCTACCT' *.fastq > count/B11797_Rm0.txt
agrep -0 -c 'AGGCGTCCATTTGCATT' *.fastq > count/B11798_Rm0.txt
agrep -0 -c 'GTTGATGCTACCTACTG' *.fastq > count/B11799_Rm0.txt
agrep -0 -c 'ATATGACCGTTGCTCTC' *.fastq > count/B11800_Rm0.txt
agrep -0 -c 'TAGCTTATCCGGTTGAT' *.fastq > count/B11802_Rm0.txt
agrep -0 -c 'TGTTCGAATTATCCACG' *.fastq > count/B11803_Rm0.txt
agrep -0 -c 'CCATCTTAGCACACTCG' *.fastq > count/B11804_Rm0.txt
agrep -0 -c 'CGTTCATAACGTTCCGT' *.fastq > count/B11806_Rm0.txt
agrep -0 -c 'CGATAAATAACACCGCT' *.fastq > count/B11807_Rm0.txt
agrep -0 -c 'GATAATACCCACAGTCC' *.fastq > count/B11808_Rm0.txt
agrep -0 -c 'CTTAAGAGTGCAGACTT' *.fastq > count/B11809_Rm0.txt
agrep -0 -c 'ATCCACCGACTTATCAG' *.fastq > count/B11810_Rm0.txt
agrep -0 -c 'TCGATGTCCCATTCCGG' *.fastq > count/B11812_Rm0.txt
agrep -0 -c 'ACGCACACCCAAAGCTT' *.fastq > count/B11813_Rm0.txt
agrep -0 -c 'TATCAGGAGTACCTCCG' *.fastq > count/B11814_Rm0.txt
agrep -0 -c 'AAAGACGTTCGGCTGGT' *.fastq > count/B11815_Rm0.txt
agrep -0 -c 'CGATGCAACATGTGCGC' *.fastq > count/B11816_Rm0.txt
agrep -0 -c 'GCCCTTCATCCTAGCTC' *.fastq > count/B11818_Rm0.txt
agrep -0 -c 'ATGTTCACACCAGTCGT' *.fastq > count/B11819_Rm0.txt
agrep -0 -c 'CCCGAAATGCTCACATC' *.fastq > count/B11821_Rm0.txt
agrep -0 -c 'GTCTCAAAGCGAAGACT' *.fastq > count/B11822_Rm0.txt
agrep -0 -c 'AAAGTCGGGACTTATAC' *.fastq > count/B11823_Rm0.txt
agrep -0 -c 'TCGCTCTCCCGCGTTAT' *.fastq > count/B11824_Rm0.txt
agrep -0 -c 'ATTGGAGGAGACCTTGA' *.fastq > count/B11825_Rm0.txt
agrep -0 -c 'CTGTTGAGCGACGTTCG' *.fastq > count/B11826_Rm0.txt
agrep -0 -c 'AGTACCATCCCCGTGGT' *.fastq > count/B11827_Rm0.txt
agrep -0 -c 'TAACTCCATAGCGACCT' *.fastq > count/B11828_Rm0.txt
agrep -0 -c 'GAGACCGAATCAAGACC' *.fastq > count/B11829_Rm0.txt
agrep -0 -c 'AGCCCCGAGGTTCAATG' *.fastq > count/B11830_Rm0.txt
agrep -0 -c 'GAGAACGAGTTCGGATG' *.fastq > count/B11831_Rm0.txt
agrep -0 -c 'AGTAATGGTCGATAGGC' *.fastq > count/B11833_Rm0.txt
agrep -0 -c 'GTCAATGTGCCACCCGA' *.fastq > count/B11836_Rm0.txt
agrep -0 -c 'TACACGGCGCTTGGATT' *.fastq > count/B11837_Rm0.txt
agrep -0 -c 'TTCCCATGTATAAAGCC' *.fastq > count/B11838_Rm0.txt
agrep -0 -c 'TAGATGCTGGATTCAAC' *.fastq > count/B11839_Rm0.txt
agrep -0 -c 'GATGTTCCTTCTGTTAC' *.fastq > count/B11840_Rm0.txt
agrep -0 -c 'GAATACCGCTCGAACCT' *.fastq > count/B11841_Rm0.txt
agrep -0 -c 'TCGGTCTAGCAACTTGA' *.fastq > count/B11842_Rm0.txt
agrep -0 -c 'AAAACCCACGTCAGGGT' *.fastq > count/B11843_Rm0.txt
agrep -0 -c 'CTAGGCCGATCGAGAAC' *.fastq > count/B11844_Rm0.txt
agrep -0 -c 'TACCCCCGCGTACAAAC' *.fastq > count/B11845_Rm0.txt
agrep -0 -c 'TAATGCATGATCAGCCG' *.fastq > count/B11846_Rm0.txt
agrep -0 -c 'ATTAATCTCTGCGCTGC' *.fastq > count/B11847_Rm0.txt
agrep -0 -c 'GGTTCTCGCAAGACCCT' *.fastq > count/B11848_Rm0.txt
agrep -0 -c 'AACACTGGATCTGGAAC' *.fastq > count/B11849_Rm0.txt
agrep -0 -c 'AGTGATGCGGGGAGAAT' *.fastq > count/B11851_Rm0.txt
agrep -0 -c 'TACCCGATGCATGCTAA' *.fastq > count/B11853_Rm0.txt
agrep -0 -c 'GCAAGTGTGAGATCGCC' *.fastq > count/B11855_Rm0.txt
agrep -0 -c 'CGCGTACATAGGCTATG' *.fastq > count/B11856_Rm0.txt
agrep -0 -c 'CATCGGTGGGAGTAGAA' *.fastq > count/B11858_Rm0.txt
agrep -0 -c 'AGGCACTTTGAGCGTCC' *.fastq > count/B11859_Rm0.txt
agrep -0 -c 'GATAAACTTCGCCTCTA' *.fastq > count/B11860_Rm0.txt
agrep -0 -c 'CCTCCAAAGAAACGGAG' *.fastq > count/B11862_Rm0.txt
agrep -0 -c 'CGCATGACACTAGGATT' *.fastq > count/B11863_Rm0.txt
agrep -0 -c 'TCCGGTAATCCCTCGCT' *.fastq > count/B11864_Rm0.txt
agrep -0 -c 'GTGGCCAACTCCTTTAC' *.fastq > count/B11865_Rm0.txt
agrep -0 -c 'GGATCGGGACATGAACG' *.fastq > count/B11866_Rm0.txt
agrep -0 -c 'GACAACGGAGTTATCCT' *.fastq > count/B11867_Rm0.txt
agrep -0 -c 'AGCGGCATAAACATTCT' *.fastq > count/B11868_Rm0.txt
agrep -0 -c 'AGGCATACCCGAATGAT' *.fastq > count/B11869_Rm0.txt
agrep -0 -c 'TGTAGAAACGTGCGCTT' *.fastq > count/B11870_Rm0.txt
agrep -0 -c 'GGATTGTTTGGATCTGT' *.fastq > count/B11871_Rm0.txt
agrep -0 -c 'TATATTGTCTCGATCCC' *.fastq > count/B11872_Rm0.txt
agrep -0 -c 'ATACGTTCAGGACGACA' *.fastq > count/B11873_Rm0.txt
agrep -0 -c 'GATACTGCGTAAACGTC' *.fastq > count/B11875_Rm0.txt
agrep -0 -c 'TAGAATCCATGGTACGG' *.fastq > count/B11876_Rm0.txt
agrep -0 -c 'CTTGTGGTCGTTCTAGC' *.fastq > count/B11877_Rm0.txt
agrep -0 -c 'ATAAAGGGGCCACACTT' *.fastq > count/B11878_Rm0.txt
agrep -0 -c 'GGTTGAATCGGATGACG' *.fastq > count/B11879_Rm0.txt
agrep -0 -c 'GCCTCAAGCGTACCGTA' *.fastq > count/B11881_Rm0.txt
agrep -0 -c 'CGGGCACAATTTCAGCT' *.fastq > count/B11882_Rm0.txt
agrep -0 -c 'CACGTTCGATGTCCGAG' *.fastq > count/B11883_Rm0.txt
agrep -0 -c 'TTGACGATATTCTCTGG' *.fastq > count/B11884_Rm0.txt
agrep -0 -c 'TATCGCGAGTCAGTCAG' *.fastq > count/B11885_Rm0.txt
agrep -0 -c 'GTCACGAATGTTCCGTA' *.fastq > count/B11887_Rm0.txt
agrep -0 -c 'GTATAGCAGACAAGCTA' *.fastq > count/B11889_Rm0.txt
agrep -0 -c 'CCCTGTTAGGCACAACG' *.fastq > count/B11890_Rm0.txt
agrep -0 -c 'ATCTGAATTTGCAACCC' *.fastq > count/B11892_Rm0.txt
agrep -0 -c 'AGCGACGATTGCTAGTA' *.fastq > count/B11893_Rm0.txt
agrep -0 -c 'TGTTGGATGAGAAACGT' *.fastq > count/B11895_Rm0.txt
agrep -0 -c 'CTCGACACATAACCTAG' *.fastq > count/B11896_Rm0.txt
agrep -0 -c 'TCATGCTCGAGGGAGTT' *.fastq > count/B11897_Rm0.txt
agrep -0 -c 'TTGACGCGAACTGTTGC' *.fastq > count/B11899_Rm0.txt
agrep -0 -c 'GGGGTTCGAAAGGCGTT' *.fastq > count/B11900_Rm0.txt
agrep -0 -c 'AACGTTCCGAACGGTGA' *.fastq > count/B11901_Rm0.txt
agrep -0 -c 'GCCGACCATTATTGTCG' *.fastq > count/B11902_Rm0.txt
agrep -0 -c 'AGGTTGTGCCGTGCCAA' *.fastq > count/B11903_Rm0.txt
agrep -0 -c 'TGTCGTGGGGCAAGAGT' *.fastq > count/B11904_Rm0.txt
agrep -0 -c 'GGTCCGATACCGATGAG' *.fastq > count/B11905_Rm0.txt
agrep -0 -c 'AAGGTCCTGTTTAGTGC' *.fastq > count/B11906_Rm0.txt
agrep -0 -c 'ACTCTTAGACGACCTGC' *.fastq > count/B11907_Rm0.txt
agrep -0 -c 'CTTAGTCGGAGAGGTTA' *.fastq > count/B11908_Rm0.txt
agrep -0 -c 'GGGACGCCGATTGATAT' *.fastq > count/B11909_Rm0.txt
agrep -0 -c 'AGCTTATTTACGCGACT' *.fastq > count/B11910_Rm0.txt
agrep -0 -c 'GCCAATCACATTCAGAA' *.fastq > count/B11911_Rm0.txt
agrep -0 -c 'CTAAATCGTGCCGACGG' *.fastq > count/B11912_Rm0.txt
agrep -0 -c 'TAAGGCTGGTGGGGGTT' *.fastq > count/B11914_Rm0.txt
agrep -0 -c 'CGACACGCTTAGCCGTA' *.fastq > count/B11915_Rm0.txt
agrep -0 -c 'GTAGTCCATTGGGCCGT' *.fastq > count/B11916_Rm0.txt
agrep -0 -c 'TTTCCACGCTGCATTAC' *.fastq > count/B11918_Rm0.txt
agrep -0 -c 'GTTGGTGTTTTTCGCGT' *.fastq > count/B11919_Rm0.txt
agrep -0 -c 'CTTCTGAATAATGCGCG' *.fastq > count/B11920_Rm0.txt
agrep -0 -c 'GTAGGGACGAAAAAGCA' *.fastq > count/B11921_Rm0.txt
agrep -0 -c 'TTATGGACGTCCACATA' *.fastq > count/B11923_Rm0.txt
agrep -0 -c 'TTTCCCATGCAATCTGT' *.fastq > count/B11924_Rm0.txt
agrep -0 -c 'CGTGTGGAACCCTTCTA' *.fastq > count/B11925_Rm0.txt
agrep -0 -c 'TATACATCCCGTCTGAT' *.fastq > count/B11926_Rm0.txt
agrep -0 -c 'GTTCACGTAGATTGAGT' *.fastq > count/B11927_Rm0.txt
agrep -0 -c 'TATGCCGAAGCGCGCTT' *.fastq > count/B11928_Rm0.txt
agrep -0 -c 'ACTCCTAAGCCCGTACG' *.fastq > count/B11929_Rm0.txt
agrep -0 -c 'CCGTCTGCTTGGTTTAC' *.fastq > count/B11930_Rm0.txt
agrep -0 -c 'ACGTTCTGAGATCGGTG' *.fastq > count/B11931_Rm0.txt
agrep -0 -c 'AGTGTGTATGCTATTCG' *.fastq > count/B11932_Rm0.txt
agrep -0 -c 'GCTATGGAGGAGTAACA' *.fastq > count/B11933_Rm0.txt
agrep -0 -c 'CGTGAACTGCCATATGA' *.fastq > count/B11934_Rm0.txt
agrep -0 -c 'CTCTGTTTTTCTTGAGC' *.fastq > count/B11935_Rm0.txt
agrep -0 -c 'TGACCCTCGTCGTATAC' *.fastq > count/B11936_Rm0.txt
agrep -0 -c 'TTCCGCTATCGAGAAAC' *.fastq > count/B11937_Rm0.txt
agrep -0 -c 'TAGAAGAGACGCACGAT' *.fastq > count/B11938_Rm0.txt
agrep -0 -c 'TACCCTCATCCCAGTCT' *.fastq > count/B11939_Rm0.txt
agrep -0 -c 'TGCAATGTCAGGTTTAC' *.fastq > count/B11940_Rm0.txt
agrep -0 -c 'CTCCTCTGACAGTGATG' *.fastq > count/B11941_Rm0.txt
agrep -0 -c 'CTCTTAAGGCGACCAAT' *.fastq > count/B11942_Rm0.txt
agrep -0 -c 'CACGGAAGCTCCTACAT' *.fastq > count/B11946_Rm0.txt
agrep -0 -c 'TAAATCTCAGCTGGCTC' *.fastq > count/B11947_Rm0.txt
agrep -0 -c 'TACAGATGGTTCAGAGT' *.fastq > count/B11948_Rm0.txt
agrep -0 -c 'TCTACTATGTTAGACCC' *.fastq > count/B11949_Rm0.txt
agrep -0 -c 'CAAGCGACGAATTTACT' *.fastq > count/B11950_Rm0.txt
agrep -0 -c 'GTTGTCGTCATACGTAT' *.fastq > count/B11953_Rm0.txt
agrep -0 -c 'AAAGGACCACTAGTTCA' *.fastq > count/B11954_Rm0.txt
agrep -0 -c 'GTCGACTGACTTGTGAC' *.fastq > count/B11955_Rm0.txt
agrep -0 -c 'ACCCCGCAAGCTTTCAG' *.fastq > count/B11956_Rm0.txt
agrep -0 -c 'TAGCTGGTCAAGTTCCC' *.fastq > count/B11957_Rm0.txt
agrep -0 -c 'ATTCGCATTCCACGATT' *.fastq > count/B11958_Rm0.txt
agrep -0 -c 'ATCAGAGCCATAACGCC' *.fastq > count/B11959_Rm0.txt
agrep -0 -c 'CAGGGATGTCCATCGTT' *.fastq > count/B11960_Rm0.txt
agrep -0 -c 'GGCTCCCTGAGTACCTA' *.fastq > count/B11961_Rm0.txt
agrep -0 -c 'CAACGCGTAAATAGTCT' *.fastq > count/B11962_Rm0.txt
agrep -0 -c 'ATTACCAACGCATTCCC' *.fastq > count/B11963_Rm0.txt
agrep -0 -c 'CGGTAATTTTCGGCGGT' *.fastq > count/B11965_Rm0.txt
agrep -0 -c 'CGGAGGACAATACGTTA' *.fastq > count/B11966_Rm0.txt
agrep -0 -c 'ACTGACCAGACTTTATG' *.fastq > count/B11967_Rm0.txt
agrep -0 -c 'GCTAGATAGCTGATCCT' *.fastq > count/B11969_Rm0.txt
agrep -0 -c 'AGAGATAGACGACCATA' *.fastq > count/B11971_Rm0.txt
agrep -0 -c 'GAACCTTAACCAACCAG' *.fastq > count/B11972_Rm0.txt
agrep -0 -c 'ACTGTGTTGGAATCGTG' *.fastq > count/B11973_Rm0.txt
agrep -0 -c 'TAATTGTGGCGCCTCGC' *.fastq > count/B11974_Rm0.txt
agrep -0 -c 'CCGCAGTACTCCTATAA' *.fastq > count/B11975_Rm0.txt
agrep -0 -c 'TGCGGACCTTATATCGA' *.fastq > count/B11976_Rm0.txt
agrep -0 -c 'ATTCCCAGAGCTTGAAC' *.fastq > count/B11977_Rm0.txt
agrep -0 -c 'CAATCATCCTTGTTCAG' *.fastq > count/B11980_Rm0.txt
agrep -0 -c 'CGAAGACCATCATTCAT' *.fastq > count/B11981_Rm0.txt
agrep -0 -c 'ACTATAGGTGCAAATGC' *.fastq > count/B11983_Rm0.txt
agrep -0 -c 'ACAGGTTAATACGGGAT' *.fastq > count/B11984_Rm0.txt
agrep -0 -c 'AACTGGCAGATCACTCG' *.fastq > count/B11985_Rm0.txt
agrep -0 -c 'AAGCGGAGCATTCGTCG' *.fastq > count/B11986_Rm0.txt
agrep -0 -c 'TCGAGTTTACTGGCATA' *.fastq > count/B11987_Rm0.txt
agrep -0 -c 'CAATAGTCCTGCAACTT' *.fastq > count/B11988_Rm0.txt
agrep -0 -c 'CATGAGGAACGTCCTAA' *.fastq > count/B11989_Rm0.txt
agrep -0 -c 'GCTTATTGAGCGGGACG' *.fastq > count/B11990_Rm0.txt
agrep -0 -c 'CGAACTTACGCATTGTC' *.fastq > count/B11991_Rm0.txt
agrep -0 -c 'CTCGTCGAGGAAGTTCG' *.fastq > count/B11992_Rm0.txt
agrep -0 -c 'ATACGGACGGTTTACAT' *.fastq > count/B11993_Rm0.txt
agrep -0 -c 'TTATTCTTGCGTACGAG' *.fastq > count/B11994_Rm0.txt
agrep -0 -c 'GCCATAGATGGGCAATT' *.fastq > count/B11996_Rm0.txt
agrep -0 -c 'ACCCGAGCATTAAGGAC' *.fastq > count/B11997_Rm0.txt
agrep -0 -c 'GGTTTTCGTGCAGTGTC' *.fastq > count/B12000_Rm0.txt
agrep -0 -c 'TGTAGTCTTTGCGTAGG' *.fastq > count/B12001_Rm0.txt
agrep -0 -c 'GATCCTTCGATTAGGTA' *.fastq > count/B12002_Rm0.txt
agrep -0 -c 'CGAGCAGCAGATGGGTA' *.fastq > count/B12003_Rm0.txt
agrep -0 -c 'GAGGTTAAGGTTCTGAC' *.fastq > count/B12004_Rm0.txt
agrep -0 -c 'GCAGTGCAACTACTATC' *.fastq > count/B12005_Rm0.txt
agrep -0 -c 'GACCACCAGCGTAATCT' *.fastq > count/B12006_Rm0.txt
agrep -0 -c 'GGTCTTAACATCCCGAG' *.fastq > count/B12007_Rm0.txt
agrep -0 -c 'GACCTAGGACGCCTAGA' *.fastq > count/B12008_Rm0.txt
agrep -0 -c 'CCCCAACCTTTCGACAT' *.fastq > count/B12009_Rm0.txt
agrep -0 -c 'ATCGCCTGTAGAGGTAT' *.fastq > count/B12010_Rm0.txt
agrep -0 -c 'GCAAATAGCCGTTATCC' *.fastq > count/B12011_Rm0.txt
agrep -0 -c 'ACACCACTTGCATAGCC' *.fastq > count/B12012_Rm0.txt
agrep -0 -c 'TATAGCAATCCAGTCGT' *.fastq > count/B12013_Rm0.txt
agrep -0 -c 'CGTTAGGTTCAGGATAA' *.fastq > count/B12014_Rm0.txt
agrep -0 -c 'CACCGCATCGGTCTTCA' *.fastq > count/B12015_Rm0.txt
agrep -0 -c 'GCAAGTTCTACTATCGA' *.fastq > count/B12016_Rm0.txt
agrep -0 -c 'GAATCAACGGATTGCAG' *.fastq > count/B12017_Rm0.txt
agrep -0 -c 'CTAAGGCGCAGTTCTCT' *.fastq > count/B12018_Rm0.txt
agrep -0 -c 'GGACTGGTCAAAAGGTT' *.fastq > count/B12020_Rm0.txt
agrep -0 -c 'AGGATCCCAATGCGGTA' *.fastq > count/B12021_Rm0.txt
agrep -0 -c 'GGTCAGACTACGACCAG' *.fastq > count/B12022_Rm0.txt
agrep -0 -c 'TGCCGCACTTCTCCGTA' *.fastq > count/B12023_Rm0.txt
agrep -0 -c 'TGATACCGGGCTACACA' *.fastq > count/B12024_Rm0.txt
agrep -0 -c 'GATGGTGCTTCCTGCGT' *.fastq > count/B12025_Rm0.txt
agrep -0 -c 'ACCCCGTAGTGAACTTG' *.fastq > count/B12026_Rm0.txt
agrep -0 -c 'AGAAAGCGCGCTTCTTA' *.fastq > count/B12027_Rm0.txt
agrep -0 -c 'CGGCTAGAAACAGCAGC' *.fastq > count/B12029_Rm0.txt
agrep -0 -c 'CGATTGGGACGGATACG' *.fastq > count/B12030_Rm0.txt
agrep -0 -c 'TCTACGGAGAGAATTCT' *.fastq > count/B12031_Rm0.txt
agrep -0 -c 'GGCGGTGATCTCTCCTA' *.fastq > count/B12032_Rm0.txt
agrep -0 -c 'GAATTCAATCCAGGCAT' *.fastq > count/B12033_Rm0.txt
agrep -0 -c 'GGCTGAGCATGATCACT' *.fastq > count/B12034_Rm0.txt
agrep -0 -c 'AGAGTCGCGTAATGCAC' *.fastq > count/B12036_Rm0.txt
agrep -0 -c 'GGGGATCACAGAAGTAT' *.fastq > count/B12037_Rm0.txt
agrep -0 -c 'CTTATGGCAGAGTCGAT' *.fastq > count/B12038_Rm0.txt
agrep -0 -c 'TCGGTCAGGCACAAGAT' *.fastq > count/B12039_Rm0.txt
agrep -0 -c 'GCAAGAGGTTCTCGTGA' *.fastq > count/B12040_Rm0.txt
agrep -0 -c 'TGTGCCCATCAGCCTAG' *.fastq > count/B12041_Rm0.txt
agrep -0 -c 'CACGGAAACTTGCGGCT' *.fastq > count/B12042_Rm0.txt
agrep -0 -c 'AGAATGACCGCGCAAGA' *.fastq > count/B12043_Rm0.txt
agrep -0 -c 'CGGCTGCTCCCTGATAT' *.fastq > count/B12044_Rm0.txt
agrep -0 -c 'TCCGGAAAACAGTGATG' *.fastq > count/B12045_Rm0.txt
agrep -0 -c 'CAAAACTCTCTGCAGTC' *.fastq > count/B12046_Rm0.txt
agrep -0 -c 'CTTTGGAGACTCCGAGT' *.fastq > count/B12047_Rm0.txt
agrep -0 -c 'TGTTCGTGTAGGCGACT' *.fastq > count/B12048_Rm0.txt
agrep -0 -c 'AAGTGGGAGTTCTGTTG' *.fastq > count/B12049_Rm0.txt
agrep -0 -c 'AGAGAATAACCACTCCA' *.fastq > count/B12050_Rm0.txt
agrep -0 -c 'CTGACGATAGAAACGAT' *.fastq > count/B12052_Rm0.txt
agrep -0 -c 'GTGTTTGTCGCTAGAAG' *.fastq > count/B12053_Rm0.txt
agrep -0 -c 'CTCCCACGACGTTACTA' *.fastq > count/B12055_Rm0.txt
agrep -0 -c 'CATCTAGCATCACCATC' *.fastq > count/B12056_Rm0.txt
agrep -0 -c 'TGAGCTATCGATGCGGC' *.fastq > count/B12057_Rm0.txt
agrep -0 -c 'GCAAACGCTATGTTCCG' *.fastq > count/B12058_Rm0.txt
agrep -0 -c 'CTTTAGCTCTGGCCCAC' *.fastq > count/B12059_Rm0.txt
agrep -0 -c 'AGCGGCGTATAGGTACT' *.fastq > count/B12060_Rm0.txt
agrep -0 -c 'TCGAATAGATTCCGGAA' *.fastq > count/B12061_Rm0.txt
agrep -0 -c 'TGCCTATGACGACTGAG' *.fastq > count/B12062_Rm0.txt
agrep -0 -c 'GAGATTGAGGTCGCACG' *.fastq > count/B12063_Rm0.txt
agrep -0 -c 'ATGCCATTTACGGAATG' *.fastq > count/B12065_Rm0.txt
agrep -0 -c 'TTCCTCTGTCCCGTGCT' *.fastq > count/B12066_Rm0.txt
agrep -0 -c 'TCGGAGTTACTGTGTCC' *.fastq > count/B12068_Rm0.txt
agrep -0 -c 'TGGAATAACTGCGACTG' *.fastq > count/B12069_Rm0.txt
agrep -0 -c 'CAGATATGATGTGTGAC' *.fastq > count/B12070_Rm0.txt
agrep -0 -c 'CTGCCTGATAGGTTATT' *.fastq > count/B12071_Rm0.txt
agrep -0 -c 'TCTGATGAAATAGGCGG' *.fastq > count/B12072_Rm0.txt
agrep -0 -c 'TAACATCAATCCGTCAC' *.fastq > count/B12074_Rm0.txt
agrep -0 -c 'TTACCTAGGCCGGACGT' *.fastq > count/B12075_Rm0.txt
agrep -0 -c 'TAGCAGCCTGTCGAAGA' *.fastq > count/B12076_Rm0.txt
agrep -0 -c 'CACTATTTAAGGATGGC' *.fastq > count/B12077_Rm0.txt
agrep -0 -c 'ATCAACTCAGTGCGACA' *.fastq > count/B12078_Rm0.txt
agrep -0 -c 'TCGGGGTAAGGCCTATG' *.fastq > count/B12079_Rm0.txt
agrep -0 -c 'GCCCAGAATTTCCGGCA' *.fastq > count/B12080_Rm0.txt
agrep -0 -c 'ACATGCGAGATTCTGAA' *.fastq > count/B12081_Rm0.txt
agrep -0 -c 'TTCCGCTAGAGAATTTG' *.fastq > count/B12084_Rm0.txt
agrep -0 -c 'GTAAAAACTCGCGGCTG' *.fastq > count/B12086_Rm0.txt
agrep -0 -c 'AGGGCACTGAGGAGAAC' *.fastq > count/B12087_Rm0.txt
agrep -0 -c 'TACTAGTCAACCGTCTA' *.fastq > count/B12088_Rm0.txt
agrep -0 -c 'CAGTCATAGCATGCTTA' *.fastq > count/B12089_Rm0.txt
agrep -0 -c 'CATAAGTCACGTTGCCG' *.fastq > count/B12090_Rm0.txt
agrep -0 -c 'TCGACCTAACATTTGCA' *.fastq > count/B12091_Rm0.txt
agrep -0 -c 'TTATGGACATATTGCGG' *.fastq > count/B12092_Rm0.txt
agrep -0 -c 'GCTGTCCCAGGGTAAAC' *.fastq > count/B12096_Rm0.txt
agrep -0 -c 'CGCGGTTTCTTTCTGTG' *.fastq > count/B12098_Rm0.txt
agrep -0 -c 'TTATACCCGGAAACCCC' *.fastq > count/B12099_Rm0.txt
agrep -0 -c 'AACTCTTAGGTTGGGTT' *.fastq > count/B12100_Rm0.txt
agrep -0 -c 'ACCGTGCGGATCGTCTA' *.fastq > count/B12101_Rm0.txt
agrep -0 -c 'CTCGGTGAGATGTGGCT' *.fastq > count/B12103_Rm0.txt
agrep -0 -c 'ATAATGGGTGGCTGCTT' *.fastq > count/B12104_Rm0.txt
agrep -0 -c 'ATAGATCGGAGGCCTAT' *.fastq > count/B12105_Rm0.txt
agrep -0 -c 'GGTTTCGCACTGTTAGT' *.fastq > count/B12106_Rm0.txt
agrep -0 -c 'GTCCGCGAAGTAGAGTG' *.fastq > count/B12107_Rm0.txt
agrep -0 -c 'CCCGAAATAACCTATCC' *.fastq > count/B12108_Rm0.txt
agrep -0 -c 'TTGAACGCCTTTGAAAC' *.fastq > count/B12109_Rm0.txt
agrep -0 -c 'ATAGCTGTAACATTCGG' *.fastq > count/B12111_Rm0.txt
agrep -0 -c 'CACCCAAATTCTTAACG' *.fastq > count/B12112_Rm0.txt
agrep -0 -c 'GTAGGGTGACGAGAATT' *.fastq > count/B12113_Rm0.txt
agrep -0 -c 'GCTAATTCGCCCCAGAA' *.fastq > count/B12115_Rm0.txt
agrep -0 -c 'AGCGTTCACATAACCGT' *.fastq > count/B12117_Rm0.txt
agrep -0 -c 'TAAAGTATGACCACCGT' *.fastq > count/B12118_Rm0.txt
agrep -0 -c 'TCACTTTACATCCTCGA' *.fastq > count/B12119_Rm0.txt
agrep -0 -c 'TGCGACATCAATTGTCC' *.fastq > count/B12120_Rm0.txt
agrep -0 -c 'TTGTATATTCGCGGCCT' *.fastq > count/B12121_Rm0.txt
agrep -0 -c 'CTATTCCTCCGCCACTA' *.fastq > count/B12122_Rm0.txt
agrep -0 -c 'TGTCGGGGCGTTTTCAC' *.fastq > count/B12123_Rm0.txt
agrep -0 -c 'TCTCCTTCAGTCGAACC' *.fastq > count/B12124_Rm0.txt
agrep -0 -c 'CGGTTAGCATTGAGCCT' *.fastq > count/B12125_Rm0.txt
agrep -0 -c 'TCCGTCAGTAGAAAGTT' *.fastq > count/B12126_Rm0.txt
agrep -0 -c 'TACGGTTACGCCGGTTA' *.fastq > count/B12127_Rm0.txt
agrep -0 -c 'CTACCTGATCTCAGTGC' *.fastq > count/B12128_Rm0.txt
agrep -0 -c 'GCTTGTCCCCTTAGTCC' *.fastq > count/B12129_Rm0.txt
agrep -0 -c 'CCATGGAATCAGCTCTC' *.fastq > count/B12131_Rm0.txt
agrep -0 -c 'ACAGTAAGCACTGAGGC' *.fastq > count/B12132_Rm0.txt
agrep -0 -c 'CACGAAAACCGGCAATG' *.fastq > count/B12134_Rm0.txt
agrep -0 -c 'CTATGAATCGCCGAGAG' *.fastq > count/B12135_Rm0.txt
agrep -0 -c 'CCGGTCCGTGAAGCTAT' *.fastq > count/B12136_Rm0.txt
agrep -0 -c 'TTTCGGCTTACTTGACC' *.fastq > count/B12137_Rm0.txt
agrep -0 -c 'TCTACTACTCGGATGGC' *.fastq > count/B12139_Rm0.txt
agrep -0 -c 'ATCGTCCTAGTGTATCC' *.fastq > count/B12140_Rm0.txt
agrep -0 -c 'CAGCTCGAGGTATTCCG' *.fastq > count/B12141_Rm0.txt
agrep -0 -c 'ATTACATTCCGAGAGAC' *.fastq > count/B12142_Rm0.txt
agrep -0 -c 'CGGGTGAAACAGCATGT' *.fastq > count/B12143_Rm0.txt
agrep -0 -c 'CTGGCTAACAAGTCAAT' *.fastq > count/B12144_Rm0.txt
agrep -0 -c 'CAAACATGTGAAGTCCT' *.fastq > count/B12145_Rm0.txt
agrep -0 -c 'TGGACCCACAACATTCG' *.fastq > count/B12146_Rm0.txt
agrep -0 -c 'TAAAGCAGCTCGCAGCC' *.fastq > count/B12147_Rm0.txt
agrep -0 -c 'TTCGAATAGTGTGGAAG' *.fastq > count/B12148_Rm0.txt
agrep -0 -c 'CTGGTCTTTTCCCCGCT' *.fastq > count/B12149_Rm0.txt
agrep -0 -c 'CAATGACTTACGCGCAA' *.fastq > count/B12150_Rm0.txt
agrep -0 -c 'TTTTGGAGGTTAGTCGT' *.fastq > count/B12151_Rm0.txt
agrep -0 -c 'ACTCCGTCAAATCTAGT' *.fastq > count/B12152_Rm0.txt
agrep -0 -c 'GGTGTTTCGTACCGTAT' *.fastq > count/B12153_Rm0.txt
agrep -0 -c 'CACTTCCGCTACTAACA' *.fastq > count/B12154_Rm0.txt
agrep -0 -c 'TTGCAAGGTCCAGAAGG' *.fastq > count/B12155_Rm0.txt
agrep -0 -c 'GAGCTAGCTTCGCTACA' *.fastq > count/B12156_Rm0.txt
agrep -0 -c 'AGAATCGTCTGCATCGA' *.fastq > count/B12157_Rm0.txt
agrep -0 -c 'AATCAAGAACTCGCTCC' *.fastq > count/B12158_Rm0.txt
agrep -0 -c 'GCATCAGTAGAGCTCTA' *.fastq > count/B12159_Rm0.txt
agrep -0 -c 'CGTTTCTCATGGCCGAT' *.fastq > count/B12161_Rm0.txt
agrep -0 -c 'TCCGTGCACTTCGAATA' *.fastq > count/B12162_Rm0.txt
agrep -0 -c 'AGAAGTCTGGATCACAT' *.fastq > count/B12163_Rm0.txt
agrep -0 -c 'CGCTTTCGTAAGCGTAC' *.fastq > count/B12164_Rm0.txt
agrep -0 -c 'GTTGCGCCAGTTTTAGG' *.fastq > count/B12165_Rm0.txt
agrep -0 -c 'CGTGTGTCGGTTATGCC' *.fastq > count/B12167_Rm0.txt
agrep -0 -c 'GTTATAAATGCGCGCTG' *.fastq > count/B12168_Rm0.txt
agrep -0 -c 'TTGACCATTGACCGACA' *.fastq > count/B12169_Rm0.txt
agrep -0 -c 'TTTAGCTGGGGATGCAA' *.fastq > count/B12170_Rm0.txt
agrep -0 -c 'GCTGAACTAAGAATCCA' *.fastq > count/B12171_Rm0.txt
agrep -0 -c 'TGATTGCATCGGACCTA' *.fastq > count/B12172_Rm0.txt
agrep -0 -c 'CGATATCCTCGCATATA' *.fastq > count/B12173_Rm0.txt
agrep -0 -c 'GACACTCAATTTTAGCG' *.fastq > count/B12174_Rm0.txt
agrep -0 -c 'CACAAGGGATCACTTGT' *.fastq > count/B12175_Rm0.txt
agrep -0 -c 'GCCTGTCGAACTTGAGG' *.fastq > count/B12176_Rm0.txt
agrep -0 -c 'TGGTCAGGTGGTGTTAG' *.fastq > count/B12181_Rm0.txt
agrep -0 -c 'CACAAGTACAATAACGC' *.fastq > count/B12182_Rm0.txt
agrep -0 -c 'ACAGTTGGTCTTGCGTT' *.fastq > count/B12183_Rm0.txt
agrep -0 -c 'GCCAAGGGTAACAGGAG' *.fastq > count/B12184_Rm0.txt
agrep -0 -c 'TACAGGGTCGAGGGCAA' *.fastq > count/B12185_Rm0.txt
agrep -0 -c 'GCAGTAAAATGCCTCGC' *.fastq > count/B12186_Rm0.txt
agrep -0 -c 'TGTCGTTCATCGCAAGT' *.fastq > count/B12187_Rm0.txt
agrep -0 -c 'GGCGGTCTCCATTACGT' *.fastq > count/B12188_Rm0.txt
agrep -0 -c 'CCAGAACACACGTCCGT' *.fastq > count/B12189_Rm0.txt
agrep -0 -c 'ACTGCCACGTGCTCTGA' *.fastq > count/B12190_Rm0.txt
agrep -0 -c 'GCAGATCTTAGATGAAC' *.fastq > count/B12191_Rm0.txt
agrep -0 -c 'TGAAAGCTTTTCCGCAG' *.fastq > count/B12192_Rm0.txt
agrep -0 -c 'GTCTGACTGTCAACACG' *.fastq > count/B12194_Rm0.txt
agrep -0 -c 'TCGACGCTTAACACTCT' *.fastq > count/B12195_Rm0.txt
agrep -0 -c 'TGTGGGTCAAACTGCCA' *.fastq > count/B12196_Rm0.txt
agrep -0 -c 'GGTTAAAACTCGATCCG' *.fastq > count/B12198_Rm0.txt
agrep -0 -c 'GTCATGACGACTCTACT' *.fastq > count/B12199_Rm0.txt
agrep -0 -c 'TCTCATGAGCGTCGGAG' *.fastq > count/B12200_Rm0.txt
agrep -0 -c 'ATTTAACGCCGAGTAGC' *.fastq > count/B12201_Rm0.txt
agrep -0 -c 'AGCGAGAAACCAGTTAC' *.fastq > count/B12202_Rm0.txt
agrep -0 -c 'TCCTCGTCGAGGCAACT' *.fastq > count/B12203_Rm0.txt
agrep -0 -c 'GAGCAATACCATCGAAC' *.fastq > count/B12204_Rm0.txt
agrep -0 -c 'GGGTTTTCGTGGGCCTA' *.fastq > count/B12205_Rm0.txt
agrep -0 -c 'CTATGCTAAGGAAGTGC' *.fastq > count/B12206_Rm0.txt
agrep -0 -c 'TGGGGATAGCGTGAGAA' *.fastq > count/B12207_Rm0.txt
agrep -0 -c 'AGGTCTAATGTAGTTGC' *.fastq > count/B12208_Rm0.txt
agrep -0 -c 'TGAGGTCATTGTCACGC' *.fastq > count/B12210_Rm0.txt
agrep -0 -c 'AAACTGGATCATGTACG' *.fastq > count/B12212_Rm0.txt
agrep -0 -c 'AGGCCAATCAGCTTGTG' *.fastq > count/B12213_Rm0.txt
agrep -0 -c 'TTGGAAGCGCAACAGGC' *.fastq > count/B12214_Rm0.txt
agrep -0 -c 'AAAGGTGGATGATACCC' *.fastq > count/B12216_Rm0.txt
agrep -0 -c 'GGTCTAACGCCCCTGTA' *.fastq > count/B12217_Rm0.txt
agrep -0 -c 'ATACATGGTCGTCCTGA' *.fastq > count/B12218_Rm0.txt
agrep -0 -c 'ACGGAGCGCATTACAAG' *.fastq > count/B12219_Rm0.txt
agrep -0 -c 'TCACTGGCTGGGGAGTT' *.fastq > count/B12221_Rm0.txt
agrep -0 -c 'TAAACCCGTGGTAGCCC' *.fastq > count/B12222_Rm0.txt
agrep -0 -c 'ACTGGGTACGGGTAGTT' *.fastq > count/B12223_Rm0.txt
agrep -0 -c 'TACCCTCTATGGGGAAG' *.fastq > count/B12224_Rm0.txt
agrep -0 -c 'TTTTGGGATTCACGCAA' *.fastq > count/B12225_Rm0.txt
agrep -0 -c 'AGCCTCATACTAAGGGC' *.fastq > count/B12227_Rm0.txt
agrep -0 -c 'TTCGGGATGTGTAATAC' *.fastq > count/B12228_Rm0.txt
agrep -0 -c 'ACAAAGCCAATTCTGGT' *.fastq > count/B12229_Rm0.txt
agrep -0 -c 'AACGGAACCGGGACTAA' *.fastq > count/B12230_Rm0.txt
agrep -0 -c 'TAGCCTAAGTATCCTGG' *.fastq > count/B12231_Rm0.txt
agrep -0 -c 'CACGTCTCACCGACAGT' *.fastq > count/B12233_Rm0.txt
agrep -0 -c 'CTATTACACAACTTCGG' *.fastq > count/B12234_Rm0.txt
agrep -0 -c 'TATATAGGACGGGGTAA' *.fastq > count/B12235_Rm0.txt
agrep -0 -c 'CAATCTAAGCGCTGGGC' *.fastq > count/B12237_Rm0.txt
agrep -0 -c 'TTGGCGCTGCTTGGGTA' *.fastq > count/B12238_Rm0.txt
agrep -0 -c 'ATACGACTCCCCATGGC' *.fastq > count/B12239_Rm0.txt
agrep -0 -c 'CAGATTTGCGCCTGACT' *.fastq > count/B12241_Rm0.txt
agrep -0 -c 'GCCGTCTGCATTCCATG' *.fastq > count/B12242_Rm0.txt
agrep -0 -c 'TGGTGCCGATCAAGTAT' *.fastq > count/B12243_Rm0.txt
agrep -0 -c 'ACTACGTCATGATAAGC' *.fastq > count/B12245_Rm0.txt
agrep -0 -c 'TGTGTCAGATCTTGCAT' *.fastq > count/B12246_Rm0.txt
agrep -0 -c 'GTGGTATCGTGTAAATG' *.fastq > count/B12247_Rm0.txt
agrep -0 -c 'ACACTAGACAGGGTTAA' *.fastq > count/B12249_Rm0.txt
agrep -0 -c 'GTGCGACGATGTCACGT' *.fastq > count/B12250_Rm0.txt
agrep -0 -c 'GCAATGAGGTTGAAGCT' *.fastq > count/B12251_Rm0.txt
agrep -0 -c 'CAAAAGTCCTGGTCTAT' *.fastq > count/B12252_Rm0.txt
agrep -0 -c 'ATAGTTCAGATCCCGCC' *.fastq > count/B12253_Rm0.txt
agrep -0 -c 'GGCTACCATGATCCCTA' *.fastq > count/B12254_Rm0.txt
agrep -0 -c 'TTTGAGAACCGTCGCGA' *.fastq > count/B12255_Rm0.txt
agrep -0 -c 'GCGCCAGCTCATCTATA' *.fastq > count/B12256_Rm0.txt
agrep -0 -c 'GTGTATAAGGGTCTCGT' *.fastq > count/B12257_Rm0.txt
agrep -0 -c 'GGCGAGACAGTTCATGA' *.fastq > count/B12259_Rm0.txt
agrep -0 -c 'CCTGCAGAACACGCACT' *.fastq > count/B12260_Rm0.txt
agrep -0 -c 'GCCGGACATTACAGCAC' *.fastq > count/B12261_Rm0.txt
agrep -0 -c 'TCTTAAAAGGCCGTAAG' *.fastq > count/B12263_Rm0.txt
agrep -0 -c 'GTCACATACATCGCCTG' *.fastq > count/B12264_Rm0.txt
agrep -0 -c 'TCATAAGGCAGGCGACA' *.fastq > count/B12265_Rm0.txt
agrep -0 -c 'CTTCATACCAAGTATCC' *.fastq > count/B12267_Rm0.txt
agrep -0 -c 'GTAACTGCCTCGATAGT' *.fastq > count/B12268_Rm0.txt
agrep -0 -c 'TACGTCTCACGGGTTGT' *.fastq > count/B12269_Rm0.txt
agrep -0 -c 'GATCAATCGCCCATCTA' *.fastq > count/B12270_Rm0.txt
agrep -0 -c 'TGGTTTGATAACGGGGC' *.fastq > count/B12272_Rm0.txt
agrep -0 -c 'CAAGCACTGCATGAGAT' *.fastq > count/B12273_Rm0.txt
agrep -0 -c 'GTATGAGGAAGGAGCTA' *.fastq > count/B12274_Rm0.txt
agrep -0 -c 'TGCCGTGTTTTCAAGAG' *.fastq > count/B12275_Rm0.txt
agrep -0 -c 'TTTTGGGAGTAGCATAC' *.fastq > count/B12276_Rm0.txt
agrep -0 -c 'AAGAAGCTGGCCCCGTT' *.fastq > count/B12277_Rm0.txt
agrep -0 -c 'TCTTCGAACACTCTGAC' *.fastq > count/B12278_Rm0.txt
agrep -0 -c 'GTTACATTAGCAGGTCG' *.fastq > count/B12279_Rm0.txt
agrep -0 -c 'AGCAACCCATGTTCTAG' *.fastq > count/B12280_Rm0.txt
agrep -0 -c 'TGCTGGTCCAATTGCGT' *.fastq > count/B12281_Rm0.txt
agrep -0 -c 'TGTCTAAGCGACTTCCT' *.fastq > count/B12283_Rm0.txt
agrep -0 -c 'GGCGTGCGAACCATGAT' *.fastq > count/B12284_Rm0.txt
agrep -0 -c 'GCCGGTGTACTTGAAAT' *.fastq > count/B12285_Rm0.txt
agrep -0 -c 'TAGTACGTGACATCCCT' *.fastq > count/B12287_Rm0.txt
agrep -0 -c 'TAGTATGGTGTGCGAGA' *.fastq > count/B12288_Rm0.txt
agrep -0 -c 'TTCGTGTTCGACGTACC' *.fastq > count/B12289_Rm0.txt
agrep -0 -c 'GGTACGATTACACAACC' *.fastq > count/B12290_Rm0.txt
agrep -0 -c 'CGTAAAACCGGACTTTG' *.fastq > count/B12291_Rm0.txt
agrep -0 -c 'GTCAGGATTTACACGAG' *.fastq > count/B12293_Rm0.txt
agrep -0 -c 'CGGTATCGACAATCGAC' *.fastq > count/B12294_Rm0.txt
agrep -0 -c 'GGTTTCACCACAGGCTC' *.fastq > count/B12295_Rm0.txt
agrep -0 -c 'GATGCAGGTGAGTTATG' *.fastq > count/B12296_Rm0.txt
agrep -0 -c 'TAAAGCGACGTGATCCC' *.fastq > count/B12297_Rm0.txt
agrep -0 -c 'GGCCCGGAATCTGCATT' *.fastq > count/B12299_Rm0.txt
agrep -0 -c 'CACGAACCAGTTTGTCA' *.fastq > count/B12300_Rm0.txt
agrep -0 -c 'CATACGGGGACCTGACA' *.fastq > count/B12301_Rm0.txt
agrep -0 -c 'CGATAATGGGTAGCGAA' *.fastq > count/B12302_Rm0.txt
agrep -0 -c 'TACGTTCTACTGCTCAA' *.fastq > count/B12303_Rm0.txt
agrep -0 -c 'TACCCAACGAAACGAGG' *.fastq > count/B12304_Rm0.txt
agrep -0 -c 'CGGAATCGAATGGCGGT' *.fastq > count/B12305_Rm0.txt
agrep -0 -c 'AAGGCTATCACCCTCAA' *.fastq > count/B12306_Rm0.txt
agrep -0 -c 'CGGGACTGAAGGTTCGT' *.fastq > count/B12307_Rm0.txt
agrep -0 -c 'TTCCTCCAGTCAAGCGG' *.fastq > count/B12308_Rm0.txt
agrep -0 -c 'ACAGCTACTTGTTATCG' *.fastq > count/B12311_Rm0.txt
agrep -0 -c 'CGCCGTCAGTTCATGAC' *.fastq > count/B12312_Rm0.txt
agrep -0 -c 'GGCATACTTCCGGCATG' *.fastq > count/B12313_Rm0.txt
agrep -0 -c 'GTTCGAGAGCAGTATAA' *.fastq > count/B12314_Rm0.txt
agrep -0 -c 'ATTTAGGTGTCGGGGAG' *.fastq > count/B12315_Rm0.txt
agrep -0 -c 'GTCGAGTGGTTTATCAA' *.fastq > count/B12316_Rm0.txt
agrep -0 -c 'CGCCATGCTACGTGTAA' *.fastq > count/B12317_Rm0.txt
agrep -0 -c 'GAACGTCGTAGTACGTC' *.fastq > count/B12318_Rm0.txt
agrep -0 -c 'CACCGTGAACTCCGAAT' *.fastq > count/B12319_Rm0.txt
agrep -0 -c 'GGCTATCCTAAGTCAAC' *.fastq > count/B12320_Rm0.txt
agrep -0 -c 'GATACGTGGTCAGCAAG' *.fastq > count/B12322_Rm0.txt
agrep -0 -c 'GAGCGGAAAACTAACAT' *.fastq > count/B12325_Rm0.txt
agrep -0 -c 'TTGCTCAGTACGGAGTC' *.fastq > count/B12327_Rm0.txt
agrep -0 -c 'TAGGCTGGCGCTCAGAT' *.fastq > count/B12328_Rm0.txt
agrep -0 -c 'AGGAAAGCGCGAAACAC' *.fastq > count/B12329_Rm0.txt
agrep -0 -c 'TGTTGATTGGCGGAACA' *.fastq > count/B12330_Rm0.txt
agrep -0 -c 'CTCGGAAGACTAGCCCT' *.fastq > count/B12332_Rm0.txt
agrep -0 -c 'TGTCAGAGGTAGGTTAC' *.fastq > count/B12333_Rm0.txt
agrep -0 -c 'TGTCGATTGATGGGCAA' *.fastq > count/B12334_Rm0.txt
agrep -0 -c 'CCTCGGAGAAATCGGTC' *.fastq > count/B12335_Rm0.txt
agrep -0 -c 'CCACAAATTCGCTGCTT' *.fastq > count/B12336_Rm0.txt
agrep -0 -c 'GGCATTTCCGTGTGACT' *.fastq > count/B12337_Rm0.txt
agrep -0 -c 'TTGACGGATATGGGTCG' *.fastq > count/B12338_Rm0.txt
agrep -0 -c 'GTGAAGGAGTTGGTCCA' *.fastq > count/B12339_Rm0.txt
agrep -0 -c 'CACACTTCCACTCGGAC' *.fastq > count/B12340_Rm0.txt
agrep -0 -c 'CCACATGATAGGGCTTG' *.fastq > count/B12341_Rm0.txt
agrep -0 -c 'CGTGACGGAGTAGTCAA' *.fastq > count/B12342_Rm0.txt
agrep -0 -c 'GCGTCCGGACCTATTGA' *.fastq > count/B12343_Rm0.txt
agrep -0 -c 'CAATCCGGACCTAATGT' *.fastq > count/B12344_Rm0.txt
agrep -0 -c 'CCGCTAACGAGTTGAGT' *.fastq > count/B12345_Rm0.txt
agrep -0 -c 'TAGTTGTTACCACGGGT' *.fastq > count/B12346_Rm0.txt
agrep -0 -c 'ATGAATGGAGAGCTCCT' *.fastq > count/B12347_Rm0.txt
agrep -0 -c 'CGCTAATGCGCCCAATT' *.fastq > count/B12348_Rm0.txt
agrep -0 -c 'CCTAGACTGTTGACCGG' *.fastq > count/B12349_Rm0.txt
agrep -0 -c 'TCGGTTACCGCTTGCTT' *.fastq > count/B12350_Rm0.txt
agrep -0 -c 'GCGACTTTACACTCACT' *.fastq > count/B12351_Rm0.txt
agrep -0 -c 'GAGTAAGCTAGAGAAGG' *.fastq > count/B12352_Rm0.txt
agrep -0 -c 'CCAATCTGCATAGGGGC' *.fastq > count/B12353_Rm0.txt
agrep -0 -c 'ATTCGTGAATCTCCGCT' *.fastq > count/B12355_Rm0.txt
agrep -0 -c 'TATGCCCTAGCGAGATC' *.fastq > count/B12356_Rm0.txt
agrep -0 -c 'GGATGTAAACCGACTAC' *.fastq > count/B12357_Rm0.txt
agrep -0 -c 'AACTTGCAATCAGAGCC' *.fastq > count/B12358_Rm0.txt
agrep -0 -c 'GACGATGTCGTGTAACT' *.fastq > count/B12359_Rm0.txt
agrep -0 -c 'CGAAAAGTCTAAGCGTT' *.fastq > count/B12360_Rm0.txt
agrep -0 -c 'CAGTCCGAGGTGATGTA' *.fastq > count/B12361_Rm0.txt
agrep -0 -c 'TGTAATCCGAGTGGTGC' *.fastq > count/B12363_Rm0.txt
agrep -0 -c 'TCTAGCTAATTGCCACT' *.fastq > count/B12365_Rm0.txt
agrep -0 -c 'TAATGATCCGTGTAGCC' *.fastq > count/B12367_Rm0.txt
agrep -0 -c 'TGTCAACCTGGCGCGTT' *.fastq > count/B12368_Rm0.txt
agrep -0 -c 'GGTTAACGACGTCCATA' *.fastq > count/B12369_Rm0.txt
agrep -0 -c 'GGATATTAGTTGGTGCT' *.fastq > count/B12370_Rm0.txt
agrep -0 -c 'ACCCTCCTACCAATAGT' *.fastq > count/B12371_Rm0.txt
agrep -0 -c 'ACCCACTACTCTAATGG' *.fastq > count/B12373_Rm0.txt
agrep -0 -c 'AAAGACCATATCTCACG' *.fastq > count/B12375_Rm0.txt
agrep -0 -c 'GATGCATAGGTTGCGAC' *.fastq > count/B12377_Rm0.txt
agrep -0 -c 'TTTGTGTCACGCTACAC' *.fastq > count/B12378_Rm0.txt
agrep -0 -c 'CCGACTGAAATCCTAAG' *.fastq > count/B12379_Rm0.txt
agrep -0 -c 'TCAACCCGTAAGCTGTG' *.fastq > count/B12380_Rm0.txt
agrep -0 -c 'GCGGAGTCACAATGACG' *.fastq > count/B12381_Rm0.txt
agrep -0 -c 'ATCCATTTTGTGTGCAC' *.fastq > count/B12382_Rm0.txt
agrep -0 -c 'TCGTGGATATGGGTAAT' *.fastq > count/B12383_Rm0.txt
agrep -0 -c 'TTACAGGGCAGTTAGAT' *.fastq > count/B12384_Rm0.txt
agrep -0 -c 'ACAGCGTACGCACTACT' *.fastq > count/B12386_Rm0.txt
agrep -0 -c 'TTATGGGGCGATATAGT' *.fastq > count/B12387_Rm0.txt
agrep -0 -c 'TCTTAACGAAACCGCGA' *.fastq > count/B12388_Rm0.txt
agrep -0 -c 'GATGGGAGTTCGATTCG' *.fastq > count/B12391_Rm0.txt
agrep -0 -c 'GATCCTACCGTTTTAAG' *.fastq > count/B12392_Rm0.txt
agrep -0 -c 'ATCGAGTAACCCCCCTC' *.fastq > count/B12393_Rm0.txt
agrep -0 -c 'GGTCATCTAATAGTGCT' *.fastq > count/B12394_Rm0.txt
agrep -0 -c 'CGTTGTAAAACACGAGG' *.fastq > count/B12395_Rm0.txt
agrep -0 -c 'CACTGTATTAGTCCGCG' *.fastq > count/B12396_Rm0.txt
agrep -0 -c 'CTCGTAGTTATTTCTCC' *.fastq > count/B12397_Rm0.txt
agrep -0 -c 'TGAGGGCAATAGGAAAT' *.fastq > count/B12398_Rm0.txt
agrep -0 -c 'CAAGGCGGGGATCTTGT' *.fastq > count/B12400_Rm0.txt
agrep -0 -c 'AAGCGCCAAAGGTAAGT' *.fastq > count/B12401_Rm0.txt
agrep -0 -c 'AATACCCTCCTAGAGCC' *.fastq > count/B12402_Rm0.txt
agrep -0 -c 'AACAAAAACGAGGTCGG' *.fastq > count/B12403_Rm0.txt
agrep -0 -c 'GATCCAACCGTATCCCG' *.fastq > count/B12404_Rm0.txt
agrep -0 -c 'AGTGGGTGCGAGACCTT' *.fastq > count/B12405_Rm0.txt
agrep -0 -c 'GTCGTTCCTGGTCAAGA' *.fastq > count/B12406_Rm0.txt
agrep -0 -c 'TTCGTCACCCGTAACAC' *.fastq > count/B12411_Rm0.txt
agrep -0 -c 'GTACGGTGCTTCGTAAG' *.fastq > count/B12412_Rm0.txt
agrep -0 -c 'GGCAAAGAAGCCGATTG' *.fastq > count/B12413_Rm0.txt
agrep -0 -c 'AGGACATGAAATCCGCG' *.fastq > count/B12414_Rm0.txt
agrep -0 -c 'TACGAAGTCCCAGTGAC' *.fastq > count/B12417_Rm0.txt
agrep -0 -c 'TTGGGTGCAGTATCCTA' *.fastq > count/B12418_Rm0.txt
agrep -0 -c 'ACTCTTGCCATAACCGA' *.fastq > count/B12419_Rm0.txt
agrep -0 -c 'GGCTTAGCCAACTGAGC' *.fastq > count/B12420_Rm0.txt
agrep -0 -c 'TTGTCGCGTATTGCGGT' *.fastq > count/B12422_Rm0.txt
agrep -0 -c 'CCTTTACTTTGGCCTTA' *.fastq > count/B12423_Rm0.txt
agrep -0 -c 'GAGCGTAATGAGTTTAG' *.fastq > count/B12424_Rm0.txt
agrep -0 -c 'CAGATGGGAGCTAATAC' *.fastq > count/B12425_Rm0.txt
agrep -0 -c 'TCACTCTTCTTAAGGAG' *.fastq > count/B12426_Rm0.txt
agrep -0 -c 'ATGCTGGTAAGCGAGTA' *.fastq > count/B12428_Rm0.txt
agrep -0 -c 'TGCTGGCCTTAGAGGTG' *.fastq > count/B12429_Rm0.txt
agrep -0 -c 'GCCTGAGTTCTGCGAGT' *.fastq > count/B12430_Rm0.txt
agrep -0 -c 'GATCATCACCGACCATC' *.fastq > count/B12431_Rm0.txt
agrep -0 -c 'TAATTCTCAACCCCCTG' *.fastq > count/B12432_Rm0.txt
agrep -0 -c 'CGCCTACTTACCGTTAC' *.fastq > count/B12433_Rm0.txt
agrep -0 -c 'AGTCAGCAGTCGATCGA' *.fastq > count/B12434_Rm0.txt
agrep -0 -c 'CTCATACGTCCTCGTGG' *.fastq > count/B12435_Rm0.txt
agrep -0 -c 'GCACAATGGCGCACACT' *.fastq > count/B12436_Rm0.txt
agrep -0 -c 'AGGATTCCGTAACGAAC' *.fastq > count/B12437_Rm0.txt
agrep -0 -c 'AACAACGCATGCCTTCG' *.fastq > count/B12438_Rm0.txt
agrep -0 -c 'TTTGGACACGATCAACA' *.fastq > count/B12440_Rm0.txt
agrep -0 -c 'GTCCGCTTATACTAAGC' *.fastq > count/B12441_Rm0.txt
agrep -0 -c 'GCGTCCACTTCGGATCT' *.fastq > count/B12442_Rm0.txt
agrep -0 -c 'TAACGGACAATGACCAC' *.fastq > count/B12443_Rm0.txt
agrep -0 -c 'CAGTTGACGGGCTTACA' *.fastq > count/B12444_Rm0.txt
agrep -0 -c 'TTGGGGTGTTCACAGTA' *.fastq > count/B12445_Rm0.txt
agrep -0 -c 'TGGTTAACTGGTGGAAT' *.fastq > count/B12446_Rm0.txt
agrep -0 -c 'CCGTAGAGCACTAAGAC' *.fastq > count/B12447_Rm0.txt
agrep -0 -c 'GTGTAAACTTGTTCCTG' *.fastq > count/B12449_Rm0.txt
agrep -0 -c 'TTAAGGTGAGCCAGATA' *.fastq > count/B12450_Rm0.txt
agrep -0 -c 'GTCCGGAGCTTATGCAT' *.fastq > count/B12451_Rm0.txt
agrep -0 -c 'GTTGGCGTTCCATTTGA' *.fastq > count/B12452_Rm0.txt
agrep -0 -c 'TTTTTTCCGTCGTTGCG' *.fastq > count/B12453_Rm0.txt
agrep -0 -c 'TCCAGGTACCGAGCCTT' *.fastq > count/B12455_Rm0.txt
agrep -0 -c 'AGTGCTAGATACGCATT' *.fastq > count/B12456_Rm0.txt
agrep -0 -c 'GTAGCAGGCATTTGTGG' *.fastq > count/B12457_Rm0.txt
agrep -0 -c 'CGGTCGTATCGAAAAGG' *.fastq > count/B12458_Rm0.txt
agrep -0 -c 'CTCCTGGTGGACTAGAT' *.fastq > count/B12459_Rm0.txt
agrep -0 -c 'ATACGCGCGTAAGTGTT' *.fastq > count/B12461_Rm0.txt
agrep -0 -c 'GTGGTATGGCGCTTAGT' *.fastq > count/B12462_Rm0.txt
agrep -0 -c 'GATCGCGCAATTTAGAA' *.fastq > count/B12464_Rm0.txt
agrep -0 -c 'CTAGGCCACTTTCATAG' *.fastq > count/B12465_Rm0.txt
agrep -0 -c 'TTTGTTTAGCCGCGAAC' *.fastq > count/B12467_Rm0.txt
agrep -0 -c 'AGCGACTATGTCCGAAT' *.fastq > count/B12468_Rm0.txt
agrep -0 -c 'TTCCAGTGTCAGAGGGC' *.fastq > count/B12469_Rm0.txt
agrep -0 -c 'CTAGGCTATAAACTCGC' *.fastq > count/B12470_Rm0.txt
agrep -0 -c 'GTCCCAGCTGATAAGGC' *.fastq > count/B12472_Rm0.txt
agrep -0 -c 'AACGATGGTTAGCAACT' *.fastq > count/B12473_Rm0.txt
agrep -0 -c 'TTAGGAACTCGTCTGTT' *.fastq > count/B12474_Rm0.txt
agrep -0 -c 'CAGCGGCATACACCAGT' *.fastq > count/B12475_Rm0.txt
agrep -0 -c 'TTCTCCACAAGCATACG' *.fastq > count/B12476_Rm0.txt
agrep -0 -c 'TGACTTCCTAGTACGCG' *.fastq > count/B12477_Rm0.txt
agrep -0 -c 'GCGAAAATTGTAGTACC' *.fastq > count/B12478_Rm0.txt
agrep -0 -c 'CTGCTTACATGTTCTAG' *.fastq > count/B12479_Rm0.txt
agrep -0 -c 'CCGTTTCTGGTTGGAGT' *.fastq > count/B12480_Rm0.txt
agrep -0 -c 'GAATACCTCCGAGTGAG' *.fastq > count/B12481_Rm0.txt
agrep -0 -c 'GAGTTCGGTACTCACTC' *.fastq > count/B12482_Rm0.txt
agrep -0 -c 'CGTAAGGCTTCACGCGT' *.fastq > count/B12483_Rm0.txt
agrep -0 -c 'GTAAGCCTCGAAGTACA' *.fastq > count/B12485_Rm0.txt
agrep -0 -c 'ATGGAACATGGTGACAA' *.fastq > count/B12486_Rm0.txt
agrep -0 -c 'CAACTCGTGTCGACCAT' *.fastq > count/B12487_Rm0.txt
agrep -0 -c 'AGATTGCCGAAGGGGTC' *.fastq > count/B12488_Rm0.txt
agrep -0 -c 'AACGGCCAGTACTTTAT' *.fastq > count/B12489_Rm0.txt
agrep -0 -c 'AGGTCAGGCTTAGCTGC' *.fastq > count/B12490_Rm0.txt
agrep -0 -c 'TACATGATTGTACAGCG' *.fastq > count/B12492_Rm0.txt
agrep -0 -c 'GCCAAGCCCGTAATCGT' *.fastq > count/B12493_Rm0.txt
agrep -0 -c 'TGCGGCAAGCGTAACTC' *.fastq > count/B12495_Rm0.txt
agrep -0 -c 'GATCCTGTTTAAGCCGA' *.fastq > count/B12496_Rm0.txt
agrep -0 -c 'CTAGCGGGATAATTAGT' *.fastq > count/B12497_Rm0.txt
agrep -0 -c 'GACTGTTGAATCGAGTA' *.fastq > count/B12500_Rm0.txt
agrep -0 -c 'TACGTTTGTGGGTGTAG' *.fastq > count/B12501_Rm0.txt
agrep -0 -c 'CGCGCAGTATCAAGGAC' *.fastq > count/B12504_Rm0.txt
agrep -0 -c 'CGTGTTAAGGTGACTCG' *.fastq > count/B12505_Rm0.txt
agrep -0 -c 'AGGGTTATGTTAGGCCG' *.fastq > count/B12506_Rm0.txt
agrep -0 -c 'GAGAAGAACCGTAGATC' *.fastq > count/B12507_Rm0.txt
agrep -0 -c 'ACAAGGAATCCGTCGAG' *.fastq > count/B12508_Rm0.txt
agrep -0 -c 'TGACAGAGGCCAGCACT' *.fastq > count/B12510_Rm0.txt
agrep -0 -c 'TGCGAGACCCCGTTATT' *.fastq > count/B12512_Rm0.txt
agrep -0 -c 'CTGGCCTTCACCGTCAT' *.fastq > count/B12513_Rm0.txt
agrep -0 -c 'CGACAACGGCTGTAGAT' *.fastq > count/B12514_Rm0.txt
agrep -0 -c 'ACCGCAACAAGGCTGCA' *.fastq > count/B12515_Rm0.txt
agrep -0 -c 'TATCCACTGCTACCCGT' *.fastq > count/B12516_Rm0.txt
agrep -0 -c 'TGGATCTTTCCATCCGA' *.fastq > count/B12517_Rm0.txt
agrep -0 -c 'TACGTGTTTTCGCCATA' *.fastq > count/B12518_Rm0.txt
agrep -0 -c 'ACTGAGCTGAATGACGA' *.fastq > count/B12519_Rm0.txt
agrep -0 -c 'GGTACTCTCAGGATTAC' *.fastq > count/B12520_Rm0.txt
agrep -0 -c 'GCCCCTTCTACGTCCTT' *.fastq > count/B12522_Rm0.txt
agrep -0 -c 'GCTTACGGCTGGTACAA' *.fastq > count/B12523_Rm0.txt
agrep -0 -c 'AGATCTGAATGCGAGCA' *.fastq > count/B12524_Rm0.txt
agrep -0 -c 'GATCTGGGGTAAAATGC' *.fastq > count/B12525_Rm0.txt
agrep -0 -c 'ATCTTTGAAGGGCCGTG' *.fastq > count/B12526_Rm0.txt
agrep -0 -c 'GGAAACATAGGAGCATC' *.fastq > count/B12528_Rm0.txt
agrep -0 -c 'CCTGGTAAACGGGGAGT' *.fastq > count/B12529_Rm0.txt
agrep -0 -c 'GGGGTACGTCCCATTAC' *.fastq > count/B12530_Rm0.txt
agrep -0 -c 'AGACCCGAGTGTACTCG' *.fastq > count/B12531_Rm0.txt
agrep -0 -c 'TAGAGTGAGCCTTACTT' *.fastq > count/B12532_Rm0.txt
agrep -0 -c 'ACGGACATGCGTATTTG' *.fastq > count/B12533_Rm0.txt
agrep -0 -c 'ATCCCGGTAATAACTGT' *.fastq > count/B12535_Rm0.txt
agrep -0 -c 'AGATTACGATCCTGCGT' *.fastq > count/B12537_Rm0.txt
agrep -0 -c 'GACGATAAGGTGTGCCG' *.fastq > count/B12538_Rm0.txt
agrep -0 -c 'CAAGAGTAACTTCCCTA' *.fastq > count/B12539_Rm0.txt
agrep -0 -c 'CGACATGGTATCGTTAC' *.fastq > count/B12540_Rm0.txt
agrep -0 -c 'TGCTGATTCGCATTCTA' *.fastq > count/B12541_Rm0.txt
agrep -0 -c 'CACGTTAAGGAACCTTA' *.fastq > count/B12543_Rm0.txt
agrep -0 -c 'ACGGTTTCACAGCATCC' *.fastq > count/B12544_Rm0.txt
agrep -0 -c 'ATGTGCATAATGCCGCT' *.fastq > count/B12545_Rm0.txt
agrep -0 -c 'CCGCTAGTTGGTACAAT' *.fastq > count/B12546_Rm0.txt
agrep -0 -c 'GCCTGCTAGTTAGGGAT' *.fastq > count/B12547_Rm0.txt
agrep -0 -c 'TTTGTTATTGCGGCTAC' *.fastq > count/B12548_Rm0.txt
agrep -0 -c 'CTAGCGCAATGCAACCC' *.fastq > count/B12549_Rm0.txt
agrep -0 -c 'ATGACTCACCTACCATA' *.fastq > count/B12550_Rm0.txt
agrep -0 -c 'GTCCGTTAGCCGTTATT' *.fastq > count/B12551_Rm0.txt
agrep -0 -c 'AGACCCCCAGTTAACCT' *.fastq > count/B12552_Rm0.txt
agrep -0 -c 'GAGTATGAACGGGGTGG' *.fastq > count/B12553_Rm0.txt
agrep -0 -c 'TGGTTCTCAGCAGAATG' *.fastq > count/B12554_Rm0.txt
agrep -0 -c 'GCTAGCAATAATCGTCA' *.fastq > count/B12555_Rm0.txt
agrep -0 -c 'TCCCGTAGCAGACTCCA' *.fastq > count/B12557_Rm0.txt
agrep -0 -c 'AAGTCGTACGAGACGTG' *.fastq > count/B12558_Rm0.txt
agrep -0 -c 'AGTTAAGTAGGTCGAGC' *.fastq > count/B12559_Rm0.txt
agrep -0 -c 'CGGTTTGAGAGAACACG' *.fastq > count/B12560_Rm0.txt
agrep -0 -c 'CAATCATTCGTAGACCT' *.fastq > count/B12561_Rm0.txt
agrep -0 -c 'AAACTTCAAGGACTCGC' *.fastq > count/B12563_Rm0.txt
agrep -0 -c 'CACGACACTGTCTGGTG' *.fastq > count/B12564_Rm0.txt
agrep -0 -c 'GCGTTCAAGCGCAAACG' *.fastq > count/B12566_Rm0.txt
agrep -0 -c 'TACGTACGGACTACCTT' *.fastq > count/B12567_Rm0.txt
agrep -0 -c 'TTGACGCGGTAGAGGCT' *.fastq > count/B12568_Rm0.txt
agrep -0 -c 'CAAGAACGTAAGTCGCC' *.fastq > count/B12571_Rm0.txt
agrep -0 -c 'TAACCGTTCATGCGATA' *.fastq > count/B12572_Rm0.txt
agrep -0 -c 'TTGTACTAAGACCACTG' *.fastq > count/B12573_Rm0.txt
agrep -0 -c 'CAATCGGGCGTAGCATC' *.fastq > count/B12574_Rm0.txt
agrep -0 -c 'ATCGATTGACATGCCGC' *.fastq > count/B12578_Rm0.txt
agrep -0 -c 'ACGATTAAGCCTTTTGC' *.fastq > count/B12579_Rm0.txt
agrep -0 -c 'GCTTTGAAGCGAGCGCT' *.fastq > count/B12580_Rm0.txt
agrep -0 -c 'TGGGAGGAAGCCTGATA' *.fastq > count/B12581_Rm0.txt
agrep -0 -c 'GCGTACTGTCTTGTTCA' *.fastq > count/B12582_Rm0.txt
agrep -0 -c 'ATGTGGTTCCACTACTT' *.fastq > count/B12583_Rm0.txt
agrep -0 -c 'CACGGGACCTTTTGCAA' *.fastq > count/B12584_Rm0.txt
agrep -0 -c 'GACCTACCTTCGGGACA' *.fastq > count/B12585_Rm0.txt
agrep -0 -c 'ACTCAACTTTTGTGACG' *.fastq > count/B12586_Rm0.txt
agrep -0 -c 'AGAATCTTGCCGGAAGG' *.fastq > count/B12587_Rm0.txt
agrep -0 -c 'GTGTGTTTCTCGCATCT' *.fastq > count/B12588_Rm0.txt
agrep -0 -c 'AACACGTTTCCTAACAC' *.fastq > count/B12589_Rm0.txt
agrep -0 -c 'CTTCAACGTACAGCATG' *.fastq > count/B12590_Rm0.txt
agrep -0 -c 'ACACCTCGAGTCTTCGC' *.fastq > count/B12591_Rm0.txt
agrep -0 -c 'GCGTCAATGTCTCAAAT' *.fastq > count/B12592_Rm0.txt
agrep -0 -c 'CGAAGACTTGTCGGCTT' *.fastq > count/B12593_Rm0.txt
agrep -0 -c 'CTGTGCCACGAATGTGC' *.fastq > count/B12594_Rm0.txt
agrep -0 -c 'CTTAGAGGCCCGTCTAA' *.fastq > count/B12595_Rm0.txt
agrep -0 -c 'TGCTTATACCGTGCTGG' *.fastq > count/B12596_Rm0.txt
agrep -0 -c 'CCAAGGAAATTCTTGTG' *.fastq > count/B12597_Rm0.txt
agrep -0 -c 'TGATAGTGGTCAACTAC' *.fastq > count/B12599_Rm0.txt
agrep -0 -c 'GCTTCAGATTGAGCTGT' *.fastq > count/B12600_Rm0.txt
agrep -0 -c 'CTACCGCTGTGTACGTA' *.fastq > count/B12601_Rm0.txt
agrep -0 -c 'GAGAGTTTGACGCGTGC' *.fastq > count/B12602_Rm0.txt
agrep -0 -c 'TCGATCATTCTCCGTTG' *.fastq > count/B12604_Rm0.txt
agrep -0 -c 'GTTCGTAAAGACATCCT' *.fastq > count/B12606_Rm0.txt
agrep -0 -c 'ACGGTTAAGTAGGTGAC' *.fastq > count/B12607_Rm0.txt
agrep -0 -c 'TGACGGGATAAGGCTGT' *.fastq > count/B12609_Rm0.txt
agrep -0 -c 'GGATTTTTCAGCATCGA' *.fastq > count/B12610_Rm0.txt
agrep -0 -c 'TGCCTGACCTACTGCAA' *.fastq > count/B12611_Rm0.txt
agrep -0 -c 'GTCGGGTAACGACGAGT' *.fastq > count/B12613_Rm0.txt
agrep -0 -c 'GGTATTCAACAGTGTAG' *.fastq > count/B12614_Rm0.txt
agrep -0 -c 'AAGTGCGTAACCTCGGT' *.fastq > count/B12615_Rm0.txt
agrep -0 -c 'CCGACATGTGCATGAGG' *.fastq > count/B12616_Rm0.txt
agrep -0 -c 'GGGTGTTACGTGGGAGA' *.fastq > count/B12617_Rm0.txt
agrep -0 -c 'CCCTAGATATAGGCACA' *.fastq > count/B12618_Rm0.txt
agrep -0 -c 'AATTGTCTCCGAGTGAA' *.fastq > count/B12620_Rm0.txt
agrep -0 -c 'TAGCCTTGGAATGATAC' *.fastq > count/B12621_Rm0.txt
agrep -0 -c 'CAGTATGCATACGAACT' *.fastq > count/B12622_Rm0.txt
agrep -0 -c 'CAGAACAAGAAGGTATC' *.fastq > count/B12623_Rm0.txt
agrep -0 -c 'TGAGAATCGCCCTGATT' *.fastq > count/B12624_Rm0.txt
agrep -0 -c 'ACTCAGAAAGCGCAAGA' *.fastq > count/B12625_Rm0.txt
agrep -0 -c 'TTGATGAGTTCACGAGA' *.fastq > count/B12626_Rm0.txt
agrep -0 -c 'GGACATCCAAGTTTGTT' *.fastq > count/B12627_Rm0.txt
agrep -0 -c 'TAATGCTACGATACGAC' *.fastq > count/B12630_Rm0.txt
agrep -0 -c 'TTACTCGACCGAGAAGG' *.fastq > count/B12631_Rm0.txt
agrep -0 -c 'CGATACTTGAAAGTGCA' *.fastq > count/B12632_Rm0.txt
agrep -0 -c 'TCGAACTCGGTTCGAGG' *.fastq > count/B12633_Rm0.txt
agrep -0 -c 'CTACGAAGTTTGGCTCC' *.fastq > count/B12634_Rm0.txt
agrep -0 -c 'AGACGTTAGCTAAGTGC' *.fastq > count/B12636_Rm0.txt
agrep -0 -c 'CCGGAGCCAAGCTAGAA' *.fastq > count/B12637_Rm0.txt
agrep -0 -c 'AGCGCTATTCTATGGAT' *.fastq > count/B12638_Rm0.txt
agrep -0 -c 'TGTTTTAGCGTTCACTG' *.fastq > count/B12639_Rm0.txt
agrep -0 -c 'TGTTAGTAGCACTTGAC' *.fastq > count/B12640_Rm0.txt
agrep -0 -c 'ACCGCAGACATAGTGTA' *.fastq > count/B12641_Rm0.txt
agrep -0 -c 'ACTCCACTCTCGTCACT' *.fastq > count/B12642_Rm0.txt
agrep -0 -c 'ACTCGAGTAAAACTTCC' *.fastq > count/B12643_Rm0.txt
agrep -0 -c 'CAGCGTTGGATTCCGCA' *.fastq > count/B12644_Rm0.txt
agrep -0 -c 'CGAAGAGCTCAACAAAT' *.fastq > count/B12645_Rm0.txt
agrep -0 -c 'GGCTGCAACCGCTAAGA' *.fastq > count/B12646_Rm0.txt
agrep -0 -c 'TGAGCGATCCTACTGGC' *.fastq > count/B12648_Rm0.txt
agrep -0 -c 'CCTTGGAGGTGTAAGAA' *.fastq > count/B12650_Rm0.txt
agrep -0 -c 'CGGTTTGGATTGTAATG' *.fastq > count/B12651_Rm0.txt
agrep -0 -c 'TGTACATGCGCCGGACA' *.fastq > count/B12652_Rm0.txt
agrep -0 -c 'TTGCACAGGGTCATGTT' *.fastq > count/B12653_Rm0.txt
agrep -0 -c 'AGCTCGAATTTACGCCA' *.fastq > count/B12654_Rm0.txt
agrep -0 -c 'ATGCCGTGTGACTCCCT' *.fastq > count/B12656_Rm0.txt
agrep -0 -c 'GAAATGCTCCCGACCGA' *.fastq > count/B12658_Rm0.txt
agrep -0 -c 'AGTGTCGATACATCTCA' *.fastq > count/B12659_Rm0.txt
agrep -0 -c 'ATTAGCGGGTCCCGTAC' *.fastq > count/B12660_Rm0.txt
agrep -0 -c 'CGATCGACTATACTGTA' *.fastq > count/B12661_Rm0.txt
agrep -0 -c 'TGCGCGATCCTGGAAAC' *.fastq > count/B12663_Rm0.txt
agrep -0 -c 'GTGAGGAGCTGGCTATT' *.fastq > count/B12664_Rm0.txt
agrep -0 -c 'TCTCACACACCTCGACC' *.fastq > count/B12665_Rm0.txt
agrep -0 -c 'GGGATATTCTATGGCCA' *.fastq > count/B12666_Rm0.txt
agrep -0 -c 'TAGTCCTACTTAGGCGT' *.fastq > count/B12667_Rm0.txt
agrep -0 -c 'TACAATGCCCACTCATA' *.fastq > count/B12668_Rm0.txt
agrep -0 -c 'ATCGAGGTGAATATGGC' *.fastq > count/B12669_Rm0.txt
agrep -0 -c 'CGCGTAGCACATACCTG' *.fastq > count/B12670_Rm0.txt
agrep -0 -c 'GTGTCTGTAGATCTATG' *.fastq > count/B12671_Rm0.txt
agrep -0 -c 'TTTACACAGCGTCGAAC' *.fastq > count/B12672_Rm0.txt
agrep -0 -c 'GACTCAGGTGATGCACA' *.fastq > count/B12673_Rm0.txt
agrep -0 -c 'CGTGTGCCATCTGACCT' *.fastq > count/B12674_Rm0.txt
agrep -0 -c 'GGTTAGAGGTATAGTCA' *.fastq > count/B12675_Rm0.txt
agrep -0 -c 'CGCGTTCTGCTTACCAA' *.fastq > count/B12677_Rm0.txt
agrep -0 -c 'CACTTGTACCGAACCGG' *.fastq > count/B12678_Rm0.txt
agrep -0 -c 'GACGCGGTACAAGCTGT' *.fastq > count/B12679_Rm0.txt
agrep -0 -c 'ATAACCTTCCACATTCC' *.fastq > count/B12680_Rm0.txt
agrep -0 -c 'CAAACGGGTAAACGACC' *.fastq > count/B12681_Rm0.txt
agrep -0 -c 'CTTAAGTGTCATGTGTG' *.fastq > count/B12682_Rm0.txt
agrep -0 -c 'TTGTATGCAGCGGGTGA' *.fastq > count/B12683_Rm0.txt
agrep -0 -c 'GTCCTATCTACCCGTCT' *.fastq > count/B12684_Rm0.txt
agrep -0 -c 'AAACGCTTCCGAAAGAT' *.fastq > count/B12685_Rm0.txt
agrep -0 -c 'CAATGAATCGTCGTCTA' *.fastq > count/B12686_Rm0.txt
agrep -0 -c 'AGTTAGCCCAATTCGCG' *.fastq > count/B12687_Rm0.txt
agrep -0 -c 'CATAGTGTTACCGAAGG' *.fastq > count/B12689_Rm0.txt
agrep -0 -c 'GGATTTTAACGCAGGTT' *.fastq > count/B12690_Rm0.txt
agrep -0 -c 'TGATGCAAATCGCCATA' *.fastq > count/B12691_Rm0.txt
agrep -0 -c 'ATGGTTACGAGTCGAAG' *.fastq > count/B12692_Rm0.txt
agrep -0 -c 'AAGACCATCGACCGTAA' *.fastq > count/B12694_Rm0.txt
agrep -0 -c 'GAACGTGAGTGGTAGAT' *.fastq > count/B12695_Rm0.txt
agrep -0 -c 'GGACGACCCTGTATCAC' *.fastq > count/B12696_Rm0.txt
agrep -0 -c 'GACAGGGAATGGACACT' *.fastq > count/B12697_Rm0.txt
agrep -0 -c 'ACGATGGATCAATGACA' *.fastq > count/B12698_Rm0.txt
agrep -0 -c 'TGGAGCACACTGGAGGT' *.fastq > count/B12699_Rm0.txt
agrep -0 -c 'CGAAGATCTCTACAACC' *.fastq > count/B12700_Rm0.txt
agrep -0 -c 'GACTGCCGATGCTCATC' *.fastq > count/B12701_Rm0.txt
agrep -0 -c 'GAGGATTACCCCCGAGA' *.fastq > count/B12702_Rm0.txt
agrep -0 -c 'CGATCTGCCAGTCGACA' *.fastq > count/B12703_Rm0.txt
agrep -0 -c 'TTCAGCAATTAGTGCGT' *.fastq > count/B12705_Rm0.txt
agrep -0 -c 'CGCATAAGCTGACGAGC' *.fastq > count/B12706_Rm0.txt
agrep -0 -c 'CTTATCTAGGTTGGGAG' *.fastq > count/B12707_Rm0.txt
agrep -0 -c 'CAGCTGAGCAAGAGCAA' *.fastq > count/B12708_Rm0.txt
agrep -0 -c 'AGGCACCTTAGCGTTCC' *.fastq > count/B12709_Rm0.txt
agrep -0 -c 'GGTTGGCAAGTATACTA' *.fastq > count/B12710_Rm0.txt
agrep -0 -c 'CGGTGGTTACCAGAAGC' *.fastq > count/B12711_Rm0.txt
agrep -0 -c 'CTAATATCTGCGTCGTA' *.fastq > count/B12712_Rm0.txt
agrep -0 -c 'TTCCACCGGCAGTTTCG' *.fastq > count/B12713_Rm0.txt
agrep -0 -c 'TGACGATCGTTGTAGCT' *.fastq > count/B12715_Rm0.txt
agrep -0 -c 'AGTACAAGACGAATCTC' *.fastq > count/B12716_Rm0.txt
agrep -0 -c 'GCGAAGATAGGCGTCGT' *.fastq > count/B12717_Rm0.txt
agrep -0 -c 'GCTGATGGTAATGCCGC' *.fastq > count/B12718_Rm0.txt
agrep -0 -c 'GTCACCCGCAACTTGAA' *.fastq > count/B12720_Rm0.txt
agrep -0 -c 'GGATTTGAGCGGCGCTT' *.fastq > count/B12722_Rm0.txt
agrep -0 -c 'CATCAGGTTATCGGACT' *.fastq > count/B12724_Rm0.txt
agrep -0 -c 'GAGCCGGGTATTTTACC' *.fastq > count/B12725_Rm0.txt
agrep -0 -c 'TTGCGGATCGACCTCTC' *.fastq > count/B12727_Rm0.txt
agrep -0 -c 'GTGACGTCCTAACCTGC' *.fastq > count/B12728_Rm0.txt
agrep -0 -c 'ACAAGGCAAATAAGCGG' *.fastq > count/B12729_Rm0.txt
agrep -0 -c 'GGAAGCGAAGAGCCATC' *.fastq > count/B12730_Rm0.txt
agrep -0 -c 'GAGCCGTACCTACGTCT' *.fastq > count/B12731_Rm0.txt
agrep -0 -c 'CCATACAAGTGCGTAAC' *.fastq > count/B12732_Rm0.txt
agrep -0 -c 'GTTCGGTCACTAATGGT' *.fastq > count/B12733_Rm0.txt
agrep -0 -c 'TAGCCACCAGTTAATTG' *.fastq > count/B12734_Rm0.txt
agrep -0 -c 'ATGTTGGAGGCTTGATA' *.fastq > count/B12735_Rm0.txt
agrep -0 -c 'TAGACCAAAGATCTGGT' *.fastq > count/B12736_Rm0.txt
agrep -0 -c 'TCGGCCTCTAATTAGAG' *.fastq > count/B12738_Rm0.txt
agrep -0 -c 'TTATCGGCTCGTGTCGG' *.fastq > count/B12739_Rm0.txt
agrep -0 -c 'AACATACAGACGGATGG' *.fastq > count/B12740_Rm0.txt
agrep -0 -c 'ACGCACAAGGCATCAAC' *.fastq > count/B12742_Rm0.txt
agrep -0 -c 'CCCACCAGGTCTAAACC' *.fastq > count/B12743_Rm0.txt
agrep -0 -c 'TTGGTCGTTACTCTACA' *.fastq > count/B12744_Rm0.txt
agrep -0 -c 'AATATTAACACCAGGGC' *.fastq > count/B12745_Rm0.txt
agrep -0 -c 'TCTTGGCTGCATCGGGT' *.fastq > count/B12746_Rm0.txt
agrep -0 -c 'TTGAGTTCGGGATATTG' *.fastq > count/B12747_Rm0.txt
agrep -0 -c 'CAAATCTGGCTGATCTC' *.fastq > count/B12748_Rm0.txt
agrep -0 -c 'TGGACATTGCTCAGACG' *.fastq > count/B12749_Rm0.txt
agrep -0 -c 'GCCTGAATACGGGTATG' *.fastq > count/B12751_Rm0.txt
agrep -0 -c 'AGTTGGACAAGGCCGTT' *.fastq > count/B12752_Rm0.txt
agrep -0 -c 'GGACTGACCACATACAA' *.fastq > count/B12753_Rm0.txt
agrep -0 -c 'TCGTACGCAACAGAAAC' *.fastq > count/B12754_Rm0.txt
agrep -0 -c 'GGTACATAGTCTGTTGA' *.fastq > count/B12755_Rm0.txt
agrep -0 -c 'ATTAGCCGGTTTCGAAT' *.fastq > count/B12757_Rm0.txt
agrep -0 -c 'CGGAAGATGCACCTTAC' *.fastq > count/B12758_Rm0.txt
agrep -0 -c 'CTCAACGTCGTTTCCAT' *.fastq > count/B12759_Rm0.txt
agrep -0 -c 'TTGGACACTCAACGCAG' *.fastq > count/B12760_Rm0.txt
agrep -0 -c 'TTCCGCGTCGGAACGTA' *.fastq > count/B12761_Rm0.txt
agrep -0 -c 'GGTGGAATCAGTATGTA' *.fastq > count/B12762_Rm0.txt
agrep -0 -c 'AAAGTGGGGCTTTGGGT' *.fastq > count/B12763_Rm0.txt
agrep -0 -c 'AGACTCTCGTGGCTTAT' *.fastq > count/B12764_Rm0.txt
agrep -0 -c 'TCCATCCGGTCTTTGGC' *.fastq > count/B12765_Rm0.txt
agrep -0 -c 'GAACACTAGCTGCGAGC' *.fastq > count/B12766_Rm0.txt
agrep -0 -c 'TTTACTTGACGGAGTGG' *.fastq > count/B12767_Rm0.txt
agrep -0 -c 'AAAGTGCAGCCGCACCT' *.fastq > count/B12769_Rm0.txt
agrep -0 -c 'GCTAAACTTCCCCGAGT' *.fastq > count/B12770_Rm0.txt
agrep -0 -c 'GGCAAGCCGTGATAGCT' *.fastq > count/B12771_Rm0.txt
agrep -0 -c 'TGTCCTTGGGAGGAACC' *.fastq > count/B12772_Rm0.txt
agrep -0 -c 'CTGAAGTAAGCTGTCTT' *.fastq > count/B12773_Rm0.txt
agrep -0 -c 'TGCCCTCCGGGTTTACT' *.fastq > count/B12774_Rm0.txt
agrep -0 -c 'GTCTCGTTGGACGTATT' *.fastq > count/B12775_Rm0.txt
agrep -0 -c 'TGTAACGACATTCGGCG' *.fastq > count/B12776_Rm0.txt
agrep -0 -c 'AATGTCGATCGCCGACT' *.fastq > count/B12777_Rm0.txt
agrep -0 -c 'AGGCTGTCAAACGCGTG' *.fastq > count/B12778_Rm0.txt
agrep -0 -c 'GAGATAGAGTTCGCTCA' *.fastq > count/B12779_Rm0.txt
agrep -0 -c 'GCGAGCTTTTGTGACCT' *.fastq > count/B12780_Rm0.txt
agrep -0 -c 'ATTGCATGCAACCAGAG' *.fastq > count/B12781_Rm0.txt
agrep -0 -c 'TGGCTGAATCATTAACC' *.fastq > count/B12782_Rm0.txt
agrep -0 -c 'GATCTTCCAATAGCAGT' *.fastq > count/B12784_Rm0.txt
agrep -0 -c 'TAATACCAGGAAGGCTT' *.fastq > count/B12785_Rm0.txt
agrep -0 -c 'CAAATCAACAGGCGCGA' *.fastq > count/B12787_Rm0.txt
agrep -0 -c 'TACGTGTACATCGTCCC' *.fastq > count/B12788_Rm0.txt
agrep -0 -c 'ACTTTCGTCCGACTGCC' *.fastq > count/B12789_Rm0.txt
agrep -0 -c 'TAGCGGAGGTTTCGGTG' *.fastq > count/B12790_Rm0.txt
agrep -0 -c 'TGCGAGGTGTGAACCGA' *.fastq > count/B12791_Rm0.txt
agrep -0 -c 'CCGCTGGGTACTTGTCA' *.fastq > count/B12792_Rm0.txt
agrep -0 -c 'GGAGCGATCCTCATCAA' *.fastq > count/B12793_Rm0.txt
agrep -0 -c 'TCGTGAGAAGCCCAATG' *.fastq > count/B12794_Rm0.txt
agrep -0 -c 'CTGGTGACGGAGTAATG' *.fastq > count/B12795_Rm0.txt
agrep -0 -c 'GATCTCTACGTTGCTGT' *.fastq > count/B12796_Rm0.txt
agrep -0 -c 'GTAAGATCCGACAGAAC' *.fastq > count/B12797_Rm0.txt
agrep -0 -c 'TACGGTCTACTATGCTT' *.fastq > count/B12798_Rm0.txt
agrep -0 -c 'ATGCATCCTGCAGTCGG' *.fastq > count/B12799_Rm0.txt
agrep -0 -c 'GAACTGCTAAGGCTGAA' *.fastq > count/B12800_Rm0.txt
agrep -0 -c 'AAGGAGAGTCCTCAGTA' *.fastq > count/B12802_Rm0.txt
agrep -0 -c 'TTGAACCACACATGTGG' *.fastq > count/B12803_Rm0.txt
agrep -0 -c 'CCGGTATATATCGTCGA' *.fastq > count/B12804_Rm0.txt
agrep -0 -c 'AACGGTTCAAAATCTCG' *.fastq > count/B12805_Rm0.txt
agrep -0 -c 'CGCGTCCATTTAGCACC' *.fastq > count/B12808_Rm0.txt
agrep -0 -c 'CCTGCAGTAGCATTGCT' *.fastq > count/B12809_Rm0.txt
agrep -0 -c 'ACTTACTAGTCATCCCC' *.fastq > count/B12810_Rm0.txt
agrep -0 -c 'CTTGAGATCCCCCGGAT' *.fastq > count/B12811_Rm0.txt
agrep -0 -c 'CCCTCCACAGTTAGGTT' *.fastq > count/B12814_Rm0.txt
agrep -0 -c 'TCCGACTCCCGACCTAT' *.fastq > count/B12815_Rm0.txt
agrep -0 -c 'GTAAGTGAAGACGGGGC' *.fastq > count/B12816_Rm0.txt
agrep -0 -c 'GAGTGGAGCGACTAGTA' *.fastq > count/B12819_Rm0.txt
agrep -0 -c 'AGATAACAGACCCTCGT' *.fastq > count/B12824_Rm0.txt
agrep -0 -c 'GATGGATCGCTCTGACA' *.fastq > count/B12825_Rm0.txt
agrep -0 -c 'TGTGCATGGGGATCTCG' *.fastq > count/B12826_Rm0.txt
agrep -0 -c 'TGGCTGTTGGTAAGCAA' *.fastq > count/B12827_Rm0.txt
agrep -0 -c 'CTGGACATACGGTCCTC' *.fastq > count/B12828_Rm0.txt
agrep -0 -c 'ATCCGTACAAGCTACAC' *.fastq > count/B12829_Rm0.txt
agrep -0 -c 'TCTCTCCATTATTGCGC' *.fastq > count/B12830_Rm0.txt
agrep -0 -c 'CAGATAATAAGTCCGCA' *.fastq > count/B12831_Rm0.txt
agrep -0 -c 'GGTCGTGACTCTAGATC' *.fastq > count/B12832_Rm0.txt
agrep -0 -c 'ATCACTCAAGGAGTGCG' *.fastq > count/B12833_Rm0.txt
agrep -0 -c 'CTCCGAGGGCTCTTTGA' *.fastq > count/B12834_Rm0.txt
agrep -0 -c 'TCGATAGCAGCCACTGG' *.fastq > count/B12836_Rm0.txt
agrep -0 -c 'CATGAGACTCGCGTTCG' *.fastq > count/B12837_Rm0.txt
agrep -0 -c 'CATTCGACACAGAGATC' *.fastq > count/B12838_Rm0.txt
agrep -0 -c 'GCCACGCTTCAGTCCTT' *.fastq > count/B12839_Rm0.txt
agrep -0 -c 'TCAAACCAGATCGGCCA' *.fastq > count/B12840_Rm0.txt
agrep -0 -c 'GTACCCTATAATGTCTC' *.fastq > count/B12841_Rm0.txt
agrep -0 -c 'ACTGAAGCTTGAGAGCC' *.fastq > count/B12842_Rm0.txt
agrep -0 -c 'CCATTCACTACGTCCAC' *.fastq > count/B12843_Rm0.txt
agrep -0 -c 'CATACGCCCGAGACCAA' *.fastq > count/B12844_Rm0.txt
agrep -0 -c 'CACAAGAACTAGAGGAA' *.fastq > count/B12845_Rm0.txt
agrep -0 -c 'CGAAGACTGAACAGTGT' *.fastq > count/B12846_Rm0.txt
agrep -0 -c 'TTACACAGCCAGCGTAG' *.fastq > count/B12847_Rm0.txt
agrep -0 -c 'ACAGCTGGGCTACAACG' *.fastq > count/B12848_Rm0.txt
agrep -0 -c 'ACCCTTTCCGGTTTGCG' *.fastq > count/B12849_Rm0.txt
agrep -0 -c 'ACTACTGCCGTCGACAA' *.fastq > count/B12850_Rm0.txt
agrep -0 -c 'ACGTTCTGTCCGCACAG' *.fastq > count/B12851_Rm0.txt
agrep -0 -c 'CGTCGAGTTCGAGTTGT' *.fastq > count/B12852_Rm0.txt
agrep -0 -c 'CGTGTCACGTATTGGAT' *.fastq > count/B12853_Rm0.txt
agrep -0 -c 'CCCTTATGTTGAGCAAC' *.fastq > count/B12855_Rm0.txt
agrep -0 -c 'CTGATAGCATACCTCGC' *.fastq > count/B12856_Rm0.txt
agrep -0 -c 'GAAGCCGTGCAATAAGG' *.fastq > count/B12857_Rm0.txt
agrep -0 -c 'GCAAACGCAACTCGTAG' *.fastq > count/B12858_Rm0.txt
agrep -0 -c 'GCCGTGGCGTTAGGAAT' *.fastq > count/B12859_Rm0.txt
agrep -0 -c 'TAGCTAACGAAAGTGTC' *.fastq > count/B12860_Rm0.txt
agrep -0 -c 'TAGGCGGAATCGACATC' *.fastq > count/B12861_Rm0.txt
agrep -0 -c 'TCAGTCGCACTCTCATG' *.fastq > count/B12862_Rm0.txt
agrep -0 -c 'TAAAGGGTTCACGATGA' *.fastq > count/B12863_Rm0.txt
agrep -0 -c 'TTTTGGGTTTGGCACTG' *.fastq > count/B12864_Rm0.txt
agrep -0 -c 'ATTCCTACCCACTATGA' *.fastq > count/B12866_Rm0.txt
agrep -0 -c 'GCTCGGAGCTTAGTTAA' *.fastq > count/B12867_Rm0.txt
agrep -0 -c 'CCAGTCTAGTCTCACTA' *.fastq > count/B12868_Rm0.txt
agrep -0 -c 'GCATTGACTTAGAGCCG' *.fastq > count/B12869_Rm0.txt
agrep -0 -c 'CAGACACCGTTTACGAC' *.fastq > count/B12870_Rm0.txt
agrep -0 -c 'TTTCGCGGAAGGAAGGT' *.fastq > count/B12872_Rm0.txt
agrep -0 -c 'CCCCAATTTGGGATGAT' *.fastq > count/B12873_Rm0.txt
agrep -0 -c 'CTTTCTAGATCGCCTCA' *.fastq > count/B12874_Rm0.txt
agrep -0 -c 'ACCTCATGGCCACAGTA' *.fastq > count/B12876_Rm0.txt
agrep -0 -c 'CACTATCGGCTAGGTCA' *.fastq > count/B12877_Rm0.txt
agrep -0 -c 'CGTATTGGCCTCGTCCA' *.fastq > count/B12878_Rm0.txt
agrep -0 -c 'CACTACGCTGACGAAAC' *.fastq > count/B12879_Rm0.txt
agrep -0 -c 'TGTTACGGTTCTTCCCT' *.fastq > count/B12880_Rm0.txt
agrep -0 -c 'TGAGTGCGGTGTCCATA' *.fastq > count/B12882_Rm0.txt
agrep -0 -c 'GCCCACACCCCTAGTAA' *.fastq > count/B12883_Rm0.txt
agrep -0 -c 'GAGTAACGGGAACGAGA' *.fastq > count/B12884_Rm0.txt
agrep -0 -c 'TAGATGGAGTGTCCGGT' *.fastq > count/B12885_Rm0.txt
agrep -0 -c 'GGAGAAAAACCTAGACT' *.fastq > count/B12886_Rm0.txt
agrep -0 -c 'CTGAATCACTGGCGGAG' *.fastq > count/B12887_Rm0.txt
agrep -0 -c 'GTGAAGCGTCATAACTT' *.fastq > count/B12888_Rm0.txt
agrep -0 -c 'TTTACGCCGAGTTAGGT' *.fastq > count/B12889_Rm0.txt
agrep -0 -c 'CAGCGGCATAGATGATC' *.fastq > count/B12890_Rm0.txt
agrep -0 -c 'CTACCGCCACTGTCATA' *.fastq > count/B12891_Rm0.txt
agrep -0 -c 'TCGTAGAGTGCTAGTAC' *.fastq > count/B12892_Rm0.txt
agrep -0 -c 'CCTACTGGGTGCGTAAT' *.fastq > count/B12893_Rm0.txt
agrep -0 -c 'GTGATAAACAGACCCAA' *.fastq > count/B12894_Rm0.txt
agrep -0 -c 'ACCTGGGGAGTTCCTAG' *.fastq > count/B12895_Rm0.txt
agrep -0 -c 'GTCATATGCTTTCGCGT' *.fastq > count/B12896_Rm0.txt
agrep -0 -c 'GTCCCGAATGGCCTTAT' *.fastq > count/B12897_Rm0.txt
agrep -0 -c 'GTAAGTGTCAAATCCGG' *.fastq > count/B12898_Rm0.txt
agrep -0 -c 'CGATAATGGCTACGAGT' *.fastq > count/B12899_Rm0.txt
agrep -0 -c 'CAGGTAATCTATCGCCT' *.fastq > count/B12900_Rm0.txt
agrep -0 -c 'GGTGATCGGACCCTACA' *.fastq > count/B12901_Rm0.txt
agrep -0 -c 'GACCTTGCCAAACTACG' *.fastq > count/B12902_Rm0.txt
agrep -0 -c 'GAGCAACGTCGCCTGTT' *.fastq > count/B12903_Rm0.txt
agrep -0 -c 'GAACACGAGTCCTTCAC' *.fastq > count/B12904_Rm0.txt
agrep -0 -c 'CCGCAGTGACACCTTAC' *.fastq > count/B12905_Rm0.txt
agrep -0 -c 'ACGGGATGGCATCCCTT' *.fastq > count/B12906_Rm0.txt
agrep -0 -c 'GAAGGGGCTGGGATATT' *.fastq > count/B12907_Rm0.txt
agrep -0 -c 'CTGGGTAACCTTGGGGT' *.fastq > count/B12908_Rm0.txt
agrep -0 -c 'AGACTTCGGGATTAGCC' *.fastq > count/B12909_Rm0.txt
agrep -0 -c 'ACGTAACCCGAGTTTGC' *.fastq > count/B12910_Rm0.txt
agrep -0 -c 'CAGGGGAAAAGGGACAT' *.fastq > count/B12911_Rm0.txt
agrep -0 -c 'CCAATGTGCCCAAACAA' *.fastq > count/B12912_Rm0.txt
agrep -0 -c 'AGTTCGACCCCACAGGT' *.fastq > count/B12913_Rm0.txt
agrep -0 -c 'ACAGTCATTGATGCTCG' *.fastq > count/B12914_Rm0.txt
agrep -0 -c 'CACTAGATGTCTTACGA' *.fastq > count/B12916_Rm0.txt
agrep -0 -c 'CTTATGCGCACACCTCG' *.fastq > count/B12917_Rm0.txt
agrep -0 -c 'GTCTCATAATCAGGAAC' *.fastq > count/B12921_Rm0.txt
agrep -0 -c 'TCTTAGAGACGACGACG' *.fastq > count/B12922_Rm0.txt
agrep -0 -c 'AGTTCATTCTGACGGTT' *.fastq > count/B12923_Rm0.txt
agrep -0 -c 'GCCAACCATGTTTAAGA' *.fastq > count/B12925_Rm0.txt
agrep -0 -c 'GACTTCCCCAGTGTACG' *.fastq > count/B12926_Rm0.txt
agrep -0 -c 'TTCGTCGCACTGATTTA' *.fastq > count/B12927_Rm0.txt
agrep -0 -c 'TGTTGTCTGAGCTTTGT' *.fastq > count/B12928_Rm0.txt
agrep -0 -c 'ATAGAAGGCGAGGTGGC' *.fastq > count/B12929_Rm0.txt
agrep -0 -c 'AGAATTTGGCAAGCTGA' *.fastq > count/B12930_Rm0.txt
agrep -0 -c 'TCAAGAGCTTAGGGTTA' *.fastq > count/B12931_Rm0.txt
agrep -0 -c 'ATGCCGGAAGAAGGATA' *.fastq > count/B12932_Rm0.txt
agrep -0 -c 'CCGTACTAGGATGTATC' *.fastq > count/B12933_Rm0.txt
agrep -0 -c 'CCTATTCCTCGCCTTTA' *.fastq > count/B12934_Rm0.txt
agrep -0 -c 'CTGTCGCGCCATATTAT' *.fastq > count/B12935_Rm0.txt
agrep -0 -c 'AATCCACTAGGGACATC' *.fastq > count/B12936_Rm0.txt
agrep -0 -c 'CTAACAAGGAGCACACT' *.fastq > count/B12938_Rm0.txt
agrep -0 -c 'TGTACCGTTTACCCTAC' *.fastq > count/B12940_Rm0.txt
agrep -0 -c 'GGCGGTGATAATCAGCA' *.fastq > count/B12942_Rm0.txt
agrep -0 -c 'AACTGCGCCGGAATTAA' *.fastq > count/B12944_Rm0.txt
agrep -0 -c 'TATCAGACCCGTTCATA' *.fastq > count/B12946_Rm0.txt
agrep -0 -c 'CAATTTGACGGGGTTAG' *.fastq > count/B12947_Rm0.txt
agrep -0 -c 'CTCGTGAGAAATCTCAC' *.fastq > count/B12948_Rm0.txt
agrep -0 -c 'TGATTCCAGTTGTCACG' *.fastq > count/B12949_Rm0.txt
agrep -0 -c 'TTCATTACTTACGCAGC' *.fastq > count/B12950_Rm0.txt
agrep -0 -c 'GCGAGTTGGCTTCACGA' *.fastq > count/B12951_Rm0.txt
agrep -0 -c 'GCAGCACGATTTTTACC' *.fastq > count/B12952_Rm0.txt
agrep -0 -c 'TAGGAGGACTTATTGGT' *.fastq > count/B12954_Rm0.txt
agrep -0 -c 'CTTGATCTCATACCTCT' *.fastq > count/B12956_Rm0.txt
agrep -0 -c 'GTACATACAGTGATTGC' *.fastq > count/B12957_Rm0.txt
agrep -0 -c 'TTAAGTGCAGTGATCAC' *.fastq > count/B12958_Rm0.txt
agrep -0 -c 'GTGATACTCTCTAGCGG' *.fastq > count/B12961_Rm0.txt
agrep -0 -c 'GACTTGGTAAACGAGAT' *.fastq > count/B12964_Rm0.txt
agrep -0 -c 'GTGGCGACAACTATGTT' *.fastq > count/B12965_Rm0.txt
agrep -0 -c 'GGAACCGCTCAAACCAA' *.fastq > count/B12966_Rm0.txt
agrep -0 -c 'CAGGCTAAACTGCCGCT' *.fastq > count/B12967_Rm0.txt
agrep -0 -c 'ATCAGGACTGTTGCGTA' *.fastq > count/B12968_Rm0.txt
agrep -0 -c 'GGTCTTTATGAACCCGG' *.fastq > count/B12969_Rm0.txt
agrep -0 -c 'GTTCCCATTACTCTTGG' *.fastq > count/B12970_Rm0.txt
agrep -0 -c 'CTACTGTGAATCCAGTT' *.fastq > count/B12971_Rm0.txt
agrep -0 -c 'AGCAGTCGTCGGGTACA' *.fastq > count/B12972_Rm0.txt
agrep -0 -c 'ATCAAAGCCTCAGTCAC' *.fastq > count/B12974_Rm0.txt
agrep -0 -c 'TGGATTCGTTTCGCCCG' *.fastq > count/B12975_Rm0.txt
agrep -0 -c 'CAGGTTATGCTTGAGAT' *.fastq > count/B12976_Rm0.txt
agrep -0 -c 'ATGTGCCCTTCGTTCAC' *.fastq > count/B12977_Rm0.txt
agrep -0 -c 'GTCAATTCTGGACAAGA' *.fastq > count/B12978_Rm0.txt
agrep -0 -c 'AAGGAGTCTGGTATCGA' *.fastq > count/B12980_Rm0.txt
agrep -0 -c 'AACTTGATTTCCCGTGT' *.fastq > count/B12981_Rm0.txt
agrep -0 -c 'TGTCCTAAACGTTCACG' *.fastq > count/B12982_Rm0.txt
agrep -0 -c 'TGTCACACGAGTCATCC' *.fastq > count/B12983_Rm0.txt
agrep -0 -c 'CTTACCCGTCCAGAATT' *.fastq > count/B12984_Rm0.txt
agrep -0 -c 'CCCGAAGCTATGCTCCT' *.fastq > count/B12985_Rm0.txt
agrep -0 -c 'TTGCACGAAAAGTCACC' *.fastq > count/B12986_Rm0.txt
agrep -0 -c 'TCCGCCAACTGTGAAGG' *.fastq > count/B12987_Rm0.txt
agrep -0 -c 'GGTCTGCGTTGTGGATT' *.fastq > count/B12988_Rm0.txt
agrep -0 -c 'GGCCACTAGCATCCTGA' *.fastq > count/B12989_Rm0.txt
agrep -0 -c 'TAATCGTGAAAGCGTCG' *.fastq > count/B12990_Rm0.txt
agrep -0 -c 'CCCGCGTGTACTTACGA' *.fastq > count/B12991_Rm0.txt
agrep -0 -c 'CGGCTCTGCACATTTCT' *.fastq > count/B12992_Rm0.txt
agrep -0 -c 'GTCTCCTTCTACCTATG' *.fastq > count/B12994_Rm0.txt
agrep -0 -c 'CATTACGTCGCTAACAA' *.fastq > count/B12995_Rm0.txt
agrep -0 -c 'AACTGTTGATACGTGCG' *.fastq > count/B12996_Rm0.txt
agrep -0 -c 'AGTCAGCTCATAACACC' *.fastq > count/B12997_Rm0.txt
agrep -0 -c 'ACCTTTCTATGTCTCGC' *.fastq > count/B12999_Rm0.txt
agrep -0 -c 'GTCGCAAAGGGAATGTT' *.fastq > count/B13000_Rm0.txt
agrep -0 -c 'AACCCGTATTAATCGGT' *.fastq > count/B13002_Rm0.txt
agrep -0 -c 'ACTTCTATGTTGGACCC' *.fastq > count/B13003_Rm0.txt
agrep -0 -c 'TATGTCACTATAGCCAG' *.fastq > count/B13004_Rm0.txt
agrep -0 -c 'AGAGAAACCCGACGTCA' *.fastq > count/B13005_Rm0.txt
agrep -0 -c 'AGCATGAGTCCAGCCAC' *.fastq > count/B13006_Rm0.txt
agrep -0 -c 'GCGAAGGTATTTAGATG' *.fastq > count/B13007_Rm0.txt
agrep -0 -c 'GTAAAAAACCATCCGTC' *.fastq > count/B13008_Rm0.txt
agrep -0 -c 'ATTGCGCACGTCCTCGA' *.fastq > count/B13009_Rm0.txt
agrep -0 -c 'TAATGAATCACGTGTGC' *.fastq > count/B13013_Rm0.txt
agrep -0 -c 'CGCATTTAAGGATGCGA' *.fastq > count/B13014_Rm0.txt
agrep -0 -c 'CGTCGCTATCAGTGATA' *.fastq > count/B13015_Rm0.txt
agrep -0 -c 'TCTCGTTAATCTTGACG' *.fastq > count/B13016_Rm0.txt
agrep -0 -c 'AAATAACGACGGGTATG' *.fastq > count/B13017_Rm0.txt
agrep -0 -c 'GTAGTAGGGAAGCTGCT' *.fastq > count/B13018_Rm0.txt
agrep -0 -c 'GTCGAACCGTTACTGCT' *.fastq > count/B13019_Rm0.txt
agrep -0 -c 'TATCTGAGCCGTATGTA' *.fastq > count/B13020_Rm0.txt
agrep -0 -c 'ACGGGAGTCGCCATTTG' *.fastq > count/B13023_Rm0.txt
agrep -0 -c 'CATGAGTAGTGACGCCT' *.fastq > count/B13024_Rm0.txt
agrep -0 -c 'TTACGTTAGAGCCAGAC' *.fastq > count/B13026_Rm0.txt
agrep -0 -c 'GAGGTAGCTGCGTACTA' *.fastq > count/B13029_Rm0.txt
agrep -0 -c 'TGCACCACAATTGGGAA' *.fastq > count/B13030_Rm0.txt
agrep -0 -c 'TGTTAGGCTAGGTAGAT' *.fastq > count/B13031_Rm0.txt
agrep -0 -c 'AGACAGACTCACGCTTG' *.fastq > count/B13037_Rm0.txt
agrep -0 -c 'TACGGCATACCTCCATA' *.fastq > count/B13038_Rm0.txt
agrep -0 -c 'ACGCTTGCGTCTTTACA' *.fastq > count/B13039_Rm0.txt
agrep -0 -c 'CACGCGTGATAACGCTG' *.fastq > count/B13040_Rm0.txt
agrep -0 -c 'TAAGTGACGCTTCTGTT' *.fastq > count/B13041_Rm0.txt
agrep -0 -c 'CATGGTTGTTAGGCGAT' *.fastq > count/B13042_Rm0.txt
agrep -0 -c 'CGTAATGTCCCAGAATC' *.fastq > count/B13043_Rm0.txt
agrep -0 -c 'AAGGGGGTCAGACTAGT' *.fastq > count/B13044_Rm0.txt
agrep -0 -c 'ACCTACACTCGACATAA' *.fastq > count/B13045_Rm0.txt
agrep -0 -c 'TTCAGTGCACTCGAATT' *.fastq > count/B13047_Rm0.txt
agrep -0 -c 'TTTGTTCTAGCGGCGAT' *.fastq > count/B13048_Rm0.txt
agrep -0 -c 'CCGTTTAACGGTGACAG' *.fastq > count/B13049_Rm0.txt
agrep -0 -c 'GCCTAGGCAATTGTTTG' *.fastq > count/B13050_Rm0.txt
agrep -0 -c 'GCCAATTTGTGAGTAGC' *.fastq > count/B13051_Rm0.txt
agrep -0 -c 'CTCATCTGCCCGTGATA' *.fastq > count/B13052_Rm0.txt
agrep -0 -c 'CTTCTGCGACGGGAGAT' *.fastq > count/B13053_Rm0.txt
agrep -0 -c 'GAGAAAACGAGTGGCCC' *.fastq > count/B13054_Rm0.txt
agrep -0 -c 'AATTGATCCTATCCCTG' *.fastq > count/B13055_Rm0.txt
agrep -0 -c 'TGTTTGGAGTAGCAAGT' *.fastq > count/B13056_Rm0.txt
agrep -0 -c 'ACCATTTGTGTATCAGC' *.fastq > count/B13057_Rm0.txt
agrep -0 -c 'TTGGAACAAGGGAGAGG' *.fastq > count/B13058_Rm0.txt
agrep -0 -c 'GTACTATCGCTTCACAA' *.fastq > count/B13060_Rm0.txt
agrep -0 -c 'CGGACACTTGGTAGGCA' *.fastq > count/B13061_Rm0.txt
agrep -0 -c 'ATCAAGCGTTTCACTGT' *.fastq > count/B13062_Rm0.txt
agrep -0 -c 'AGGATATGTGGCTAAGC' *.fastq > count/B13063_Rm0.txt
agrep -0 -c 'CCGTAATGCACTCACTC' *.fastq > count/B13064_Rm0.txt
agrep -0 -c 'CCTAACTCAAGTTTTCG' *.fastq > count/B13065_Rm0.txt
agrep -0 -c 'TCTTGTCCCATAATTCC' *.fastq > count/B13066_Rm0.txt
agrep -0 -c 'AGCCTAGGCGTCCATGA' *.fastq > count/B13067_Rm0.txt
agrep -0 -c 'TAAGACATCGGGGTTAT' *.fastq > count/B13068_Rm0.txt
agrep -0 -c 'TGTGAGGCAGGAATCCC' *.fastq > count/B13069_Rm0.txt
agrep -0 -c 'CGAAGCATCGGACTTCC' *.fastq > count/B13072_Rm0.txt
agrep -0 -c 'ATTATCGATGTGTGGAG' *.fastq > count/B13073_Rm0.txt
agrep -0 -c 'TTCAACAACGAATCGTG' *.fastq > count/B13074_Rm0.txt
agrep -0 -c 'CGCTTGGGCTACGAGTT' *.fastq > count/B13076_Rm0.txt
agrep -0 -c 'CTCCCAATAGGAAGGAT' *.fastq > count/B13078_Rm0.txt
agrep -0 -c 'AAGATAAGGACGAGACT' *.fastq > count/B13080_Rm0.txt
agrep -0 -c 'CGGAATTTCCTTCCTGC' *.fastq > count/B13081_Rm0.txt
agrep -0 -c 'GAACCAGCACTGGAACG' *.fastq > count/B13083_Rm0.txt
agrep -0 -c 'CGGAGTGAGCGGAATGA' *.fastq > count/B13084_Rm0.txt
agrep -0 -c 'CGTGTACTAGAATCTTG' *.fastq > count/B13085_Rm0.txt
agrep -0 -c 'TGTCAAATTAACCCGAG' *.fastq > count/B13086_Rm0.txt
agrep -0 -c 'TATTGGGGATCGGTCCC' *.fastq > count/B13087_Rm0.txt
agrep -0 -c 'AGATAAAGGGCGCGTCA' *.fastq > count/B13088_Rm0.txt
agrep -0 -c 'CTTACGGGCAAGTGCAT' *.fastq > count/B13089_Rm0.txt
agrep -0 -c 'TAGGCACCCGTAGACAT' *.fastq > count/B13090_Rm0.txt
agrep -0 -c 'AAATCCGGTGGCTCGCT' *.fastq > count/B13091_Rm0.txt
agrep -0 -c 'TTTGACACCCCGATGCG' *.fastq > count/B13092_Rm0.txt
agrep -0 -c 'CCGAGAACTCGCCTGTA' *.fastq > count/B13093_Rm0.txt
agrep -0 -c 'CGGACCTTTCAAATTTG' *.fastq > count/B13094_Rm0.txt
agrep -0 -c 'CAGGTCGATTGCGTTGG' *.fastq > count/B13096_Rm0.txt
agrep -0 -c 'TTCTTCTGCCCGTGCAC' *.fastq > count/B13097_Rm0.txt
agrep -0 -c 'GGGCACCTTCGATGTAA' *.fastq > count/B13098_Rm0.txt
agrep -0 -c 'ACGGATCGTAAGCTTAC' *.fastq > count/B13099_Rm0.txt
agrep -0 -c 'GACTAGTATGCTGAAGG' *.fastq > count/B13100_Rm0.txt
agrep -0 -c 'CTAATGGACAGTGGATG' *.fastq > count/B13101_Rm0.txt
agrep -0 -c 'TACAGCGAGACGAGTAG' *.fastq > count/B13103_Rm0.txt
agrep -0 -c 'CACCGCAAGAAAAGTCG' *.fastq > count/B13104_Rm0.txt
agrep -0 -c 'ACACCTACACTAGGACA' *.fastq > count/B13105_Rm0.txt
agrep -0 -c 'ATGATCATGCGAATGCC' *.fastq > count/B13107_Rm0.txt
agrep -0 -c 'GCGTGTATGAACCCGTA' *.fastq > count/B13108_Rm0.txt
agrep -0 -c 'GCCTAGATGCTGTGAAC' *.fastq > count/B13109_Rm0.txt
agrep -0 -c 'TCGCGTACAACAACCAT' *.fastq > count/B13110_Rm0.txt
agrep -0 -c 'AGACACGTATGTGGTCG' *.fastq > count/B13112_Rm0.txt
agrep -0 -c 'ACGATCTTAACTTCGGT' *.fastq > count/B13113_Rm0.txt
agrep -0 -c 'CAGTGGGTTTCATGGTC' *.fastq > count/B13114_Rm0.txt
agrep -0 -c 'CTCTAGATAACTTGTCG' *.fastq > count/B13116_Rm0.txt
agrep -0 -c 'GGACTGTACGAGTAGAG' *.fastq > count/B13117_Rm0.txt
agrep -0 -c 'GCCTTTAATCACCATCC' *.fastq > count/B13118_Rm0.txt
agrep -0 -c 'AGATTCGCCCGACTAGC' *.fastq > count/B13119_Rm0.txt
agrep -0 -c 'AGCGATCGGAGGCTTAT' *.fastq > count/B13120_Rm0.txt
agrep -0 -c 'ACGGTGAGTGTCATCAC' *.fastq > count/B13121_Rm0.txt
agrep -0 -c 'ATGTTGGATGGAGTCTA' *.fastq > count/B13122_Rm0.txt
agrep -0 -c 'CGGTGTAAGACCCGAAC' *.fastq > count/B13124_Rm0.txt
agrep -0 -c 'AGTCTAGGATCCGGGCA' *.fastq > count/B13125_Rm0.txt
agrep -0 -c 'CTAACATGTTTTGCCGG' *.fastq > count/B13127_Rm0.txt
agrep -0 -c 'TGGCAGCTACAGCTGTG' *.fastq > count/B13128_Rm0.txt
agrep -0 -c 'TGAGCGTTGCTCTTTAT' *.fastq > count/B13129_Rm0.txt
agrep -0 -c 'ACCACTCCATCAAACAT' *.fastq > count/B13130_Rm0.txt
agrep -0 -c 'GCGGTATTGAGGCCTGT' *.fastq > count/B13132_Rm0.txt
agrep -0 -c 'CCCGTATGTTAGAGCGT' *.fastq > count/B13133_Rm0.txt
agrep -0 -c 'GATCGATGGTTTTTTGC' *.fastq > count/B13134_Rm0.txt
agrep -0 -c 'AAGCGTCAAATTCGCCT' *.fastq > count/B13135_Rm0.txt
agrep -0 -c 'TTGGAGGACCAACTAGA' *.fastq > count/B13136_Rm0.txt
agrep -0 -c 'TTGTTTTACGCAGTCCT' *.fastq > count/B13137_Rm0.txt
agrep -0 -c 'ATAGCAGACTCGATTGT' *.fastq > count/B13139_Rm0.txt
agrep -0 -c 'GCACAATACCTGTTGCA' *.fastq > count/B13140_Rm0.txt
agrep -0 -c 'ACGTAGTGTTGGTATGA' *.fastq > count/B13141_Rm0.txt
agrep -0 -c 'CGGAGGAACAATAAGAA' *.fastq > count/B13142_Rm0.txt
agrep -0 -c 'ACAGTGGGTATCGTGTG' *.fastq > count/B13143_Rm0.txt
agrep -0 -c 'GACCTTACAAGTGAATG' *.fastq > count/B13144_Rm0.txt
agrep -0 -c 'AAAGAATTTTGAGCGCC' *.fastq > count/B13145_Rm0.txt
agrep -0 -c 'AGGGAATTGTAGTTCCA' *.fastq > count/B13146_Rm0.txt
agrep -0 -c 'GTCAAATAGTTGAGGGC' *.fastq > count/B13148_Rm0.txt
agrep -0 -c 'GAAGTGGTGACGCTTCG' *.fastq > count/B13152_Rm0.txt
agrep -0 -c 'TGCTGGGTCGAAACCTA' *.fastq > count/B13153_Rm0.txt
agrep -0 -c 'GGTTGCATGGAGTCAGT' *.fastq > count/B13154_Rm0.txt
agrep -0 -c 'GGGACGTCCAAATACGG' *.fastq > count/B13157_Rm0.txt
agrep -0 -c 'TAACATGACAGCGCCTT' *.fastq > count/B13158_Rm0.txt
agrep -0 -c 'TAATGACGACACACGGC' *.fastq > count/B13159_Rm0.txt
agrep -0 -c 'GATGAAGACTCTACTCT' *.fastq > count/B13160_Rm0.txt
agrep -0 -c 'GTCAGCGGCTTTTAGTT' *.fastq > count/B13162_Rm0.txt
agrep -0 -c 'TTATCCCTCGTAACCCT' *.fastq > count/B13164_Rm0.txt
agrep -0 -c 'ACTGGTCCAAAGCGGTG' *.fastq > count/B13165_Rm0.txt
agrep -0 -c 'GCCAGAGGCTCATCCTT' *.fastq > count/B13166_Rm0.txt
agrep -0 -c 'GTCAACTGGAGTGGCGA' *.fastq > count/B13168_Rm0.txt
agrep -0 -c 'GGCGGAACAACCACATC' *.fastq > count/B13169_Rm0.txt
agrep -0 -c 'TCCGCAAACCCCAAGCA' *.fastq > count/B13170_Rm0.txt
agrep -0 -c 'TACTCGTAGGCGGTCAT' *.fastq > count/B13171_Rm0.txt
agrep -0 -c 'GGGATATAGTATCGGAC' *.fastq > count/B13172_Rm0.txt
agrep -0 -c 'AGCCATCTATATGCCCT' *.fastq > count/B13174_Rm0.txt
agrep -0 -c 'AGCGTGCCCTATCACTC' *.fastq > count/B13175_Rm0.txt
agrep -0 -c 'TTCTGGTTAGGTGAGCG' *.fastq > count/B13176_Rm0.txt
agrep -0 -c 'ACAAACCTCAATCAACC' *.fastq > count/B13178_Rm0.txt
agrep -0 -c 'TCTCGTACTGCCGCGTA' *.fastq > count/B13179_Rm0.txt
agrep -0 -c 'CGGCACACTAGTATTAC' *.fastq > count/B13180_Rm0.txt
agrep -0 -c 'GCTTGCATTAGTAGGCC' *.fastq > count/B13181_Rm0.txt
agrep -0 -c 'TCTACAATAGGCTAGAG' *.fastq > count/B13182_Rm0.txt
agrep -0 -c 'TATGATCGCTGGTAAGA' *.fastq > count/B13183_Rm0.txt
agrep -0 -c 'GCGATCTGATACTCTGT' *.fastq > count/B13186_Rm0.txt
agrep -0 -c 'GTTTGCACCACCGAGAG' *.fastq > count/B13187_Rm0.txt
agrep -0 -c 'CGCGGATCACTAGCTCA' *.fastq > count/B13188_Rm0.txt
agrep -0 -c 'AAGCGGAACCTGGGCTA' *.fastq > count/B13190_Rm0.txt
agrep -0 -c 'CTGGATAATACCCGTGT' *.fastq > count/B13191_Rm0.txt
agrep -0 -c 'GCTCGACTAGACCCAAG' *.fastq > count/B13192_Rm0.txt
agrep -0 -c 'CCTCTAACTCGAACGTA' *.fastq > count/B13194_Rm0.txt
agrep -0 -c 'TGACTTCGATTTAGTGC' *.fastq > count/B13196_Rm0.txt
agrep -0 -c 'ACTATATAATCGAGGCC' *.fastq > count/B13197_Rm0.txt
agrep -0 -c 'GAGGACCGACGACTCTA' *.fastq > count/B13198_Rm0.txt
agrep -0 -c 'ATAACTGGGATATCCAG' *.fastq > count/B13199_Rm0.txt
agrep -0 -c 'CCCAGAAACTTTCGCGG' *.fastq > count/B13200_Rm0.txt
agrep -0 -c 'TAACCCGTATGTAGAGC' *.fastq > count/B13202_Rm0.txt
agrep -0 -c 'GGGACACGTTAGCATAA' *.fastq > count/B13205_Rm0.txt
agrep -0 -c 'TTAACCCACACACACCC' *.fastq > count/B13207_Rm0.txt
agrep -0 -c 'TGCCGGAGGGCAGTAAT' *.fastq > count/B13208_Rm0.txt
agrep -0 -c 'CCTGTTACACAGCACGG' *.fastq > count/B13209_Rm0.txt
agrep -0 -c 'ATTGCAACCCCAACTGG' *.fastq > count/B13211_Rm0.txt
agrep -0 -c 'GGCTGATATAGAACCCT' *.fastq > count/B13212_Rm0.txt
agrep -0 -c 'AAGGTAAAGTCTCCGCT' *.fastq > count/B13213_Rm0.txt
agrep -0 -c 'ATCACCCCGGAGTTGAA' *.fastq > count/B13214_Rm0.txt
agrep -0 -c 'GCGGGATAACGCAGTAT' *.fastq > count/B13215_Rm0.txt
agrep -0 -c 'CAACTTCTGTATCGGAC' *.fastq > count/B13217_Rm0.txt
agrep -0 -c 'ATCACCCTCGGAGGACT' *.fastq > count/B13218_Rm0.txt
agrep -0 -c 'GGTTGCAGTGTGTACCG' *.fastq > count/B13219_Rm0.txt
agrep -0 -c 'GCACACGCTGAGGTACT' *.fastq > count/B13220_Rm0.txt
agrep -0 -c 'TTGGCAACTTCACCCAT' *.fastq > count/B13221_Rm0.txt
agrep -0 -c 'CATGCAAATTCGTGAGT' *.fastq > count/B13222_Rm0.txt
agrep -0 -c 'CCTTGTTCCGTTGGATC' *.fastq > count/B13223_Rm0.txt
agrep -0 -c 'TTCACGATCAATTCGCG' *.fastq > count/B13224_Rm0.txt
agrep -0 -c 'GCAGAAACCCTATGGCG' *.fastq > count/B13226_Rm0.txt
agrep -0 -c 'GGCCATAAATAGCTCAT' *.fastq > count/B13227_Rm0.txt
agrep -0 -c 'CAACATCCCGTGTCCTA' *.fastq > count/B13228_Rm0.txt
agrep -0 -c 'ACCGTGAGATTCCCGAA' *.fastq > count/B13229_Rm0.txt
agrep -0 -c 'AGATACTACGTGATGGT' *.fastq > count/B13230_Rm0.txt
agrep -0 -c 'AACGGCGACGAGACTAA' *.fastq > count/B13231_Rm0.txt
agrep -0 -c 'GCACCCCCTATTGAATT' *.fastq > count/B13232_Rm0.txt
agrep -0 -c 'ATCTGTTGAATTCCCTG' *.fastq > count/B13233_Rm0.txt
agrep -0 -c 'TACGGGTCGTGTCTAGG' *.fastq > count/B13234_Rm0.txt
agrep -0 -c 'GAGAATCGCACGTAACA' *.fastq > count/B13235_Rm0.txt
agrep -0 -c 'ACGTAAGGTACAATGTC' *.fastq > count/B13236_Rm0.txt
agrep -0 -c 'CTTGTGTGAGTCAGGAG' *.fastq > count/B13237_Rm0.txt
agrep -0 -c 'AGCACCCAGGCGTATAG' *.fastq > count/B13238_Rm0.txt
agrep -0 -c 'CCCGTGTTGATCCACAG' *.fastq > count/B13239_Rm0.txt
agrep -0 -c 'TGTGTAGGTTATCCCTT' *.fastq > count/B13240_Rm0.txt
agrep -0 -c 'CGCTTCCAACGTTCTGC' *.fastq > count/B13241_Rm0.txt
agrep -0 -c 'GAGCACCCCAGAAGACA' *.fastq > count/B13242_Rm0.txt
agrep -0 -c 'ATCACTTCCATATGGCA' *.fastq > count/B13244_Rm0.txt
agrep -0 -c 'GTACAGTTGTTAGACAG' *.fastq > count/B13246_Rm0.txt
agrep -0 -c 'TTAGGTGATCGATTCCC' *.fastq > count/B13248_Rm0.txt
agrep -0 -c 'GCCTAGTTCCAGATAGT' *.fastq > count/B13249_Rm0.txt
agrep -0 -c 'AATTCGATGAGGACCAA' *.fastq > count/B13250_Rm0.txt
agrep -0 -c 'TACCGTGACGTCCTTCA' *.fastq > count/B13251_Rm0.txt
agrep -0 -c 'GCGGTATATTGTGTGTA' *.fastq > count/B13252_Rm0.txt
agrep -0 -c 'TTTGAGCACCCTACTAG' *.fastq > count/B13254_Rm0.txt
agrep -0 -c 'ACCGATAACGTGTAGTC' *.fastq > count/B13256_Rm0.txt
agrep -0 -c 'AACAGTCTCGAGCTGCA' *.fastq > count/B13259_Rm0.txt
agrep -0 -c 'TCGCCGCTTTAAGACGT' *.fastq > count/B13261_Rm0.txt
agrep -0 -c 'CTCGTATATCAGCGGGT' *.fastq > count/B13262_Rm0.txt
agrep -0 -c 'ATCATGTCGCCCGATGG' *.fastq > count/B13263_Rm0.txt
agrep -0 -c 'TTTTTGTGCCCGATGTG' *.fastq > count/B13264_Rm0.txt
agrep -0 -c 'ATAGCGGGAATAGCCAG' *.fastq > count/B13265_Rm0.txt
agrep -0 -c 'GATTGCACAGTCAATGC' *.fastq > count/B13266_Rm0.txt
agrep -0 -c 'TACCCCTGATAGGGACT' *.fastq > count/B13267_Rm0.txt
agrep -0 -c 'CGCAGAATATATTCGGT' *.fastq > count/B13268_Rm0.txt
agrep -0 -c 'GACAGTAAGTCGTGGTA' *.fastq > count/B13269_Rm0.txt
agrep -0 -c 'TGCAGTTTGACGACGAA' *.fastq > count/B13271_Rm0.txt
agrep -0 -c 'ACAGTTCGGGCGTATGA' *.fastq > count/B13272_Rm0.txt
agrep -0 -c 'TTAAAGTGTACCGCGTG' *.fastq > count/B13273_Rm0.txt
agrep -0 -c 'TGTAGCTTGAGGTGCGC' *.fastq > count/B13274_Rm0.txt
agrep -0 -c 'GGTAGGGCGAACGAAGA' *.fastq > count/B13275_Rm0.txt
agrep -0 -c 'GTGCAGTTAAACGCGAC' *.fastq > count/B13276_Rm0.txt
agrep -0 -c 'CTAAAAGGCGGCTAGCC' *.fastq > count/B13277_Rm0.txt
agrep -0 -c 'CTCGGTTCATCAAAAGG' *.fastq > count/B13278_Rm0.txt
agrep -0 -c 'TTCCCAGTGGATATGTT' *.fastq > count/B13279_Rm0.txt
agrep -0 -c 'ATGCTACGTGCTGCTCA' *.fastq > count/B13281_Rm0.txt
agrep -0 -c 'GACCTAGGACGTTTCAC' *.fastq > count/B13282_Rm0.txt
agrep -0 -c 'GAGAATGTAAGGAGGCA' *.fastq > count/B13283_Rm0.txt
agrep -0 -c 'CCGTACAACTATCTGCG' *.fastq > count/B13284_Rm0.txt
agrep -0 -c 'GAAACCTCGTAGGCGCA' *.fastq > count/B13285_Rm0.txt
agrep -0 -c 'GCTTGACCGAGTAAAGA' *.fastq > count/B13286_Rm0.txt
agrep -0 -c 'CCCAATTATGGCAGCTA' *.fastq > count/B13287_Rm0.txt
agrep -0 -c 'AATTCCTTGCGCGTACT' *.fastq > count/B13288_Rm0.txt
agrep -0 -c 'TACCGTGGATACACATT' *.fastq > count/B13289_Rm0.txt
agrep -0 -c 'CACCCGTTCTCGCTCAT' *.fastq > count/B13290_Rm0.txt
agrep -0 -c 'CGTCTACGCAAACGACG' *.fastq > count/B13293_Rm0.txt
agrep -0 -c 'CGAACACCCTTGAATGA' *.fastq > count/B13294_Rm0.txt
agrep -0 -c 'CCTGGATACGACCTAAC' *.fastq > count/B13295_Rm0.txt
agrep -0 -c 'ATGAAGGATATAACCGC' *.fastq > count/B13296_Rm0.txt
agrep -0 -c 'TGTTGGCTACCAAGACC' *.fastq > count/B13300_Rm0.txt
agrep -0 -c 'GCAAGATGCCCGTACTT' *.fastq > count/B13301_Rm0.txt
agrep -0 -c 'GTCTCTTGCCACTGTAG' *.fastq > count/B13302_Rm0.txt
agrep -0 -c 'GCAGACTTCTACAGGTC' *.fastq > count/B13303_Rm0.txt
agrep -0 -c 'CTGGATCAAATCCAATG' *.fastq > count/B13305_Rm0.txt
agrep -0 -c 'GGGGGAACATAGGATAT' *.fastq > count/B13306_Rm0.txt
agrep -0 -c 'GTGTGCGTTCGGAAACG' *.fastq > count/B13307_Rm0.txt
agrep -0 -c 'TAGGCAACGAGTCCCAG' *.fastq > count/B13309_Rm0.txt
agrep -0 -c 'GACTATTGCGCGTCTCG' *.fastq > count/B13310_Rm0.txt
agrep -0 -c 'GTTGGCTCCTGCAGAAC' *.fastq > count/B13311_Rm0.txt
agrep -0 -c 'TCATTCGAGGTGATCAG' *.fastq > count/B13312_Rm0.txt
agrep -0 -c 'CTTATCCGATTTGGAGG' *.fastq > count/B13313_Rm0.txt
agrep -0 -c 'CTTTAGGCGGTCAGTGG' *.fastq > count/B13314_Rm0.txt
agrep -0 -c 'TCACTACCGGCGATAGG' *.fastq > count/B13315_Rm0.txt
agrep -0 -c 'CGCTCGATCGGTGGATT' *.fastq > count/B13316_Rm0.txt
agrep -0 -c 'CCAGTCACTCAATGGTT' *.fastq > count/B13317_Rm0.txt
agrep -0 -c 'GTAGCTTCATGTGGTCG' *.fastq > count/B13318_Rm0.txt
agrep -0 -c 'ATGGAAATCTCTCCCGC' *.fastq > count/B13319_Rm0.txt
agrep -0 -c 'CACCTAGAAAGCACAAG' *.fastq > count/B13320_Rm0.txt
agrep -0 -c 'CCTACATGTCGTTGTCA' *.fastq > count/B13321_Rm0.txt
agrep -0 -c 'AATACTGAGCTGCGCCT' *.fastq > count/B13322_Rm0.txt
agrep -0 -c 'CTAGCGCCGCTTTATCG' *.fastq > count/B13324_Rm0.txt
agrep -0 -c 'CGGCCTCGACTCTTAAC' *.fastq > count/B13325_Rm0.txt
agrep -0 -c 'TAGTGGTTAGGCACTTA' *.fastq > count/B13326_Rm0.txt
agrep -0 -c 'TGACCGGAGACGCAACT' *.fastq > count/B13330_Rm0.txt
agrep -0 -c 'GACACGTACACGAGCCT' *.fastq > count/B13331_Rm0.txt
agrep -0 -c 'ATTCCGATCCTAACTCT' *.fastq > count/B13332_Rm0.txt
agrep -0 -c 'GCCATACTCCAGTGAGC' *.fastq > count/B13333_Rm0.txt
agrep -0 -c 'CGTAGTGTAGAGGCGCA' *.fastq > count/B13334_Rm0.txt
agrep -0 -c 'AACGGTGATTTGACGTT' *.fastq > count/B13336_Rm0.txt
agrep -0 -c 'AAGCTGTGAAAGCATCA' *.fastq > count/B13337_Rm0.txt
agrep -0 -c 'TCGACTAGCCCCTCAAG' *.fastq > count/B13338_Rm0.txt
agrep -0 -c 'TAAACCTTCGTTCAGGT' *.fastq > count/B13340_Rm0.txt
agrep -0 -c 'GTCAGTACCGTTATTGT' *.fastq > count/B13341_Rm0.txt
agrep -0 -c 'TCTCGACTAGGCTTTTA' *.fastq > count/B13343_Rm0.txt
agrep -0 -c 'CATCGTTGTGCATTGCC' *.fastq > count/B13344_Rm0.txt
agrep -0 -c 'GCTCCCATACCAATCCA' *.fastq > count/B13345_Rm0.txt
agrep -0 -c 'AAAGCGGCGTAGTTCGT' *.fastq > count/B13346_Rm0.txt
agrep -0 -c 'ATTATGACACAGCGTCT' *.fastq > count/B13348_Rm0.txt
agrep -0 -c 'GACGGGTACCGTCAGTT' *.fastq > count/B13349_Rm0.txt
agrep -0 -c 'TGCCAGTGTATAGTAAC' *.fastq > count/B13350_Rm0.txt
agrep -0 -c 'TAGGCTGAGTGATGGAA' *.fastq > count/B13351_Rm0.txt
agrep -0 -c 'AAACCATCGCACGCATC' *.fastq > count/B13352_Rm0.txt
agrep -0 -c 'CCACCTAACGTCATGTG' *.fastq > count/B13354_Rm0.txt
agrep -0 -c 'TTGTCAATGTGTCTAGG' *.fastq > count/B13355_Rm0.txt
agrep -0 -c 'CGGACTAAACCTTTACA' *.fastq > count/B13357_Rm0.txt
agrep -0 -c 'AGCAACCAAGAGATCGG' *.fastq > count/B13358_Rm0.txt
agrep -0 -c 'TATGGAGGCAGGTTTGC' *.fastq > count/B13359_Rm0.txt
agrep -0 -c 'TTTGTCCGCCTATTCAA' *.fastq > count/B13360_Rm0.txt
agrep -0 -c 'AACATTGCTACTCACGT' *.fastq > count/B13361_Rm0.txt
agrep -0 -c 'GATATCCCTGTGAAATG' *.fastq > count/B13362_Rm0.txt
agrep -0 -c 'CAGGCTGCATATACACC' *.fastq > count/B13363_Rm0.txt
agrep -0 -c 'TTGTATGGGTAGCGGTT' *.fastq > count/B13364_Rm0.txt
agrep -0 -c 'CTCGGAAGACTATGCGC' *.fastq > count/B13365_Rm0.txt
agrep -0 -c 'TCTGGGCTGCTACAATG' *.fastq > count/B13366_Rm0.txt
agrep -0 -c 'TCGTCAAGAGGCTATCA' *.fastq > count/B13367_Rm0.txt
agrep -0 -c 'GCTAGCCTAGCGTATAC' *.fastq > count/B13368_Rm0.txt
agrep -0 -c 'TGCCACTATGACTCTCT' *.fastq > count/B13369_Rm0.txt
agrep -0 -c 'TATGGATGCGTTTCCAC' *.fastq > count/B13370_Rm0.txt
agrep -0 -c 'ACTGAACCCACGACAGT' *.fastq > count/B13371_Rm0.txt
agrep -0 -c 'TAACGATATACGGTGAG' *.fastq > count/B13373_Rm0.txt
agrep -0 -c 'AACTTAAGTGGGGTATC' *.fastq > count/B13375_Rm0.txt
agrep -0 -c 'GAGTGACCTGCTTGATG' *.fastq > count/B13376_Rm0.txt
agrep -0 -c 'ACTACACCCCGGCTTTA' *.fastq > count/B13377_Rm0.txt
agrep -0 -c 'CACCACGATCTTTCGAC' *.fastq > count/B13378_Rm0.txt
agrep -0 -c 'AGATCCGGTAAAACCAG' *.fastq > count/B13380_Rm0.txt
agrep -0 -c 'GGTAAGTGCCACACCTG' *.fastq > count/B13381_Rm0.txt
agrep -0 -c 'ACGATTAAGGATTCAGC' *.fastq > count/B13382_Rm0.txt
agrep -0 -c 'TCCAATCCAGGATGGCG' *.fastq > count/B13383_Rm0.txt
agrep -0 -c 'TAATGGGTCCACTCGCA' *.fastq > count/B13384_Rm0.txt
agrep -0 -c 'GCCCTTCTTAGGGCATT' *.fastq > count/B13385_Rm0.txt
agrep -0 -c 'GTAGATTACGGCTACCC' *.fastq > count/B13388_Rm0.txt
agrep -0 -c 'GAGTTTATCTGGAGTCA' *.fastq > count/B13391_Rm0.txt
agrep -0 -c 'TCCCCGGTTCCTTTTAG' *.fastq > count/B13394_Rm0.txt
agrep -0 -c 'TTAGAGGGAAGGAATAG' *.fastq > count/B13396_Rm0.txt
agrep -0 -c 'TCAGCTGCGGATCACTG' *.fastq > count/B13399_Rm0.txt
agrep -0 -c 'GAGTCTACTATCTGTCC' *.fastq > count/B13400_Rm0.txt
agrep -0 -c 'GATCGGAATTTGGGAGC' *.fastq > count/B13401_Rm0.txt
agrep -0 -c 'ACCCGGACATCAAATTG' *.fastq > count/B13402_Rm0.txt
agrep -0 -c 'CGAGAAGAGACAAACTT' *.fastq > count/B13403_Rm0.txt
agrep -0 -c 'CCGTAATATATCATCGG' *.fastq > count/B13405_Rm0.txt
agrep -0 -c 'ATCAACGGCCCTAATCC' *.fastq > count/B13406_Rm0.txt
agrep -0 -c 'GCTGAGGAGAGTATTAA' *.fastq > count/B13407_Rm0.txt
agrep -0 -c 'ACGAGTTTAGTAGGCAG' *.fastq > count/B13408_Rm0.txt
agrep -0 -c 'CCGAAGTGCACACTAGA' *.fastq > count/B13409_Rm0.txt
agrep -0 -c 'GTTACTGGAAGGAGCAC' *.fastq > count/B13410_Rm0.txt
agrep -0 -c 'ACGCGACATGATTATCA' *.fastq > count/B13411_Rm0.txt
agrep -0 -c 'CGCGATCAAAGGCAGGT' *.fastq > count/B13412_Rm0.txt
agrep -0 -c 'GGCACAAACCAGGTTGG' *.fastq > count/B13413_Rm0.txt
agrep -0 -c 'CGTAGAAACGTTAACCT' *.fastq > count/B13414_Rm0.txt
agrep -0 -c 'TAGCTGACTTCATGGCG' *.fastq > count/B13415_Rm0.txt
agrep -0 -c 'GGGGTATGATGACCAGA' *.fastq > count/B13417_Rm0.txt
agrep -0 -c 'GATAAGCTATCTGTCGC' *.fastq > count/B13419_Rm0.txt
agrep -0 -c 'TGAGGAGACCCAGGAAC' *.fastq > count/B13420_Rm0.txt
agrep -0 -c 'CAAGAGATGGTCCATGA' *.fastq > count/B13423_Rm0.txt
agrep -0 -c 'ACACTGGAAACCCGGGT' *.fastq > count/B13424_Rm0.txt
agrep -0 -c 'CATTTCGTCGAGTCCGG' *.fastq > count/B13425_Rm0.txt
agrep -0 -c 'AGACCCGCAATCATACA' *.fastq > count/B13426_Rm0.txt
agrep -0 -c 'TCTGTCGGAGTAGTAGA' *.fastq > count/B13427_Rm0.txt
agrep -0 -c 'CTCCCATCAGGATTTAG' *.fastq > count/B13428_Rm0.txt
agrep -0 -c 'AGCGTGTATAATCTCTG' *.fastq > count/B13429_Rm0.txt
agrep -0 -c 'GGGGCGCAGTGATTAAG' *.fastq > count/B13430_Rm0.txt
agrep -0 -c 'CGGGTAGGCTTCAAATC' *.fastq > count/B13431_Rm0.txt
agrep -0 -c 'AAGTTAAGTCGGATAGC' *.fastq > count/B13432_Rm0.txt
agrep -0 -c 'ATAATGCAGCGCAGGAA' *.fastq > count/B13433_Rm0.txt
agrep -0 -c 'GACAGATGCGCAGGATT' *.fastq > count/B13434_Rm0.txt
agrep -0 -c 'AAACCACACTGATGCAG' *.fastq > count/B13435_Rm0.txt
agrep -0 -c 'GAGACATGTGGCTGATG' *.fastq > count/B13436_Rm0.txt
agrep -0 -c 'GTGCCACAACTCGCTAC' *.fastq > count/B13438_Rm0.txt
agrep -0 -c 'TTCTAACCTCGTCCCGA' *.fastq > count/B13439_Rm0.txt
agrep -0 -c 'ATCCAGGACACCTTTCA' *.fastq > count/B13440_Rm0.txt
agrep -0 -c 'ACAAGACATTGGAGGTC' *.fastq > count/B13441_Rm0.txt
agrep -0 -c 'TCCACGTTTCTGGGGTT' *.fastq > count/B13442_Rm0.txt
agrep -0 -c 'TAGAACGAAGGGATATG' *.fastq > count/B13443_Rm0.txt
agrep -0 -c 'GCTGAATCAGCCCCATC' *.fastq > count/B13444_Rm0.txt
agrep -0 -c 'TGCATATTGCGGCAGAA' *.fastq > count/B13445_Rm0.txt
agrep -0 -c 'TGACGATCCTGCTATCG' *.fastq > count/B13447_Rm0.txt
agrep -0 -c 'GTGTGGGCCAGTCGAAT' *.fastq > count/B13448_Rm0.txt
agrep -0 -c 'TCGAGGGTATTCGTATG' *.fastq > count/B13449_Rm0.txt
agrep -0 -c 'TTTGGGCGAAAGATACA' *.fastq > count/B13450_Rm0.txt
agrep -0 -c 'AGACATTTATGTGCGGC' *.fastq > count/B13451_Rm0.txt
agrep -0 -c 'CCGGCTCTATAAAGGAC' *.fastq > count/B13453_Rm0.txt
agrep -0 -c 'CGGAGCGACTTCCAGTT' *.fastq > count/B13455_Rm0.txt
agrep -0 -c 'CTCGAAACAGAAGTCGG' *.fastq > count/B13456_Rm0.txt
agrep -0 -c 'CGCTGGCAAACATCTCG' *.fastq > count/B13457_Rm0.txt
agrep -0 -c 'TCCAAGGGACTATTCTA' *.fastq > count/B13458_Rm0.txt
agrep -0 -c 'CGAGGGGGTGTGTAAAT' *.fastq > count/B13460_Rm0.txt
agrep -0 -c 'CGGACCCGAATATTAGT' *.fastq > count/B13463_Rm0.txt
agrep -0 -c 'TAGGCAGACCACTTTTG' *.fastq > count/B13464_Rm0.txt
agrep -0 -c 'GGCTGAACTCACTATCT' *.fastq > count/B13465_Rm0.txt
agrep -0 -c 'TCTGGGATAAGGCATCG' *.fastq > count/B13467_Rm0.txt
agrep -0 -c 'ATTGAACGACGCCGATG' *.fastq > count/B13468_Rm0.txt
agrep -0 -c 'TACGCGATCCTACGAAC' *.fastq > count/B13470_Rm0.txt
agrep -0 -c 'CCAAGTAGGGGTTAGCA' *.fastq > count/B13471_Rm0.txt
agrep -0 -c 'GACCGGTTTGGATTTTG' *.fastq > count/B13472_Rm0.txt
agrep -0 -c 'GGACTCTAAGGACCAAT' *.fastq > count/B13473_Rm0.txt
agrep -0 -c 'CGGCGCATCGGATAATT' *.fastq > count/B13474_Rm0.txt
agrep -0 -c 'GCTTGTTACTACTAGCA' *.fastq > count/B13475_Rm0.txt
agrep -0 -c 'TCTCCGGTAAGGTTAAG' *.fastq > count/B13476_Rm0.txt
agrep -0 -c 'GTAAGCTTGCGGAGCAC' *.fastq > count/B13477_Rm0.txt
agrep -0 -c 'ACCTATGGCTCTTCAAT' *.fastq > count/B13478_Rm0.txt
agrep -0 -c 'GCCATGCCATAGGCTCA' *.fastq > count/B13479_Rm0.txt
agrep -0 -c 'GCCAATGATGTGACTGA' *.fastq > count/B13480_Rm0.txt
agrep -0 -c 'AAAAGCATCAGGGACGC' *.fastq > count/B13481_Rm0.txt
agrep -0 -c 'CACTTCTTGCTACTCGA' *.fastq > count/B13483_Rm0.txt
agrep -0 -c 'CAAGTAGGCTCTCGGAA' *.fastq > count/B13484_Rm0.txt
agrep -0 -c 'TGGAGCTTGGGAATACG' *.fastq > count/B13485_Rm0.txt
agrep -0 -c 'TCTATGCACTCATCGCC' *.fastq > count/B13486_Rm0.txt
agrep -0 -c 'GGTACGCGACTTTCAGG' *.fastq > count/B13487_Rm0.txt
agrep -0 -c 'ACATCACGTTCCTGAGG' *.fastq > count/B13488_Rm0.txt
agrep -0 -c 'AATATGTCCCCTAGAAG' *.fastq > count/B13489_Rm0.txt
agrep -0 -c 'TGAGCATTGCCAGGTCG' *.fastq > count/B13490_Rm0.txt
agrep -0 -c 'TCATTGGCCGGATAAGA' *.fastq > count/B13491_Rm0.txt
agrep -0 -c 'CGTGATGGCTTGGTTAC' *.fastq > count/B13492_Rm0.txt
agrep -0 -c 'GAGAGAGGCTTTTACAT' *.fastq > count/B13493_Rm0.txt
agrep -0 -c 'CAAACAAAGGCTCATGT' *.fastq > count/B13495_Rm0.txt
agrep -0 -c 'AGGATTGTAGAGGCTAA' *.fastq > count/B13496_Rm0.txt
agrep -0 -c 'ACCATCGGCAGAATACT' *.fastq > count/B13497_Rm0.txt
agrep -0 -c 'CGCAAAACTTAAAGGTC' *.fastq > count/B13498_Rm0.txt
agrep -0 -c 'TTATCAGGTAGGACAAC' *.fastq > count/B13499_Rm0.txt
agrep -0 -c 'CTAATAACGGACGGCCC' *.fastq > count/B13500_Rm0.txt
agrep -0 -c 'GGATCAATGTGCGTATA' *.fastq > count/B13501_Rm0.txt
agrep -0 -c 'GCCAGAATTTCTACCGT' *.fastq > count/B13502_Rm0.txt
agrep -0 -c 'TGTAGCGATGCAGGTTA' *.fastq > count/B13503_Rm0.txt
agrep -0 -c 'GCGCTCCAGGATATGAG' *.fastq > count/B13504_Rm0.txt
agrep -0 -c 'AAAACAGAGGAGGCCCC' *.fastq > count/B13505_Rm0.txt
agrep -0 -c 'CATCTTTAGTGTACGGT' *.fastq > count/B13506_Rm0.txt
agrep -0 -c 'GAATCTCGTCCTGAATG' *.fastq > count/B13508_Rm0.txt
agrep -0 -c 'GATGACTAACGCTAACG' *.fastq > count/B13509_Rm0.txt
agrep -0 -c 'CCTCGCGGAATAGGCAT' *.fastq > count/B13511_Rm0.txt
agrep -0 -c 'CGGATGTACGGACTCGT' *.fastq > count/B13512_Rm0.txt
agrep -0 -c 'CTTCGCGGGAAAAACGC' *.fastq > count/B13513_Rm0.txt
agrep -0 -c 'AAACAGTCAACGAAGCC' *.fastq > count/B13514_Rm0.txt
agrep -0 -c 'ATGCGGCCTGGGAATAC' *.fastq > count/B13515_Rm0.txt
agrep -0 -c 'CAGGATCCTACTATCAA' *.fastq > count/B13516_Rm0.txt
agrep -0 -c 'TCATTGCTTGTCGGTAC' *.fastq > count/B13517_Rm0.txt
agrep -0 -c 'CTCGCCGATGCCAAACT' *.fastq > count/B13518_Rm0.txt
agrep -0 -c 'GAAGAAATCCACTCTGC' *.fastq > count/B13519_Rm0.txt
agrep -0 -c 'CCCAACAAAATCTAACC' *.fastq > count/B13521_Rm0.txt
agrep -0 -c 'GCAACGAGGGCTACAAG' *.fastq > count/B13522_Rm0.txt
agrep -0 -c 'CGTTCAGGTCGCAGTAA' *.fastq > count/B13524_Rm0.txt
agrep -0 -c 'GTTACTGCATTGGTGAC' *.fastq > count/B13525_Rm0.txt
agrep -0 -c 'TGAAGCATCTGGACACC' *.fastq > count/B13526_Rm0.txt
agrep -0 -c 'CTTGTAGTCGCAGGACG' *.fastq > count/B13528_Rm0.txt
agrep -0 -c 'GACATTCCCGATTGCGG' *.fastq > count/B13529_Rm0.txt
agrep -0 -c 'CCCGTGCCTGCTTACTT' *.fastq > count/B13530_Rm0.txt
agrep -0 -c 'TAATGCCGTGGTATATC' *.fastq > count/B13531_Rm0.txt
agrep -0 -c 'ATTCAATGCCCCTCATG' *.fastq > count/B13533_Rm0.txt
agrep -0 -c 'CAACCCGACACTGGATG' *.fastq > count/B13534_Rm0.txt
agrep -0 -c 'AAAGGGGCATTTTAGCG' *.fastq > count/B13536_Rm0.txt
agrep -0 -c 'CAAACCTACGGCGTCTA' *.fastq > count/B13537_Rm0.txt
agrep -0 -c 'GGCGATACTTCATGGCA' *.fastq > count/B13538_Rm0.txt
agrep -0 -c 'TCAGTGGTACCCCAGGT' *.fastq > count/B13539_Rm0.txt
agrep -0 -c 'GTAGCACGGCCTCTAAT' *.fastq > count/B13540_Rm0.txt
agrep -0 -c 'TTCTCCCTGATATGCTC' *.fastq > count/B13541_Rm0.txt
agrep -0 -c 'TCAACGTGCACTTGAAG' *.fastq > count/B13542_Rm0.txt
agrep -0 -c 'TCTTTCTGTCGTTCTAG' *.fastq > count/B13543_Rm0.txt
agrep -0 -c 'GGCGATTAGAGGTCTAT' *.fastq > count/B13544_Rm0.txt
agrep -0 -c 'CAAACTGGGCCTATCGT' *.fastq > count/B13546_Rm0.txt
agrep -0 -c 'AGGATACCGTCTCCATA' *.fastq > count/B13547_Rm0.txt
agrep -0 -c 'ATTGTAACGAGCCGCCT' *.fastq > count/B13548_Rm0.txt
agrep -0 -c 'ATGTTTAGCTGTAGAGC' *.fastq > count/B13549_Rm0.txt
agrep -0 -c 'GATGGTCCGAACGACTC' *.fastq > count/B13551_Rm0.txt
agrep -0 -c 'CCCCCTTTCACCCTATC' *.fastq > count/B13552_Rm0.txt
agrep -0 -c 'CGGATTGCCAAGCACTG' *.fastq > count/B13553_Rm0.txt
agrep -0 -c 'CCCGTCAATTCCCACAA' *.fastq > count/B13554_Rm0.txt
agrep -0 -c 'GCGTTAAGCCTGTCTAT' *.fastq > count/B13555_Rm0.txt
agrep -0 -c 'TGATACCGGCCGTCCTT' *.fastq > count/B13556_Rm0.txt
agrep -0 -c 'ATGAACACACCAGGCGC' *.fastq > count/B13557_Rm0.txt
agrep -0 -c 'GTAACTTGTCTCCGGGC' *.fastq > count/B13559_Rm0.txt
agrep -0 -c 'GCACGATGTCTACCCAT' *.fastq > count/B13560_Rm0.txt
agrep -0 -c 'TTGAGTAGTGGGATCGG' *.fastq > count/B13562_Rm0.txt
agrep -0 -c 'ATTGAGGTCGCTACGTG' *.fastq > count/B13564_Rm0.txt
agrep -0 -c 'TAACGCTACACTGGCGA' *.fastq > count/B13565_Rm0.txt
agrep -0 -c 'ATCGGCCCTATAACGCA' *.fastq > count/B13566_Rm0.txt
agrep -0 -c 'ACCTACGACTATCATCT' *.fastq > count/B13567_Rm0.txt
agrep -0 -c 'ATGAACAGGTCGCGCAC' *.fastq > count/B13568_Rm0.txt
agrep -0 -c 'GGCACTTACACGAGGTC' *.fastq > count/B13569_Rm0.txt
agrep -0 -c 'GACGACATCGGCAGGAT' *.fastq > count/B13570_Rm0.txt
agrep -0 -c 'TAGAACAATGACGCGGC' *.fastq > count/B13571_Rm0.txt
agrep -0 -c 'TCACTAGGGAAACCTGA' *.fastq > count/B13573_Rm0.txt
agrep -0 -c 'CCGCAAATTGCCCGATG' *.fastq > count/B13574_Rm0.txt
agrep -0 -c 'CGGGTTATTACGTCTAT' *.fastq > count/B13575_Rm0.txt
agrep -0 -c 'GTCTTTTCGAGCGCTTA' *.fastq > count/B13576_Rm0.txt
agrep -0 -c 'GTTCCTCACCGCCAATA' *.fastq > count/B13578_Rm0.txt
agrep -0 -c 'AGGCAGTCCTTCGTTCA' *.fastq > count/B13579_Rm0.txt
agrep -0 -c 'TGTGGTCGGTGAATCTT' *.fastq > count/B13581_Rm0.txt
agrep -0 -c 'TACGCGGATCTATCGAA' *.fastq > count/B13582_Rm0.txt
agrep -0 -c 'CTAGTGGGCCTGATAGA' *.fastq > count/B13583_Rm0.txt
agrep -0 -c 'TTAATGGGTCCCTACGT' *.fastq > count/B13585_Rm0.txt
agrep -0 -c 'TTCCGTGTTCGCGTCCA' *.fastq > count/B13587_Rm0.txt
agrep -0 -c 'AGCGAGAACTGAGGGCA' *.fastq > count/B13588_Rm0.txt
agrep -0 -c 'TGAGGGCGGTTACAACT' *.fastq > count/B13589_Rm0.txt
agrep -0 -c 'TTAGGTGGATAACGCGT' *.fastq > count/B13590_Rm0.txt
agrep -0 -c 'CCCGTTACCAGTGGTGA' *.fastq > count/B13591_Rm0.txt
agrep -0 -c 'TACGTAGGCGTGAATAT' *.fastq > count/B13592_Rm0.txt
agrep -0 -c 'TTGTACCTCAGGTCGGC' *.fastq > count/B13593_Rm0.txt
agrep -0 -c 'AGAGGAGCTCCCATCAG' *.fastq > count/B13595_Rm0.txt
agrep -0 -c 'TCTTCTACTAACGGCTA' *.fastq > count/B13596_Rm0.txt
agrep -0 -c 'CAGAACGGTCATGCTGT' *.fastq > count/B13597_Rm0.txt
agrep -0 -c 'TAGGCGTAACCGCACAT' *.fastq > count/B13598_Rm0.txt
agrep -0 -c 'GTGTACCCAAGTCCATT' *.fastq > count/B13599_Rm0.txt
agrep -0 -c 'AAGATTCGAAGCGATGA' *.fastq > count/B13600_Rm0.txt
agrep -0 -c 'GGTCGATCTCCAACTCG' *.fastq > count/B13601_Rm0.txt
agrep -0 -c 'ATCAGAATGTCCAACAG' *.fastq > count/B13604_Rm0.txt
agrep -0 -c 'GTACAATCATGCCGCCT' *.fastq > count/B13605_Rm0.txt
agrep -0 -c 'AATGGCGACTGTTCTAC' *.fastq > count/B13606_Rm0.txt
agrep -0 -c 'GGACGCTTGACAATCAC' *.fastq > count/B13607_Rm0.txt
agrep -0 -c 'GTAAGCGCGTTCGCGTA' *.fastq > count/B13609_Rm0.txt
agrep -0 -c 'AATTGCCCTCTTGTGAT' *.fastq > count/B13610_Rm0.txt
agrep -0 -c 'CCGGGGAATGAAAACAG' *.fastq > count/B13611_Rm0.txt
agrep -0 -c 'TTCTGGCCGAGCCAAGT' *.fastq > count/B13612_Rm0.txt
agrep -0 -c 'CGCGCCAACAACAGGTT' *.fastq > count/B13613_Rm0.txt
agrep -0 -c 'GAATCATCACATCAGTC' *.fastq > count/B13614_Rm0.txt
agrep -0 -c 'GGTCTCACTACTCCGGT' *.fastq > count/B13615_Rm0.txt
agrep -0 -c 'CACACTCACGTAAGGTA' *.fastq > count/B13617_Rm0.txt
agrep -0 -c 'TCGCTTCCTATAAACGC' *.fastq > count/B13618_Rm0.txt
agrep -0 -c 'CCCCTTGATTACCCGGT' *.fastq > count/B13619_Rm0.txt
agrep -0 -c 'ATAGCTTGCGGGCCTCT' *.fastq > count/B13620_Rm0.txt
agrep -0 -c 'ACCGTTATGGGCATGCG' *.fastq > count/B13621_Rm0.txt
agrep -0 -c 'TCGGACTAGATTCTATC' *.fastq > count/B13622_Rm0.txt
agrep -0 -c 'GACGGCGTAGAACTAGT' *.fastq > count/B13624_Rm0.txt
agrep -0 -c 'AACCGTTCTTAGGAGGT' *.fastq > count/B13625_Rm0.txt
agrep -0 -c 'TCCCGGTTATTAACAAG' *.fastq > count/B13626_Rm0.txt
agrep -0 -c 'ATGTGTTCAGCATCCTA' *.fastq > count/B13627_Rm0.txt
agrep -0 -c 'TCAAGTAACGCGTGTAA' *.fastq > count/B13628_Rm0.txt
agrep -0 -c 'CATCTCGTTAAATCGCT' *.fastq > count/B13629_Rm0.txt
agrep -0 -c 'AACTTACCCCACGAGCA' *.fastq > count/B13631_Rm0.txt
agrep -0 -c 'GCGGCTCACACAACACA' *.fastq > count/B13632_Rm0.txt
agrep -0 -c 'TTACAAGTCTGCGTGTA' *.fastq > count/B13633_Rm0.txt
agrep -0 -c 'CATCGTGTTGGCGCGTT' *.fastq > count/B13634_Rm0.txt
agrep -0 -c 'ACACACATTATGTCTGG' *.fastq > count/B13636_Rm0.txt
agrep -0 -c 'TCCGGAATGCACAGGAC' *.fastq > count/B13637_Rm0.txt
agrep -0 -c 'GCGGAAATAGCCCAGTC' *.fastq > count/B13638_Rm0.txt
agrep -0 -c 'TCTGTAGCATAGTTGAC' *.fastq > count/B13640_Rm0.txt
agrep -0 -c 'CGGTGATTCGAGAACCT' *.fastq > count/B13642_Rm0.txt
agrep -0 -c 'GTCTTCTGAACTAGATC' *.fastq > count/B13644_Rm0.txt
agrep -0 -c 'TATTTGAGAGGCTGTCA' *.fastq > count/B13645_Rm0.txt
agrep -0 -c 'TTCCGGTATTGCGAACC' *.fastq > count/B13646_Rm0.txt
agrep -0 -c 'CCCCCGCAATTTGTATT' *.fastq > count/B13647_Rm0.txt
agrep -0 -c 'AGACATCGGGGGTTAGT' *.fastq > count/B13648_Rm0.txt
agrep -0 -c 'TACAATCGCCGTCCATG' *.fastq > count/B13649_Rm0.txt
agrep -0 -c 'CTTCAGGCTCGCTGTGA' *.fastq > count/B13650_Rm0.txt
agrep -0 -c 'TTAATATCCGTACCTGC' *.fastq > count/B13651_Rm0.txt
agrep -0 -c 'GGCCAACGTACGTAACT' *.fastq > count/B13652_Rm0.txt
agrep -0 -c 'GGGCCTATTACTCCACG' *.fastq > count/B13654_Rm0.txt
agrep -0 -c 'TCAAGGTCCCAGTTAGA' *.fastq > count/B13655_Rm0.txt
agrep -0 -c 'ACACTCACCTCTACTTA' *.fastq > count/B13656_Rm0.txt
agrep -0 -c 'TCATATGTACCGTGCCC' *.fastq > count/B13657_Rm0.txt
agrep -0 -c 'GGATGACAAGTGAACCC' *.fastq > count/B13658_Rm0.txt
agrep -0 -c 'GGTGAAGTTGAGACTCG' *.fastq > count/B13659_Rm0.txt
agrep -0 -c 'AACTCGCAGTGAACCTC' *.fastq > count/B13660_Rm0.txt
agrep -0 -c 'GCGAACCCTTTGGGCTA' *.fastq > count/B13661_Rm0.txt
agrep -0 -c 'ACAGTAATTTCGATCGG' *.fastq > count/B13663_Rm0.txt
agrep -0 -c 'CCCTAAATACATTACGC' *.fastq > count/B13664_Rm0.txt
agrep -0 -c 'TACACGACGCTGCACCT' *.fastq > count/B13665_Rm0.txt
agrep -0 -c 'CGCGTTCAGTGTATGCT' *.fastq > count/B13666_Rm0.txt
agrep -0 -c 'TCTAACGTCTTGCAGTC' *.fastq > count/B13667_Rm0.txt
agrep -0 -c 'AGAGCCCTTGAGAGTTA' *.fastq > count/B13668_Rm0.txt
agrep -0 -c 'AAGGGCTTAGTATCAGG' *.fastq > count/B13669_Rm0.txt
agrep -0 -c 'CTAACGATTCACTCATG' *.fastq > count/B13671_Rm0.txt
agrep -0 -c 'TAACCTGAGTTGTCTCA' *.fastq > count/B13672_Rm0.txt
agrep -0 -c 'GGTCAAGACAGGCTAGG' *.fastq > count/B13673_Rm0.txt
agrep -0 -c 'TGTTCAGACTACTTGAC' *.fastq > count/B13674_Rm0.txt
agrep -0 -c 'ACTCGCTGATCGAAGTC' *.fastq > count/B13675_Rm0.txt
agrep -0 -c 'TCCAGATAGTGGATAGC' *.fastq > count/B13677_Rm0.txt
agrep -0 -c 'TGGGAACAACCTACGGT' *.fastq > count/B13678_Rm0.txt
agrep -0 -c 'GCTACCCATGTGTTCAT' *.fastq > count/B13680_Rm0.txt
agrep -0 -c 'CACTAGTGTAAATGGGC' *.fastq > count/B13681_Rm0.txt
agrep -0 -c 'CAAGTCAGTCACGTGCC' *.fastq > count/B13682_Rm0.txt
agrep -0 -c 'CAATGTCGACGCGCACA' *.fastq > count/B13683_Rm0.txt
agrep -0 -c 'GGTGCTGGTCCTGATTA' *.fastq > count/B13684_Rm0.txt
agrep -0 -c 'AATAGGCCCGCTAACAC' *.fastq > count/B13685_Rm0.txt
agrep -0 -c 'ATCAAGGATCAACTGAC' *.fastq > count/B13686_Rm0.txt
agrep -0 -c 'TAGCTCTCCCGCGAATC' *.fastq > count/B13687_Rm0.txt
agrep -0 -c 'GCACACCTATGCAGATA' *.fastq > count/B13689_Rm0.txt
agrep -0 -c 'TCAAACACTCCATGACC' *.fastq > count/B13691_Rm0.txt
agrep -0 -c 'GCTTCTGATATACGTGC' *.fastq > count/B13692_Rm0.txt
agrep -0 -c 'GAGCTGGCTATAACCTC' *.fastq > count/B13693_Rm0.txt
agrep -0 -c 'GCCAAATTTATCCCCAA' *.fastq > count/B13695_Rm0.txt
agrep -0 -c 'AATCGTGGGTTGTGGGC' *.fastq > count/B13697_Rm0.txt
agrep -0 -c 'CCATATCCAAAATCCAG' *.fastq > count/B13698_Rm0.txt
agrep -0 -c 'TGGTCAATTGGGGCCTG' *.fastq > count/B13699_Rm0.txt
agrep -0 -c 'GAACGTACATGCTGAAT' *.fastq > count/B13700_Rm0.txt
agrep -0 -c 'TCTTATAACCTGGGTGG' *.fastq > count/B13701_Rm0.txt
agrep -0 -c 'CTTGCATTGTGGCGGTC' *.fastq > count/B13702_Rm0.txt
agrep -0 -c 'TGGACTCTATAGAGAAG' *.fastq > count/B13703_Rm0.txt
agrep -0 -c 'TGTTTCCTCAACGTGAG' *.fastq > count/B13704_Rm0.txt
agrep -0 -c 'CGTCGAAGTGTGTAGGC' *.fastq > count/B13705_Rm0.txt
agrep -0 -c 'ATTCGTCTCGCTTGACG' *.fastq > count/B13706_Rm0.txt
agrep -0 -c 'ATGGTGGTAATGCGTTA' *.fastq > count/B13708_Rm0.txt
agrep -0 -c 'TAGGGAACTTCGATTGG' *.fastq > count/B13709_Rm0.txt
agrep -0 -c 'ATCTGAGTGCCTTCTTA' *.fastq > count/B13710_Rm0.txt
agrep -0 -c 'AGTACGGAGAACATCCT' *.fastq > count/B13711_Rm0.txt
agrep -0 -c 'TTCGGACTGACGTCTGC' *.fastq > count/B13712_Rm0.txt
agrep -0 -c 'TCTCCAGGTATTTCACG' *.fastq > count/B13714_Rm0.txt
agrep -0 -c 'CGCACTAGAGATTTTCT' *.fastq > count/B13715_Rm0.txt
agrep -0 -c 'CGTTGTCGGTCTGTGGT' *.fastq > count/B13716_Rm0.txt
agrep -0 -c 'TCCCGACTGGAAGCATC' *.fastq > count/B13717_Rm0.txt
agrep -0 -c 'ACATCGGGGTAATGTGC' *.fastq > count/B13719_Rm0.txt
agrep -0 -c 'AATAACTCGGAGCCTGC' *.fastq > count/B13720_Rm0.txt
agrep -0 -c 'CGGATTAAGGACGTGCC' *.fastq > count/B13721_Rm0.txt
agrep -0 -c 'CTAAGCTCGAACGATCA' *.fastq > count/B13722_Rm0.txt
agrep -0 -c 'AAACCAACGCGCTATGA' *.fastq > count/B13723_Rm0.txt
agrep -0 -c 'CTGTCTCAGGATGAGGC' *.fastq > count/B13725_Rm0.txt
agrep -0 -c 'CGACGAACAAGGTGCGA' *.fastq > count/B13726_Rm0.txt
agrep -0 -c 'TGAGCAAGAGATAGCTC' *.fastq > count/B13727_Rm0.txt
agrep -0 -c 'TTTCGACAAGTTAACGG' *.fastq > count/B13728_Rm0.txt
agrep -0 -c 'TCGTTAGCTGAAGAGAG' *.fastq > count/B13729_Rm0.txt
agrep -0 -c 'TTGCCGCCGAAGTTTCA' *.fastq > count/B13730_Rm0.txt
agrep -0 -c 'GCGGCTGCTTAGGCATA' *.fastq > count/B13732_Rm0.txt
agrep -0 -c 'GTACATAATACGGTCTC' *.fastq > count/B13733_Rm0.txt
agrep -0 -c 'ACTTGTCCCATATATCC' *.fastq > count/B13734_Rm0.txt
agrep -0 -c 'CAAGTCTACGGTTATGT' *.fastq > count/B13735_Rm0.txt
agrep -0 -c 'TTGAACAACGTGGCTAG' *.fastq > count/B13736_Rm0.txt
agrep -0 -c 'CCTCGGACATAGGGACA' *.fastq > count/B13739_Rm0.txt
agrep -0 -c 'GCTGTAGGTACGGCGAT' *.fastq > count/B13740_Rm0.txt
agrep -0 -c 'TCGCAGTGAAGAAACCG' *.fastq > count/B13741_Rm0.txt
agrep -0 -c 'TGACACTCACGTACAGT' *.fastq > count/B13742_Rm0.txt
agrep -0 -c 'ATGTGCTGTTAGACCTC' *.fastq > count/B13744_Rm0.txt
agrep -0 -c 'CTCGTTGCCTTAGGAAG' *.fastq > count/B13745_Rm0.txt
agrep -0 -c 'CATACGCGAATTCGACG' *.fastq > count/B13746_Rm0.txt
agrep -0 -c 'GAGTTGTTTCTAGCGAT' *.fastq > count/B13747_Rm0.txt
agrep -0 -c 'TATTCTGCGCAGAAGAT' *.fastq > count/B13748_Rm0.txt
agrep -0 -c 'CGGGATGCAATGGGGAT' *.fastq > count/B13749_Rm0.txt
agrep -0 -c 'TCAATGGAGCGTGGCTC' *.fastq > count/B13750_Rm0.txt
agrep -0 -c 'CTCAGATTTTCGAACTG' *.fastq > count/B13751_Rm0.txt
agrep -0 -c 'GGCGTGCTCAGTTTCTA' *.fastq > count/B13753_Rm0.txt
agrep -0 -c 'CAGTCTTACTCCTGGTC' *.fastq > count/B13754_Rm0.txt
agrep -0 -c 'GCGTGAATGGAACGAAT' *.fastq > count/B13756_Rm0.txt
agrep -0 -c 'GACTCAGTTCGACTACC' *.fastq > count/B13758_Rm0.txt
agrep -0 -c 'GCGCCCTCTAAAATACG' *.fastq > count/B13760_Rm0.txt
agrep -0 -c 'ACGTAAGGGCGATAACT' *.fastq > count/B13762_Rm0.txt
agrep -0 -c 'TACCCTTAAAGGCTACA' *.fastq > count/B13763_Rm0.txt
agrep -0 -c 'AGATTGCTGCCTGGGTC' *.fastq > count/B13764_Rm0.txt
agrep -0 -c 'TCAGTACTGGAGCAAGT' *.fastq > count/B13765_Rm0.txt
agrep -0 -c 'AAGGTGGCAATACAAGT' *.fastq > count/B13766_Rm0.txt
agrep -0 -c 'AAAAGTCGGAACTCATG' *.fastq > count/B13767_Rm0.txt
agrep -0 -c 'ACAATAGTGATCAGGAG' *.fastq > count/B13768_Rm0.txt
agrep -0 -c 'AAGCCCGCGCCAATTAG' *.fastq > count/B13770_Rm0.txt
agrep -0 -c 'ACACCTAGGCTTTCTAG' *.fastq > count/B13771_Rm0.txt
agrep -0 -c 'AAAAGAGGTGTCAGCCG' *.fastq > count/B13772_Rm0.txt
agrep -0 -c 'ACTGACCAGCAAGCCAT' *.fastq > count/B13773_Rm0.txt
agrep -0 -c 'CATCGTGACCCTAGCTC' *.fastq > count/B13774_Rm0.txt
agrep -0 -c 'CCGTGAACACACCTACT' *.fastq > count/B13775_Rm0.txt
agrep -0 -c 'TCAACAGGCGGACTACC' *.fastq > count/B13776_Rm0.txt
agrep -0 -c 'TTCAGTACCAGCGCTTG' *.fastq > count/B13778_Rm0.txt
agrep -0 -c 'GGGGTATTGACGTGCTC' *.fastq > count/B13780_Rm0.txt
agrep -0 -c 'AACGGCTGGGAACTGAG' *.fastq > count/B13782_Rm0.txt
agrep -0 -c 'TGGTAGGACCAGTTTCG' *.fastq > count/B13783_Rm0.txt
agrep -0 -c 'TGCCCGTGTGGACTCTA' *.fastq > count/B13784_Rm0.txt
agrep -0 -c 'TGGATCGGGATTATTGG' *.fastq > count/B13785_Rm0.txt
agrep -0 -c 'ACCGCGGGTAGATTTGC' *.fastq > count/B13788_Rm0.txt
agrep -0 -c 'GGCCTCATCGGATCAAG' *.fastq > count/B13789_Rm0.txt
agrep -0 -c 'CGCGGGATACGAATAAT' *.fastq > count/B13791_Rm0.txt
agrep -0 -c 'GAGTAAGGAGAGCCTAC' *.fastq > count/B13792_Rm0.txt
agrep -0 -c 'GTACAGGGGTGATATCT' *.fastq > count/B13793_Rm0.txt
agrep -0 -c 'GACTCTATATGAGGACT' *.fastq > count/B13794_Rm0.txt
agrep -0 -c 'GCCTAGATGCATAAACA' *.fastq > count/B13795_Rm0.txt
agrep -0 -c 'TCACGATGATGACCTTA' *.fastq > count/B13796_Rm0.txt
agrep -0 -c 'GGACATCGTCAGTTCGA' *.fastq > count/B13797_Rm0.txt
agrep -0 -c 'CCCCGTTTCACTAATGG' *.fastq > count/B13798_Rm0.txt
agrep -0 -c 'AAGTGCGAAATGAGGCT' *.fastq > count/B13799_Rm0.txt
agrep -0 -c 'GTCGAAACGTGTTGCGA' *.fastq > count/B13800_Rm0.txt
agrep -0 -c 'TCACCACTTGATAGCCA' *.fastq > count/B13802_Rm0.txt
agrep -0 -c 'CGGTACTCGCCATTCTG' *.fastq > count/B13803_Rm0.txt
agrep -0 -c 'TCAGGCTGGACGGTCTT' *.fastq > count/B13804_Rm0.txt
agrep -0 -c 'ATTTAGGCTGCGCGGTG' *.fastq > count/B13805_Rm0.txt
agrep -0 -c 'AACGCGGCTGATTGTGT' *.fastq > count/B13806_Rm0.txt
agrep -0 -c 'CGGCCTTTTAGTCTAGG' *.fastq > count/B13807_Rm0.txt
agrep -0 -c 'GTGTCGTCGTATCAGCA' *.fastq > count/B13808_Rm0.txt
agrep -0 -c 'ATGCGCGTACCAACTGA' *.fastq > count/B13809_Rm0.txt
agrep -0 -c 'ACCTGAAGCCTTCTTAT' *.fastq > count/B13810_Rm0.txt
agrep -0 -c 'TGGTGGCTTACATTTCG' *.fastq > count/B13811_Rm0.txt
agrep -0 -c 'CAGAACACGCCTGAGTA' *.fastq > count/B13813_Rm0.txt
agrep -0 -c 'ATCCGATCATCCCTAAG' *.fastq > count/B13815_Rm0.txt
agrep -0 -c 'TATTCTCGCAGTGACTA' *.fastq > count/B13816_Rm0.txt
agrep -0 -c 'ATCATCCGCTAGAGCGC' *.fastq > count/B13817_Rm0.txt
agrep -0 -c 'AATGGCGCTAGCAAGGC' *.fastq > count/B13819_Rm0.txt
agrep -0 -c 'CGAGTATTTCTATGTCG' *.fastq > count/B13820_Rm0.txt
agrep -0 -c 'GCATAGTCGAATTACCG' *.fastq > count/B13821_Rm0.txt
agrep -0 -c 'TAGGCTATAACTCGCAA' *.fastq > count/B13823_Rm0.txt
agrep -0 -c 'TCCAGACACTCCCCGTA' *.fastq > count/B13825_Rm0.txt
agrep -0 -c 'CCCTCGTCCAGAACAGT' *.fastq > count/B13826_Rm0.txt
agrep -0 -c 'CTTACATCTGGATCGCG' *.fastq > count/B13827_Rm0.txt
agrep -0 -c 'AACGGTAGAGCGAAACT' *.fastq > count/B13828_Rm0.txt
agrep -0 -c 'TCCAATGGCGTGTCTGT' *.fastq > count/B13830_Rm0.txt
agrep -0 -c 'TCATAATGTTACGAGCG' *.fastq > count/B13833_Rm0.txt
agrep -0 -c 'ACTACTAAAACCCTACG' *.fastq > count/B13834_Rm0.txt
agrep -0 -c 'GTACGCACTTGTCCTCC' *.fastq > count/B13835_Rm0.txt
agrep -0 -c 'ACCGATCAGACCGCCTT' *.fastq > count/B13836_Rm0.txt
agrep -0 -c 'TGGGCGATTCGGCTTTA' *.fastq > count/B13838_Rm0.txt
agrep -0 -c 'CCCGTAATCAGCCCACT' *.fastq > count/B13839_Rm0.txt
agrep -0 -c 'TCATCGGAGAACCCAAC' *.fastq > count/B13840_Rm0.txt
agrep -0 -c 'TACTGTGCTGCCGATAT' *.fastq > count/B13841_Rm0.txt
agrep -0 -c 'CTGAACAAGGCCCCTTG' *.fastq > count/B13842_Rm0.txt
agrep -0 -c 'AGGACGCAAACACCGAA' *.fastq > count/B13844_Rm0.txt
agrep -0 -c 'CAAAGAGCCAAGCAGAC' *.fastq > count/B13845_Rm0.txt
agrep -0 -c 'GCCGACGAAACGGTTTG' *.fastq > count/B13847_Rm0.txt
agrep -0 -c 'TTATCGTAAGATGGACG' *.fastq > count/B13848_Rm0.txt
agrep -0 -c 'TTACCATGGACAGGCGC' *.fastq > count/B13849_Rm0.txt
agrep -0 -c 'ACCATGTGAAAGGCCGA' *.fastq > count/B13850_Rm0.txt
agrep -0 -c 'GCGTGAAATTTAGTTGC' *.fastq > count/B13851_Rm0.txt
agrep -0 -c 'ACGCGCATGTAAACAGA' *.fastq > count/B13852_Rm0.txt
agrep -0 -c 'CGGTACTCAACCAGACC' *.fastq > count/B13853_Rm0.txt
agrep -0 -c 'TCTGAGTCGCGAACCCT' *.fastq > count/B13854_Rm0.txt
agrep -0 -c 'ACAAATTGCGACAGAAC' *.fastq > count/B13855_Rm0.txt
agrep -0 -c 'AAACCGTCGGACACGGT' *.fastq > count/B13856_Rm0.txt
agrep -0 -c 'TTCGTTCCTCTAACTCA' *.fastq > count/B13857_Rm0.txt
agrep -0 -c 'ATCTCGTGCGACAAGGT' *.fastq > count/B13858_Rm0.txt
agrep -0 -c 'GGGGTCCTGGAAGTGAT' *.fastq > count/B13860_Rm0.txt
agrep -0 -c 'GTGGTACTTCCCAGAAC' *.fastq > count/B13861_Rm0.txt
agrep -0 -c 'CAGATGGTCTTAGAGAA' *.fastq > count/B13862_Rm0.txt
agrep -0 -c 'GCAATCCGAGGTACGGT' *.fastq > count/B13863_Rm0.txt
agrep -0 -c 'TTGGTGCACGTAACTGC' *.fastq > count/B13864_Rm0.txt
agrep -0 -c 'TAGCGTGTCTGCCTTAT' *.fastq > count/B13865_Rm0.txt
agrep -0 -c 'AGCTGCGCCGTATACTC' *.fastq > count/B13867_Rm0.txt
agrep -0 -c 'TTGCTTCGTCTAACAAC' *.fastq > count/B13868_Rm0.txt
agrep -0 -c 'CTGTGGATCGTCTCGAG' *.fastq > count/B13870_Rm0.txt
agrep -0 -c 'CCGGCTTATCCCACTTA' *.fastq > count/B13871_Rm0.txt
agrep -0 -c 'CTGAATGAAGAATCGTG' *.fastq > count/B13872_Rm0.txt
agrep -0 -c 'CTGGGACACCGAGTACA' *.fastq > count/B13873_Rm0.txt
agrep -0 -c 'AGATTTGCCTGCATTGG' *.fastq > count/B13874_Rm0.txt
agrep -0 -c 'TATGATTCGGCTGGGAC' *.fastq > count/B13875_Rm0.txt
agrep -0 -c 'AACAAATTCGCGCACGT' *.fastq > count/B13876_Rm0.txt
agrep -0 -c 'TCGCTTATGAGTACCAC' *.fastq > count/B13877_Rm0.txt
agrep -0 -c 'GGCATGGTATTATCGGT' *.fastq > count/B13878_Rm0.txt
agrep -0 -c 'TTGCGCATAGGAATCGA' *.fastq > count/B13879_Rm0.txt
agrep -0 -c 'CTATTGCCCGCACGACA' *.fastq > count/B13881_Rm0.txt
agrep -0 -c 'CAAGCCGGACTATTGAC' *.fastq > count/B13884_Rm0.txt
agrep -0 -c 'TGTTAGACGGCCACCTG' *.fastq > count/B13885_Rm0.txt
agrep -0 -c 'AGTTTCCCGCTGGTACT' *.fastq > count/B13886_Rm0.txt
agrep -0 -c 'AGACGACCATTCTGTCA' *.fastq > count/B13887_Rm0.txt
agrep -0 -c 'AGACGAAACTAGCAGAA' *.fastq > count/B13888_Rm0.txt
agrep -0 -c 'TAGAGGCAGTCAGTCCG' *.fastq > count/B13889_Rm0.txt
agrep -0 -c 'GCGTAGTAGCTTGTTCT' *.fastq > count/B13890_Rm0.txt
agrep -0 -c 'ATAAGGCTCGCTTTTCT' *.fastq > count/B13891_Rm0.txt
agrep -0 -c 'TAAAGCTTCCTGCAGGT' *.fastq > count/B13893_Rm0.txt
agrep -0 -c 'GATAATCGGGACTGCCA' *.fastq > count/B13894_Rm0.txt
agrep -0 -c 'AGCTCGAAAGTACGACT' *.fastq > count/B13895_Rm0.txt
agrep -0 -c 'CAAACTGATCCGTGTGG' *.fastq > count/B13896_Rm0.txt
agrep -0 -c 'GGAGCTCCTCGACATAA' *.fastq > count/B13899_Rm0.txt
agrep -0 -c 'AGCCGATACATGTCATC' *.fastq > count/B13900_Rm0.txt
agrep -0 -c 'TATGGAGATTGCGCCGA' *.fastq > count/B13902_Rm0.txt
agrep -0 -c 'TAAAACGTCGAAGTGGT' *.fastq > count/B13906_Rm0.txt
agrep -0 -c 'CCCGACATACCGAACGT' *.fastq > count/B13907_Rm0.txt
agrep -0 -c 'TGTCCCTGTCAAAAGTC' *.fastq > count/B13908_Rm0.txt
agrep -0 -c 'GACTTTTAGAGTCTGTC' *.fastq > count/B13909_Rm0.txt
agrep -0 -c 'GTTAGGTCCTGATTGCA' *.fastq > count/B13910_Rm0.txt
agrep -0 -c 'GAATCCCAGAGACATCC' *.fastq > count/B13912_Rm0.txt
agrep -0 -c 'CAAAACACGAACCCTAG' *.fastq > count/B13913_Rm0.txt
agrep -0 -c 'TTCTGATTAGACGGGAT' *.fastq > count/B13914_Rm0.txt
agrep -0 -c 'GGCAAATGTAAGCTCCC' *.fastq > count/B13915_Rm0.txt
agrep -0 -c 'AAGACCAAGCCGTCAGC' *.fastq > count/B13916_Rm0.txt
agrep -0 -c 'CTTGGGCTACGAGTTCC' *.fastq > count/B13917_Rm0.txt
agrep -0 -c 'AGAAATGGTTCCCCTCC' *.fastq > count/B13918_Rm0.txt
agrep -0 -c 'GAACCGTAAAACATGTG' *.fastq > count/B13919_Rm0.txt
agrep -0 -c 'TCTCACTCACAAGGGCG' *.fastq > count/B13920_Rm0.txt
agrep -0 -c 'GAGCGATTAGACTTTAG' *.fastq > count/B13921_Rm0.txt
agrep -0 -c 'AGCTCAGAGCAATGGAC' *.fastq > count/B13922_Rm0.txt
agrep -0 -c 'ATCAAGTTAGCTAGGAC' *.fastq > count/B13923_Rm0.txt
agrep -0 -c 'TTAGTCTGCTTCAGGCC' *.fastq > count/B13924_Rm0.txt
agrep -0 -c 'AAACCCCTCTTAACAGA' *.fastq > count/B13925_Rm0.txt
agrep -0 -c 'CGATCACTTAAAGCTCT' *.fastq > count/B13927_Rm0.txt
agrep -0 -c 'GAAATGTAGCGGGCGTT' *.fastq > count/B13928_Rm0.txt
agrep -0 -c 'CCTAATAAACAACGCTC' *.fastq > count/B13930_Rm0.txt
agrep -0 -c 'GGCCAAACCGCACATAT' *.fastq > count/B13931_Rm0.txt
agrep -0 -c 'CGCTAGTAACGAAACTA' *.fastq > count/B13932_Rm0.txt
agrep -0 -c 'CCAGAAGACTATTACAC' *.fastq > count/B13933_Rm0.txt
agrep -0 -c 'CACTAACGATCGTGAGA' *.fastq > count/B13934_Rm0.txt
agrep -0 -c 'AAACATTTCCGAGCATC' *.fastq > count/B13936_Rm0.txt
agrep -0 -c 'CACTCTATTGTTACCTC' *.fastq > count/B13938_Rm0.txt
agrep -0 -c 'ATAATGGCTAAACCGGC' *.fastq > count/B13939_Rm0.txt
agrep -0 -c 'AACATTGTACATAGGCC' *.fastq > count/B13940_Rm0.txt
agrep -0 -c 'TTTCATTGACGTAGTCG' *.fastq > count/B13941_Rm0.txt
agrep -0 -c 'TCGATTCCCAATAGTGA' *.fastq > count/B13942_Rm0.txt
agrep -0 -c 'GTTGATCTGATTCACTG' *.fastq > count/B13945_Rm0.txt
agrep -0 -c 'TAAGCCAAGGCCTTATC' *.fastq > count/B13947_Rm0.txt
agrep -0 -c 'TGAGAAGTATCGTCCTC' *.fastq > count/B13949_Rm0.txt
agrep -0 -c 'GCGAATCACCCTAGTGC' *.fastq > count/B13950_Rm0.txt
agrep -0 -c 'CACGAAGATTCTGCACC' *.fastq > count/B13951_Rm0.txt
agrep -0 -c 'CGAACCTTGTGTACTTG' *.fastq > count/B13952_Rm0.txt
agrep -0 -c 'TTAGCCGAACACGCCAA' *.fastq > count/B13953_Rm0.txt
agrep -0 -c 'TCTATTCATGGGTGCCA' *.fastq > count/B13954_Rm0.txt
agrep -0 -c 'TACGCCCCGCGAATTAC' *.fastq > count/B13955_Rm0.txt
agrep -0 -c 'TCAAGCGGATCTTATAG' *.fastq > count/B13956_Rm0.txt
agrep -0 -c 'CACTTGTCTACTGGACG' *.fastq > count/B13959_Rm0.txt
agrep -0 -c 'AAATGATTTCCCGGCGG' *.fastq > count/B13960_Rm0.txt
agrep -0 -c 'GCGGGTCTAGATTACGG' *.fastq > count/B13961_Rm0.txt
agrep -0 -c 'GAGGTTAAACGGCGTGT' *.fastq > count/B13962_Rm0.txt
agrep -0 -c 'AATTTTGGGGTCCTCTC' *.fastq > count/B13964_Rm0.txt
agrep -0 -c 'GCCGTTACTCGTCATCC' *.fastq > count/B13965_Rm0.txt
agrep -0 -c 'CTCGATCACGAGCAAGG' *.fastq > count/B13966_Rm0.txt
agrep -0 -c 'TTCCGCAGTATGCACCC' *.fastq > count/B13967_Rm0.txt
agrep -0 -c 'GACGAGAGATCGGTTGA' *.fastq > count/B13968_Rm0.txt
agrep -0 -c 'CCATCACCTTGATTCAC' *.fastq > count/B13970_Rm0.txt
agrep -0 -c 'GAGCACAACCTAAGATG' *.fastq > count/B13971_Rm0.txt
agrep -0 -c 'GTAGGTGATAAAGGACG' *.fastq > count/B13972_Rm0.txt
agrep -0 -c 'CTGGCATCATTCGGATT' *.fastq > count/B13973_Rm0.txt
agrep -0 -c 'AGAGTGGCCTGCTCACA' *.fastq > count/B13974_Rm0.txt
agrep -0 -c 'GCACACAACCTAACGGT' *.fastq > count/B13975_Rm0.txt
agrep -0 -c 'ACGTCGTTTATCGAGCT' *.fastq > count/B13977_Rm0.txt
agrep -0 -c 'TGTCAGCCCGGAGCATT' *.fastq > count/B13979_Rm0.txt
agrep -0 -c 'TCGGAAACGAACCACTT' *.fastq > count/B13980_Rm0.txt
agrep -0 -c 'TCGCGGAAAAGAAAGCG' *.fastq > count/B13984_Rm0.txt
agrep -0 -c 'ATCCAATAGCGTTTCTC' *.fastq > count/B13985_Rm0.txt
agrep -0 -c 'CACCTTACCAGCGGAGA' *.fastq > count/B13986_Rm0.txt
agrep -0 -c 'AGGTTAATAGGTAGCGA' *.fastq > count/B13987_Rm0.txt
agrep -0 -c 'AGTCCTGGCCCTATCAT' *.fastq > count/B13989_Rm0.txt
agrep -0 -c 'GCCGAAGACCGAACACT' *.fastq > count/B13990_Rm0.txt
agrep -0 -c 'TTGGGTGAACGAGAATG' *.fastq > count/B13993_Rm0.txt
agrep -0 -c 'GAGCTACTCCTACTGAA' *.fastq > count/B13994_Rm0.txt
agrep -0 -c 'CTCGGCCGTGCTTTTTG' *.fastq > count/B13995_Rm0.txt
agrep -0 -c 'TTATCTGGCCAGGGACA' *.fastq > count/B13996_Rm0.txt
agrep -0 -c 'AGTGTTCTCGGGTATAT' *.fastq > count/B13997_Rm0.txt
agrep -0 -c 'AATGCATCCCTGGCACG' *.fastq > count/B14001_Rm0.txt
agrep -0 -c 'CTCTACTTTGGCAGTTG' *.fastq > count/B14002_Rm0.txt
agrep -0 -c 'GACGATCACGACGAGTC' *.fastq > count/B14003_Rm0.txt
agrep -0 -c 'ACAGTATAATGGTGACC' *.fastq > count/B14004_Rm0.txt
agrep -0 -c 'CACCCCCTACTAGTCAC' *.fastq > count/B14005_Rm0.txt
agrep -0 -c 'CGCACAAGTTACTTCTA' *.fastq > count/B14006_Rm0.txt
agrep -0 -c 'AGACGGTTTCCAGGCCA' *.fastq > count/B14007_Rm0.txt
agrep -0 -c 'TCGGTGTCGACCGTATG' *.fastq > count/B14008_Rm0.txt
agrep -0 -c 'CCTAACTGATGGGAGGC' *.fastq > count/B14009_Rm0.txt
agrep -0 -c 'GGAACAACTATTCGGAT' *.fastq > count/B14010_Rm0.txt
agrep -0 -c 'TGCGAGCCTACTTTTTA' *.fastq > count/B14013_Rm0.txt
agrep -0 -c 'TGTGCGATGCCTAGGAT' *.fastq > count/B14014_Rm0.txt
agrep -0 -c 'GATCCGGCCTTTAAATA' *.fastq > count/B14015_Rm0.txt
agrep -0 -c 'TGATACGTCAATCGCGA' *.fastq > count/B14016_Rm0.txt
agrep -0 -c 'TGCGCTCTGTCTACATT' *.fastq > count/B14017_Rm0.txt
agrep -0 -c 'ACTGGTCTTCTCTACGC' *.fastq > count/B14018_Rm0.txt
agrep -0 -c 'AACGGTAGGGTTTATAG' *.fastq > count/B14019_Rm0.txt
agrep -0 -c 'CACTACTGGCTGAATGC' *.fastq > count/B14020_Rm0.txt
agrep -0 -c 'TTTTCGACCTACACCAG' *.fastq > count/B14021_Rm0.txt
agrep -0 -c 'CTCAGAGCGACCCATTG' *.fastq > count/B14023_Rm0.txt
agrep -0 -c 'GCGATGATTCTACAGCT' *.fastq > count/B14024_Rm0.txt
agrep -0 -c 'TAAGATCGCGCAGGGAA' *.fastq > count/B14025_Rm0.txt
agrep -0 -c 'ATGAGCACCTAACAAGG' *.fastq > count/B14027_Rm0.txt
agrep -0 -c 'TCCTAGCGTACTGCACA' *.fastq > count/B14028_Rm0.txt
agrep -0 -c 'ATGCCTACCATACTACC' *.fastq > count/B14029_Rm0.txt
agrep -0 -c 'TCGCGGAATGTACCTGA' *.fastq > count/B14030_Rm0.txt
agrep -0 -c 'TGGGCCAAAACGACTGC' *.fastq > count/B14032_Rm0.txt
agrep -0 -c 'CCAGCTCTGTACACGTG' *.fastq > count/B14033_Rm0.txt
agrep -0 -c 'CCTGCACACCACTACTA' *.fastq > count/B14035_Rm0.txt
agrep -0 -c 'CCATCATCATTCGCCCG' *.fastq > count/B14036_Rm0.txt
agrep -0 -c 'CATAACACGGCGTATAT' *.fastq > count/B14037_Rm0.txt
agrep -0 -c 'GATGTGGCTAGGAAATA' *.fastq > count/B14038_Rm0.txt
agrep -0 -c 'AGTTCGTGCGCCATAAG' *.fastq > count/B14039_Rm0.txt
agrep -0 -c 'CGCCGGTTAATTTTCTA' *.fastq > count/B14040_Rm0.txt
agrep -0 -c 'TAATCCGTCATCTCACG' *.fastq > count/B14041_Rm0.txt
agrep -0 -c 'ATCGAGCGTCATAGCTC' *.fastq > count/B14042_Rm0.txt
agrep -0 -c 'GCTTCTAGGTTCTAGAG' *.fastq > count/B14044_Rm0.txt
agrep -0 -c 'CGGTCACAATGCATCCC' *.fastq > count/B14045_Rm0.txt
agrep -0 -c 'ATCTGGGCTGTTGGTCT' *.fastq > count/B14046_Rm0.txt
agrep -0 -c 'TCTCCGCAGTGAGCTAT' *.fastq > count/B14048_Rm0.txt
agrep -0 -c 'GTCTTGCGTAGCCGGAA' *.fastq > count/B14050_Rm0.txt
agrep -0 -c 'ATCTGCGAATGGGCAAC' *.fastq > count/B14051_Rm0.txt
agrep -0 -c 'AGTACATCCTTTGTTGG' *.fastq > count/B14052_Rm0.txt
agrep -0 -c 'TTACAGATACAGGACGA' *.fastq > count/B14053_Rm0.txt
agrep -0 -c 'TTTCAGCCCCGTTCCGA' *.fastq > count/B14054_Rm0.txt
agrep -0 -c 'GCGAACTAGACAGAGAT' *.fastq > count/B14055_Rm0.txt
agrep -0 -c 'GGATATAAGGGAGCCAA' *.fastq > count/B14057_Rm0.txt
agrep -0 -c 'ATAGCACGAGGGAATTA' *.fastq > count/B14058_Rm0.txt
agrep -0 -c 'GAAAACTTAGAGGCAGG' *.fastq > count/B14059_Rm0.txt
agrep -0 -c 'GGGTTCTTATAAGACAC' *.fastq > count/B14060_Rm0.txt
agrep -0 -c 'GACCTTGAGGCTATGTC' *.fastq > count/B14061_Rm0.txt
agrep -0 -c 'GGATGTAGTCTGGTAGA' *.fastq > count/B14063_Rm0.txt
agrep -0 -c 'GAGCGTACTAGTCAGGC' *.fastq > count/B14064_Rm0.txt
agrep -0 -c 'TAACCCCAAACCCCATG' *.fastq > count/B14065_Rm0.txt
agrep -0 -c 'TCGTGCCACGTGATCGT' *.fastq > count/B14067_Rm0.txt
agrep -0 -c 'TCGGTCGATTAACTATG' *.fastq > count/B14068_Rm0.txt
agrep -0 -c 'TGCTGATTACGTTTACC' *.fastq > count/B14069_Rm0.txt
agrep -0 -c 'CCTGTGCTTGCGACATG' *.fastq > count/B14070_Rm0.txt
agrep -0 -c 'CTCTATGAGGCATCCGG' *.fastq > count/B14071_Rm0.txt
agrep -0 -c 'GCAGTAGCCTAATTCGT' *.fastq > count/B14072_Rm0.txt
agrep -0 -c 'ATGGTGTCATCGACAAC' *.fastq > count/B14073_Rm0.txt
agrep -0 -c 'GGTGATCCGATTAGAAC' *.fastq > count/B14074_Rm0.txt
agrep -0 -c 'AGAACAACGCAGTTGTT' *.fastq > count/B14075_Rm0.txt
agrep -0 -c 'GTTTAGCCTAACTGACA' *.fastq > count/B14077_Rm0.txt
agrep -0 -c 'TATCATATAGACCCGCA' *.fastq > count/B14078_Rm0.txt
agrep -0 -c 'TTGTGCATGGGGTGTAG' *.fastq > count/B14079_Rm0.txt
agrep -0 -c 'CAGAAGTGTGTTATTGC' *.fastq > count/B14080_Rm0.txt
agrep -0 -c 'TCGCTGGGGTTTCACGT' *.fastq > count/B14081_Rm0.txt
agrep -0 -c 'AGTTGGCAGGTTTCGAC' *.fastq > count/B14082_Rm0.txt
agrep -0 -c 'CATGGGCTCATGAGAGC' *.fastq > count/B14083_Rm0.txt
agrep -0 -c 'CCTGACTTTTATTCCAG' *.fastq > count/B14084_Rm0.txt
agrep -0 -c 'TTTACTACCCAGAAGTC' *.fastq > count/B14085_Rm0.txt
agrep -0 -c 'GGCAGTACACTTGGTCA' *.fastq > count/B14086_Rm0.txt
agrep -0 -c 'CGACGTTCGTTTATCTT' *.fastq > count/B14088_Rm0.txt
agrep -0 -c 'ATCCCATTAACACAGCC' *.fastq > count/B14089_Rm0.txt
agrep -0 -c 'GCGTCTTACCTACTTCA' *.fastq > count/B14090_Rm0.txt
agrep -0 -c 'AGTCATTCACGGATTGT' *.fastq > count/B14092_Rm0.txt
agrep -0 -c 'GTATTTGTGAACTGGGC' *.fastq > count/B14093_Rm0.txt
agrep -0 -c 'ATCGCGAGGTTCTCTGG' *.fastq > count/B14094_Rm0.txt
agrep -0 -c 'ATTCCGAAATGGGGTCG' *.fastq > count/B14095_Rm0.txt
agrep -0 -c 'ACGCTCGTTGTAGGGAG' *.fastq > count/B14096_Rm0.txt
agrep -0 -c 'ACGCTCCATCGTCCGAA' *.fastq > count/B14097_Rm0.txt
agrep -0 -c 'TGAAGTTCGGTGATAGT' *.fastq > count/B14098_Rm0.txt
agrep -0 -c 'CGCTAGTAGGAGGATAG' *.fastq > count/B14102_Rm0.txt
agrep -0 -c 'TCCCCATACCGTCGAAC' *.fastq > count/B14104_Rm0.txt
agrep -0 -c 'CATGTTTCAGTAGAGCA' *.fastq > count/B14105_Rm0.txt
agrep -0 -c 'ACGACGATACACCCGTT' *.fastq > count/B14107_Rm0.txt
agrep -0 -c 'CGGGGTTTTATGGTGCA' *.fastq > count/B14108_Rm0.txt
agrep -0 -c 'TTAGGCGCGCCGTACAT' *.fastq > count/B14109_Rm0.txt
agrep -0 -c 'GTTAGGTTTGCTATGAG' *.fastq > count/B14110_Rm0.txt
agrep -0 -c 'CCGTATCACCGAGCAAC' *.fastq > count/B14111_Rm0.txt
agrep -0 -c 'CGCAAATTGCCAGATGT' *.fastq > count/B14112_Rm0.txt
agrep -0 -c 'GATTTCGACGAACGAAC' *.fastq > count/B14113_Rm0.txt
agrep -0 -c 'GATAGTCATGACGTAGA' *.fastq > count/B14114_Rm0.txt
agrep -0 -c 'GCTACTAATTCCTCAAC' *.fastq > count/B14115_Rm0.txt
agrep -0 -c 'TCTGCATTGCAACCATA' *.fastq > count/B14116_Rm0.txt
agrep -0 -c 'ACGCATCGCGTTTCTCC' *.fastq > count/B14117_Rm0.txt
agrep -0 -c 'GAACTCTTCTGGAGTGA' *.fastq > count/B14118_Rm0.txt
agrep -0 -c 'ACAAAAGACTGCCGTAG' *.fastq > count/B14119_Rm0.txt
agrep -0 -c 'ATAACTAGCATACCCCC' *.fastq > count/B14120_Rm0.txt
agrep -0 -c 'TGTAGCGGATAAACTGT' *.fastq > count/B14121_Rm0.txt
agrep -0 -c 'GGGAGTCCGATTAACAT' *.fastq > count/B14122_Rm0.txt
agrep -0 -c 'GGGGTACCATGATAAGT' *.fastq > count/B14123_Rm0.txt
agrep -0 -c 'AAAGAGGTATGGCAGCC' *.fastq > count/B14124_Rm0.txt
agrep -0 -c 'AGCTATTGAGCCCCAAT' *.fastq > count/B14125_Rm0.txt
agrep -0 -c 'GTAAGTGGCACGCTCAG' *.fastq > count/B14127_Rm0.txt
agrep -0 -c 'GGCTTGCTGAGAAAATT' *.fastq > count/B14128_Rm0.txt
agrep -0 -c 'TCGAGGTGAGATTCGAT' *.fastq > count/B14129_Rm0.txt
agrep -0 -c 'AACGTAGGCTTCAAGCG' *.fastq > count/B14130_Rm0.txt
agrep -0 -c 'ATAGCTTAGAGACATGC' *.fastq > count/B14131_Rm0.txt
agrep -0 -c 'AAGTACCCTCTCGGATT' *.fastq > count/B14132_Rm0.txt
agrep -0 -c 'CGAGACGATTGAGAGAA' *.fastq > count/B14133_Rm0.txt
agrep -0 -c 'GTATATAGACGCCCCAC' *.fastq > count/B14134_Rm0.txt
agrep -0 -c 'TCGAAAAGGCGGCTCAA' *.fastq > count/B14135_Rm0.txt
agrep -0 -c 'ATAGTCTCAGCCCGACC' *.fastq > count/B14137_Rm0.txt
agrep -0 -c 'GCCGGGACTTTTAACGG' *.fastq > count/B14138_Rm0.txt
agrep -0 -c 'AGTAGAAGTAGGTCCAG' *.fastq > count/B14139_Rm0.txt
agrep -0 -c 'CAGCTACTCCTAACTGC' *.fastq > count/B14140_Rm0.txt
agrep -0 -c 'CGTCTCACTCAAGCTAG' *.fastq > count/B14141_Rm0.txt
agrep -0 -c 'ATCACGAAGTCCTACTT' *.fastq > count/B14142_Rm0.txt
agrep -0 -c 'CTTCGTAAAAGGACCAT' *.fastq > count/B14143_Rm0.txt
agrep -0 -c 'AATCGGATACCCCGAAT' *.fastq > count/B14144_Rm0.txt
agrep -0 -c 'GACCGCATCTCAGCTAA' *.fastq > count/B14147_Rm0.txt
agrep -0 -c 'CTGCCAACCTATGTGGC' *.fastq > count/B14149_Rm0.txt
agrep -0 -c 'GAGGGTTAAAGCTACTT' *.fastq > count/B14150_Rm0.txt
agrep -0 -c 'GTTCTATCGCCCTTGCT' *.fastq > count/B14151_Rm0.txt
agrep -0 -c 'TGTCTTAGGGGTGATGC' *.fastq > count/B14152_Rm0.txt
agrep -0 -c 'TCGCGCTACTCATATAT' *.fastq > count/B14153_Rm0.txt
agrep -0 -c 'GTACAGGCCGAGGTTGT' *.fastq > count/B14154_Rm0.txt
agrep -0 -c 'CAAACTGAATTGTACCG' *.fastq > count/B14155_Rm0.txt
agrep -0 -c 'GGCTCAACTCGAATCCT' *.fastq > count/B14156_Rm0.txt
agrep -0 -c 'ATCTATGCAGGCTACTA' *.fastq > count/B14158_Rm0.txt
agrep -0 -c 'ACACGTTTATAGCCTCA' *.fastq > count/B14159_Rm0.txt
agrep -0 -c 'TTGTAGAATGCGACCCT' *.fastq > count/B14160_Rm0.txt
agrep -0 -c 'AGTAGAGCGGGGTGCTT' *.fastq > count/B14162_Rm0.txt
agrep -0 -c 'GTACTTGCTCGTCGCAA' *.fastq > count/B14163_Rm0.txt
agrep -0 -c 'CGAGTTACGCTCTTCAG' *.fastq > count/B14164_Rm0.txt
agrep -0 -c 'CGTTCATCTCTTCGCAC' *.fastq > count/B14165_Rm0.txt
agrep -0 -c 'GCAATCCGCGATCTGGT' *.fastq > count/B14166_Rm0.txt
agrep -0 -c 'CATTATTGACGAGGTCT' *.fastq > count/B14167_Rm0.txt
agrep -0 -c 'TGAAAACGACCGACCAC' *.fastq > count/B14168_Rm0.txt
agrep -0 -c 'TGCTGAAAGTGAGAGTA' *.fastq > count/B14169_Rm0.txt
agrep -0 -c 'AGATATCGGTTCTGACT' *.fastq > count/B14170_Rm0.txt
agrep -0 -c 'GGATTAGCTGTATCCGT' *.fastq > count/B14171_Rm0.txt
agrep -0 -c 'GGAGATCGATGAAATCC' *.fastq > count/B14172_Rm0.txt
agrep -0 -c 'ACCTCTAGAGCTGCATA' *.fastq > count/B14173_Rm0.txt
agrep -0 -c 'ATGCTAACCTAAGCGGC' *.fastq > count/B14175_Rm0.txt
agrep -0 -c 'CAACTGGTTCGATCCTG' *.fastq > count/B14176_Rm0.txt
agrep -0 -c 'TCGAGCAACCTTTCGCC' *.fastq > count/B14177_Rm0.txt
agrep -0 -c 'TCATTCGCAGTCATTAC' *.fastq > count/B14178_Rm0.txt
agrep -0 -c 'GCTGCTTTCCGAAAGCT' *.fastq > count/B14179_Rm0.txt
agrep -0 -c 'GAGAAGGAATCAACCAC' *.fastq > count/B14180_Rm0.txt
agrep -0 -c 'CTAGGTGGTAGCATCTA' *.fastq > count/B14181_Rm0.txt
agrep -0 -c 'ATGCCTAAAGGGGTCCT' *.fastq > count/B14182_Rm0.txt
agrep -0 -c 'CATAGACGTAGGTTCAC' *.fastq > count/B14184_Rm0.txt
agrep -0 -c 'ATTCGATTTCGACGTCA' *.fastq > count/B14185_Rm0.txt
agrep -0 -c 'ACCTACTCGATCGTGCA' *.fastq > count/B14186_Rm0.txt
agrep -0 -c 'ATCCAGTGGTCTTGTCG' *.fastq > count/B14187_Rm0.txt
agrep -0 -c 'AGCACTTAAAGTATGCG' *.fastq > count/B14188_Rm0.txt
agrep -0 -c 'GGAATCAAGGAGGCCAC' *.fastq > count/B14190_Rm0.txt
agrep -0 -c 'CGCGTTACGAGCGATCA' *.fastq > count/B14191_Rm0.txt
agrep -0 -c 'GTTGAATCCGGCCATTA' *.fastq > count/B14192_Rm0.txt
agrep -0 -c 'CAGGCTGAGCGAAATGG' *.fastq > count/B14193_Rm0.txt
agrep -0 -c 'TCCATTCAGAGTTATGG' *.fastq > count/B14194_Rm0.txt
agrep -0 -c 'GAATCCTAGGGCATCCT' *.fastq > count/B14196_Rm0.txt
agrep -0 -c 'ACACTTCGTATGAGCCT' *.fastq > count/B14197_Rm0.txt
agrep -0 -c 'GTTCTGGAGCGAGATCC' *.fastq > count/B14198_Rm0.txt
agrep -0 -c 'GTCCGGTCTTATATACC' *.fastq > count/B14199_Rm0.txt
agrep -0 -c 'GCACCCAGACTGGTTAC' *.fastq > count/B14200_Rm0.txt
agrep -0 -c 'CAAGGATCAGCCCTGTT' *.fastq > count/B14201_Rm0.txt
agrep -0 -c 'AGGTATAGATCAGGGAT' *.fastq > count/B14202_Rm0.txt
agrep -0 -c 'CATGTTTTTCCCAGGAC' *.fastq > count/B14203_Rm0.txt
agrep -0 -c 'CTCGCAATATCCCTGGT' *.fastq > count/B14204_Rm0.txt
agrep -0 -c 'CGCACGTACTTCTGTAG' *.fastq > count/B14205_Rm0.txt
agrep -0 -c 'GCTGTCAAACGTTTTGA' *.fastq > count/B14206_Rm0.txt
agrep -0 -c 'CCCCGACTATTTATACA' *.fastq > count/B14207_Rm0.txt
agrep -0 -c 'CATAACCCGGTAGATCA' *.fastq > count/B14208_Rm0.txt
agrep -0 -c 'TCCCGCAGATGAAGAGA' *.fastq > count/B14209_Rm0.txt
agrep -0 -c 'ACGTCGGTTAACCACTT' *.fastq > count/B14210_Rm0.txt
agrep -0 -c 'TTTTATAACCGACCGAC' *.fastq > count/B14211_Rm0.txt
agrep -0 -c 'CGCGTGCTCTAAAGAGA' *.fastq > count/B14212_Rm0.txt
agrep -0 -c 'CGATCCGGAGTACAGGT' *.fastq > count/B14213_Rm0.txt
agrep -0 -c 'CGAGGGGTGGATTAGAA' *.fastq > count/B14214_Rm0.txt
agrep -0 -c 'GCGAACTTAAAGCTGAG' *.fastq > count/B14215_Rm0.txt
agrep -0 -c 'CACTTGATGGATGGTAT' *.fastq > count/B14216_Rm0.txt
agrep -0 -c 'TCACTGGTAACTCATGA' *.fastq > count/B14217_Rm0.txt
agrep -0 -c 'GCGGATGGTACAGACTA' *.fastq > count/B14218_Rm0.txt
agrep -0 -c 'TGTCAGTATGTACGTAG' *.fastq > count/B14219_Rm0.txt
agrep -0 -c 'CTCGCTCGTTCTGGACT' *.fastq > count/B14220_Rm0.txt
agrep -0 -c 'TTGGACCATACAGGCGA' *.fastq > count/B14221_Rm0.txt
agrep -0 -c 'GGGTGTCAGTCTCCCTA' *.fastq > count/B14223_Rm0.txt
agrep -0 -c 'ATGCCTTTACCGCAACC' *.fastq > count/B14224_Rm0.txt
agrep -0 -c 'CAACTCGTGATGCGCCT' *.fastq > count/B14225_Rm0.txt
agrep -0 -c 'GGCCTGAGAATCCTATT' *.fastq > count/B14226_Rm0.txt
agrep -0 -c 'TCATCCAAGGATGACGG' *.fastq > count/B14227_Rm0.txt
agrep -0 -c 'GTGTAGTGCTCCCAATC' *.fastq > count/B14228_Rm0.txt
agrep -0 -c 'TTTACTGTGACCCGACG' *.fastq > count/B14229_Rm0.txt
agrep -0 -c 'CTCTTGACTCAGACGTC' *.fastq > count/B14230_Rm0.txt
agrep -0 -c 'GTAGGGTCGACTGATTA' *.fastq > count/B14231_Rm0.txt
agrep -0 -c 'GAGCGGCCGCAAATTAA' *.fastq > count/B14233_Rm0.txt
agrep -0 -c 'GTATTTCGATCGTGCGA' *.fastq > count/B14235_Rm0.txt
agrep -0 -c 'TCAAACGGGCTACGACG' *.fastq > count/B14236_Rm0.txt
agrep -0 -c 'TGCTTTAGGGCGAGTAC' *.fastq > count/B14238_Rm0.txt
agrep -0 -c 'CGTGTTGTGTCATGTAG' *.fastq > count/B14239_Rm0.txt
agrep -0 -c 'ATCGGGTTTTGGCATGT' *.fastq > count/B14240_Rm0.txt
agrep -0 -c 'ATTTGTCAGTTCCGGTT' *.fastq > count/B14241_Rm0.txt
agrep -0 -c 'ACAATCAGCGTACTGTT' *.fastq > count/B14242_Rm0.txt
agrep -0 -c 'AGACTTATCTGTCACGC' *.fastq > count/B14244_Rm0.txt
agrep -0 -c 'GGTGCCAGATATCTCTA' *.fastq > count/B14245_Rm0.txt
agrep -0 -c 'CAATGTGGGGCTTGGCA' *.fastq > count/B14247_Rm0.txt
agrep -0 -c 'CACACCATCATCTTACG' *.fastq > count/B14248_Rm0.txt
agrep -0 -c 'AACGCTAGTCTTACCAT' *.fastq > count/B14249_Rm0.txt
agrep -0 -c 'AGGAATAAGACTTGCGG' *.fastq > count/B14250_Rm0.txt
agrep -0 -c 'GTTCGCGTTGGCCTTTA' *.fastq > count/B14252_Rm0.txt
agrep -0 -c 'ACACACGGTCTGTGAGC' *.fastq > count/B14253_Rm0.txt
agrep -0 -c 'TAACGCACCATCTACAT' *.fastq > count/B14254_Rm0.txt
agrep -0 -c 'ACCAGGAAAGATCGATC' *.fastq > count/B14255_Rm0.txt
agrep -0 -c 'AATGCTCTCCGATAGTG' *.fastq > count/B14256_Rm0.txt
agrep -0 -c 'AGACGACCTTAGTAGCC' *.fastq > count/B14258_Rm0.txt
agrep -0 -c 'AATGCGAACTTGCAAGA' *.fastq > count/B14259_Rm0.txt
agrep -0 -c 'GGAGATCGAAACCCAAG' *.fastq > count/B14260_Rm0.txt
agrep -0 -c 'TGGTCCGTACCCGTTGA' *.fastq > count/B14261_Rm0.txt
agrep -0 -c 'TGGCTTCCGGGCTAACA' *.fastq > count/B14262_Rm0.txt
agrep -0 -c 'GTCTCTTCCCGGTTTGT' *.fastq > count/B14263_Rm0.txt
agrep -0 -c 'GGAGCGTAAGACCACAA' *.fastq > count/B14264_Rm0.txt
agrep -0 -c 'ACCTTTAGCAACCTCTG' *.fastq > count/B14265_Rm0.txt
agrep -0 -c 'GTCAACATGCGATTGTG' *.fastq > count/B14266_Rm0.txt
agrep -0 -c 'GGTACGTTGCTCATAGC' *.fastq > count/B14267_Rm0.txt
agrep -0 -c 'TGTATGGCGAGTCAGGC' *.fastq > count/B14269_Rm0.txt
agrep -0 -c 'ACCCCCAGTTGTTATGA' *.fastq > count/B14270_Rm0.txt
agrep -0 -c 'TACAGTTTCGGAGACCC' *.fastq > count/B14271_Rm0.txt
agrep -0 -c 'GATCTCTACAAGGCCTG' *.fastq > count/B14272_Rm0.txt
agrep -0 -c 'GCTAATTCGTTCTATCG' *.fastq > count/B14273_Rm0.txt
agrep -0 -c 'ACCGTCATAAGGCCATT' *.fastq > count/B14275_Rm0.txt
agrep -0 -c 'CAGCCCAGTAGGTTTGC' *.fastq > count/B14276_Rm0.txt
agrep -0 -c 'AGATAATTGCAACGGAC' *.fastq > count/B14277_Rm0.txt
agrep -0 -c 'TACCGCAGAAACGTAGT' *.fastq > count/B14278_Rm0.txt
agrep -0 -c 'GGCGTCCCACTTTGTCT' *.fastq > count/B14279_Rm0.txt
agrep -0 -c 'AAATCCCCGCTCAAGGT' *.fastq > count/B14280_Rm0.txt
agrep -0 -c 'GCTAGGAATAATCCTCG' *.fastq > count/B14281_Rm0.txt
agrep -0 -c 'GGTCCGCTTTCGTTCAC' *.fastq > count/B14282_Rm0.txt
agrep -0 -c 'ACACCGTCCGAGATTGG' *.fastq > count/B14283_Rm0.txt
agrep -0 -c 'AGGATGTAACGCAGCGG' *.fastq > count/B14284_Rm0.txt
agrep -0 -c 'CACCCGTGCCTCTAAAC' *.fastq > count/B14285_Rm0.txt
agrep -0 -c 'TCTGTTGGACGTTTGTG' *.fastq > count/B14286_Rm0.txt
agrep -0 -c 'CTGTAAGAAGGTGCAAT' *.fastq > count/B14288_Rm0.txt
agrep -0 -c 'ACAGCATGTTGCCTAGG' *.fastq > count/B14289_Rm0.txt
agrep -0 -c 'AGGCACGATTAGTGCTA' *.fastq > count/B14290_Rm0.txt
agrep -0 -c 'CCGATGTCTTCACAGCT' *.fastq > count/B14291_Rm0.txt
agrep -0 -c 'AGAGCATCAGTACATAG' *.fastq > count/B14292_Rm0.txt
agrep -0 -c 'CCTTAGGGTCGTCTTGG' *.fastq > count/B14294_Rm0.txt
agrep -0 -c 'ATGGTGCTAACGGCTGC' *.fastq > count/B14295_Rm0.txt
agrep -0 -c 'ATTCACTGTCAAGGGCT' *.fastq > count/B14297_Rm0.txt
agrep -0 -c 'TTCGTCGTTGTGGATCC' *.fastq > count/B14298_Rm0.txt
agrep -0 -c 'GGGTCGCTAAACTATCC' *.fastq > count/B14299_Rm0.txt
agrep -0 -c 'CTGGTTTGACAAATCGA' *.fastq > count/B14300_Rm0.txt
agrep -0 -c 'TCGCATTAACTCTCGAT' *.fastq > count/B14302_Rm0.txt
agrep -0 -c 'CAGCGCATCCTTAGATT' *.fastq > count/B14303_Rm0.txt
agrep -0 -c 'CCAGGCAAATCAGCGAT' *.fastq > count/B14305_Rm0.txt
agrep -0 -c 'TGTTGACTCAGAGTTGC' *.fastq > count/B14306_Rm0.txt
agrep -0 -c 'TCGGACACCAAGCACTT' *.fastq > count/B14307_Rm0.txt
agrep -0 -c 'GCGATCAAAGTCCCATT' *.fastq > count/B14308_Rm0.txt
agrep -0 -c 'ACCTGTTGCTTACACCT' *.fastq > count/B14309_Rm0.txt
agrep -0 -c 'CTACGCTACACGCCCTT' *.fastq > count/B14310_Rm0.txt
agrep -0 -c 'GAAGACCAAGGATAGCT' *.fastq > count/B14311_Rm0.txt
agrep -0 -c 'CTTGAGGCCACGATCAA' *.fastq > count/B14312_Rm0.txt
agrep -0 -c 'CGTGCAATGGCCTAGTG' *.fastq > count/B14314_Rm0.txt
agrep -0 -c 'TGGGTCCTACGTTAAGA' *.fastq > count/B14315_Rm0.txt
agrep -0 -c 'GCTGAAAGAAGGCTACG' *.fastq > count/B14316_Rm0.txt
agrep -0 -c 'CAGGTAATGGCACCGGT' *.fastq > count/B14318_Rm0.txt
agrep -0 -c 'TTTATACCGTTTGGGCA' *.fastq > count/B14319_Rm0.txt
agrep -0 -c 'GCTACATGAATCCCGAA' *.fastq > count/B14321_Rm0.txt
agrep -0 -c 'GTCAAGCGGGTTACGGT' *.fastq > count/B14322_Rm0.txt
agrep -0 -c 'GTCTTACTCGGGTGATT' *.fastq > count/B14324_Rm0.txt
agrep -0 -c 'TGTAGGCAGTGGGCTTG' *.fastq > count/B14325_Rm0.txt
agrep -0 -c 'CGTTCCCTGTTGATGAT' *.fastq > count/B14326_Rm0.txt
agrep -0 -c 'GGTACCTGATCAGTTGT' *.fastq > count/B14327_Rm0.txt
agrep -0 -c 'CAACCCTACATAAACGA' *.fastq > count/B14330_Rm0.txt
agrep -0 -c 'CCTAATCTGAGAAGTCC' *.fastq > count/B14331_Rm0.txt
agrep -0 -c 'AGAAAAATACTCCCTCC' *.fastq > count/B14332_Rm0.txt
agrep -0 -c 'GTTAGAGGTAGTCTTGT' *.fastq > count/B14333_Rm0.txt
agrep -0 -c 'TAAAATCCAGGTGAACC' *.fastq > count/B14335_Rm0.txt
agrep -0 -c 'TATTTTCGACGCGTATG' *.fastq > count/B14336_Rm0.txt
agrep -0 -c 'TCTGTATACCTAGACTG' *.fastq > count/B14337_Rm0.txt
agrep -0 -c 'TACCCCCCTCTCAGAAC' *.fastq > count/B14338_Rm0.txt
agrep -0 -c 'TATGGTGAGTGCGTCCC' *.fastq > count/B14339_Rm0.txt
agrep -0 -c 'TTCCAGATACTTCGACA' *.fastq > count/B14340_Rm0.txt
agrep -0 -c 'ATCGTTATTGACCCCAG' *.fastq > count/B14341_Rm0.txt
agrep -0 -c 'CCATGAGCCTTATGTGC' *.fastq > count/B14342_Rm0.txt
agrep -0 -c 'TCTAATCGGGACATCCG' *.fastq > count/B14343_Rm0.txt
agrep -0 -c 'TTTACATCCACTAAGCG' *.fastq > count/B14344_Rm0.txt
agrep -0 -c 'CAGTGACGTCGCCTGAT' *.fastq > count/B14345_Rm0.txt
agrep -0 -c 'TACACCAGTCATACGTT' *.fastq > count/B14346_Rm0.txt
agrep -0 -c 'AGGCTCGACGTACATAC' *.fastq > count/B14347_Rm0.txt
agrep -0 -c 'CGCTAGGCTCACAGCTA' *.fastq > count/B14349_Rm0.txt
agrep -0 -c 'AACGAGCCATGGGAGCT' *.fastq > count/B14350_Rm0.txt
agrep -0 -c 'TTCCATACATTGGACCT' *.fastq > count/B14352_Rm0.txt
agrep -0 -c 'GTGCAAGTGAAGCAATG' *.fastq > count/B14353_Rm0.txt
agrep -0 -c 'GTTGTGTACAACGCATT' *.fastq > count/B14354_Rm0.txt
agrep -0 -c 'GAGGAACGTGTCTTATG' *.fastq > count/B14355_Rm0.txt
agrep -0 -c 'TTTAGTCAACCTGTCGC' *.fastq > count/B14357_Rm0.txt
agrep -0 -c 'ACGGCTAGGTGGTGTTA' *.fastq > count/B14358_Rm0.txt
agrep -0 -c 'ATCTGTACTCCCAATCT' *.fastq > count/B14359_Rm0.txt
agrep -0 -c 'TGGGTCGGTTCTAGTCT' *.fastq > count/B14360_Rm0.txt
agrep -0 -c 'TATTGCCTTTATCGCGC' *.fastq > count/B14361_Rm0.txt
agrep -0 -c 'GGTCCCCGAATGCAAAT' *.fastq > count/B14362_Rm0.txt
agrep -0 -c 'GAGTTTCATCGGACGTG' *.fastq > count/B14363_Rm0.txt
agrep -0 -c 'AGATTCGGGTCACCACA' *.fastq > count/B14364_Rm0.txt
agrep -0 -c 'CGCGAAAAAAGAGCCAG' *.fastq > count/B14365_Rm0.txt
agrep -0 -c 'GACGTCTCCCACGATAA' *.fastq > count/B14366_Rm0.txt
agrep -0 -c 'CGTGACCGTTCTCCATG' *.fastq > count/B14367_Rm0.txt
agrep -0 -c 'GTCACTGACGCAGTTCC' *.fastq > count/B14368_Rm0.txt
agrep -0 -c 'GTTAATCCGCTCGACAG' *.fastq > count/B14369_Rm0.txt
agrep -0 -c 'ATCTATTCCGACCTACC' *.fastq > count/B14370_Rm0.txt
agrep -0 -c 'GCGGTTCTGCATACCGA' *.fastq > count/B14371_Rm0.txt
agrep -0 -c 'AATCGCGCTTACAAGCC' *.fastq > count/B14372_Rm0.txt
agrep -0 -c 'CTCACGTAGTGCGCCTA' *.fastq > count/B14373_Rm0.txt
agrep -0 -c 'GGGCATTTTCCATGGTT' *.fastq > count/B14374_Rm0.txt
agrep -0 -c 'AGTACCTACTAGGCGAG' *.fastq > count/B14375_Rm0.txt
agrep -0 -c 'CAGCTCCGAGAATGTAA' *.fastq > count/B14377_Rm0.txt
agrep -0 -c 'CAATACATGTCTGTACC' *.fastq > count/B14378_Rm0.txt
agrep -0 -c 'ATTGACAAGCCGGTAAT' *.fastq > count/B14380_Rm0.txt
agrep -0 -c 'AACCGAGACTGGCTTGA' *.fastq > count/B14381_Rm0.txt
agrep -0 -c 'GGACAAAGGTGTGGAAT' *.fastq > count/B14383_Rm0.txt
agrep -0 -c 'ACCGCACCTGGACATAA' *.fastq > count/B14384_Rm0.txt
agrep -0 -c 'ACATAAACCTTAGGCCT' *.fastq > count/B14385_Rm0.txt
agrep -0 -c 'CAGCCAGTTTACCTTCT' *.fastq > count/B14386_Rm0.txt
agrep -0 -c 'GCGTAAGGATTGCAACT' *.fastq > count/B14387_Rm0.txt
agrep -0 -c 'TTGGGAGATGTCTTGAA' *.fastq > count/B14388_Rm0.txt
agrep -0 -c 'AGCCTCCTCTATAGATC' *.fastq > count/B14390_Rm0.txt
agrep -0 -c 'CTGATGCCGAACAAGCA' *.fastq > count/B14391_Rm0.txt
agrep -0 -c 'TAACTCGCTGTCAGCCT' *.fastq > count/B14392_Rm0.txt
agrep -0 -c 'GTACGAGCTGTTATACG' *.fastq > count/B14393_Rm0.txt
agrep -0 -c 'TGGCTAGGGTATAACAG' *.fastq > count/B14394_Rm0.txt
agrep -0 -c 'TACGTGGATAGCGCGTC' *.fastq > count/B14395_Rm0.txt
agrep -0 -c 'TGGAGACGCTTAACTCG' *.fastq > count/B14396_Rm0.txt
agrep -0 -c 'CTCTCACGGACGTTGAA' *.fastq > count/B14397_Rm0.txt
agrep -0 -c 'TGCTTCAAGAGCCATAT' *.fastq > count/B14398_Rm0.txt
agrep -0 -c 'GAGTTGCGCTGTCCAGT' *.fastq > count/B14399_Rm0.txt
agrep -0 -c 'CCGGGTCCCATCAATAC' *.fastq > count/B14400_Rm0.txt
agrep -0 -c 'ACGTCGGGAACTTCACT' *.fastq > count/B14401_Rm0.txt
agrep -0 -c 'TTACTCGCCGGTTCTGC' *.fastq > count/B14402_Rm0.txt
agrep -0 -c 'GAGACCATCTAGGTTGA' *.fastq > count/B14403_Rm0.txt
agrep -0 -c 'GACCGACAACAAACACA' *.fastq > count/B14404_Rm0.txt
agrep -0 -c 'TGTAGGCGCTTCTAATA' *.fastq > count/B14405_Rm0.txt
agrep -0 -c 'GTTACTCGGCAACCTCG' *.fastq > count/B14406_Rm0.txt
agrep -0 -c 'GATCGTCTAGCGTACAT' *.fastq > count/B14407_Rm0.txt
agrep -0 -c 'ATCTCGGATGGAGCTCG' *.fastq > count/B14408_Rm0.txt
agrep -0 -c 'AGACCTCGCTTGGATAG' *.fastq > count/B14409_Rm0.txt
agrep -0 -c 'GCCTATAATGCGAAACA' *.fastq > count/B14410_Rm0.txt
agrep -0 -c 'ACCGCCATGACGATTAC' *.fastq > count/B14411_Rm0.txt
agrep -0 -c 'CATTCTACACACGATCC' *.fastq > count/B14412_Rm0.txt
agrep -0 -c 'GCCAGAGGAGTTATAGA' *.fastq > count/B14413_Rm0.txt
agrep -0 -c 'AACATTAGTGTGGGGTA' *.fastq > count/B14414_Rm0.txt
agrep -0 -c 'CATAAGGTGCATAGACA' *.fastq > count/B14415_Rm0.txt
agrep -0 -c 'TTGTCGGTGTGGTTTCG' *.fastq > count/B14417_Rm0.txt
agrep -0 -c 'GTCGCATTGCCCAATAT' *.fastq > count/B14418_Rm0.txt
agrep -0 -c 'ATCTAACGGTTGTTCAC' *.fastq > count/B14419_Rm0.txt
agrep -0 -c 'GGGATTGGAGTGCATCG' *.fastq > count/B14420_Rm0.txt
agrep -0 -c 'TAAAGCGTGCAGGGTGG' *.fastq > count/B14422_Rm0.txt
agrep -0 -c 'GTTGATGTAATGCGCAG' *.fastq > count/B14425_Rm0.txt
agrep -0 -c 'TGGTAGTGTTCCATACG' *.fastq > count/B14426_Rm0.txt
agrep -0 -c 'CTCGCATATGTCCGGAT' *.fastq > count/B14427_Rm0.txt
agrep -0 -c 'GGTTTATTTTGTACCGG' *.fastq > count/B14428_Rm0.txt
agrep -0 -c 'ACGCAGGGTTCTTCGAA' *.fastq > count/B14429_Rm0.txt
agrep -0 -c 'GTGACCCGCAGGACTAT' *.fastq > count/B14430_Rm0.txt
agrep -0 -c 'CATCGATGACTGGCGTT' *.fastq > count/B14431_Rm0.txt
agrep -0 -c 'GGGATATGTATTCGCGC' *.fastq > count/B14432_Rm0.txt
agrep -0 -c 'GCTTATCCAGCTAGACA' *.fastq > count/B14433_Rm0.txt
agrep -0 -c 'TCGTTTTCGGCGAGCTT' *.fastq > count/B14434_Rm0.txt
agrep -0 -c 'GGTCATGACGAGAGAGC' *.fastq > count/B14435_Rm0.txt
agrep -0 -c 'TAGGAGGTAGCCTCTAC' *.fastq > count/B14436_Rm0.txt
agrep -0 -c 'AGATTCTTGGAGTACGA' *.fastq > count/B14440_Rm0.txt
agrep -0 -c 'TGTAGACGCTTAAGTGC' *.fastq > count/B14441_Rm0.txt
agrep -0 -c 'TTCGATCCTTTAGTCGT' *.fastq > count/B14442_Rm0.txt
agrep -0 -c 'AGCCATATTCACGGGCA' *.fastq > count/B14443_Rm0.txt
agrep -0 -c 'ACGCCACTATTGGACTA' *.fastq > count/B14444_Rm0.txt
agrep -0 -c 'CATCAGGGTAGGACCAC' *.fastq > count/B14445_Rm0.txt
agrep -0 -c 'GATAACCGAAACCCAGC' *.fastq > count/B14446_Rm0.txt
agrep -0 -c 'TAGCGTAAGAATTACCC' *.fastq > count/B14447_Rm0.txt
agrep -0 -c 'ACAGGTATAGTACCCGA' *.fastq > count/B14449_Rm0.txt
agrep -0 -c 'AAGAGGGTCGATCAGTG' *.fastq > count/B14450_Rm0.txt
agrep -0 -c 'TCTCCCCCTTCCGAACT' *.fastq > count/B14451_Rm0.txt
agrep -0 -c 'GATAGGACTACAGACGA' *.fastq > count/B14453_Rm0.txt
agrep -0 -c 'GTCCTATGCCGATACGA' *.fastq > count/B14454_Rm0.txt
agrep -0 -c 'CCCCAATGTGCTAACCT' *.fastq > count/B14457_Rm0.txt
agrep -0 -c 'CGGCTTGGGGTTGTTCA' *.fastq > count/B14458_Rm0.txt
agrep -0 -c 'ACATCCCTAGTTAGCAA' *.fastq > count/B14459_Rm0.txt
agrep -0 -c 'AGCGGTATCAACGAATA' *.fastq > count/B14461_Rm0.txt
agrep -0 -c 'CGAGTTCATGTCAGTCC' *.fastq > count/B14462_Rm0.txt
agrep -0 -c 'AGTGCGCAGCTAGCTCT' *.fastq > count/B14463_Rm0.txt
agrep -0 -c 'GGGAGCCAGGTGTACAT' *.fastq > count/B14464_Rm0.txt
agrep -0 -c 'CTTCCAGTCGGTTCGAA' *.fastq > count/B14465_Rm0.txt
agrep -0 -c 'GTAACTTTCGGTGAGAT' *.fastq > count/B14466_Rm0.txt
agrep -0 -c 'CAGCTTCGGCTGTTTAA' *.fastq > count/B14467_Rm0.txt
agrep -0 -c 'CGACCTTTTAGCGGAGC' *.fastq > count/B14469_Rm0.txt
agrep -0 -c 'AACGTACGTCAGACAGG' *.fastq > count/B14470_Rm0.txt
agrep -0 -c 'TGTTTGGCTCGGTGGGT' *.fastq > count/B14471_Rm0.txt
agrep -0 -c 'ACCACTAAAGTCTGGCC' *.fastq > count/B14472_Rm0.txt
agrep -0 -c 'GAGCGTGGGATCCTTAC' *.fastq > count/B14474_Rm0.txt
agrep -0 -c 'GCCACCTGGTAGAGACA' *.fastq > count/B14475_Rm0.txt
agrep -0 -c 'GCAAAGGGTCCGTGTTA' *.fastq > count/B14476_Rm0.txt
agrep -0 -c 'AACGGCGCCTCCTTTCT' *.fastq > count/B14477_Rm0.txt
agrep -0 -c 'CTGTTCAGGGACTCTCC' *.fastq > count/B14478_Rm0.txt
agrep -0 -c 'GTCCGCTGGTAGTCAGT' *.fastq > count/B14479_Rm0.txt
agrep -0 -c 'GTATTAGAGCACCATCG' *.fastq > count/B14481_Rm0.txt
agrep -0 -c 'GGTTCAGTTTATCTCGT' *.fastq > count/B14482_Rm0.txt
agrep -0 -c 'TATCAAATCGTAGCTGG' *.fastq > count/B14483_Rm0.txt
agrep -0 -c 'GGCGTGATGTACCATCC' *.fastq > count/B14485_Rm0.txt
agrep -0 -c 'ATACCAACGCTAGTTGG' *.fastq > count/B14486_Rm0.txt
agrep -0 -c 'TCGGTTGCCAAAGGGTG' *.fastq > count/B14487_Rm0.txt
agrep -0 -c 'ACGTATTGCAGATCAAG' *.fastq > count/B14488_Rm0.txt
agrep -0 -c 'AGCAGCACAGAATCTAG' *.fastq > count/B14489_Rm0.txt
agrep -0 -c 'CTTACATTCGGTGTACT' *.fastq > count/B14491_Rm0.txt
agrep -0 -c 'CTGCGATTTAGGGGCTA' *.fastq > count/B14494_Rm0.txt
agrep -0 -c 'TTAGACGTCTCACAGTG' *.fastq > count/B14495_Rm0.txt
agrep -0 -c 'CTTTCGGGAGGATCAGG' *.fastq > count/B14497_Rm0.txt
agrep -0 -c 'GACACCCGAGAGCCTAA' *.fastq > count/B14500_Rm0.txt
agrep -0 -c 'GGTGCACGTTTCACGCA' *.fastq > count/B14501_Rm0.txt
agrep -0 -c 'ATTACGTGTACTTGGAG' *.fastq > count/B14502_Rm0.txt
agrep -0 -c 'AGTGGGAGTGAGCTCTG' *.fastq > count/B14504_Rm0.txt
agrep -0 -c 'TCGTCAGTTGATCCATA' *.fastq > count/B14505_Rm0.txt
agrep -0 -c 'GACTTTTGAGTGCTCCT' *.fastq > count/B14506_Rm0.txt
agrep -0 -c 'CCCATCCACAATACCAC' *.fastq > count/B14509_Rm0.txt
agrep -0 -c 'ACCCTCAACTCGTCCTC' *.fastq > count/B14511_Rm0.txt
agrep -0 -c 'AGCCTATTGCACACCAA' *.fastq > count/B14512_Rm0.txt
agrep -0 -c 'TATGCCGCTGGCGTTGA' *.fastq > count/B14513_Rm0.txt
agrep -0 -c 'CATCCGTTTGTAGACAA' *.fastq > count/B14514_Rm0.txt
agrep -0 -c 'TACTTCGGCGTTCTCGC' *.fastq > count/B14515_Rm0.txt
agrep -0 -c 'TGCATGCACGGAGTCAT' *.fastq > count/B14516_Rm0.txt
agrep -0 -c 'ACCAGGAGCTAAGAGAA' *.fastq > count/B14517_Rm0.txt
agrep -0 -c 'GTGGTTACGGGTTTGTG' *.fastq > count/B14518_Rm0.txt
agrep -0 -c 'GCCGCTTACAGTTAAAT' *.fastq > count/B14519_Rm0.txt
agrep -0 -c 'GTACGTCGGGTGCGATT' *.fastq > count/B14521_Rm0.txt
agrep -0 -c 'GTTCTACTCTCACCCGA' *.fastq > count/B14522_Rm0.txt
agrep -0 -c 'TTCATCGGGGTCATTAT' *.fastq > count/B14524_Rm0.txt
agrep -0 -c 'ACGGGAAATCCACTTAG' *.fastq > count/B14525_Rm0.txt
agrep -0 -c 'GGGTGCGAAAACCTTGG' *.fastq > count/B14526_Rm0.txt
agrep -0 -c 'CCGTTACCACTAGTTTA' *.fastq > count/B14527_Rm0.txt
agrep -0 -c 'GTCGTAGTCCCTCGATT' *.fastq > count/B14528_Rm0.txt
agrep -0 -c 'GCTGGACGTTCAACGAA' *.fastq > count/B14530_Rm0.txt
agrep -0 -c 'GGCTGAATTCAATTGCC' *.fastq > count/B14532_Rm0.txt
agrep -0 -c 'TCATTGGTGTTCGAGCT' *.fastq > count/B14533_Rm0.txt
agrep -0 -c 'ACATACCCGGTTAGCCT' *.fastq > count/B14534_Rm0.txt
agrep -0 -c 'GGAGAAAGCCCTATAAT' *.fastq > count/B14535_Rm0.txt
agrep -0 -c 'GCGACCACGGCTATATC' *.fastq > count/B14536_Rm0.txt
agrep -0 -c 'CATATGGTAGAGCAGTG' *.fastq > count/B14537_Rm0.txt
agrep -0 -c 'TACCTCCTAGAACGGCT' *.fastq > count/B14538_Rm0.txt
agrep -0 -c 'TAGGTAAGCGAGGGAAG' *.fastq > count/B14539_Rm0.txt
agrep -0 -c 'AAAACACTACCGTTTGC' *.fastq > count/B14540_Rm0.txt
agrep -0 -c 'TAGTGCCGTTTCGACTC' *.fastq > count/B14541_Rm0.txt
agrep -0 -c 'AAGCAAAGGCGACGATC' *.fastq > count/B14542_Rm0.txt
agrep -0 -c 'TGTCCGTCCGTTCGATC' *.fastq > count/B14543_Rm0.txt
agrep -0 -c 'AAGCAACCATCGAATGA' *.fastq > count/B14545_Rm0.txt
agrep -0 -c 'ATCGAATAGGAGACCTG' *.fastq > count/B14546_Rm0.txt
agrep -0 -c 'TATTCAGATGCCGCTGG' *.fastq > count/B14547_Rm0.txt
agrep -0 -c 'TTGAGGCACTCGTCATA' *.fastq > count/B14548_Rm0.txt
agrep -0 -c 'GAGGATTCCGTTAATGG' *.fastq > count/B14549_Rm0.txt
agrep -0 -c 'AAGAGCCCACCCTTGTC' *.fastq > count/B14550_Rm0.txt
agrep -0 -c 'CTTTGAAAGGACCACGT' *.fastq > count/B14551_Rm0.txt
agrep -0 -c 'GGCATTGTGTACGGGAC' *.fastq > count/B14552_Rm0.txt
agrep -0 -c 'TTGAGGGTCCAGCGGTA' *.fastq > count/B14553_Rm0.txt
agrep -0 -c 'CACTAATAAGGCGTAGT' *.fastq > count/B14554_Rm0.txt
agrep -0 -c 'GGCTGTAAGCATCAGTC' *.fastq > count/B14555_Rm0.txt
agrep -0 -c 'AGACGAGTTGTCGTAAC' *.fastq > count/B14556_Rm0.txt
agrep -0 -c 'CTCAACGGACAAAGCGG' *.fastq > count/B14557_Rm0.txt
agrep -0 -c 'ATTATCTCGTGAGGCAC' *.fastq > count/B14558_Rm0.txt
agrep -0 -c 'CTACGATATGTGGGTGC' *.fastq > count/B14559_Rm0.txt
agrep -0 -c 'ACAAGCAAGCCAGTTTG' *.fastq > count/B14561_Rm0.txt
agrep -0 -c 'GGTGGAGTTCGCGTCTT' *.fastq > count/B14562_Rm0.txt
agrep -0 -c 'CCGGGTATCTTCATTCA' *.fastq > count/B14563_Rm0.txt
agrep -0 -c 'AAGCCGCCTAATATCAT' *.fastq > count/B14564_Rm0.txt
agrep -0 -c 'TCTCTTATACTGCATGG' *.fastq > count/B14565_Rm0.txt
agrep -0 -c 'CTTAATAACAGCCGTTG' *.fastq > count/B14566_Rm0.txt
agrep -0 -c 'TTCATCTTTCCACGAGT' *.fastq > count/B14568_Rm0.txt
agrep -0 -c 'TACTGTATGGTCCGCGG' *.fastq > count/B14569_Rm0.txt
agrep -0 -c 'ACGCCAATTACAGGTCC' *.fastq > count/B14570_Rm0.txt
agrep -0 -c 'ATAGTCATGGGATCTTG' *.fastq > count/B14571_Rm0.txt
agrep -0 -c 'CATCCAGAATTGAACAC' *.fastq > count/B14572_Rm0.txt
agrep -0 -c 'GAAAGCTGGGCAATTAC' *.fastq > count/B14573_Rm0.txt
agrep -0 -c 'TTGGGCCATTAAAGTCA' *.fastq > count/B14574_Rm0.txt
agrep -0 -c 'TCGGACGGGATACTCCT' *.fastq > count/B14575_Rm0.txt
agrep -0 -c 'GTTCGAAAGTAGAGTAC' *.fastq > count/B14576_Rm0.txt
agrep -0 -c 'ATGACTTAGATGGGCGC' *.fastq > count/B14577_Rm0.txt
agrep -0 -c 'AGCATTTAAGGGACTGC' *.fastq > count/B14578_Rm0.txt
agrep -0 -c 'GACCTCTTGAGTAACGT' *.fastq > count/B14579_Rm0.txt
agrep -0 -c 'GCTGGTGTACGTAACAC' *.fastq > count/B14580_Rm0.txt
agrep -0 -c 'TCTCGATCTGCCGAGCT' *.fastq > count/B14581_Rm0.txt
agrep -0 -c 'CCTTCGACTGATGACCC' *.fastq > count/B14583_Rm0.txt
agrep -0 -c 'ATGTCAGATATCGACTC' *.fastq > count/B14584_Rm0.txt
agrep -0 -c 'CCGTTACGGCCTGTAAT' *.fastq > count/B14586_Rm0.txt
agrep -0 -c 'CGACGCAAACGTTCTAT' *.fastq > count/B14587_Rm0.txt
agrep -0 -c 'GGGTACCTGAGCTAATC' *.fastq > count/B14589_Rm0.txt
agrep -0 -c 'GCTGTCATTACTCCCGT' *.fastq > count/B14590_Rm0.txt
agrep -0 -c 'TGTTGGCCCTACTACGA' *.fastq > count/B14591_Rm0.txt
agrep -0 -c 'AACTGGGTAACCGTTGC' *.fastq > count/B14592_Rm0.txt
agrep -0 -c 'CCGCAGGGATTCCTTCA' *.fastq > count/B14593_Rm0.txt
agrep -0 -c 'TACGGAAACCAGCGAGA' *.fastq > count/B14594_Rm0.txt
agrep -0 -c 'CGAACTCGTCTTAGCAG' *.fastq > count/B14596_Rm0.txt
agrep -0 -c 'ATCCAATAGAACCCCCC' *.fastq > count/B14597_Rm0.txt
agrep -0 -c 'GCGAGATCGCGCTCAAT' *.fastq > count/B14598_Rm0.txt
agrep -0 -c 'TCGGACCGTTCTCAACA' *.fastq > count/B14599_Rm0.txt
agrep -0 -c 'TGCCGCTTTACGGATCA' *.fastq > count/B14600_Rm0.txt
agrep -0 -c 'CGGGACATTTTCTATGC' *.fastq > count/B14601_Rm0.txt
agrep -0 -c 'GCTAGAGTCATAGTAGA' *.fastq > count/B14602_Rm0.txt
agrep -0 -c 'TTTCCTAGTCCCCATCG' *.fastq > count/B14603_Rm0.txt
agrep -0 -c 'AACCTTCTAACGGGCTG' *.fastq > count/B14604_Rm0.txt
agrep -0 -c 'CCCTTTGACCATCGACG' *.fastq > count/B14606_Rm0.txt
agrep -0 -c 'AACCCATGCGCTCGTCT' *.fastq > count/B14607_Rm0.txt
agrep -0 -c 'ACACCAGCGCAATCGTG' *.fastq > count/B14608_Rm0.txt
agrep -0 -c 'CCCCTGGCACCTTAATG' *.fastq > count/B14610_Rm0.txt
agrep -0 -c 'GCGAGTGATTTTACAAG' *.fastq > count/B14612_Rm0.txt
agrep -0 -c 'TAACACGTTCGCTACAC' *.fastq > count/B14613_Rm0.txt
agrep -0 -c 'AGGCATGCTTAGCCATC' *.fastq > count/B14614_Rm0.txt
agrep -0 -c 'TTTATGTAGGTAGCGTC' *.fastq > count/B14615_Rm0.txt
agrep -0 -c 'ACGGCCTAGCTAACTCA' *.fastq > count/B14616_Rm0.txt
agrep -0 -c 'GGTGTGGCGACGCTTTA' *.fastq > count/B14618_Rm0.txt
agrep -0 -c 'CGTATACAGCCATCGTA' *.fastq > count/B14619_Rm0.txt
agrep -0 -c 'CCCCATCTCTTCGGTGA' *.fastq > count/B14620_Rm0.txt
agrep -0 -c 'AATTCCGTGCCTCAGTC' *.fastq > count/B14621_Rm0.txt
agrep -0 -c 'CTCGCAAGTAGGCAAGG' *.fastq > count/B14622_Rm0.txt
agrep -0 -c 'TGCCTACGGTTCCGATC' *.fastq > count/B14623_Rm0.txt
agrep -0 -c 'GGGGCACTTTTAGAATT' *.fastq > count/B14624_Rm0.txt
agrep -0 -c 'CTCAACCAGTCATACTC' *.fastq > count/B14625_Rm0.txt
agrep -0 -c 'CGGACCAATAACTCATC' *.fastq > count/B14626_Rm0.txt
agrep -0 -c 'GGCCGTTTAGGTTAATC' *.fastq > count/B14628_Rm0.txt
agrep -0 -c 'GCTCTATGACCATAAGT' *.fastq > count/B14629_Rm0.txt
agrep -0 -c 'AACTTATCGCTTGTCAG' *.fastq > count/B14630_Rm0.txt
agrep -0 -c 'CCCGTGTTAGACATCGG' *.fastq > count/B14631_Rm0.txt
agrep -0 -c 'ACGAAGTCGATTGCTGC' *.fastq > count/B14632_Rm0.txt
agrep -0 -c 'AGCTGTAATCTGCACGA' *.fastq > count/B14633_Rm0.txt
agrep -0 -c 'GTAGGAGAAGACCCTGA' *.fastq > count/B14634_Rm0.txt
agrep -0 -c 'GTCATCGTAGTCTGTAC' *.fastq > count/B14636_Rm0.txt
agrep -0 -c 'TCTATGTGAGGTTTGCG' *.fastq > count/B14637_Rm0.txt
agrep -0 -c 'CGACGGACTTAAGTAGC' *.fastq > count/B14638_Rm0.txt
agrep -0 -c 'TCAAGTAAGATGTCTCC' *.fastq > count/B14639_Rm0.txt
agrep -0 -c 'AGCATAGCCGTTGACGC' *.fastq > count/B14641_Rm0.txt
agrep -0 -c 'CCCTCTGCGGATACACA' *.fastq > count/B14642_Rm0.txt
agrep -0 -c 'TCTGCCATGAGGAACGT' *.fastq > count/B14643_Rm0.txt
agrep -0 -c 'CTCCGGGTATATGCTCT' *.fastq > count/B14644_Rm0.txt
agrep -0 -c 'CACCTCCGTTCACTTCA' *.fastq > count/B14645_Rm0.txt
agrep -0 -c 'GGCGAAATACGAAATTG' *.fastq > count/B14646_Rm0.txt
agrep -0 -c 'TAATGGAGGGCCATGAA' *.fastq > count/B14647_Rm0.txt
agrep -0 -c 'ACGTTCCGAACCAAACT' *.fastq > count/B14648_Rm0.txt
agrep -0 -c 'ACATCTACCCGGCTCGA' *.fastq > count/B14649_Rm0.txt
agrep -0 -c 'CTAAGGCATTGATTCTC' *.fastq > count/B14650_Rm0.txt
agrep -0 -c 'CCTACACAGGGCTCTCT' *.fastq > count/B14651_Rm0.txt
agrep -0 -c 'CAAACTTCAACTTCCAG' *.fastq > count/B14652_Rm0.txt
agrep -0 -c 'CCGCGGTTGAAGTAGCA' *.fastq > count/B14653_Rm0.txt
agrep -0 -c 'CTAATCTAGCGCCACAG' *.fastq > count/B14656_Rm0.txt
agrep -0 -c 'GCCAAAACTGCGGGGAT' *.fastq > count/B14657_Rm0.txt
agrep -0 -c 'GCATGTTTACACCGCTG' *.fastq > count/B14658_Rm0.txt
agrep -0 -c 'ATTCAATCGCCGACGTT' *.fastq > count/B14659_Rm0.txt
agrep -0 -c 'CTATGTCAGACGCAGTA' *.fastq > count/B14660_Rm0.txt
agrep -0 -c 'GGCCCAGGGCATTCTAA' *.fastq > count/B14661_Rm0.txt
agrep -0 -c 'TCAGGGACAAGCCGGTA' *.fastq > count/B14662_Rm0.txt
agrep -0 -c 'AATCCAATCTCTGGGGT' *.fastq > count/B14663_Rm0.txt
agrep -0 -c 'TATCATTTTCGTTGCGG' *.fastq > count/B14664_Rm0.txt
agrep -0 -c 'GCGTGGCACGACGTAAT' *.fastq > count/B14665_Rm0.txt
agrep -0 -c 'GGAGTGGATGCTCAACA' *.fastq > count/B14666_Rm0.txt
agrep -0 -c 'CTCTCTTTTAGAACCAG' *.fastq > count/B14667_Rm0.txt
agrep -0 -c 'GAAATGTCTGTACCGTT' *.fastq > count/B14668_Rm0.txt
agrep -0 -c 'TAGGAAGGTTCCGATAG' *.fastq > count/B14669_Rm0.txt
agrep -0 -c 'TGGTGTGTAATCAGTAG' *.fastq > count/B14671_Rm0.txt
agrep -0 -c 'TTAGACCAAGTCGGTGT' *.fastq > count/B14672_Rm0.txt
agrep -0 -c 'CAATAACCCTCAGCGGT' *.fastq > count/B14674_Rm0.txt
agrep -0 -c 'TTCTGCGCTACCCTGAT' *.fastq > count/B14675_Rm0.txt
agrep -0 -c 'CCCAAAATACCTAGCAT' *.fastq > count/B14676_Rm0.txt
agrep -0 -c 'AACGGATTCAGCTAACA' *.fastq > count/B14677_Rm0.txt
agrep -0 -c 'AATCGGGCGCATGTTCC' *.fastq > count/B14678_Rm0.txt
agrep -0 -c 'CACCAATTCCGAACTCC' *.fastq > count/B14679_Rm0.txt
agrep -0 -c 'CTGAACTGACACAGTCC' *.fastq > count/B14680_Rm0.txt
agrep -0 -c 'ATTGTTGAGCCCTGGTG' *.fastq > count/B14681_Rm0.txt
agrep -0 -c 'ATTCTAGTGAAGGCAAC' *.fastq > count/B14682_Rm0.txt
agrep -0 -c 'GTTGGAAAAGGTCACGC' *.fastq > count/B14683_Rm0.txt
agrep -0 -c 'CCTGTAAGGTCTACAAG' *.fastq > count/B14684_Rm0.txt
agrep -0 -c 'CGCTGTGTGGATCGTAA' *.fastq > count/B14685_Rm0.txt
agrep -0 -c 'ATTCTTTGTTCCCTTGG' *.fastq > count/B14686_Rm0.txt
agrep -0 -c 'ACTCTTGAGCTTGCGAT' *.fastq > count/B14688_Rm0.txt
agrep -0 -c 'CTAAGGCCTGATGTCAG' *.fastq > count/B14690_Rm0.txt
agrep -0 -c 'TTCAGGGCACGATAATG' *.fastq > count/B14692_Rm0.txt
agrep -0 -c 'GTTCCCACGTCTTTACC' *.fastq > count/B14694_Rm0.txt
agrep -0 -c 'AGATACCTAACCACAGG' *.fastq > count/B14695_Rm0.txt
agrep -0 -c 'ATGGGCTCCTTCTTCAC' *.fastq > count/B14696_Rm0.txt
agrep -0 -c 'AGTACGTCCCTAAATTG' *.fastq > count/B14698_Rm0.txt
agrep -0 -c 'AACGTTTATCCAGGCCC' *.fastq > count/B14699_Rm0.txt
agrep -0 -c 'AGTCTGCTCTAAGGACC' *.fastq > count/B14700_Rm0.txt
agrep -0 -c 'CAGTCCCTACGTAAAGG' *.fastq > count/B14701_Rm0.txt
agrep -0 -c 'AAACCACATCCGAGACA' *.fastq > count/B14702_Rm0.txt
agrep -0 -c 'AAGCGCCTTCATTGTAT' *.fastq > count/B14703_Rm0.txt
agrep -0 -c 'CCGTACTAATCCGACCT' *.fastq > count/B14704_Rm0.txt
agrep -0 -c 'AGTGTTATGTCTCCCCC' *.fastq > count/B14705_Rm0.txt
agrep -0 -c 'ATCTTGGCAAGGGACGT' *.fastq > count/B14706_Rm0.txt
agrep -0 -c 'CTCGCCTGATGTACGCT' *.fastq > count/B14707_Rm0.txt
agrep -0 -c 'CGGCGGTCAATCATAAT' *.fastq > count/B14708_Rm0.txt
agrep -0 -c 'AAGTCGACTGTGCTACG' *.fastq > count/B14709_Rm0.txt
agrep -0 -c 'TTTGTTGGGCTATCATC' *.fastq > count/B14711_Rm0.txt
agrep -0 -c 'CGATAAGGGTGTGACCG' *.fastq > count/B14712_Rm0.txt
agrep -0 -c 'CCTACGAGCTAGATCGT' *.fastq > count/B14713_Rm0.txt
agrep -0 -c 'ACGGTATGAGGGACGAT' *.fastq > count/B14715_Rm0.txt
agrep -0 -c 'TGAGACCGCTGCTACGT' *.fastq > count/B14716_Rm0.txt
agrep -0 -c 'CTATGAGAGGTGACTGG' *.fastq > count/B14717_Rm0.txt
agrep -0 -c 'GAACGTGCTATTGTCTC' *.fastq > count/B14718_Rm0.txt
agrep -0 -c 'AGAACGATTAACAGAGG' *.fastq > count/B14719_Rm0.txt
agrep -0 -c 'ACCAATACCCTTCCGAC' *.fastq > count/B14721_Rm0.txt
agrep -0 -c 'CTACTTTAAGAATGCGC' *.fastq > count/B14722_Rm0.txt
agrep -0 -c 'CCACTAGAAACGCCTAG' *.fastq > count/B14723_Rm0.txt
agrep -0 -c 'TCCGCGATATTTTGGGC' *.fastq > count/B14724_Rm0.txt
agrep -0 -c 'TACATACCAGGTAGGAC' *.fastq > count/B14726_Rm0.txt
agrep -0 -c 'ATTGGCGCTTAGAACAT' *.fastq > count/B14727_Rm0.txt
agrep -0 -c 'GTACCTACCGTTGAACA' *.fastq > count/B14728_Rm0.txt
agrep -0 -c 'CGTACCTTACCTAGAAT' *.fastq > count/B14729_Rm0.txt
agrep -0 -c 'TAAGTGGGGATGAACGA' *.fastq > count/B14730_Rm0.txt
agrep -0 -c 'TTGTGCGTACACGGACG' *.fastq > count/B14732_Rm0.txt
agrep -0 -c 'GGCAATAATTGGTCTAG' *.fastq > count/B14733_Rm0.txt
agrep -0 -c 'ACGATTCGCCACAAGAG' *.fastq > count/B14734_Rm0.txt
agrep -0 -c 'TACGCTCATTAGATCAC' *.fastq > count/B14735_Rm0.txt
agrep -0 -c 'AGGGAATTGAGCGACCC' *.fastq > count/B14736_Rm0.txt
agrep -0 -c 'AATTAGGACCCCTGTGG' *.fastq > count/B14737_Rm0.txt
agrep -0 -c 'GATCTACACTCGGCGTG' *.fastq > count/B14738_Rm0.txt
agrep -0 -c 'CTCACCGACCCTTAGAT' *.fastq > count/B14739_Rm0.txt
agrep -0 -c 'TGTGACCGGGATAACCT' *.fastq > count/B14740_Rm0.txt
agrep -0 -c 'GATGTTCCCTTGCATAG' *.fastq > count/B14741_Rm0.txt
agrep -0 -c 'CAGAAGATCATCCTCAC' *.fastq > count/B14742_Rm0.txt
agrep -0 -c 'TGTTTGCATCGTGACCC' *.fastq > count/B14743_Rm0.txt
agrep -0 -c 'GCTTTCATGCCGCTTAG' *.fastq > count/B14744_Rm0.txt
agrep -0 -c 'AGCAGGCACATGGACGT' *.fastq > count/B14745_Rm0.txt
agrep -0 -c 'AGATATGTCTAGCTCGC' *.fastq > count/B14747_Rm0.txt
agrep -0 -c 'AGGCCCACACGTTTTTG' *.fastq > count/B14748_Rm0.txt
agrep -0 -c 'ATCAAACGCTGTGGACT' *.fastq > count/B14749_Rm0.txt
agrep -0 -c 'TCGCCTGTGTGCTTACA' *.fastq > count/B14751_Rm0.txt
agrep -0 -c 'GGCCACGAAAGAATGCG' *.fastq > count/B14752_Rm0.txt
agrep -0 -c 'CGGTGCTTCCATGGTAC' *.fastq > count/B14753_Rm0.txt
agrep -0 -c 'CGCATGAGGACTTATAA' *.fastq > count/B14755_Rm0.txt
agrep -0 -c 'GTCGGATACTCTGGTGC' *.fastq > count/B14757_Rm0.txt
agrep -0 -c 'GTAATAGTCGGCCCAAG' *.fastq > count/B14758_Rm0.txt
agrep -0 -c 'ACACCCAATTTTCGCCG' *.fastq > count/B14759_Rm0.txt
agrep -0 -c 'GTACCTAATCGACGCTA' *.fastq > count/B14760_Rm0.txt
agrep -0 -c 'TCTGACCATCGTGTTCA' *.fastq > count/B14761_Rm0.txt
agrep -0 -c 'CCGATGTGCTCGTAAAC' *.fastq > count/B14763_Rm0.txt
agrep -0 -c 'CATAATGCAGGATCGTC' *.fastq > count/B14765_Rm0.txt
agrep -0 -c 'TTGATTCCGACGAATCT' *.fastq > count/B14766_Rm0.txt
agrep -0 -c 'CGATAGAGGCTCACGAC' *.fastq > count/B14767_Rm0.txt
agrep -0 -c 'TTCATGCCGAACTCCGG' *.fastq > count/B14768_Rm0.txt
agrep -0 -c 'AGGACGGTCCTCATGAA' *.fastq > count/B14769_Rm0.txt
agrep -0 -c 'ATCTGCAGGGGTCATAC' *.fastq > count/B14770_Rm0.txt
agrep -0 -c 'GATCTAGTTCGGGGAAT' *.fastq > count/B14771_Rm0.txt
agrep -0 -c 'ACCTTTCTTACCAATCC' *.fastq > count/B14772_Rm0.txt
agrep -0 -c 'GTGGTCGTTGCATGTTA' *.fastq > count/B14773_Rm0.txt
agrep -0 -c 'ATTATAGCGCAAGCGCG' *.fastq > count/B14774_Rm0.txt
agrep -0 -c 'AAAAGCGAGAGCGGATT' *.fastq > count/B14775_Rm0.txt
agrep -0 -c 'GCTATAGCCTTCCACGC' *.fastq > count/B14778_Rm0.txt
agrep -0 -c 'ACGGCCTCGTTGCTTAC' *.fastq > count/B14779_Rm0.txt
agrep -0 -c 'GCTAACCCCGTTAAAGG' *.fastq > count/B14780_Rm0.txt
agrep -0 -c 'TTCGGGGATACCATCCG' *.fastq > count/B14781_Rm0.txt
agrep -0 -c 'CCGTATTCTTGAACGCC' *.fastq > count/B14782_Rm0.txt
agrep -0 -c 'CAAGCTCGCCGTTTAAC' *.fastq > count/B14783_Rm0.txt
agrep -0 -c 'TCAGGTTCAGCACTGCG' *.fastq > count/B14784_Rm0.txt
agrep -0 -c 'CCCGTGCATTAGGATAT' *.fastq > count/B14785_Rm0.txt
agrep -0 -c 'AAGATCCGCTCATGCCG' *.fastq > count/B14786_Rm0.txt
agrep -0 -c 'TTAGCCGGAACTACGGC' *.fastq > count/B14787_Rm0.txt
agrep -0 -c 'TATTATGATGTTCCGGC' *.fastq > count/B14788_Rm0.txt
agrep -0 -c 'GAAAGCGCTTTTAGGCT' *.fastq > count/B14789_Rm0.txt
agrep -0 -c 'TTTAGCGCCAACCGTGA' *.fastq > count/B14790_Rm0.txt
agrep -0 -c 'GAATACTTCGGCACAAT' *.fastq > count/B14791_Rm0.txt
agrep -0 -c 'GAACGTTGCATAATAGC' *.fastq > count/B14792_Rm0.txt
agrep -0 -c 'GCTATCAAATCGTCTAC' *.fastq > count/B14795_Rm0.txt
agrep -0 -c 'GCATATCTTTACTCGAC' *.fastq > count/B14796_Rm0.txt
agrep -0 -c 'TGTGCTAGCGCCGTCAT' *.fastq > count/B14797_Rm0.txt
agrep -0 -c 'ATAGACGTCGATACGAC' *.fastq > count/B14798_Rm0.txt
agrep -0 -c 'TGCCGTCCTTATCGTCT' *.fastq > count/B14799_Rm0.txt
agrep -0 -c 'CTCCTCCTACGAAGAAG' *.fastq > count/B14800_Rm0.txt
agrep -0 -c 'AATAGGAGGGTAAGTGA' *.fastq > count/B14801_Rm0.txt
agrep -0 -c 'TCGCACTACTCCCCGAT' *.fastq > count/B14802_Rm0.txt
agrep -0 -c 'ATGGTAATCCACGAATG' *.fastq > count/B14803_Rm0.txt
agrep -0 -c 'GCAGCACCAGGCTTAGA' *.fastq > count/B14806_Rm0.txt
agrep -0 -c 'ATCTCGAAACGGGAACG' *.fastq > count/B14807_Rm0.txt
agrep -0 -c 'GATGCAGTGCGTAGCTT' *.fastq > count/B14808_Rm0.txt
agrep -0 -c 'TCTGTAACCCAGAACAT' *.fastq > count/B14809_Rm0.txt
agrep -0 -c 'TCGTGCTATATGTCAGC' *.fastq > count/B14810_Rm0.txt
agrep -0 -c 'TGGTACGATTGGCTCTC' *.fastq > count/B14811_Rm0.txt
agrep -0 -c 'GCCGAATGAACCTAAAC' *.fastq > count/B14812_Rm0.txt
agrep -0 -c 'CGAGTACTCATTACATC' *.fastq > count/B14813_Rm0.txt
agrep -0 -c 'AGCTCAGACAATTGGGC' *.fastq > count/B14814_Rm0.txt
agrep -0 -c 'CTGGTCCGAACAGAGAG' *.fastq > count/B14815_Rm0.txt
agrep -0 -c 'ATCCAGTTAGCGCGTTA' *.fastq > count/B14816_Rm0.txt
agrep -0 -c 'GTCAAGTCGGCTCTTTG' *.fastq > count/B14817_Rm0.txt
agrep -0 -c 'AACACCGCCTGCTTACT' *.fastq > count/B14818_Rm0.txt
agrep -0 -c 'TAATAAGCCGCTGGCCT' *.fastq > count/B14819_Rm0.txt
agrep -0 -c 'CGTAGTCCAGATCTGCT' *.fastq > count/B14820_Rm0.txt
agrep -0 -c 'CCTCGTGTGGACATTGC' *.fastq > count/B14821_Rm0.txt
agrep -0 -c 'TGTAGAGCAGTCACGCA' *.fastq > count/B14822_Rm0.txt
agrep -0 -c 'GATATTGGAGGGCCCAA' *.fastq > count/B14823_Rm0.txt
agrep -0 -c 'TCGTTCCCTGGACTCTC' *.fastq > count/B14824_Rm0.txt
agrep -0 -c 'CTCTTGGATGACCACTG' *.fastq > count/B14826_Rm0.txt
agrep -0 -c 'TTGCTGCGGTGACGAAT' *.fastq > count/B14827_Rm0.txt
agrep -0 -c 'CGTTAGGACTAGCCAGC' *.fastq > count/B14828_Rm0.txt
agrep -0 -c 'GTTAAGCCGCGTTATTA' *.fastq > count/B14829_Rm0.txt
agrep -0 -c 'AGACTTCCACACCGGCT' *.fastq > count/B14830_Rm0.txt
agrep -0 -c 'GCATTTAGTACCCGCTA' *.fastq > count/B14831_Rm0.txt
agrep -0 -c 'CTATAATGGGTCACCTG' *.fastq > count/B14832_Rm0.txt
agrep -0 -c 'AGTTCGTTTCCGCATTG' *.fastq > count/B14833_Rm0.txt
agrep -0 -c 'TCGGCAGAGCCCTAATA' *.fastq > count/B14834_Rm0.txt
agrep -0 -c 'ATTCGGGCTGTCAGGAT' *.fastq > count/B14835_Rm0.txt
agrep -0 -c 'GATATTACGCGATGTCG' *.fastq > count/B14836_Rm0.txt
agrep -0 -c 'ATAAACCGCCAACGCTG' *.fastq > count/B14837_Rm0.txt
agrep -0 -c 'GTACAACTACACGTAAC' *.fastq > count/B14838_Rm0.txt
agrep -0 -c 'GCTTTATCGGCCGGCTT' *.fastq > count/B14839_Rm0.txt
agrep -0 -c 'CCTGCGACAATTAGCAT' *.fastq > count/B14843_Rm0.txt
agrep -0 -c 'GTATTCGGATCTATAGC' *.fastq > count/B14844_Rm0.txt
agrep -0 -c 'TAAGAGCGCGTGAGGTT' *.fastq > count/B14845_Rm0.txt
agrep -0 -c 'TCGGCTCACAGTACCTA' *.fastq > count/B14846_Rm0.txt
agrep -0 -c 'TTAGATGAGCTTCGCAG' *.fastq > count/B14847_Rm0.txt
agrep -0 -c 'GCTGATGGCTAGCATCC' *.fastq > count/B14848_Rm0.txt
agrep -0 -c 'TGACGAAAGGTCTTTCT' *.fastq > count/B14849_Rm0.txt
agrep -0 -c 'ACGATCAGACGTGTGAG' *.fastq > count/B14850_Rm0.txt
agrep -0 -c 'CTTGGTGTATCGTGTAG' *.fastq > count/B14852_Rm0.txt
agrep -0 -c 'CCACATCACCTACATCG' *.fastq > count/B14853_Rm0.txt
agrep -0 -c 'TTGACCCTCGATTGTGA' *.fastq > count/B14854_Rm0.txt
agrep -0 -c 'CTCTTCGGACCTTCCTG' *.fastq > count/B14855_Rm0.txt
agrep -0 -c 'AACCGTCGCGTCATTGA' *.fastq > count/B14857_Rm0.txt
agrep -0 -c 'GATGATGGTCATCCGAA' *.fastq > count/B14858_Rm0.txt
agrep -0 -c 'GTGTTGATATCGACTAC' *.fastq > count/B14859_Rm0.txt
agrep -0 -c 'TGAGATATCTGAGGACT' *.fastq > count/B14860_Rm0.txt
agrep -0 -c 'CCTTGCCGTCACGTGAA' *.fastq > count/B14861_Rm0.txt
agrep -0 -c 'AACCCTCGTGGACAGAC' *.fastq > count/B14862_Rm0.txt
agrep -0 -c 'CCTAACTCGTCAAGCAA' *.fastq > count/B14864_Rm0.txt
agrep -0 -c 'GATCTGCAATGACCTCT' *.fastq > count/B14865_Rm0.txt
agrep -0 -c 'CCTAACCGCCCATAGTC' *.fastq > count/B14866_Rm0.txt
agrep -0 -c 'ATAGGTCGAGTGGGCTC' *.fastq > count/B14867_Rm0.txt
agrep -0 -c 'GTAATGATCCGTTCAAG' *.fastq > count/B14868_Rm0.txt
agrep -0 -c 'AGTGTCGGTTGCCCAAT' *.fastq > count/B14870_Rm0.txt
agrep -0 -c 'CGATTGAAAAGGCCAAC' *.fastq > count/B14871_Rm0.txt
agrep -0 -c 'CTGTCTCGCGTAGATAA' *.fastq > count/B14872_Rm0.txt
agrep -0 -c 'CTCTAGAGGTCGAGGTA' *.fastq > count/B14873_Rm0.txt
agrep -0 -c 'GTCGCCTGAGATCCTAT' *.fastq > count/B14874_Rm0.txt
agrep -0 -c 'CGGAACGTGGTTTGGTC' *.fastq > count/B14875_Rm0.txt
agrep -0 -c 'GCCTTTTACTCTGGATT' *.fastq > count/B14876_Rm0.txt
agrep -0 -c 'GGGGGGAGGTAAGATCA' *.fastq > count/B14877_Rm0.txt
agrep -0 -c 'ATGAAAGCAACGCTGAA' *.fastq > count/B14878_Rm0.txt
agrep -0 -c 'ATGCCCATGCCTAGTAT' *.fastq > count/B14879_Rm0.txt
agrep -0 -c 'AAACCGAACTAGTATGG' *.fastq > count/B14880_Rm0.txt
agrep -0 -c 'TTGACTGACTCACAATG' *.fastq > count/B14881_Rm0.txt
agrep -0 -c 'CGCCGTCATATAACCTG' *.fastq > count/B14882_Rm0.txt
agrep -0 -c 'TTGCCCGGACAAATTCT' *.fastq > count/B14884_Rm0.txt
agrep -0 -c 'GGCGAGTTGTATATAGG' *.fastq > count/B14885_Rm0.txt
agrep -0 -c 'CGTCGTCCTAGTTCACA' *.fastq > count/B14887_Rm0.txt
agrep -0 -c 'CTGCGTTTGTGACCTAC' *.fastq > count/B14888_Rm0.txt
agrep -0 -c 'ACCGTTAAGCTGGTCGT' *.fastq > count/B14889_Rm0.txt
agrep -0 -c 'CCAATCAATCAGGGTGT' *.fastq > count/B14891_Rm0.txt
agrep -0 -c 'TTCTTTGAACAGTCCGG' *.fastq > count/B14894_Rm0.txt
agrep -0 -c 'TATCGTTTATGCGGCCC' *.fastq > count/B14895_Rm0.txt
agrep -0 -c 'CACCATAAGAGAGCACT' *.fastq > count/B14896_Rm0.txt
agrep -0 -c 'CATTAAGCCTACGTGTA' *.fastq > count/B14897_Rm0.txt
agrep -0 -c 'ACAGACCGAGTAAGCCT' *.fastq > count/B14898_Rm0.txt
agrep -0 -c 'CCCCATTCTAAACTTCA' *.fastq > count/B14899_Rm0.txt
agrep -0 -c 'CTCTAACGATGGAGGTA' *.fastq > count/B14900_Rm0.txt
agrep -0 -c 'GACAAGCGGTGCGTACA' *.fastq > count/B14901_Rm0.txt
agrep -0 -c 'TTCGGGCTCTTCGCATC' *.fastq > count/B14902_Rm0.txt
agrep -0 -c 'TTTGTTTTCGACTCGTC' *.fastq > count/B14903_Rm0.txt
agrep -0 -c 'TTACTTATAAGGCGGGC' *.fastq > count/B14905_Rm0.txt
agrep -0 -c 'AATGAGCGTATCGTCAC' *.fastq > count/B14906_Rm0.txt
agrep -0 -c 'GACTGTCTTTGGACCAC' *.fastq > count/B14907_Rm0.txt
agrep -0 -c 'TAGTCCGGGTGCTTATA' *.fastq > count/B14908_Rm0.txt
agrep -0 -c 'CCGGATACTTGTGCGTC' *.fastq > count/B14911_Rm0.txt
agrep -0 -c 'AGCTCAGATAACTCCGA' *.fastq > count/B14912_Rm0.txt
agrep -0 -c 'GATCCACATCATCCGCA' *.fastq > count/B14913_Rm0.txt
agrep -0 -c 'GAGGACGACCCTCTATG' *.fastq > count/B14915_Rm0.txt
agrep -0 -c 'ACCTCTCTACGATCGGT' *.fastq > count/B14917_Rm0.txt
agrep -0 -c 'CAGTACAGTCAGCTGTG' *.fastq > count/B14919_Rm0.txt
agrep -0 -c 'GAGGTTATGTCTGTAGC' *.fastq > count/B14920_Rm0.txt
agrep -0 -c 'GGACAATAGTTAAGCGG' *.fastq > count/B14921_Rm0.txt
agrep -0 -c 'AACCACGTCTAGTTTGA' *.fastq > count/B14922_Rm0.txt
agrep -0 -c 'TATCCTCAAGTCAGTTG' *.fastq > count/B14923_Rm0.txt
agrep -0 -c 'TCGGCAGTCCGTATTCC' *.fastq > count/B14924_Rm0.txt
agrep -0 -c 'GTCCATCAGTAGTATAG' *.fastq > count/B14925_Rm0.txt
agrep -0 -c 'AGACGGCATGTAGCACT' *.fastq > count/B14927_Rm0.txt
agrep -0 -c 'CTGTCCGTATCACCTCA' *.fastq > count/B14929_Rm0.txt
agrep -0 -c 'ACTTCGAAATACCGGTA' *.fastq > count/B14930_Rm0.txt
agrep -0 -c 'CGAAAGGCAAGAATGTG' *.fastq > count/B14931_Rm0.txt
agrep -0 -c 'CTCTGCCTAAACCTCGA' *.fastq > count/B14932_Rm0.txt
agrep -0 -c 'CTCGGGAAATCAATCCA' *.fastq > count/B14933_Rm0.txt
agrep -0 -c 'GTCTCGAGTCTTAGTTG' *.fastq > count/B14934_Rm0.txt
agrep -0 -c 'CCAATGAATTGTCTCCC' *.fastq > count/B14935_Rm0.txt
agrep -0 -c 'GATCGACCTTTGTAGAT' *.fastq > count/B14936_Rm0.txt
agrep -0 -c 'GTCCAATATAGTAGTGC' *.fastq > count/B14937_Rm0.txt
agrep -0 -c 'TGGCTCGTTCAACGTAT' *.fastq > count/B14938_Rm0.txt
agrep -0 -c 'CATCCCTGCTCAATATA' *.fastq > count/B14939_Rm0.txt
agrep -0 -c 'CGAGGACAAGACTTGGT' *.fastq > count/B14940_Rm0.txt
agrep -0 -c 'ACCACTAAGAAAGGGGC' *.fastq > count/B14941_Rm0.txt
agrep -0 -c 'ACCCAGTTACGGCTACC' *.fastq > count/B14942_Rm0.txt
agrep -0 -c 'CCCTAGAGGCTTAACGA' *.fastq > count/B14943_Rm0.txt
agrep -0 -c 'CTGCATCAAGAACTCCT' *.fastq > count/B14944_Rm0.txt
agrep -0 -c 'CCCCAATCAGGCAATTA' *.fastq > count/B14945_Rm0.txt
agrep -0 -c 'CAACAGCCCATATCCGA' *.fastq > count/B14946_Rm0.txt
agrep -0 -c 'CAACACGTGACTTGCGA' *.fastq > count/B14950_Rm0.txt
agrep -0 -c 'GTCCTTTCTTCAACCGT' *.fastq > count/B14951_Rm0.txt
agrep -0 -c 'CATTCCGTCTGGAGATT' *.fastq > count/B14952_Rm0.txt
agrep -0 -c 'ATAAAGACCCAGCACAT' *.fastq > count/B14953_Rm0.txt
agrep -0 -c 'GAATGAGAGTCAACCCT' *.fastq > count/B14954_Rm0.txt
agrep -0 -c 'GAAGCGAAGTCCTATAT' *.fastq > count/B14955_Rm0.txt
agrep -0 -c 'TCACCGATTGGCTAGTA' *.fastq > count/B14956_Rm0.txt
agrep -0 -c 'AGCGATCGTACAGAGAG' *.fastq > count/B14958_Rm0.txt
agrep -0 -c 'CTGAAGTACAATCTACG' *.fastq > count/B14959_Rm0.txt
agrep -0 -c 'TGCACCCCGTACATCCA' *.fastq > count/B14961_Rm0.txt
agrep -0 -c 'AACTCGGTTATCGCAGT' *.fastq > count/B14962_Rm0.txt
agrep -0 -c 'TACACACTTGTGATCGA' *.fastq > count/B14963_Rm0.txt
agrep -0 -c 'ACCCTGGTGAGCAATAT' *.fastq > count/B14964_Rm0.txt
agrep -0 -c 'CATAACCGGCTCTTGGC' *.fastq > count/B14966_Rm0.txt
agrep -0 -c 'GCTCGTTCGGATTGCAA' *.fastq > count/B14967_Rm0.txt
agrep -0 -c 'TTGACCGGTTGAGTGAT' *.fastq > count/B14968_Rm0.txt
agrep -0 -c 'GTCTTAGCCATCCTACA' *.fastq > count/B14969_Rm0.txt
agrep -0 -c 'TCATTGCGCCCGTACAT' *.fastq > count/B14970_Rm0.txt
agrep -0 -c 'CCCAATGCCCACTTGAA' *.fastq > count/B14971_Rm0.txt
agrep -0 -c 'ACGCATCATGTCGCTTG' *.fastq > count/B14972_Rm0.txt
agrep -0 -c 'GAAAATGTCGGGCGGAG' *.fastq > count/B14973_Rm0.txt
agrep -0 -c 'GGACTAGTCTTTTGGCT' *.fastq > count/B14974_Rm0.txt
agrep -0 -c 'TCGACTTTGGCCGATAT' *.fastq > count/B14975_Rm0.txt
agrep -0 -c 'AGTTGGCCCTTTTTCAG' *.fastq > count/B14977_Rm0.txt
agrep -0 -c 'AGGATCCAGATTTCCTC' *.fastq > count/B14978_Rm0.txt
agrep -0 -c 'CGCGTAAACATCTCCGT' *.fastq > count/B14980_Rm0.txt
agrep -0 -c 'TTGCAGACGGTAAATGA' *.fastq > count/B14981_Rm0.txt
agrep -0 -c 'GACCTGCTAGGCTTCGT' *.fastq > count/B14982_Rm0.txt
agrep -0 -c 'TCTACGTTTCTTCCCTT' *.fastq > count/B14983_Rm0.txt
agrep -0 -c 'CATAATGCCCGCGTCAT' *.fastq > count/B14984_Rm0.txt
agrep -0 -c 'AGTTTAGGTAACCCAGT' *.fastq > count/B14985_Rm0.txt
agrep -0 -c 'TAAACGCGTTATGTGGT' *.fastq > count/B14986_Rm0.txt
agrep -0 -c 'CAATCCTGTTTGCACGA' *.fastq > count/B14987_Rm0.txt
agrep -0 -c 'TTCTTGATACGTCTGCT' *.fastq > count/B14988_Rm0.txt
agrep -0 -c 'TAAACCTAAGAGTCCCT' *.fastq > count/B14993_Rm0.txt
agrep -0 -c 'GGTTTGATTGCCCTACA' *.fastq > count/B14994_Rm0.txt
agrep -0 -c 'CTGCATCGTAACAAGGC' *.fastq > count/B14995_Rm0.txt
agrep -0 -c 'ATACGACAGAAGTCAGG' *.fastq > count/B14996_Rm0.txt
agrep -0 -c 'GCTTTATATTCGACTCC' *.fastq > count/B14997_Rm0.txt
agrep -0 -c 'AGGGGAGTAGAATAACA' *.fastq > count/B14999_Rm0.txt
agrep -0 -c 'GTCTGATGCAAGATACC' *.fastq > count/B15000_Rm0.txt
agrep -0 -c 'CAATGGCGGGCTACATG' *.fastq > count/B15001_Rm0.txt
agrep -0 -c 'ACCAACGGACCGCAAGA' *.fastq > count/B15002_Rm0.txt
agrep -0 -c 'GGGTTTCACTTGCGTCC' *.fastq > count/B15003_Rm0.txt
agrep -0 -c 'CTCAGGGTTGGTTCCGT' *.fastq > count/B15004_Rm0.txt
agrep -0 -c 'GCAATTGCGGTTCCGAC' *.fastq > count/B15005_Rm0.txt
agrep -0 -c 'GTATAGAGGGTGACAAT' *.fastq > count/B15006_Rm0.txt
agrep -0 -c 'GAGGGACAATATGTCAC' *.fastq > count/B15007_Rm0.txt
agrep -0 -c 'CCCTAACCGAACGTATG' *.fastq > count/B15008_Rm0.txt
agrep -0 -c 'GTGCCCTCATGACCAAC' *.fastq > count/B15010_Rm0.txt
agrep -0 -c 'GATAATAGGGGGCATGG' *.fastq > count/B15011_Rm0.txt
agrep -0 -c 'TGGACTAATGTAAGCGC' *.fastq > count/B15012_Rm0.txt
agrep -0 -c 'CAGGTATCCGATGATTA' *.fastq > count/B15013_Rm0.txt
agrep -0 -c 'ACATTGCGAAGTCGATC' *.fastq > count/B15014_Rm0.txt
agrep -0 -c 'ATCCTCGGGGGAATGTA' *.fastq > count/B15015_Rm0.txt
agrep -0 -c 'GTCCTTGTAGCCGCTAG' *.fastq > count/B15016_Rm0.txt
agrep -0 -c 'GTATACCGCGTTGCTGA' *.fastq > count/B15017_Rm0.txt
agrep -0 -c 'GTGGAAGCGGAGCTTAG' *.fastq > count/B15019_Rm0.txt
agrep -0 -c 'TCCTACAACGCGCCATC' *.fastq > count/B15020_Rm0.txt
agrep -0 -c 'TAGTTGTTGAGGTTCTG' *.fastq > count/B15021_Rm0.txt
agrep -0 -c 'AATATGGCGGTCGAGGC' *.fastq > count/B15022_Rm0.txt
agrep -0 -c 'CGATCTATTGATCCTGT' *.fastq > count/B15024_Rm0.txt
agrep -0 -c 'CTACCAATAGGAAGCGC' *.fastq > count/B15026_Rm0.txt
agrep -0 -c 'CTGATAAGCCTAGGTGT' *.fastq > count/B15029_Rm0.txt
agrep -0 -c 'CCGGAAAGTATATCGAA' *.fastq > count/B15030_Rm0.txt
agrep -0 -c 'CGATTTCTCCCTGTTAC' *.fastq > count/B15031_Rm0.txt
agrep -0 -c 'CCTTGAACCCCTACGTT' *.fastq > count/B15032_Rm0.txt
agrep -0 -c 'AATTCGACTTGGACTGC' *.fastq > count/B15033_Rm0.txt
agrep -0 -c 'ATTGTTCGGCCAGAAAT' *.fastq > count/B15034_Rm0.txt
agrep -0 -c 'GTTGCTCATCTAGAACC' *.fastq > count/B15035_Rm0.txt
agrep -0 -c 'TGGTGAAGAAGCGTCAA' *.fastq > count/B15036_Rm0.txt
agrep -0 -c 'CAGCTATGCAAAGGAGA' *.fastq > count/B15037_Rm0.txt
agrep -0 -c 'CCCAACTAGCAGTCGTA' *.fastq > count/B15038_Rm0.txt
agrep -0 -c 'AAAAAACCGGAATGAGC' *.fastq > count/B15039_Rm0.txt
agrep -0 -c 'GCTTTAAGCATGCGGTT' *.fastq > count/B15040_Rm0.txt
agrep -0 -c 'CAATGTGCGACTCACTA' *.fastq > count/B15041_Rm0.txt
agrep -0 -c 'GTGCGATTCACGCGTAT' *.fastq > count/B15044_Rm0.txt
agrep -0 -c 'GTTAAGTCACCTTTGTC' *.fastq > count/B15045_Rm0.txt
agrep -0 -c 'GTTGCCATGCTTGATAC' *.fastq > count/B15046_Rm0.txt
agrep -0 -c 'GATGGGTTAGTTCGTAT' *.fastq > count/B15047_Rm0.txt
agrep -0 -c 'AGCACTTAGTTCACGAG' *.fastq > count/B15048_Rm0.txt
agrep -0 -c 'GATAAAGTATGCTGTCG' *.fastq > count/B15049_Rm0.txt
agrep -0 -c 'AAGGGTGAGCAGGTGCA' *.fastq > count/B15050_Rm0.txt
agrep -0 -c 'TAGGAAGGGTGTCCGCT' *.fastq > count/B15052_Rm0.txt
agrep -0 -c 'GTGTCAGTCGGATAACT' *.fastq > count/B15053_Rm0.txt
agrep -0 -c 'CCCGATTAACTACAATC' *.fastq > count/B15054_Rm0.txt
agrep -0 -c 'GTGGCTCATATCACCGA' *.fastq > count/B15055_Rm0.txt
agrep -0 -c 'AGAGGGCTACATAAGTC' *.fastq > count/B15056_Rm0.txt
agrep -0 -c 'GCTTACAAAGTACGATC' *.fastq > count/B15057_Rm0.txt
agrep -0 -c 'GGTACTGGTATGGCCAG' *.fastq > count/B15058_Rm0.txt
agrep -0 -c 'CTAGCACGACTTAATTG' *.fastq > count/B15059_Rm0.txt
agrep -0 -c 'AGACACCGAAGGGCACT' *.fastq > count/B15061_Rm0.txt
agrep -0 -c 'AGGTGCGTCCGTATTTG' *.fastq > count/B15062_Rm0.txt
agrep -0 -c 'ACGTTGAGGATGACACG' *.fastq > count/B15063_Rm0.txt
agrep -0 -c 'AAGTACTGCCGAGTGAG' *.fastq > count/B15064_Rm0.txt
agrep -0 -c 'TTTGCGCATAATACTGC' *.fastq > count/B15066_Rm0.txt
agrep -0 -c 'GCATACGTAATTTGCTG' *.fastq > count/B15067_Rm0.txt
agrep -0 -c 'ACATCGTCATGGGTACT' *.fastq > count/B15069_Rm0.txt
agrep -0 -c 'GGGGTCGTGAAACGATG' *.fastq > count/B15070_Rm0.txt
agrep -0 -c 'AATGGCTGTAATAGGCG' *.fastq > count/B15071_Rm0.txt
agrep -0 -c 'CTGGGATTGACGGCAGT' *.fastq > count/B15072_Rm0.txt
agrep -0 -c 'GAGGTGCGTTAGATTCC' *.fastq > count/B15073_Rm0.txt
agrep -0 -c 'GAGTGACTGACTAACAA' *.fastq > count/B15074_Rm0.txt
agrep -0 -c 'GTCTCGCGATACAGCAG' *.fastq > count/B15075_Rm0.txt
agrep -0 -c 'GCGTGGCTGGGACAAAT' *.fastq > count/B15076_Rm0.txt
agrep -0 -c 'ACGGAATAAATTGGACC' *.fastq > count/B15077_Rm0.txt
agrep -0 -c 'AACCAATAGTAGGGACA' *.fastq > count/B15078_Rm0.txt
agrep -0 -c 'CAAGAATGCGGTCTCTA' *.fastq > count/B15079_Rm0.txt
agrep -0 -c 'AACCAACGAGAAGTCGT' *.fastq > count/B15080_Rm0.txt
agrep -0 -c 'GTCGCTCCTCGTAATGC' *.fastq > count/B15081_Rm0.txt
agrep -0 -c 'CCTGCGCAGGGTTGTTA' *.fastq > count/B15082_Rm0.txt
agrep -0 -c 'CGAGTCCGTTTTTTATG' *.fastq > count/B15083_Rm0.txt
agrep -0 -c 'GCATTGCTATCGAACTC' *.fastq > count/B15084_Rm0.txt
agrep -0 -c 'CCGTACGTTACGAAAGG' *.fastq > count/B15086_Rm0.txt
agrep -0 -c 'TAGGAGTTGCAGCTAGG' *.fastq > count/B15087_Rm0.txt
agrep -0 -c 'CCCTATTCGATCTGTCC' *.fastq > count/B15088_Rm0.txt
agrep -0 -c 'ATATCACTTGGCGGACA' *.fastq > count/B15089_Rm0.txt
agrep -0 -c 'AGAATCTCAGACTCCTC' *.fastq > count/B15090_Rm0.txt
agrep -0 -c 'CTTTTACCCCTGTCATC' *.fastq > count/B15091_Rm0.txt
agrep -0 -c 'GCTATGCTGCGGACCTT' *.fastq > count/B15094_Rm0.txt
agrep -0 -c 'CTGACGGAAAGCAGAGG' *.fastq > count/B15095_Rm0.txt
agrep -0 -c 'GGATGTATTCCGGTGAC' *.fastq > count/B15096_Rm0.txt
agrep -0 -c 'GATTAGTCTGTCGTTGA' *.fastq > count/B15098_Rm0.txt
agrep -0 -c 'ACGCTTCGTGTACTGCG' *.fastq > count/B15099_Rm0.txt
agrep -0 -c 'TCACCGAAACGTAAGAT' *.fastq > count/B15100_Rm0.txt
agrep -0 -c 'TCTATACGGACATCCAA' *.fastq > count/B15101_Rm0.txt
agrep -0 -c 'AGCGTCCTTGGTATCAT' *.fastq > count/B15103_Rm0.txt
agrep -0 -c 'CTGTAGCCAACTTGTGA' *.fastq > count/B15104_Rm0.txt
agrep -0 -c 'AGTCCAACGTGCTGGCT' *.fastq > count/B15105_Rm0.txt
agrep -0 -c 'CATTGGGCTCCTGGTAA' *.fastq > count/B15106_Rm0.txt
agrep -0 -c 'GACTCGGCTGTAGCGAT' *.fastq > count/B15107_Rm0.txt
agrep -0 -c 'GTGCAGTTCGGAACATC' *.fastq > count/B15108_Rm0.txt
agrep -0 -c 'CCAATGACGCGGGTCAT' *.fastq > count/B15109_Rm0.txt
agrep -0 -c 'ACTCATCAACTCGTGTT' *.fastq > count/B15111_Rm0.txt
agrep -0 -c 'ATAGCTCTACGCCCCAA' *.fastq > count/B15112_Rm0.txt
agrep -0 -c 'CGGGATTTTCCGCTACG' *.fastq > count/B15113_Rm0.txt
agrep -0 -c 'AATTAGACTAGCCTGCT' *.fastq > count/B15115_Rm0.txt
agrep -0 -c 'TTCTCCTCCTTGCCGCA' *.fastq > count/B15116_Rm0.txt
agrep -0 -c 'CTTGGAGAAAGATGTCA' *.fastq > count/B15120_Rm0.txt
agrep -0 -c 'ACGACTTCTCCCGGTGA' *.fastq > count/B15121_Rm0.txt
agrep -0 -c 'ATGAGTCGCTCCGTACG' *.fastq > count/B15122_Rm0.txt
agrep -0 -c 'TGGCTCATGGCCAGTCT' *.fastq > count/B15124_Rm0.txt
agrep -0 -c 'AATGTAGAGTTCGCAGT' *.fastq > count/B15126_Rm0.txt
agrep -0 -c 'TTGAGAATACGGATTCG' *.fastq > count/B15127_Rm0.txt
agrep -0 -c 'ACCACCGTGCTTCTTGG' *.fastq > count/B15128_Rm0.txt
agrep -0 -c 'CCACATAGAGTATTGGC' *.fastq > count/B15129_Rm0.txt
agrep -0 -c 'CATGGTGTCGCACGTAC' *.fastq > count/B15130_Rm0.txt
agrep -0 -c 'TATATGCGGGCTGCGCT' *.fastq > count/B15131_Rm0.txt
agrep -0 -c 'AACCCCGGTAGAGTGAA' *.fastq > count/B15132_Rm0.txt
agrep -0 -c 'GAGTCCGGATGCCTGAT' *.fastq > count/B15133_Rm0.txt
agrep -0 -c 'TAATCCAGGTAACAGGT' *.fastq > count/B15134_Rm0.txt
agrep -0 -c 'AGGTCACGTAGAGCCTT' *.fastq > count/B15136_Rm0.txt
agrep -0 -c 'GCGACAGCCTATGTCGA' *.fastq > count/B15137_Rm0.txt
agrep -0 -c 'GATGTTAGAGCAACCAA' *.fastq > count/B15138_Rm0.txt
agrep -0 -c 'GGATCAACCTAGCCTAT' *.fastq > count/B15139_Rm0.txt
agrep -0 -c 'ATGATAGGCTGGATTCG' *.fastq > count/B15140_Rm0.txt
agrep -0 -c 'GTATTACCGCTGCCGAA' *.fastq > count/B15141_Rm0.txt
agrep -0 -c 'TTAGGCGCAACTATGTC' *.fastq > count/B15142_Rm0.txt
agrep -0 -c 'CAGGGAGATGAGGTCGA' *.fastq > count/B15143_Rm0.txt
agrep -0 -c 'TGAAAATCGTTGGTGGT' *.fastq > count/B15144_Rm0.txt
agrep -0 -c 'CAAGGCAACAACGCTAG' *.fastq > count/B15145_Rm0.txt
agrep -0 -c 'AGTTCGTAGCATGAGTT' *.fastq > count/B15146_Rm0.txt
agrep -0 -c 'AGTATAGACGCCTGCCC' *.fastq > count/B15147_Rm0.txt
agrep -0 -c 'CTACGCGCATAGACCGA' *.fastq > count/B15148_Rm0.txt
agrep -0 -c 'ATTTCCGCCAGCCTCTA' *.fastq > count/B15149_Rm0.txt
agrep -0 -c 'CAAGTAGGCTAGAGGCT' *.fastq > count/B15150_Rm0.txt
agrep -0 -c 'ATACGCGTTTCCCATGT' *.fastq > count/B15151_Rm0.txt
agrep -0 -c 'ATCCAGTCGTATGAACC' *.fastq > count/B15152_Rm0.txt
agrep -0 -c 'GGATACGGATAGGTTGT' *.fastq > count/B15153_Rm0.txt
agrep -0 -c 'TCGATGTTTCCGCCTGC' *.fastq > count/B15154_Rm0.txt
agrep -0 -c 'ACCAGTGAGACCCGTAT' *.fastq > count/B15156_Rm0.txt
agrep -0 -c 'TTTCACTCAGGTGCACT' *.fastq > count/B15157_Rm0.txt
agrep -0 -c 'CAATGGGTGTACCCATC' *.fastq > count/B15158_Rm0.txt
agrep -0 -c 'GTATGTCCTCACCATCA' *.fastq > count/B15159_Rm0.txt
agrep -0 -c 'CCTACGTCTTCCCACTG' *.fastq > count/B15160_Rm0.txt
agrep -0 -c 'TCTCCCCTAAGCTGGAT' *.fastq > count/B15161_Rm0.txt
agrep -0 -c 'TGCAGGCATCTACACTA' *.fastq > count/B15162_Rm0.txt
agrep -0 -c 'GGGACAGTGCGTGTCAA' *.fastq > count/B15163_Rm0.txt
agrep -0 -c 'ACACTTCAGTAGCGATA' *.fastq > count/B15164_Rm0.txt
agrep -0 -c 'GTAGGCTGGCGAAAGTG' *.fastq > count/B15165_Rm0.txt
agrep -0 -c 'GCGCCATACTGCATAGT' *.fastq > count/B15166_Rm0.txt
agrep -0 -c 'CCAAAACGCTCGATGAC' *.fastq > count/B15167_Rm0.txt
agrep -0 -c 'AATGTTATCACGCCAGA' *.fastq > count/B15168_Rm0.txt
agrep -0 -c 'AGGAAGAAGCTATCGGC' *.fastq > count/B15169_Rm0.txt
agrep -0 -c 'ATGTGGCAAGAATGGGC' *.fastq > count/B15170_Rm0.txt
agrep -0 -c 'ATGTAGTTGGGACTCGG' *.fastq > count/B15171_Rm0.txt
agrep -0 -c 'ATGCCATGTCCCCGGTA' *.fastq > count/B15172_Rm0.txt
agrep -0 -c 'AGTATTATACCACGCCG' *.fastq > count/B15173_Rm0.txt
agrep -0 -c 'AGGTCTCTAAAGCGAGC' *.fastq > count/B15174_Rm0.txt
agrep -0 -c 'TAATGCATAGGCCAACT' *.fastq > count/B15175_Rm0.txt
agrep -0 -c 'GAGAGTTTGGTCGTCTT' *.fastq > count/B15176_Rm0.txt
agrep -0 -c 'CCACCGACTGCCGATAA' *.fastq > count/B15178_Rm0.txt
agrep -0 -c 'TCTGGCTCTTGAGCACT' *.fastq > count/B15179_Rm0.txt
agrep -0 -c 'AACCAGGGGTGTGATTA' *.fastq > count/B15181_Rm0.txt
agrep -0 -c 'TACGTACGATAGGACAA' *.fastq > count/B15182_Rm0.txt
agrep -0 -c 'TTGCTGATCAGTTAGCG' *.fastq > count/B15183_Rm0.txt
agrep -0 -c 'AATTGAATCGGCCACGC' *.fastq > count/B15185_Rm0.txt
agrep -0 -c 'GTGGAAAATTCAACCGG' *.fastq > count/B15186_Rm0.txt
agrep -0 -c 'GACCTGGGAGTTACAGG' *.fastq > count/B15187_Rm0.txt
agrep -0 -c 'CCACTAGAGGATCGAAC' *.fastq > count/B15188_Rm0.txt
agrep -0 -c 'CCATTCGTTGCCAGCAT' *.fastq > count/B15189_Rm0.txt
agrep -0 -c 'GGTATTCGAATTCAGGT' *.fastq > count/B15190_Rm0.txt
agrep -0 -c 'CCACCGCTTAAAAGCGA' *.fastq > count/B15192_Rm0.txt
agrep -0 -c 'CCCATTACAACAGTGTT' *.fastq > count/B15193_Rm0.txt
agrep -0 -c 'GCAGTCATAGAAATCGC' *.fastq > count/B15194_Rm0.txt
agrep -0 -c 'TCGCGATGTCTGTATAC' *.fastq > count/B15195_Rm0.txt
agrep -0 -c 'AGGGTTACTAGAGCACT' *.fastq > count/B15196_Rm0.txt
agrep -0 -c 'ATCACGTATCCGTAATG' *.fastq > count/B15197_Rm0.txt
agrep -0 -c 'CACGGGAAGTGTGACAC' *.fastq > count/B15198_Rm0.txt
agrep -0 -c 'TGCCTACTAGAGGCGTT' *.fastq > count/B15199_Rm0.txt
agrep -0 -c 'ACGTCCGCATAGATCCC' *.fastq > count/B15200_Rm0.txt
agrep -0 -c 'AGGATTCGGTATGCCCT' *.fastq > count/B15202_Rm0.txt
agrep -0 -c 'GACAAGAGTATGAACCC' *.fastq > count/B15203_Rm0.txt
agrep -0 -c 'ACGGCTACTTGGACGAC' *.fastq > count/B15205_Rm0.txt
agrep -0 -c 'CGATCATGGGTTTCCGT' *.fastq > count/B15206_Rm0.txt
agrep -0 -c 'AGTCTGTCATAATCTCG' *.fastq > count/B15207_Rm0.txt
agrep -0 -c 'CATGTTCAGACGGATGC' *.fastq > count/B15208_Rm0.txt
agrep -0 -c 'GTCGTATGGTCCGCATC' *.fastq > count/B15209_Rm0.txt
agrep -0 -c 'ATGCATTGTCGCAGCGG' *.fastq > count/B15210_Rm0.txt
agrep -0 -c 'GGTGCGTGGACTCTTCT' *.fastq > count/B15211_Rm0.txt
agrep -0 -c 'CCCTTAAGCTCACAAGG' *.fastq > count/B15212_Rm0.txt
agrep -0 -c 'AGCCTTGTTTGGGCGCT' *.fastq > count/B15213_Rm0.txt
agrep -0 -c 'GCCGTAGCACAAATTGA' *.fastq > count/B15214_Rm0.txt
agrep -0 -c 'TGATCCCGTAAGCGTAC' *.fastq > count/B15215_Rm0.txt
agrep -0 -c 'GTTCTGGTAAGAGTACG' *.fastq > count/B15216_Rm0.txt
agrep -0 -c 'ACGACAATTCACCTAGG' *.fastq > count/B15217_Rm0.txt
agrep -0 -c 'CGCACGCCAAACCATTA' *.fastq > count/B15218_Rm0.txt
agrep -0 -c 'GTAGTCACTGTCCACAC' *.fastq > count/B15219_Rm0.txt
agrep -0 -c 'TGTACAGTGACGCGTTA' *.fastq > count/B15220_Rm0.txt
agrep -0 -c 'CGTCCGCGGTACAATAT' *.fastq > count/B15222_Rm0.txt
agrep -0 -c 'GGTCAAGCTTAATGTAG' *.fastq > count/B15224_Rm0.txt
agrep -0 -c 'ATCGTGATTTAGAGGCC' *.fastq > count/B15226_Rm0.txt
agrep -0 -c 'AATACCACGCTGGCGAA' *.fastq > count/B15227_Rm0.txt
agrep -0 -c 'CCTATTGTTCGGTCTAA' *.fastq > count/B15228_Rm0.txt
agrep -0 -c 'GTCCGTGACTAATGACG' *.fastq > count/B15229_Rm0.txt
agrep -0 -c 'GAGGGTCAACCCTGAGA' *.fastq > count/B15230_Rm0.txt
agrep -0 -c 'GCTCTGCTAGAGTCAGT' *.fastq > count/B15231_Rm0.txt
agrep -0 -c 'GACGTCCGTGACTTGTT' *.fastq > count/B15232_Rm0.txt
agrep -0 -c 'GGGAAATGAATCCAGTG' *.fastq > count/B15233_Rm0.txt
agrep -0 -c 'ACCATCACCGAAGGAGC' *.fastq > count/B15234_Rm0.txt
agrep -0 -c 'AGGAACCGTTACACGAA' *.fastq > count/B15235_Rm0.txt
agrep -0 -c 'GCGGTGATACTGACACC' *.fastq > count/B15236_Rm0.txt
agrep -0 -c 'GATGGGCAGCATGCAAT' *.fastq > count/B15238_Rm0.txt
agrep -0 -c 'CATGTCGTCCTAGTCCG' *.fastq > count/B15239_Rm0.txt
agrep -0 -c 'GCTGCCATAGTAAACTC' *.fastq > count/B15240_Rm0.txt
agrep -0 -c 'CGGCCTACTCGTTAACC' *.fastq > count/B15241_Rm0.txt
agrep -0 -c 'CCCCCCTATAATGGCTA' *.fastq > count/B15242_Rm0.txt
agrep -0 -c 'GTGGTAGCTTACCCTTA' *.fastq > count/B15243_Rm0.txt
agrep -0 -c 'AAACCATCGCCCGTAGT' *.fastq > count/B15244_Rm0.txt
agrep -0 -c 'TAATACGCTCTTGATCC' *.fastq > count/B15246_Rm0.txt
agrep -0 -c 'TTGTTGGTAGTGTAAGG' *.fastq > count/B15247_Rm0.txt
agrep -0 -c 'AAGCAACCTCCCCGTTG' *.fastq > count/B15248_Rm0.txt
agrep -0 -c 'TTCGTTGAACCCATTCA' *.fastq > count/B15250_Rm0.txt
agrep -0 -c 'ATATTCCCTGGTCGATA' *.fastq > count/B15253_Rm0.txt
agrep -0 -c 'GGGTTGTCAGCTACCTC' *.fastq > count/B15254_Rm0.txt
agrep -0 -c 'TCGTCCTAAAGATTCTG' *.fastq > count/B15255_Rm0.txt
agrep -0 -c 'CTCGACCCATGAACTCC' *.fastq > count/B15256_Rm0.txt
agrep -0 -c 'GTAGTGACTAAGGTGAC' *.fastq > count/B15257_Rm0.txt
agrep -0 -c 'GCCAAGGTCCATTGGTT' *.fastq > count/B15260_Rm0.txt
agrep -0 -c 'CGACTTATTCTACACGA' *.fastq > count/B15261_Rm0.txt
agrep -0 -c 'AAGTAGTCACAGTCAAC' *.fastq > count/B15262_Rm0.txt
agrep -0 -c 'CCCGATGCGCTTGCTTA' *.fastq > count/B15263_Rm0.txt
agrep -0 -c 'ACGACTGATTGGCTCCT' *.fastq > count/B15264_Rm0.txt
agrep -0 -c 'CTAAGGTCGATGGAGAT' *.fastq > count/B15265_Rm0.txt
agrep -0 -c 'CGAGGACACATCGTACC' *.fastq > count/B15266_Rm0.txt
agrep -0 -c 'ACGCTCTCGTTGACCTC' *.fastq > count/B15267_Rm0.txt
agrep -0 -c 'TTAGTCTAGACCGTTCC' *.fastq > count/B15268_Rm0.txt
agrep -0 -c 'AAAAAGGCCTGTCGACG' *.fastq > count/B15269_Rm0.txt
agrep -0 -c 'AAAAAGCTCCCGCGGAT' *.fastq > count/B15270_Rm0.txt
agrep -0 -c 'TGCTGTGGGGTCCAAAC' *.fastq > count/B15271_Rm0.txt
agrep -0 -c 'CGTTATGGCGATCCTAG' *.fastq > count/B15272_Rm0.txt
agrep -0 -c 'TTCAATGGCGAGCCCTT' *.fastq > count/B15273_Rm0.txt
agrep -0 -c 'CGAACGGCGGCTACTAT' *.fastq > count/B15274_Rm0.txt
agrep -0 -c 'GCCATACGGCATAGTGG' *.fastq > count/B15275_Rm0.txt
agrep -0 -c 'AGCTTCCGCTCACTACG' *.fastq > count/B15276_Rm0.txt
agrep -0 -c 'TAAAGCCGATCAGTTGA' *.fastq > count/B15277_Rm0.txt
agrep -0 -c 'GAGCCTATTTTTCAGCA' *.fastq > count/B15278_Rm0.txt
agrep -0 -c 'CTTGATGAGTCTTGCAG' *.fastq > count/B15279_Rm0.txt
agrep -0 -c 'CTTACACCCCGTTGAAT' *.fastq > count/B15280_Rm0.txt
agrep -0 -c 'TATCAAGTGACCTATGG' *.fastq > count/B15281_Rm0.txt
agrep -0 -c 'GTTTTTGACAACGAGCC' *.fastq > count/B15282_Rm0.txt
agrep -0 -c 'TCACCATTGCACGATTG' *.fastq > count/B15283_Rm0.txt
agrep -0 -c 'TGGCAAGCGATTTTTAG' *.fastq > count/B15285_Rm0.txt
agrep -0 -c 'TCACCGTCATTGGACTA' *.fastq > count/B15288_Rm0.txt
agrep -0 -c 'CCGTCTAAGGAGGGAGT' *.fastq > count/B15290_Rm0.txt
agrep -0 -c 'TACACTCGGATAGAAGA' *.fastq > count/B15291_Rm0.txt
agrep -0 -c 'TGTCATACTACTACAGC' *.fastq > count/B15292_Rm0.txt
agrep -0 -c 'CTAATATGAGGCAGAGC' *.fastq > count/B15293_Rm0.txt
agrep -0 -c 'CGGAACTCCCTAACAGC' *.fastq > count/B15294_Rm0.txt
agrep -0 -c 'CTGGAGTTTTTTGCTGT' *.fastq > count/B15298_Rm0.txt
agrep -0 -c 'ACATCTCTAAGGGCCAA' *.fastq > count/B15299_Rm0.txt
agrep -0 -c 'TAACCACACGTCCATGC' *.fastq > count/B15302_Rm0.txt
agrep -0 -c 'ATTGTTAGTGAGCTGCG' *.fastq > count/B15303_Rm0.txt
agrep -0 -c 'CAAGACCGGACCTTCTT' *.fastq > count/B15304_Rm0.txt
agrep -0 -c 'CAGATCATCATTCCTCC' *.fastq > count/B15305_Rm0.txt
agrep -0 -c 'CTTCTCGTAGTACCTCA' *.fastq > count/B15306_Rm0.txt
agrep -0 -c 'CTTCCACACCGGGTTGA' *.fastq > count/B15307_Rm0.txt
agrep -0 -c 'TAGTAGTTGCTGACCCC' *.fastq > count/B15308_Rm0.txt
agrep -0 -c 'GTTATATCGCTTGACCC' *.fastq > count/B15309_Rm0.txt
agrep -0 -c 'ATGAAAGCAAGCACACC' *.fastq > count/B15310_Rm0.txt
agrep -0 -c 'ATAGGCTCGTTGTGCTG' *.fastq > count/B15311_Rm0.txt
agrep -0 -c 'TGATCGACGGGGACTAC' *.fastq > count/B15312_Rm0.txt
agrep -0 -c 'GTATGCGCGTATTTCGG' *.fastq > count/B15313_Rm0.txt
agrep -0 -c 'GTCTCCTCTTCATACTT' *.fastq > count/B15314_Rm0.txt
agrep -0 -c 'GCAAGTCTTGTAATCCA' *.fastq > count/B15315_Rm0.txt
agrep -0 -c 'TGAAATCAAAAGCCCGT' *.fastq > count/B15316_Rm0.txt
agrep -0 -c 'GGCGTCAACGATATACC' *.fastq > count/B15317_Rm0.txt
agrep -0 -c 'ACATAGCCAATCCCGAG' *.fastq > count/B15318_Rm0.txt
agrep -0 -c 'TCAGTAGCAACCTCGTT' *.fastq > count/B15319_Rm0.txt
agrep -0 -c 'GCAGTATGAGTCAATAC' *.fastq > count/B15320_Rm0.txt
agrep -0 -c 'GTCGCTCTAAGCTACAC' *.fastq > count/B15321_Rm0.txt
agrep -0 -c 'TGACGAAATAGGGATCA' *.fastq > count/B15322_Rm0.txt
agrep -0 -c 'AAGGGGCACAACGTTAA' *.fastq > count/B15323_Rm0.txt
agrep -0 -c 'AGTACCATACGTCGGTG' *.fastq > count/B15324_Rm0.txt
agrep -0 -c 'CAGGTAGTGAGAATTAG' *.fastq > count/B15325_Rm0.txt
agrep -0 -c 'TTCGTGGGCTGTAGCTC' *.fastq > count/B15326_Rm0.txt
agrep -0 -c 'AGTGGCTGTACCCTTAT' *.fastq > count/B15327_Rm0.txt
agrep -0 -c 'CGCTATAGTTAGGGGCA' *.fastq > count/B15328_Rm0.txt
agrep -0 -c 'GTTTCGCCTCGTCTATA' *.fastq > count/B15330_Rm0.txt
agrep -0 -c 'TTCAACCTATCCCTCAC' *.fastq > count/B15331_Rm0.txt
agrep -0 -c 'TACCATCTTGCCGAGAA' *.fastq > count/B15332_Rm0.txt
agrep -0 -c 'TGAAGGCTTCCAAATCG' *.fastq > count/B15333_Rm0.txt
agrep -0 -c 'TTGCGTCTTTCTAAACG' *.fastq > count/B15334_Rm0.txt
agrep -0 -c 'CCTAATTTCGCATCACG' *.fastq > count/B15336_Rm0.txt
agrep -0 -c 'TTAGGCAATACCGAATC' *.fastq > count/B15337_Rm0.txt
agrep -0 -c 'TCTCCGGGGGTGTTCAT' *.fastq > count/B15338_Rm0.txt
agrep -0 -c 'TAGTCAAGGAGGTCTTG' *.fastq > count/B15339_Rm0.txt
agrep -0 -c 'AGAGATGATCAACGGTC' *.fastq > count/B15340_Rm0.txt
agrep -0 -c 'GCGAACACACGAGTACG' *.fastq > count/B15341_Rm0.txt
agrep -0 -c 'TTTCTGCCTTTGCCCGT' *.fastq > count/B15342_Rm0.txt
agrep -0 -c 'ATCGTGGTTGATCCTCC' *.fastq > count/B15344_Rm0.txt
agrep -0 -c 'AGCGTAAGGCATGCTCC' *.fastq > count/B15345_Rm0.txt
agrep -0 -c 'GGACAATGTAGTTCCCT' *.fastq > count/B15347_Rm0.txt
agrep -0 -c 'AAGAGGCCTCTCGATCG' *.fastq > count/B15348_Rm0.txt
agrep -0 -c 'CACAGGAAAGATCGCTA' *.fastq > count/B15350_Rm0.txt
agrep -0 -c 'ATCCGGTGCCAACAGAC' *.fastq > count/B15352_Rm0.txt
agrep -0 -c 'GCAACGCGCGTTATCAC' *.fastq > count/B15353_Rm0.txt
agrep -0 -c 'TTAACCTGAGCCTGCTT' *.fastq > count/B15355_Rm0.txt
agrep -0 -c 'CTATAGGACTTCGCCGT' *.fastq > count/B15356_Rm0.txt
agrep -0 -c 'CGGAGTTTATCTTACGA' *.fastq > count/B15357_Rm0.txt
agrep -0 -c 'ACATTTGATCGCAGTCA' *.fastq > count/B15359_Rm0.txt
agrep -0 -c 'TGCTTTCTCGGCGTGCA' *.fastq > count/B15360_Rm0.txt
agrep -0 -c 'TCGAGAACCTCCTAGAA' *.fastq > count/B15361_Rm0.txt
agrep -0 -c 'TTGCGCCTAGCAACGCA' *.fastq > count/B15363_Rm0.txt
agrep -0 -c 'GCGGATCAGTATGTACT' *.fastq > count/B15365_Rm0.txt
agrep -0 -c 'CATGGGGTGCCATTTCA' *.fastq > count/B15368_Rm0.txt
agrep -0 -c 'ACTTTAACAAGCGTCGT' *.fastq > count/B15369_Rm0.txt
agrep -0 -c 'AACCCTAATTCGTGTGT' *.fastq > count/B15370_Rm0.txt
agrep -0 -c 'CATGGACATGTAACCTA' *.fastq > count/B15371_Rm0.txt
agrep -0 -c 'GGCATCATACTGGCTAT' *.fastq > count/B15373_Rm0.txt
agrep -0 -c 'TAAACCTTTGGGGCCGG' *.fastq > count/B15375_Rm0.txt
agrep -0 -c 'AAAAGCCGCTGTGTAGG' *.fastq > count/B15376_Rm0.txt
agrep -0 -c 'CAGTCTCGCTCAACACT' *.fastq > count/B15379_Rm0.txt
agrep -0 -c 'TGCCGGTTCAAACAACA' *.fastq > count/B15380_Rm0.txt
agrep -0 -c 'CCGAAGCACATATTGTG' *.fastq > count/B15381_Rm0.txt
agrep -0 -c 'AAGTAACGTCCGTTTCG' *.fastq > count/B15383_Rm0.txt
agrep -0 -c 'TTCTCGCAGCATTCTGT' *.fastq > count/B15384_Rm0.txt
agrep -0 -c 'AACGAACGGATTGTGTA' *.fastq > count/B15386_Rm0.txt
agrep -0 -c 'AACGTTGGCACGCAATA' *.fastq > count/B15387_Rm0.txt
agrep -0 -c 'ATCGATCCGACCCGCTA' *.fastq > count/B15388_Rm0.txt
agrep -0 -c 'GAGCAACGGAGAAGAGG' *.fastq > count/B15389_Rm0.txt
agrep -0 -c 'TCATATTCAGCGAATGC' *.fastq > count/B15390_Rm0.txt
agrep -0 -c 'GTGCACTTCGCATTCAC' *.fastq > count/B15391_Rm0.txt
agrep -0 -c 'AACCCAGAGAGATACTT' *.fastq > count/B15392_Rm0.txt
agrep -0 -c 'GCCGGGCCATTAAGTGT' *.fastq > count/B15393_Rm0.txt
agrep -0 -c 'ACCGATCTAAGGGAAAT' *.fastq > count/B15394_Rm0.txt
agrep -0 -c 'TTCCTACGATTGAGCAC' *.fastq > count/B15395_Rm0.txt
agrep -0 -c 'CCCAGTCTGCCAGTTAT' *.fastq > count/B15398_Rm0.txt
agrep -0 -c 'CGTTTGATACTTTGGGT' *.fastq > count/B15399_Rm0.txt
agrep -0 -c 'GGTCCTGAATGCCATAA' *.fastq > count/B15400_Rm0.txt
agrep -0 -c 'TAGGGTCTCACAGGTCT' *.fastq > count/B15401_Rm0.txt
agrep -0 -c 'TTAAACATCGTTGGCCC' *.fastq > count/B15402_Rm0.txt
agrep -0 -c 'TAATTCCGGGACGTGCT' *.fastq > count/B15403_Rm0.txt
agrep -0 -c 'ACGACCCCAATGAGTCG' *.fastq > count/B15404_Rm0.txt
agrep -0 -c 'GAACGCCTTTAGTCGGT' *.fastq > count/B15405_Rm0.txt
agrep -0 -c 'CGATGATCCTGACAGGT' *.fastq > count/B15406_Rm0.txt
agrep -0 -c 'CCTCCTGATGGAAAGAG' *.fastq > count/B15408_Rm0.txt
agrep -0 -c 'CAGCGCACGACCCAATT' *.fastq > count/B15409_Rm0.txt
agrep -0 -c 'GTGACCCTTTAGGAGCT' *.fastq > count/B15410_Rm0.txt
agrep -0 -c 'GTGACCACCTTTTACGC' *.fastq > count/B15411_Rm0.txt
agrep -0 -c 'ACGCAGTAGACACTATA' *.fastq > count/B15412_Rm0.txt
agrep -0 -c 'ACGTCCTTTATTAGTCG' *.fastq > count/B15413_Rm0.txt
agrep -0 -c 'ATTTAGTGTCCCACCTT' *.fastq > count/B15415_Rm0.txt
agrep -0 -c 'TGCGAATGGTTTTTGCG' *.fastq > count/B15416_Rm0.txt
agrep -0 -c 'AAGTGAGCCTAACGATA' *.fastq > count/B15417_Rm0.txt
agrep -0 -c 'TAAACTAGCCGTCTCGG' *.fastq > count/B15418_Rm0.txt
agrep -0 -c 'GACTGAGCGGAACTTCT' *.fastq > count/B15419_Rm0.txt
agrep -0 -c 'TACGAGCAGACGTGCAT' *.fastq > count/B15420_Rm0.txt
agrep -0 -c 'CTGGTGATTGTAGACAT' *.fastq > count/B15421_Rm0.txt
agrep -0 -c 'ATTGTCATTTCGGGCGT' *.fastq > count/B15422_Rm0.txt
agrep -0 -c 'ACTCGACCCCTCTACTT' *.fastq > count/B15423_Rm0.txt
agrep -0 -c 'TAACAGGCGAGGGCCTT' *.fastq > count/B15424_Rm0.txt
agrep -0 -c 'CTTGATAACTTCTGGCT' *.fastq > count/B15426_Rm0.txt
agrep -0 -c 'CGAACTCGGATTATGCT' *.fastq > count/B15427_Rm0.txt
agrep -0 -c 'TAGCCTACATACTCCTC' *.fastq > count/B15428_Rm0.txt
agrep -0 -c 'CTAGCAGGATCTTAGTA' *.fastq > count/B15429_Rm0.txt
agrep -0 -c 'TTCGATGTCGCAAAAGT' *.fastq > count/B15430_Rm0.txt
agrep -0 -c 'TCCAGATCTTGGATGAT' *.fastq > count/B15432_Rm0.txt
agrep -0 -c 'AGGTGGCCTCATCGCTA' *.fastq > count/B15434_Rm0.txt
agrep -0 -c 'GCCAAGAGTCAGTATGA' *.fastq > count/B15436_Rm0.txt
agrep -0 -c 'CCAATAGGTCCTGAGTC' *.fastq > count/B15437_Rm0.txt
agrep -0 -c 'TCGCTTGTTAAACGGCG' *.fastq > count/B15438_Rm0.txt
agrep -0 -c 'CGTCGGTAAGAGTTATT' *.fastq > count/B15439_Rm0.txt
agrep -0 -c 'GGACCGCTTATCCGATG' *.fastq > count/B15441_Rm0.txt
agrep -0 -c 'TACTAGAACTAAGCGCA' *.fastq > count/B15442_Rm0.txt
agrep -0 -c 'GGACTCTGTATAGCTCC' *.fastq > count/B15443_Rm0.txt
agrep -0 -c 'GCTTTGTCTCACGATGG' *.fastq > count/B15444_Rm0.txt
agrep -0 -c 'CAACCTGAGTTGTAGAG' *.fastq > count/B15445_Rm0.txt
agrep -0 -c 'GCGTAGGCTCGTACTAC' *.fastq > count/B15446_Rm0.txt
agrep -0 -c 'CTTCGCAGTGAATAATG' *.fastq > count/B15447_Rm0.txt
agrep -0 -c 'CTTTTTCTGATACCCGA' *.fastq > count/B15448_Rm0.txt
agrep -0 -c 'GGTCTTACGGATACCCG' *.fastq > count/B15449_Rm0.txt
agrep -0 -c 'ATAACCCTCACCGAGAC' *.fastq > count/B15450_Rm0.txt
agrep -0 -c 'ACGGCGGGCTAAATCGA' *.fastq > count/B15451_Rm0.txt
agrep -0 -c 'CTACACCTAAGGACTAG' *.fastq > count/B15452_Rm0.txt
agrep -0 -c 'ACGTACTGATCGAGAAG' *.fastq > count/B15453_Rm0.txt
agrep -0 -c 'AATGCAACTGCCGATAT' *.fastq > count/B15454_Rm0.txt
agrep -0 -c 'GTACTGTTCAAGCGTAT' *.fastq > count/B15455_Rm0.txt
agrep -0 -c 'CGTACTCTAGATTCTGA' *.fastq > count/B15456_Rm0.txt
agrep -0 -c 'GCACAGACAGGTGAGTC' *.fastq > count/B15458_Rm0.txt
agrep -0 -c 'TCTACGTTTGCTTACTG' *.fastq > count/B15459_Rm0.txt
agrep -0 -c 'TTTAGTGACTCAGAACG' *.fastq > count/B15460_Rm0.txt
agrep -0 -c 'GACACGAGCTTACCTTA' *.fastq > count/B15461_Rm0.txt
agrep -0 -c 'GGTTTGCGAGGACATCT' *.fastq > count/B15462_Rm0.txt
agrep -0 -c 'CGATCAACCGAACACGG' *.fastq > count/B15463_Rm0.txt
agrep -0 -c 'TCGTCCGCTAATGTTGA' *.fastq > count/B15464_Rm0.txt
agrep -0 -c 'TGCGAAGCTGGAGTGAA' *.fastq > count/B15465_Rm0.txt
agrep -0 -c 'ACCGTCCTACGGTTAAT' *.fastq > count/B15466_Rm0.txt
agrep -0 -c 'ATGTGCTTGGCATGTCG' *.fastq > count/B15468_Rm0.txt
agrep -0 -c 'TGCTAGCGTACAGAGCC' *.fastq > count/B15469_Rm0.txt
agrep -0 -c 'CCTTGTATCGACCACGT' *.fastq > count/B15470_Rm0.txt
agrep -0 -c 'CGAGGCCAGCAAGATCA' *.fastq > count/B15471_Rm0.txt
agrep -0 -c 'CATTCGCCGGAAAACCT' *.fastq > count/B15472_Rm0.txt
agrep -0 -c 'ACAGTGCTGTATCCGCA' *.fastq > count/B15473_Rm0.txt
agrep -0 -c 'AATCTACGGGTCAGCAC' *.fastq > count/B15474_Rm0.txt
agrep -0 -c 'TGATGAGAAGGCAGCCT' *.fastq > count/B15475_Rm0.txt
agrep -0 -c 'ACGAGTATTCACATGTG' *.fastq > count/B15476_Rm0.txt
agrep -0 -c 'ATACAAAACCACTCGCC' *.fastq > count/B15477_Rm0.txt
agrep -0 -c 'GTTGTCGAGGATCTCGG' *.fastq > count/B15478_Rm0.txt
agrep -0 -c 'TGAGTACTAGGCAACGA' *.fastq > count/B15479_Rm0.txt
agrep -0 -c 'ATTGTTACTGCGGTGAC' *.fastq > count/B15482_Rm0.txt
agrep -0 -c 'GTAGCGGTCTGGTGTAT' *.fastq > count/B15483_Rm0.txt
agrep -0 -c 'CAGTCGTTGTAGGATCG' *.fastq > count/B15484_Rm0.txt
agrep -0 -c 'TTAGGTCCTGTTTGACG' *.fastq > count/B15485_Rm0.txt
agrep -0 -c 'GACCAAGCAGACCACAA' *.fastq > count/B15486_Rm0.txt
agrep -0 -c 'CTACAGCCGTCCCTAAG' *.fastq > count/B15488_Rm0.txt
agrep -0 -c 'CTAAAAACGGCGCCACG' *.fastq > count/B15490_Rm0.txt
agrep -0 -c 'AAGGTGGACCCGTATTA' *.fastq > count/B15492_Rm0.txt
agrep -0 -c 'TACATATACGTGGGGAT' *.fastq > count/B15493_Rm0.txt
agrep -0 -c 'CTAGCGACCTACTGGTG' *.fastq > count/B15494_Rm0.txt
agrep -0 -c 'TGCAGCAATCTATTGGT' *.fastq > count/B15495_Rm0.txt
agrep -0 -c 'ACCCCCACTTACTGTCG' *.fastq > count/B15498_Rm0.txt
agrep -0 -c 'TCAAGGCGACTACAGTA' *.fastq > count/B15499_Rm0.txt
agrep -0 -c 'TAGCTACTGCCATTCGA' *.fastq > count/B15501_Rm0.txt
agrep -0 -c 'GAAAATAGCAATAGCCG' *.fastq > count/B15502_Rm0.txt
agrep -0 -c 'AGCGACGAGTTAATCGT' *.fastq > count/B15503_Rm0.txt
agrep -0 -c 'AATAGGGCAGATCCACA' *.fastq > count/B15504_Rm0.txt
agrep -0 -c 'CACAGTCGGCCAGTAAC' *.fastq > count/B15506_Rm0.txt
agrep -0 -c 'TAAGGCTTAGCCCCAGA' *.fastq > count/B15508_Rm0.txt
agrep -0 -c 'TCGCGCGGGTCAATAAG' *.fastq > count/B15509_Rm0.txt
agrep -0 -c 'TAAGCATTTAGTCGCGT' *.fastq > count/B15510_Rm0.txt
agrep -0 -c 'CGACGAATTGTAGCGGC' *.fastq > count/B15511_Rm0.txt
agrep -0 -c 'ATCAACAGCCTACGCCT' *.fastq > count/B15512_Rm0.txt
agrep -0 -c 'AAGGCCTCGATCAGCAC' *.fastq > count/B15513_Rm0.txt
agrep -0 -c 'AGCCTGTCCAGTATGGT' *.fastq > count/B15514_Rm0.txt
agrep -0 -c 'TGTACGGGGGTAACATC' *.fastq > count/B15515_Rm0.txt
agrep -0 -c 'AACGTTCGGGAGTTCCA' *.fastq > count/B15516_Rm0.txt
agrep -0 -c 'TTCTTCCAGAAGCATCG' *.fastq > count/B15518_Rm0.txt
agrep -0 -c 'CTCTAATGGTCATACCG' *.fastq > count/B15519_Rm0.txt
agrep -0 -c 'TTAAACGTGTGGTCAGC' *.fastq > count/B15520_Rm0.txt
agrep -0 -c 'GTATCAGTCTTCGTCAA' *.fastq > count/B15521_Rm0.txt
agrep -0 -c 'CCCCCTTGCAGAGTAGT' *.fastq > count/B15522_Rm0.txt
agrep -0 -c 'GCAGTCCGCCACAATGT' *.fastq > count/B15523_Rm0.txt
agrep -0 -c 'TGAAAGGAACAACACGG' *.fastq > count/B15524_Rm0.txt
agrep -0 -c 'AGCCCGTGACTACCTAG' *.fastq > count/B15525_Rm0.txt
agrep -0 -c 'CCATGTGCAAGTAGAGC' *.fastq > count/B15526_Rm0.txt
agrep -0 -c 'TGCTAACTACCCACGCA' *.fastq > count/B15527_Rm0.txt
agrep -0 -c 'TCCCACGTCACAGTCGA' *.fastq > count/B15529_Rm0.txt
agrep -0 -c 'CCAATCGCTACATAGAC' *.fastq > count/B15530_Rm0.txt
agrep -0 -c 'CAGCAGCGATAATGACC' *.fastq > count/B15531_Rm0.txt
agrep -0 -c 'GGTACTCATTCCAAACA' *.fastq > count/B15532_Rm0.txt
agrep -0 -c 'AAGTTTATCACAGCGAC' *.fastq > count/B15534_Rm0.txt
agrep -0 -c 'TTACGCGCGCATTAGCA' *.fastq > count/B15535_Rm0.txt
agrep -0 -c 'GGGCAATGACTTTATCG' *.fastq > count/B15536_Rm0.txt
agrep -0 -c 'GTACTTTTTCCGTACGT' *.fastq > count/B15537_Rm0.txt
agrep -0 -c 'GCAATTTCCGTACGTGC' *.fastq > count/B15538_Rm0.txt
agrep -0 -c 'TTTTCGCGGCTGCATAG' *.fastq > count/B15539_Rm0.txt
agrep -0 -c 'CCGGTCTAGACAGTATA' *.fastq > count/B15542_Rm0.txt
agrep -0 -c 'TAAATGTAACCGTCCGG' *.fastq > count/B15543_Rm0.txt
agrep -0 -c 'TCCCGATTTAGCGAACT' *.fastq > count/B15544_Rm0.txt
agrep -0 -c 'GAGTAAACTTGCATTGC' *.fastq > count/B15546_Rm0.txt
agrep -0 -c 'ATGAAAGCGTTCAGGCG' *.fastq > count/B15547_Rm0.txt
agrep -0 -c 'CACCTCTTATCGCTCTT' *.fastq > count/B15548_Rm0.txt
agrep -0 -c 'ACGTAGTAGGGTCGGTT' *.fastq > count/B15549_Rm0.txt
agrep -0 -c 'GCCGACACCAACAACAG' *.fastq > count/B15550_Rm0.txt
agrep -0 -c 'TTAACCTTTCCAGACCG' *.fastq > count/B15551_Rm0.txt
agrep -0 -c 'CGTTATAATGGCTGCAT' *.fastq > count/B15552_Rm0.txt
agrep -0 -c 'CACTCCGGTTTAACTCC' *.fastq > count/B15553_Rm0.txt
agrep -0 -c 'GACCTTGACTATGTAGG' *.fastq > count/B15554_Rm0.txt
agrep -0 -c 'CACGTGTAGATATACCG' *.fastq > count/B15555_Rm0.txt
agrep -0 -c 'TAATGGCGCTTGTGGCA' *.fastq > count/B15556_Rm0.txt
agrep -0 -c 'GGCTAGTCTCTGCTCGA' *.fastq > count/B15557_Rm0.txt
agrep -0 -c 'CCCGTTATTCCACGTGC' *.fastq > count/B15558_Rm0.txt
agrep -0 -c 'CGATGTCAAGCATTATC' *.fastq > count/B15559_Rm0.txt
agrep -0 -c 'GTCCATCTTATAGTTGC' *.fastq > count/B15561_Rm0.txt
agrep -0 -c 'CATGTGATGCGTGAGGC' *.fastq > count/B15562_Rm0.txt
agrep -0 -c 'CGCTGTTTTTCTCATCC' *.fastq > count/B15564_Rm0.txt
agrep -0 -c 'GAGAATTACGGACAGCT' *.fastq > count/B15565_Rm0.txt
agrep -0 -c 'ACTAGTCCAACTTCCCC' *.fastq > count/B15568_Rm0.txt
agrep -0 -c 'GTCGGTCCGGTATGTTG' *.fastq > count/B15569_Rm0.txt
agrep -0 -c 'CAGTACTGAAGGTCCGG' *.fastq > count/B15570_Rm0.txt
agrep -0 -c 'AGAGTGAAGCCTAGACG' *.fastq > count/B15571_Rm0.txt
agrep -0 -c 'ACCCTAAAGCCCCTTGT' *.fastq > count/B15572_Rm0.txt
agrep -0 -c 'GCGGCGGCTATAGTGTA' *.fastq > count/B15574_Rm0.txt
agrep -0 -c 'CGTAACCAGTTTTCCGT' *.fastq > count/B15576_Rm0.txt
agrep -0 -c 'CTAGACAGAGGATCGCG' *.fastq > count/B15577_Rm0.txt
agrep -0 -c 'ATCGCCCACAACACCTA' *.fastq > count/B15579_Rm0.txt
agrep -0 -c 'TAAGTCGTACCTACACC' *.fastq > count/B15580_Rm0.txt
agrep -0 -c 'GGGGATGTTGATTCTGC' *.fastq > count/B15581_Rm0.txt
agrep -0 -c 'TAAGACGGCGGAACCGT' *.fastq > count/B15582_Rm0.txt
agrep -0 -c 'GTTGTTCCTAATGCGTC' *.fastq > count/B15583_Rm0.txt
agrep -0 -c 'CACTGAACGGTCGTCTG' *.fastq > count/B15584_Rm0.txt
agrep -0 -c 'GGAACCCCAATTCTAGA' *.fastq > count/B15585_Rm0.txt
agrep -0 -c 'TTTCTTCGCGAGCAACT' *.fastq > count/B15586_Rm0.txt
agrep -0 -c 'AAGAACCTGCGCTTTAG' *.fastq > count/B15588_Rm0.txt
agrep -0 -c 'CATTCGAACCTACCTCA' *.fastq > count/B15589_Rm0.txt
agrep -0 -c 'ACAACGGCCTTCGTACT' *.fastq > count/B15590_Rm0.txt
agrep -0 -c 'ATCACAGCATCGATCTG' *.fastq > count/B15592_Rm0.txt
agrep -0 -c 'CCTCACACCGCATAACA' *.fastq > count/B15593_Rm0.txt
agrep -0 -c 'TATGGTGTAAACGCCTG' *.fastq > count/B15594_Rm0.txt
agrep -0 -c 'AATGCGGGTCGTCGTGA' *.fastq > count/B15595_Rm0.txt
agrep -0 -c 'TGTCTGGCCGATCTGGT' *.fastq > count/B15596_Rm0.txt
agrep -0 -c 'AACCTCTGCACGATGGT' *.fastq > count/B15598_Rm0.txt
agrep -0 -c 'TGCGACACAGGGCCTTA' *.fastq > count/B15599_Rm0.txt
agrep -0 -c 'CCCCAATAACCTGGTCA' *.fastq > count/B15600_Rm0.txt
agrep -0 -c 'CTGGCAAAGTCAAATGG' *.fastq > count/B15601_Rm0.txt
agrep -0 -c 'CAGATGTTGCGCAGAGG' *.fastq > count/B15603_Rm0.txt
agrep -0 -c 'CAATTAGTCCACGACGC' *.fastq > count/B15604_Rm0.txt
agrep -0 -c 'GGGTATGTGAAGGAATC' *.fastq > count/B15605_Rm0.txt
agrep -0 -c 'TGTAAGTGGTTACGGAA' *.fastq > count/B15606_Rm0.txt
agrep -0 -c 'GATGCACTTAAGGTCAG' *.fastq > count/B15607_Rm0.txt
agrep -0 -c 'GCCGAATTAACGGTCTT' *.fastq > count/B15608_Rm0.txt
agrep -0 -c 'TCATGAAAGATTGGCCC' *.fastq > count/B15609_Rm0.txt
agrep -0 -c 'ACAAAGCCGAGTCTCTC' *.fastq > count/B15610_Rm0.txt
agrep -0 -c 'TACTAACCAGAGCCAAT' *.fastq > count/B15612_Rm0.txt
agrep -0 -c 'CCGATCCCTATAGCACG' *.fastq > count/B15613_Rm0.txt
agrep -0 -c 'CCGTAAGCAGGATATTG' *.fastq > count/B15614_Rm0.txt
agrep -0 -c 'TTCCGGCCTAAGAAACT' *.fastq > count/B15615_Rm0.txt
agrep -0 -c 'TCATCAGAGAACTCGAT' *.fastq > count/B15616_Rm0.txt
agrep -0 -c 'ATCTTTTCCAAGGCCTG' *.fastq > count/B15617_Rm0.txt
agrep -0 -c 'ATCTTACCGCGGTAATT' *.fastq > count/B15618_Rm0.txt
agrep -0 -c 'CCACATTCAAAGAAGTC' *.fastq > count/B15619_Rm0.txt
agrep -0 -c 'AGCTAGGTAAAGGTCGC' *.fastq > count/B15620_Rm0.txt
agrep -0 -c 'GAACCATCTAGTCACGG' *.fastq > count/B15621_Rm0.txt
agrep -0 -c 'ATGGTATCCGTATGGCT' *.fastq > count/B15622_Rm0.txt
agrep -0 -c 'CTCGGCAGTTCATAATA' *.fastq > count/B15623_Rm0.txt
agrep -0 -c 'TCTATGGTGGAGGAACA' *.fastq > count/B15624_Rm0.txt
agrep -0 -c 'AATCCTTGGCGGAAAGT' *.fastq > count/B15625_Rm0.txt
agrep -0 -c 'TCTAGAGTACTGTCAGC' *.fastq > count/B15627_Rm0.txt
agrep -0 -c 'TAATCCGTTTAACGCCC' *.fastq > count/B15629_Rm0.txt
agrep -0 -c 'GACCGACGTCACTCACT' *.fastq > count/B15630_Rm0.txt
agrep -0 -c 'TCAGCCGCTGCTGTCAT' *.fastq > count/B15632_Rm0.txt
agrep -0 -c 'TATTCGATGTAGTGTCG' *.fastq > count/B15633_Rm0.txt
agrep -0 -c 'GCAAGCGAACGATCACA' *.fastq > count/B15635_Rm0.txt
agrep -0 -c 'TGCCTGTAGGATAAGAT' *.fastq > count/B15636_Rm0.txt
agrep -0 -c 'TTTGGCTGAGTGTAGGC' *.fastq > count/B15637_Rm0.txt
agrep -0 -c 'AACACCAAGTACATGCT' *.fastq > count/B15638_Rm0.txt
agrep -0 -c 'GGGTTCGAGACAGTTGA' *.fastq > count/B15639_Rm0.txt
agrep -0 -c 'GGAGCCAAAAATCGCGA' *.fastq > count/B15640_Rm0.txt
agrep -0 -c 'CCTGTTTGCGCCCTTAG' *.fastq > count/B15641_Rm0.txt
agrep -0 -c 'TACACTCGGATACATGT' *.fastq > count/B15642_Rm0.txt
agrep -0 -c 'GCACTCCAGCCTTTCAT' *.fastq > count/B15643_Rm0.txt
agrep -0 -c 'TAGAGGAGCTGTGGCGA' *.fastq > count/B15644_Rm0.txt
agrep -0 -c 'CGATGTATCGGAGGCAT' *.fastq > count/B15645_Rm0.txt
agrep -0 -c 'CAAAGTATCGCGTACAC' *.fastq > count/B15646_Rm0.txt
agrep -0 -c 'CCGACTTGTGTATTACA' *.fastq > count/B15647_Rm0.txt
agrep -0 -c 'TTTAAGGTGTCACCTGA' *.fastq > count/B15649_Rm0.txt
agrep -0 -c 'GACGTACCAGCTTAACG' *.fastq > count/B15650_Rm0.txt
agrep -0 -c 'AAGGTAGAACTGTTACC' *.fastq > count/B15651_Rm0.txt
agrep -0 -c 'TCAGGTAGTCGAACCCC' *.fastq > count/B15652_Rm0.txt
agrep -0 -c 'CATCTCGAAGCGGAGGT' *.fastq > count/B15653_Rm0.txt
agrep -0 -c 'TGCAGACTGCAATGGAA' *.fastq > count/B15655_Rm0.txt
agrep -0 -c 'TAAGAATGTGGGTGATC' *.fastq > count/B15656_Rm0.txt
agrep -0 -c 'ATACGACCCACCATTAG' *.fastq > count/B15657_Rm0.txt
agrep -0 -c 'CGCCTAGACGCTCTAAC' *.fastq > count/B15658_Rm0.txt
agrep -0 -c 'TCCATAGGTAGACCATA' *.fastq > count/B15659_Rm0.txt
agrep -0 -c 'TCCAGAAGCTAGTCTCG' *.fastq > count/B15660_Rm0.txt
agrep -0 -c 'ATATCCTCGACCACGCT' *.fastq > count/B15661_Rm0.txt
agrep -0 -c 'ACCACTTCAGTGCGGAT' *.fastq > count/B15662_Rm0.txt
agrep -0 -c 'CGCGATAAGCCGTACTT' *.fastq > count/B15663_Rm0.txt
agrep -0 -c 'GTCCGTTAGAAATGACA' *.fastq > count/B15664_Rm0.txt
agrep -0 -c 'CTAATACGGAGGTCTAG' *.fastq > count/B15665_Rm0.txt
agrep -0 -c 'AACTACACTCGCTCAAT' *.fastq > count/B15667_Rm0.txt
agrep -0 -c 'TCTGCTGGCTTACGACG' *.fastq > count/B15668_Rm0.txt
agrep -0 -c 'CAAGCCAAGTGAAGTGG' *.fastq > count/B15669_Rm0.txt
agrep -0 -c 'GCTAAGCCTTGCGACAA' *.fastq > count/B15670_Rm0.txt
agrep -0 -c 'AAGTAGGTGGCAACGAT' *.fastq > count/B15671_Rm0.txt
agrep -0 -c 'ATACGTGTCTGTGGAGT' *.fastq > count/B15672_Rm0.txt
agrep -0 -c 'AGCTGGAAGTCTGCATT' *.fastq > count/B15673_Rm0.txt
agrep -0 -c 'AGAGCTGGATTCGAAAT' *.fastq > count/B15674_Rm0.txt
agrep -0 -c 'CATATCGGAAAGGTGTA' *.fastq > count/B15675_Rm0.txt
agrep -0 -c 'TTACTATCCATCGTGTC' *.fastq > count/B15676_Rm0.txt
agrep -0 -c 'AGATTTACCGGCTCCAG' *.fastq > count/B15677_Rm0.txt
agrep -0 -c 'TACCTCGGCTCCTAGCT' *.fastq > count/B15678_Rm0.txt
agrep -0 -c 'GGATGATTTGTCAGCCT' *.fastq > count/B15679_Rm0.txt
agrep -0 -c 'AACTTTGGGACAGTCAC' *.fastq > count/B15680_Rm0.txt
agrep -0 -c 'ACGTGACGTTACCGACT' *.fastq > count/B15681_Rm0.txt
agrep -0 -c 'AGAGTCAACTTTAGTCG' *.fastq > count/B15682_Rm0.txt
agrep -0 -c 'GTTATGACCAACAGGAC' *.fastq > count/B15683_Rm0.txt
agrep -0 -c 'GCAATTTCGTCCCTGTA' *.fastq > count/B15684_Rm0.txt
agrep -0 -c 'CCGAAAACGATAAGGTA' *.fastq > count/B15685_Rm0.txt
agrep -0 -c 'GTATGGCGATCCATAGC' *.fastq > count/B15686_Rm0.txt
agrep -0 -c 'ACTAAGCATCGTTACAC' *.fastq > count/B15687_Rm0.txt
agrep -0 -c 'ATCGATAGGTATCATCC' *.fastq > count/B15688_Rm0.txt
agrep -0 -c 'TCGGTTCCTGCGAATCA' *.fastq > count/B15689_Rm0.txt
agrep -0 -c 'TCTGAGCGCTAAAACGC' *.fastq > count/B15691_Rm0.txt
agrep -0 -c 'GTTGCCGGATGGGTGTT' *.fastq > count/B15694_Rm0.txt
agrep -0 -c 'GTTAATAGCTACGATCG' *.fastq > count/B15695_Rm0.txt
agrep -0 -c 'GACAGATGTCGACCACC' *.fastq > count/B15696_Rm0.txt
agrep -0 -c 'CTGGCTTACAAAATGGC' *.fastq > count/B15697_Rm0.txt
agrep -0 -c 'CGTTCCATGGACGACGT' *.fastq > count/B15698_Rm0.txt
agrep -0 -c 'CAAGCGGAAGCACACAG' *.fastq > count/B15699_Rm0.txt
agrep -0 -c 'GCTGACCGGTAAGTCTA' *.fastq > count/B15700_Rm0.txt
agrep -0 -c 'CCCCTATTTCGCATTGT' *.fastq > count/B15701_Rm0.txt
agrep -0 -c 'GCGTTGCTGCAATATCC' *.fastq > count/B15702_Rm0.txt
agrep -0 -c 'TCTAGGTCTGTACGACA' *.fastq > count/B15703_Rm0.txt
agrep -0 -c 'CATCAACGGAGGCTGAC' *.fastq > count/B15704_Rm0.txt
agrep -0 -c 'GTGCATTTTGCGGATCC' *.fastq > count/B15705_Rm0.txt
agrep -0 -c 'TGTGTCCAGACTAATCA' *.fastq > count/B15706_Rm0.txt
agrep -0 -c 'GATGGCCAGCAGATAGG' *.fastq > count/B15708_Rm0.txt
agrep -0 -c 'ATCTGCATGTTGCCCCG' *.fastq > count/B15709_Rm0.txt
agrep -0 -c 'GGTGCTCCTAGATCGGT' *.fastq > count/B15710_Rm0.txt
agrep -0 -c 'TTAGGATGCCCTTCTCA' *.fastq > count/B15711_Rm0.txt
agrep -0 -c 'ATCAGCATGTGTCCCCC' *.fastq > count/B15712_Rm0.txt
agrep -0 -c 'CAGGCGGAACATTCACC' *.fastq > count/B15713_Rm0.txt
agrep -0 -c 'CTCTTTCTATGATCGGC' *.fastq > count/B15714_Rm0.txt
agrep -0 -c 'GGAAATCTGTTCCACTC' *.fastq > count/B15715_Rm0.txt
agrep -0 -c 'TGGGGGGTACCACGAAT' *.fastq > count/B15716_Rm0.txt
agrep -0 -c 'TAGGCGAAACTTTGAGA' *.fastq > count/B15717_Rm0.txt
agrep -0 -c 'TTGGTAGCGATATTCAG' *.fastq > count/B15718_Rm0.txt
agrep -0 -c 'CAACGACATTGGTGCAA' *.fastq > count/B15719_Rm0.txt
agrep -0 -c 'GACCGTACGTTGTCTCA' *.fastq > count/B15720_Rm0.txt
agrep -0 -c 'GTAGGTTATATAGAGCC' *.fastq > count/B15721_Rm0.txt
agrep -0 -c 'TCTAAACGCCCGTTGCG' *.fastq > count/B15723_Rm0.txt
agrep -0 -c 'CGAGATAGCAGTACAAC' *.fastq > count/B15727_Rm0.txt
agrep -0 -c 'ATTGGTTCGCGACTTCA' *.fastq > count/B15728_Rm0.txt
agrep -0 -c 'AATGACTGTCCGCTGTA' *.fastq > count/B15729_Rm0.txt
agrep -0 -c 'CTGCTTCTATTGCGGCC' *.fastq > count/B15730_Rm0.txt
agrep -0 -c 'AAGATGCGCCTTGACTA' *.fastq > count/B15731_Rm0.txt
agrep -0 -c 'GAGCTTGACTTAACCCT' *.fastq > count/B15732_Rm0.txt
agrep -0 -c 'TTATCCAAGGATTACGC' *.fastq > count/B15733_Rm0.txt
agrep -0 -c 'TTCCTCGGGCCAGCTAT' *.fastq > count/B15734_Rm0.txt
agrep -0 -c 'AGAGATGCACAACCCGG' *.fastq > count/B15735_Rm0.txt
agrep -0 -c 'TACTGGCACTTTAATGC' *.fastq > count/B15736_Rm0.txt
agrep -0 -c 'GCATGAGGCTGACGAAG' *.fastq > count/B15737_Rm0.txt
agrep -0 -c 'TAACAGTGCCAGCGCTG' *.fastq > count/B15738_Rm0.txt
agrep -0 -c 'TCAGTGGCGTGCCTGTT' *.fastq > count/B15739_Rm0.txt
agrep -0 -c 'GGTCTCTTCCAGGATTG' *.fastq > count/B15740_Rm0.txt
agrep -0 -c 'GAGATCCTACTCACTCA' *.fastq > count/B15741_Rm0.txt
agrep -0 -c 'CCCAGAGAGGACTGTCA' *.fastq > count/B15742_Rm0.txt
agrep -0 -c 'AATCTACAATACCGGGC' *.fastq > count/B15743_Rm0.txt
agrep -0 -c 'CCGTTGCATTGATGCTG' *.fastq > count/B15744_Rm0.txt
agrep -0 -c 'GTAGCTGCACACGAGTC' *.fastq > count/B15745_Rm0.txt
agrep -0 -c 'CGCTCTCTAGGTTGGAA' *.fastq > count/B15746_Rm0.txt
agrep -0 -c 'AGAAGTTAAGGAACTGC' *.fastq > count/B15747_Rm0.txt
agrep -0 -c 'GCCAAGAAAAAAACCCC' *.fastq > count/B15748_Rm0.txt
agrep -0 -c 'TTGACTCGGCAAAAGAG' *.fastq > count/B15750_Rm0.txt
agrep -0 -c 'TATACCGCCGATGCTTG' *.fastq > count/B15751_Rm0.txt
agrep -0 -c 'TATCGGGGACTTAGCAA' *.fastq > count/B15752_Rm0.txt
agrep -0 -c 'TTGTCTACACTAATGGC' *.fastq > count/B15753_Rm0.txt
agrep -0 -c 'TGGGATGGCAGGTAAGT' *.fastq > count/B15754_Rm0.txt
agrep -0 -c 'GCAAAAGAGCACTCAGA' *.fastq > count/B15755_Rm0.txt
agrep -0 -c 'CGTTAGGGGGAGGTGAT' *.fastq > count/B15756_Rm0.txt
agrep -0 -c 'CCGGTAGTGGTAACAGG' *.fastq > count/B15758_Rm0.txt
agrep -0 -c 'CGCCCATCATGTCTACC' *.fastq > count/B15759_Rm0.txt
agrep -0 -c 'CTACGGTATGCATTAGA' *.fastq > count/B15760_Rm0.txt
agrep -0 -c 'CGGTCTTATCTTCCGAA' *.fastq > count/B15762_Rm0.txt
agrep -0 -c 'ACTATACATGATGACGG' *.fastq > count/B15763_Rm0.txt
agrep -0 -c 'CGACACTGTATAGACTT' *.fastq > count/B15764_Rm0.txt
agrep -0 -c 'CTCGTACGAATCAGTAC' *.fastq > count/B15766_Rm0.txt
agrep -0 -c 'GAGCGTGACTTAGATCA' *.fastq > count/B15767_Rm0.txt
agrep -0 -c 'TGTAGTGTGACCCAGCG' *.fastq > count/B15768_Rm0.txt
agrep -0 -c 'GGAAAATCAGGGGGCCT' *.fastq > count/B15769_Rm0.txt
agrep -0 -c 'GTGATACGAACTCGCTG' *.fastq > count/B15770_Rm0.txt
agrep -0 -c 'AGTAGTAGACTCATGAC' *.fastq > count/B15771_Rm0.txt
agrep -0 -c 'TTAGAGGACATACCTCA' *.fastq > count/B15772_Rm0.txt
agrep -0 -c 'GTATCCCAGGACTAATA' *.fastq > count/B15773_Rm0.txt
agrep -0 -c 'GCCGAAGTAACTCAGTC' *.fastq > count/B15774_Rm0.txt
agrep -0 -c 'AGGTAACCGTCAGAGTG' *.fastq > count/B15775_Rm0.txt
agrep -0 -c 'AACAAGATGCTGGCGTC' *.fastq > count/B15776_Rm0.txt
agrep -0 -c 'GGGATACGGATTGTCCG' *.fastq > count/B15777_Rm0.txt
agrep -0 -c 'CCTTAGATAGTCGCGAG' *.fastq > count/B15778_Rm0.txt
agrep -0 -c 'TTACAAGCTTGCGTGAC' *.fastq > count/B15779_Rm0.txt
agrep -0 -c 'CATTCAGGGTAGGTAAC' *.fastq > count/B15780_Rm0.txt
agrep -0 -c 'ATGCATCATACTGGCGT' *.fastq > count/B15782_Rm0.txt
agrep -0 -c 'ATTCGTCTTCCGTGGTA' *.fastq > count/B15783_Rm0.txt
agrep -0 -c 'AATGGAAGCAGGACGCG' *.fastq > count/B15784_Rm0.txt
agrep -0 -c 'GGAACTCTTCATTACGC' *.fastq > count/B15785_Rm0.txt
agrep -0 -c 'TGGGCCAGTTACAGTCA' *.fastq > count/B15786_Rm0.txt
agrep -0 -c 'CTGCATAACGTAGATGT' *.fastq > count/B15789_Rm0.txt
agrep -0 -c 'TGAATAGGCGAGTCGCC' *.fastq > count/B15790_Rm0.txt
agrep -0 -c 'CATCCGAAGGCCTGTAA' *.fastq > count/B15791_Rm0.txt
agrep -0 -c 'GTAAGTTTGGCACATGG' *.fastq > count/B15792_Rm0.txt
agrep -0 -c 'TGGTAGAGTTTCCGGGC' *.fastq > count/B15793_Rm0.txt
agrep -0 -c 'ACCTCGGCAGGGTAATA' *.fastq > count/B15794_Rm0.txt
agrep -0 -c 'AAGTTCGGAGGAAGGAA' *.fastq > count/B15796_Rm0.txt
agrep -0 -c 'TAATGCCCCGTATTGTC' *.fastq > count/B15797_Rm0.txt
agrep -0 -c 'TCCGGATAACAGAAGCT' *.fastq > count/B15799_Rm0.txt
agrep -0 -c 'TAATCGCGTTCCGACAC' *.fastq > count/B15800_Rm0.txt
agrep -0 -c 'CGCGCACCGTTAAATCC' *.fastq > count/B15801_Rm0.txt
agrep -0 -c 'ATGGTTCATGCCAATGG' *.fastq > count/B15803_Rm0.txt
agrep -0 -c 'CACTTCCTACCTTCGTC' *.fastq > count/B15804_Rm0.txt
agrep -0 -c 'GAACTAACGGGGGACTT' *.fastq > count/B15805_Rm0.txt
agrep -0 -c 'CATTGAAATCTGGCCAG' *.fastq > count/B15806_Rm0.txt
agrep -0 -c 'TTCATCAACGAGCTCCC' *.fastq > count/B15807_Rm0.txt
agrep -0 -c 'TTCGCTCGCACTGTCAA' *.fastq > count/B15808_Rm0.txt
agrep -0 -c 'CCACGTTCCATTAGATG' *.fastq > count/B15809_Rm0.txt
agrep -0 -c 'TAACCGGTGTGGGCCTA' *.fastq > count/B15812_Rm0.txt
agrep -0 -c 'AATCCTAGCGGAACCGA' *.fastq > count/B15813_Rm0.txt
agrep -0 -c 'CAATTGGAACTACCGTT' *.fastq > count/B15814_Rm0.txt
agrep -0 -c 'TGTACGGACTTGCGGAA' *.fastq > count/B15815_Rm0.txt
agrep -0 -c 'AATACAGTTGCAGTGCC' *.fastq > count/B15816_Rm0.txt
agrep -0 -c 'GCGTACGGGATTTGATT' *.fastq > count/B15817_Rm0.txt
agrep -0 -c 'CTCTTCGGAAAGCACCG' *.fastq > count/B15818_Rm0.txt
agrep -0 -c 'TTTGGCCATTTTCTGCG' *.fastq > count/B15819_Rm0.txt
agrep -0 -c 'GAGAGTCGTGTTCGCGT' *.fastq > count/B15820_Rm0.txt
agrep -0 -c 'GCTGATCGTGACTTAGC' *.fastq > count/B15821_Rm0.txt
agrep -0 -c 'GTAATCCATGCCTCGTA' *.fastq > count/B15823_Rm0.txt
agrep -0 -c 'GGTAGAGCAACCCATCC' *.fastq > count/B15824_Rm0.txt
agrep -0 -c 'CGCGTTCAGGTTAGACC' *.fastq > count/B15825_Rm0.txt
agrep -0 -c 'ACTCAGTGATCGCATCC' *.fastq > count/B15826_Rm0.txt
agrep -0 -c 'GTGGGAGCTCTACATAT' *.fastq > count/B15827_Rm0.txt
agrep -0 -c 'CCGCATCACAATCCAGC' *.fastq > count/B15829_Rm0.txt
agrep -0 -c 'GTTCATGAGGATCGGTT' *.fastq > count/B15830_Rm0.txt
agrep -0 -c 'AGTCCTGCACATTTTGC' *.fastq > count/B15831_Rm0.txt
agrep -0 -c 'AAGATGGTCCGATGGTA' *.fastq > count/B15832_Rm0.txt
agrep -0 -c 'GGATCTTTGCCGGCCAT' *.fastq > count/B15833_Rm0.txt
agrep -0 -c 'TTAAGCTTGGGAGTGGT' *.fastq > count/B15834_Rm0.txt
agrep -0 -c 'CGAAGTGCGGTAACCGA' *.fastq > count/B15837_Rm0.txt
agrep -0 -c 'CTTCTTGAGATATGACG' *.fastq > count/B15838_Rm0.txt
agrep -0 -c 'TAAGTACTTCCCTTCGT' *.fastq > count/B15839_Rm0.txt
agrep -0 -c 'TGAGTCCTCGATAGGCA' *.fastq > count/B15840_Rm0.txt
agrep -0 -c 'CATCCAGAACTACTGTA' *.fastq > count/B15841_Rm0.txt
agrep -0 -c 'CATCGGCGACTTGGTAA' *.fastq > count/B15842_Rm0.txt
agrep -0 -c 'GTAGCGTGACTTGTCCG' *.fastq > count/B15843_Rm0.txt
agrep -0 -c 'CATGAAGAACTCGGCTT' *.fastq > count/B15844_Rm0.txt
agrep -0 -c 'AACACCCCGCAAATGGT' *.fastq > count/B15845_Rm0.txt
agrep -0 -c 'ACAGGTCCGGCTAACCT' *.fastq > count/B15846_Rm0.txt
agrep -0 -c 'TTGTCGCCATACCTAGA' *.fastq > count/B15847_Rm0.txt
agrep -0 -c 'CTGTTTGCAGCGTCAGC' *.fastq > count/B15849_Rm0.txt
agrep -0 -c 'GGGTTGTCTTCGTACGA' *.fastq > count/B15851_Rm0.txt
agrep -0 -c 'AAAAACGGTCTGTGGAC' *.fastq > count/B15853_Rm0.txt
agrep -0 -c 'AACGCGGTACCGATCAG' *.fastq > count/B15854_Rm0.txt
agrep -0 -c 'AGTTGGTCAACTAGTGC' *.fastq > count/B15855_Rm0.txt
agrep -0 -c 'AAAACGCGAATTAGCAG' *.fastq > count/B15856_Rm0.txt
agrep -0 -c 'GTCCGGGGATATAAGCG' *.fastq > count/B15857_Rm0.txt
agrep -0 -c 'TTATTCTGGCCGATTAG' *.fastq > count/B15858_Rm0.txt
agrep -0 -c 'TCAGAAGTATGGACATC' *.fastq > count/B15860_Rm0.txt
agrep -0 -c 'CGTTGCAGTACTCGGTA' *.fastq > count/B15861_Rm0.txt
agrep -0 -c 'ACCAATCCTGAGAATAG' *.fastq > count/B15862_Rm0.txt
agrep -0 -c 'CCCACCAAACTGTGTGC' *.fastq > count/B15863_Rm0.txt
agrep -0 -c 'CCCTATTTGTAGCGACG' *.fastq > count/B15864_Rm0.txt
agrep -0 -c 'CGCGCAAAATAACCCAG' *.fastq > count/B15865_Rm0.txt
agrep -0 -c 'TCATAATCCTCGCCTCC' *.fastq > count/B15866_Rm0.txt
agrep -0 -c 'CCTAAAACCAGGCCACT' *.fastq > count/B15867_Rm0.txt
agrep -0 -c 'CACAGTTAACAGGGCGC' *.fastq > count/B15868_Rm0.txt
agrep -0 -c 'TCGATGTAATAAGCACC' *.fastq > count/B15869_Rm0.txt
agrep -0 -c 'TTGTAGTACCGCAGTTA' *.fastq > count/B15870_Rm0.txt
agrep -0 -c 'TCCGGATAGATGATATC' *.fastq > count/B15871_Rm0.txt
agrep -0 -c 'CATCGGTAGACTCGTAG' *.fastq > count/B15872_Rm0.txt
agrep -0 -c 'AGAAGGATCAGCCTGTT' *.fastq > count/B15874_Rm0.txt
agrep -0 -c 'AACCACAAACCTGTGTT' *.fastq > count/B15875_Rm0.txt
agrep -0 -c 'TTAACTACGCAGTTGCG' *.fastq > count/B15877_Rm0.txt
agrep -0 -c 'TGAATTCGGTCGACAGC' *.fastq > count/B15879_Rm0.txt
agrep -0 -c 'CGCTGTGCGAAAGAGGT' *.fastq > count/B15881_Rm0.txt
agrep -0 -c 'CTGGCACTATGTACGTG' *.fastq > count/B15882_Rm0.txt
agrep -0 -c 'TGTGACGCTGGCACATG' *.fastq > count/B15883_Rm0.txt
agrep -0 -c 'GACGAGCTTACGAGTTG' *.fastq > count/B15884_Rm0.txt
agrep -0 -c 'AACCAGGTAGCTCAGAG' *.fastq > count/B15885_Rm0.txt
agrep -0 -c 'GATGTGGGTGCTCTTCG' *.fastq > count/B15886_Rm0.txt
agrep -0 -c 'TGATTTGTAAGTGGCCG' *.fastq > count/B15888_Rm0.txt
agrep -0 -c 'CCGCCGAAAGGGGATTA' *.fastq > count/B15889_Rm0.txt
agrep -0 -c 'CTGTTAGGCTGCGACTT' *.fastq > count/B15890_Rm0.txt
agrep -0 -c 'TCGTCGTTATCGATCAG' *.fastq > count/B15892_Rm0.txt
agrep -0 -c 'TGAATGGAGCGGCTACG' *.fastq > count/B15893_Rm0.txt
agrep -0 -c 'GCTACCGGAACGCTCTA' *.fastq > count/B15894_Rm0.txt
agrep -0 -c 'GAATGGGGGCATTTAGT' *.fastq > count/B15895_Rm0.txt
agrep -0 -c 'GGAACCAATCACGTTGA' *.fastq > count/B15896_Rm0.txt
agrep -0 -c 'AATGGAGGAGCGGAGTC' *.fastq > count/B15897_Rm0.txt
agrep -0 -c 'TAGGACGGTCTCGTATC' *.fastq > count/B15898_Rm0.txt
agrep -0 -c 'GATCGCGTTAAGAGGGC' *.fastq > count/B15899_Rm0.txt
agrep -0 -c 'GCTGTTTTGTGCGCGAA' *.fastq > count/B15903_Rm0.txt
agrep -0 -c 'TCGGGTCTGTAGGTGAC' *.fastq > count/B15904_Rm0.txt
agrep -0 -c 'GAGTTGACTAATTGGCT' *.fastq > count/B15905_Rm0.txt
agrep -0 -c 'GACGGTATAGGTTCGCG' *.fastq > count/B15906_Rm0.txt
agrep -0 -c 'CAACTACATGGTTACCT' *.fastq > count/B15907_Rm0.txt
agrep -0 -c 'GGAAGAGGGTACAAGGT' *.fastq > count/B15908_Rm0.txt
agrep -0 -c 'GCGTTAACCCGTAGCTG' *.fastq > count/B15909_Rm0.txt
agrep -0 -c 'TTGATAGCATATCCCAC' *.fastq > count/B15910_Rm0.txt
agrep -0 -c 'TGACATCCAATTGCTGG' *.fastq > count/B15911_Rm0.txt
agrep -0 -c 'AATCCGTATACACTCGC' *.fastq > count/B15912_Rm0.txt
agrep -0 -c 'CACGCTTAGCGGCTACA' *.fastq > count/B15915_Rm0.txt
agrep -0 -c 'TATATGGTGCACGTTCA' *.fastq > count/B15917_Rm0.txt
agrep -0 -c 'AGTCACTGGTTGCTCCG' *.fastq > count/B15919_Rm0.txt
agrep -0 -c 'TGGTATGTAGCATCGCG' *.fastq > count/B15920_Rm0.txt
agrep -0 -c 'CCTTGGACAAGCAGGCT' *.fastq > count/B15921_Rm0.txt
agrep -0 -c 'GATTGCAGAGACCTTCC' *.fastq > count/B15922_Rm0.txt
agrep -0 -c 'CAGGTCGTGATCTTTGC' *.fastq > count/B15923_Rm0.txt
agrep -0 -c 'CCTGCTTATATCCTGTT' *.fastq > count/B15925_Rm0.txt
agrep -0 -c 'CATGGTCAGTTCAGTAA' *.fastq > count/B15927_Rm0.txt
agrep -0 -c 'GTTGGTCTCGAACGTAT' *.fastq > count/B15928_Rm0.txt
agrep -0 -c 'TCCATAAGCCAAAGCAG' *.fastq > count/B15929_Rm0.txt
agrep -0 -c 'ACTACCTCGAGTTCGCG' *.fastq > count/B15931_Rm0.txt
agrep -0 -c 'GTGCGGCCGTAGTTATC' *.fastq > count/B15933_Rm0.txt
agrep -0 -c 'CCGAATGACTATCACTT' *.fastq > count/B15934_Rm0.txt
agrep -0 -c 'AGGCAAAACGATAGATG' *.fastq > count/B15935_Rm0.txt
agrep -0 -c 'CGGATATTGCGACATCA' *.fastq > count/B15936_Rm0.txt
agrep -0 -c 'GAGCCCGCTAAGTTAGC' *.fastq > count/B15938_Rm0.txt
agrep -0 -c 'CGTAGGCGGCTGTTATC' *.fastq > count/B15939_Rm0.txt
agrep -0 -c 'ATTTCCGTGTGTTCGAG' *.fastq > count/B15941_Rm0.txt
agrep -0 -c 'ATGCTTTATTCGGCATC' *.fastq > count/B15942_Rm0.txt
agrep -0 -c 'GTTATGCCTCACCCGCA' *.fastq > count/B15943_Rm0.txt
agrep -0 -c 'TCTTTCCGCGAATTTTG' *.fastq > count/B15944_Rm0.txt
agrep -0 -c 'CCTCACATGAGATGTCC' *.fastq > count/B15945_Rm0.txt
agrep -0 -c 'GAAAGTAGACTTCTCCA' *.fastq > count/B15946_Rm0.txt
agrep -0 -c 'AGGCTAGGTAATGGACG' *.fastq > count/B15947_Rm0.txt
agrep -0 -c 'TCGAATCAGTCATCGTC' *.fastq > count/B15948_Rm0.txt
agrep -0 -c 'CATGTCGACGCACTTAG' *.fastq > count/B15949_Rm0.txt
agrep -0 -c 'CGAGGGGGTCTGAACTA' *.fastq > count/B15950_Rm0.txt
agrep -0 -c 'AATCGATGCGTGAGGAG' *.fastq > count/B15952_Rm0.txt
agrep -0 -c 'TCGGAGGACGTACCACT' *.fastq > count/B15953_Rm0.txt
agrep -0 -c 'AACGCGAATGGGGATGT' *.fastq > count/B15954_Rm0.txt
agrep -0 -c 'CGTTGATACAGAACAAC' *.fastq > count/B15955_Rm0.txt
agrep -0 -c 'CATGTAGGGCAACCCAT' *.fastq > count/B15956_Rm0.txt
agrep -0 -c 'TTAGTGTTTACGAGTCG' *.fastq > count/B15957_Rm0.txt
agrep -0 -c 'CTCACTTCAAACCCGAC' *.fastq > count/B15958_Rm0.txt
agrep -0 -c 'CGAGGAAGTTGATCAGA' *.fastq > count/B15959_Rm0.txt
agrep -0 -c 'CGCCATGTCTACTTCAA' *.fastq > count/B15960_Rm0.txt
agrep -0 -c 'AATAACCCAGTCTACTC' *.fastq > count/B15961_Rm0.txt
agrep -0 -c 'GGTGCTTTATTTGGGCA' *.fastq > count/B15963_Rm0.txt
agrep -0 -c 'GATTTTTGAGACGCCGC' *.fastq > count/B15964_Rm0.txt
agrep -0 -c 'AGATTTTTGAGCCGCCT' *.fastq > count/B15965_Rm0.txt
agrep -0 -c 'GTCTGCTCGGAGTTTCG' *.fastq > count/B15966_Rm0.txt
agrep -0 -c 'TATCCGTTCCTTATGCA' *.fastq > count/B15967_Rm0.txt
agrep -0 -c 'CGCTGTCAAGCTGTGTA' *.fastq > count/B15968_Rm0.txt
agrep -0 -c 'AAGGACGGGTAATGGCG' *.fastq > count/B15969_Rm0.txt
agrep -0 -c 'GCAAAGCCTGTTCGTTA' *.fastq > count/B15970_Rm0.txt
agrep -0 -c 'CAGCTTTGCGGAAGAAC' *.fastq > count/B15971_Rm0.txt
agrep -0 -c 'CGGCCATGATTGTATAC' *.fastq > count/B15973_Rm0.txt
agrep -0 -c 'GACACCTGTACGTGAAG' *.fastq > count/B15974_Rm0.txt
agrep -0 -c 'GAAGATAGCTGGGCCTT' *.fastq > count/B15975_Rm0.txt
agrep -0 -c 'GGTAACTAAACCTACGC' *.fastq > count/B15979_Rm0.txt
agrep -0 -c 'CACGCGCGAAACGAGTT' *.fastq > count/B15981_Rm0.txt
agrep -0 -c 'TTGGTAGGGCTCCGTTG' *.fastq > count/B15982_Rm0.txt
agrep -0 -c 'AATATACGAGGTCTCGG' *.fastq > count/B15983_Rm0.txt
agrep -0 -c 'GTAGCCTTGGCGACATC' *.fastq > count/B15984_Rm0.txt
agrep -0 -c 'GAAGTATTAAGCGACGG' *.fastq > count/B15987_Rm0.txt
agrep -0 -c 'CGCGGTTAGACATACGT' *.fastq > count/B15990_Rm0.txt
agrep -0 -c 'CCTAAGTGTACCACCCC' *.fastq > count/B15991_Rm0.txt
agrep -0 -c 'GAAGACATGTACGTGCT' *.fastq > count/B15992_Rm0.txt
agrep -0 -c 'AATTGGGAATGGGCCAA' *.fastq > count/B15993_Rm0.txt
agrep -0 -c 'ATGCTGGCTAGGATACT' *.fastq > count/B15994_Rm0.txt
agrep -0 -c 'GAGTCTCGTTAGGTATG' *.fastq > count/B15995_Rm0.txt
agrep -0 -c 'CGAAATGCGATAGTTGT' *.fastq > count/B15996_Rm0.txt
agrep -0 -c 'CTAAACACACTGCCCAT' *.fastq > count/B15999_Rm0.txt
agrep -0 -c 'AGGGGATAATAGCGTAG' *.fastq > count/B16000_Rm0.txt
agrep -0 -c 'CCTGAGCAAATAGCAGT' *.fastq > count/B16001_Rm0.txt
agrep -0 -c 'AGAATAGGGGTGAGGCG' *.fastq > count/B16002_Rm0.txt
agrep -0 -c 'GAAGGTGAAGACCCATA' *.fastq > count/B16003_Rm0.txt
agrep -0 -c 'TTACGTGGTGCGCCTCA' *.fastq > count/B16004_Rm0.txt
agrep -0 -c 'CTACGTGCAACAGCGCT' *.fastq > count/B16005_Rm0.txt
agrep -0 -c 'GCTAATACGGCTCCCGA' *.fastq > count/B16006_Rm0.txt
agrep -0 -c 'AGCACAAAGCAGGTTGT' *.fastq > count/B16007_Rm0.txt
agrep -0 -c 'ACCAGACGCGGACATAA' *.fastq > count/B16008_Rm0.txt
agrep -0 -c 'TTCGCGATACTCCGTTA' *.fastq > count/B16009_Rm0.txt
agrep -0 -c 'AATAACTCTGATACCGG' *.fastq > count/B16010_Rm0.txt
agrep -0 -c 'GACGTGTTAGTATTCTG' *.fastq > count/B16011_Rm0.txt
agrep -0 -c 'ACTAGTGGGCTTAAGCC' *.fastq > count/B16012_Rm0.txt
agrep -0 -c 'GTATGAACAATCCACAC' *.fastq > count/B16013_Rm0.txt
agrep -0 -c 'TTCGACTGACGTTCACA' *.fastq > count/B16014_Rm0.txt
agrep -0 -c 'GGTTGTTCATGTGAGTC' *.fastq > count/B16015_Rm0.txt
agrep -0 -c 'TCTCCGAATCCGCTTCG' *.fastq > count/B16016_Rm0.txt
agrep -0 -c 'GGGCAATTCAGGTTCAC' *.fastq > count/B16017_Rm0.txt
agrep -0 -c 'TACAATTTCTGGGGATG' *.fastq > count/B16018_Rm0.txt
agrep -0 -c 'GATCATCGGGTGGGATA' *.fastq > count/B16019_Rm0.txt
agrep -0 -c 'AATACTCCCATCTCCGA' *.fastq > count/B16020_Rm0.txt
agrep -0 -c 'TTGATTGTCGCACGATT' *.fastq > count/B16021_Rm0.txt
agrep -0 -c 'GAGAAATTCACATGGCC' *.fastq > count/B16022_Rm0.txt
agrep -0 -c 'AGGGATCTATGGTTCGT' *.fastq > count/B16023_Rm0.txt
agrep -0 -c 'GGTCAGCTACCATAAGA' *.fastq > count/B16024_Rm0.txt
agrep -0 -c 'ATGCATGATCGTATTCG' *.fastq > count/B16025_Rm0.txt
agrep -0 -c 'CGCGTTTAGACCCCCAT' *.fastq > count/B16026_Rm0.txt
agrep -0 -c 'AGCCCAACGATTCTGCT' *.fastq > count/B16027_Rm0.txt
agrep -0 -c 'CAACATAGGCTCTCATG' *.fastq > count/B16029_Rm0.txt
agrep -0 -c 'CGTAACGTTGGCTGTAC' *.fastq > count/B16030_Rm0.txt
agrep -0 -c 'GCTGGAGACCAAAAGTG' *.fastq > count/B16031_Rm0.txt
agrep -0 -c 'CTTTTTAAAGGGCTCCG' *.fastq > count/B16032_Rm0.txt
agrep -0 -c 'GGTATCGGTTCGTTCGT' *.fastq > count/B16033_Rm0.txt
agrep -0 -c 'ATAGAGACGTTAAGCAG' *.fastq > count/B16036_Rm0.txt
agrep -0 -c 'CAGGATACATCGATTGC' *.fastq > count/B16037_Rm0.txt
agrep -0 -c 'AGGCGTTGCCATCAGTC' *.fastq > count/B16038_Rm0.txt
agrep -0 -c 'ATTGACGATCGTGCCAA' *.fastq > count/B16039_Rm0.txt
agrep -0 -c 'TCCTAAATCTTCCCCGC' *.fastq > count/B16040_Rm0.txt
agrep -0 -c 'AGCATTGGTTACACGCC' *.fastq > count/B16041_Rm0.txt
agrep -0 -c 'AGGTCTGAACTCTCCGA' *.fastq > count/B16042_Rm0.txt
agrep -0 -c 'CATGATTTCGCTAGCAG' *.fastq > count/B16043_Rm0.txt
agrep -0 -c 'GTACCTGGATCCTATCT' *.fastq > count/B16044_Rm0.txt
agrep -0 -c 'GACCGTTGCTCGATATT' *.fastq > count/B16046_Rm0.txt
agrep -0 -c 'TGTCCGACGGTCTTCTC' *.fastq > count/B16047_Rm0.txt
agrep -0 -c 'AACTCTAGGTACCCGCT' *.fastq > count/B16048_Rm0.txt
agrep -0 -c 'AAGTCCTTCGTGCTCAC' *.fastq > count/B16049_Rm0.txt
agrep -0 -c 'AACAAGACCAACCGGTA' *.fastq > count/B16050_Rm0.txt
agrep -0 -c 'CACATTCTGTAACGTAG' *.fastq > count/B16051_Rm0.txt
agrep -0 -c 'ACCTCACCCCTAAACGA' *.fastq > count/B16052_Rm0.txt
agrep -0 -c 'TACGCCAAATGTGTGGC' *.fastq > count/B16053_Rm0.txt
agrep -0 -c 'CCCCACTCCGATACTCA' *.fastq > count/B16054_Rm0.txt
agrep -0 -c 'GAAGCTGGACGGAAGTG' *.fastq > count/B16055_Rm0.txt
agrep -0 -c 'GCAAGGCGATTCGGAGA' *.fastq > count/B16057_Rm0.txt
agrep -0 -c 'TGCGTTGACAAAACCTT' *.fastq > count/B16058_Rm0.txt
agrep -0 -c 'CTCGTCTCAATGAACCG' *.fastq > count/B16059_Rm0.txt
agrep -0 -c 'AAAGTGCGAAGGCTCGC' *.fastq > count/B16060_Rm0.txt
agrep -0 -c 'CCACTGGAAGACTTCAG' *.fastq > count/B16061_Rm0.txt
agrep -0 -c 'CATTACAGGGGGAGCAG' *.fastq > count/B16062_Rm0.txt
agrep -0 -c 'AACCTCCTAGTGTGAAT' *.fastq > count/B16063_Rm0.txt
agrep -0 -c 'TCCCGAACCAACTTATC' *.fastq > count/B16064_Rm0.txt
agrep -0 -c 'CAACCCAGTTCCTTAAG' *.fastq > count/B16065_Rm0.txt
agrep -0 -c 'TGCGAAGGAGATGTTAC' *.fastq > count/B16066_Rm0.txt
agrep -0 -c 'AATATCGGGTCCGCCAG' *.fastq > count/B16068_Rm0.txt
agrep -0 -c 'CAGATAAAGCGCTGGTA' *.fastq > count/B16069_Rm0.txt
agrep -0 -c 'CAACGGCCCCTTTATCA' *.fastq > count/B16070_Rm0.txt
agrep -0 -c 'TCAAGTAGCCAGCGGCT' *.fastq > count/B16071_Rm0.txt
agrep -0 -c 'TAGTGGTGGAGGCTGAC' *.fastq > count/B16072_Rm0.txt
agrep -0 -c 'GTCATGCATCTACGTTA' *.fastq > count/B16073_Rm0.txt
agrep -0 -c 'TGAACATTCGTCAGCGA' *.fastq > count/B16074_Rm0.txt
agrep -0 -c 'GACGATAGGTCTGGTAT' *.fastq > count/B16078_Rm0.txt
agrep -0 -c 'TAAATTGGGACGATCCT' *.fastq > count/B16080_Rm0.txt
agrep -0 -c 'CTGTATACTGCGCCACA' *.fastq > count/B16081_Rm0.txt
agrep -0 -c 'GCGACCCATGTATCCAA' *.fastq > count/B16082_Rm0.txt
agrep -0 -c 'ATACTAACAGTCCTCGA' *.fastq > count/B16083_Rm0.txt
agrep -0 -c 'CTACGGCTAACTACTTG' *.fastq > count/B16084_Rm0.txt
agrep -0 -c 'AGCAGCCGGGGAATAGT' *.fastq > count/B16085_Rm0.txt
agrep -0 -c 'CCTCACTCAACTAGAGC' *.fastq > count/B16086_Rm0.txt
agrep -0 -c 'GACTTGGATAAGGGTCT' *.fastq > count/B16088_Rm0.txt
agrep -0 -c 'ACGCAATGTTGAAAGCG' *.fastq > count/B16089_Rm0.txt
agrep -0 -c 'GTACTTGCGAGGCTAAC' *.fastq > count/B16090_Rm0.txt
agrep -0 -c 'CGAAAGGCTCTAGCGCT' *.fastq > count/B16091_Rm0.txt
agrep -0 -c 'ACAACTTTACGACGTGT' *.fastq > count/B16092_Rm0.txt
agrep -0 -c 'AGCCCTCTCGTTGCATG' *.fastq > count/B16093_Rm0.txt
agrep -0 -c 'CTTATCGATATGCGCTC' *.fastq > count/B16094_Rm0.txt
agrep -0 -c 'AGCAAATTGCACCTCAC' *.fastq > count/B16095_Rm0.txt
agrep -0 -c 'GCCAGATCCACTGAGGT' *.fastq > count/B16096_Rm0.txt
agrep -0 -c 'ATTAGATCCGTCCATGT' *.fastq > count/B16097_Rm0.txt
agrep -0 -c 'TAGTGCTCGGGCAAAAT' *.fastq > count/B16098_Rm0.txt
agrep -0 -c 'TCCTAAAGTTCTTCCTG' *.fastq > count/B16101_Rm0.txt
agrep -0 -c 'AGCAACGTAAGTTGGCC' *.fastq > count/B16102_Rm0.txt
agrep -0 -c 'GCCGTTTGCTGTATCAA' *.fastq > count/B16103_Rm0.txt
agrep -0 -c 'CCTCTTACACGTCCTTA' *.fastq > count/B16104_Rm0.txt
agrep -0 -c 'CTTCTAACGTGGATTTG' *.fastq > count/B16105_Rm0.txt
agrep -0 -c 'CATATCTGACATGTCGT' *.fastq > count/B16108_Rm0.txt
agrep -0 -c 'AACCATGCAGTGGACGC' *.fastq > count/B16109_Rm0.txt
agrep -0 -c 'GCAGGAGCGTAACACTC' *.fastq > count/B16110_Rm0.txt
agrep -0 -c 'ACACATCCAGTTTGTGT' *.fastq > count/B16111_Rm0.txt
agrep -0 -c 'CAACAAGGTAACCGGTC' *.fastq > count/B16113_Rm0.txt
agrep -0 -c 'CGGACCAACAAATTGTC' *.fastq > count/B16114_Rm0.txt
agrep -0 -c 'CGTAAGAAATGACCAGC' *.fastq > count/B16115_Rm0.txt
agrep -0 -c 'GGGATTACCCCAAGGTC' *.fastq > count/B16117_Rm0.txt
agrep -0 -c 'ACCTCCTCCACGTATAC' *.fastq > count/B16118_Rm0.txt
agrep -0 -c 'CGCGATGCCACTTTAGT' *.fastq > count/B16119_Rm0.txt
agrep -0 -c 'ACGGCGGTTATCCTACG' *.fastq > count/B16120_Rm0.txt
agrep -0 -c 'GGGGCCGTCTCACAATA' *.fastq > count/B16121_Rm0.txt
agrep -0 -c 'CTTGTCGATCTAGGCGA' *.fastq > count/B16122_Rm0.txt
agrep -0 -c 'TAGTAACAAGGAGCGCG' *.fastq > count/B16123_Rm0.txt
agrep -0 -c 'GTGCTCAATATCGAATC' *.fastq > count/B16124_Rm0.txt
agrep -0 -c 'TAGCAAAATTGCACGAC' *.fastq > count/B16125_Rm0.txt
agrep -0 -c 'CCTTAAGACTCGCCACG' *.fastq > count/B16126_Rm0.txt
agrep -0 -c 'GTATCTCGCGATGGCGT' *.fastq > count/B16127_Rm0.txt
agrep -0 -c 'CCTACCGCGACAAACCT' *.fastq > count/B16128_Rm0.txt
agrep -0 -c 'TCCGTGTTGCGACTGCT' *.fastq > count/B16129_Rm0.txt
agrep -0 -c 'TACCGAACGAGAGCCTC' *.fastq > count/B16130_Rm0.txt
agrep -0 -c 'GGACGATGTCGCATGGT' *.fastq > count/B16132_Rm0.txt
agrep -0 -c 'AACCCCGCTAAGCAGTG' *.fastq > count/B16133_Rm0.txt
agrep -0 -c 'ACGGTGCAAGGCTTCGA' *.fastq > count/B16137_Rm0.txt
agrep -0 -c 'GAGACTATATCTGCCGA' *.fastq > count/B16138_Rm0.txt
agrep -0 -c 'CGGTAATGTCTTCCGTG' *.fastq > count/B16139_Rm0.txt
agrep -0 -c 'TGGAACCGGTTCTTTGT' *.fastq > count/B16140_Rm0.txt
agrep -0 -c 'CACGTCAGTAGATGCGA' *.fastq > count/B16141_Rm0.txt
agrep -0 -c 'ATATGACTGTGATGCGT' *.fastq > count/B16143_Rm0.txt
agrep -0 -c 'GAGCGGATCATCAACGC' *.fastq > count/B16144_Rm0.txt
agrep -0 -c 'CTAAATCTGCGATCGCT' *.fastq > count/B16145_Rm0.txt
agrep -0 -c 'CTCATGGCAGACCTTAG' *.fastq > count/B16146_Rm0.txt
agrep -0 -c 'ACACCGGAAATGCGTCA' *.fastq > count/B16147_Rm0.txt
agrep -0 -c 'CGTAGTTTTCACAGCTC' *.fastq > count/B16149_Rm0.txt
agrep -0 -c 'TCCTGACTCGAGTAAGG' *.fastq > count/B16150_Rm0.txt
agrep -0 -c 'TTCGTTCCCCGGACTAT' *.fastq > count/B16151_Rm0.txt
agrep -0 -c 'GGTGGCAGATAATAAGT' *.fastq > count/B16152_Rm0.txt
agrep -0 -c 'CCTCACGATGCGCAATA' *.fastq > count/B16153_Rm0.txt
agrep -0 -c 'TAGGTCTACGGGTCGTG' *.fastq > count/B16154_Rm0.txt
agrep -0 -c 'GGCCTTTGATGCCGTGA' *.fastq > count/B16155_Rm0.txt
agrep -0 -c 'CCAGGCCTATTACAGAT' *.fastq > count/B16157_Rm0.txt
agrep -0 -c 'CTAACGATACTACGACG' *.fastq > count/B16158_Rm0.txt
agrep -0 -c 'CGGATTGTCATGAGACT' *.fastq > count/B16159_Rm0.txt
agrep -0 -c 'GCTTGTTTCTCAGCGAG' *.fastq > count/B16160_Rm0.txt
agrep -0 -c 'TCGAGGCCATATACCGT' *.fastq > count/B16161_Rm0.txt
agrep -0 -c 'TCATATCGCCGTTTAAC' *.fastq > count/B16163_Rm0.txt
agrep -0 -c 'CTTTGGCGCGCACTAGT' *.fastq > count/B16164_Rm0.txt
agrep -0 -c 'TCCTCGTACCCCCTAGT' *.fastq > count/B16165_Rm0.txt
agrep -0 -c 'TCCATTCACGAGTGCAA' *.fastq > count/B16166_Rm0.txt
agrep -0 -c 'GGCGTCAATCCTTTGAC' *.fastq > count/B16167_Rm0.txt
agrep -0 -c 'GATGTGCGGATCTACCC' *.fastq > count/B16168_Rm0.txt
agrep -0 -c 'TACACGTCGGCCGTGTA' *.fastq > count/B16169_Rm0.txt
agrep -0 -c 'TTTGAAACGTGCCGTAT' *.fastq > count/B16170_Rm0.txt
agrep -0 -c 'AGGGTCTGCTGTCGATA' *.fastq > count/B16171_Rm0.txt
agrep -0 -c 'TAATCGCGGGGTGGCAA' *.fastq > count/B16172_Rm0.txt
agrep -0 -c 'TACTAAGCGTGTTCCGT' *.fastq > count/B16173_Rm0.txt
agrep -0 -c 'TACCGATGGTTTTTGCC' *.fastq > count/B16174_Rm0.txt
agrep -0 -c 'CGTTTCGACTACAAACG' *.fastq > count/B16175_Rm0.txt
agrep -0 -c 'AGCTCGACGCAAAGGTC' *.fastq > count/B16176_Rm0.txt
agrep -0 -c 'TATGCCAATGTACAGCT' *.fastq > count/B16177_Rm0.txt
agrep -0 -c 'TATGGAAAACCTCGGAT' *.fastq > count/B16178_Rm0.txt
agrep -0 -c 'AATGATCCAATCGCCCG' *.fastq > count/B16180_Rm0.txt
agrep -0 -c 'AAACCGTAAAACTGCAG' *.fastq > count/B16181_Rm0.txt
agrep -0 -c 'TGCGAGGAAGTTGCCTG' *.fastq > count/B16182_Rm0.txt
agrep -0 -c 'CCGCCGTGTGTAAAACG' *.fastq > count/B16183_Rm0.txt
agrep -0 -c 'ATTCACCGAGTTTCGGC' *.fastq > count/B16184_Rm0.txt
agrep -0 -c 'ATGGCGCAACCATCAGG' *.fastq > count/B16186_Rm0.txt
agrep -0 -c 'GGCCGTAAATCTTCGAG' *.fastq > count/B16187_Rm0.txt
agrep -0 -c 'CAAGGTCACTAACCGCT' *.fastq > count/B16188_Rm0.txt
agrep -0 -c 'TAGAAGCACGCTGAGCA' *.fastq > count/B16189_Rm0.txt
agrep -0 -c 'CGCCTAGCAGAATGCTG' *.fastq > count/B16191_Rm0.txt
agrep -0 -c 'CAGTCGGGAGTGCTAAT' *.fastq > count/B16192_Rm0.txt
agrep -0 -c 'AACACACACTCGCAATG' *.fastq > count/B16193_Rm0.txt
agrep -0 -c 'GTGTGCGACTACGAGAT' *.fastq > count/B16194_Rm0.txt
agrep -0 -c 'CGCACCTCAGTTCATGT' *.fastq > count/B16196_Rm0.txt
agrep -0 -c 'TAAGGGATCTGGTTGCG' *.fastq > count/B16198_Rm0.txt
agrep -0 -c 'ATATGGGCCGAGTTTCA' *.fastq > count/B16199_Rm0.txt
agrep -0 -c 'ACCCTGTATAGCGTCGA' *.fastq > count/B16201_Rm0.txt
agrep -0 -c 'TAGACCGGGAGCAGTCT' *.fastq > count/B16202_Rm0.txt
agrep -0 -c 'TTTATCTCACCGACTGT' *.fastq > count/B16203_Rm0.txt
agrep -0 -c 'GTACCAGGTGCGTGTCA' *.fastq > count/B16204_Rm0.txt
agrep -0 -c 'GCACACCGTACGCAATC' *.fastq > count/B16205_Rm0.txt
agrep -0 -c 'GCGAGCAGATTCCTCTT' *.fastq > count/B16207_Rm0.txt
agrep -0 -c 'CTCAGGCCACGAAACGT' *.fastq > count/B16209_Rm0.txt
agrep -0 -c 'GCGCATCATCTGAACAG' *.fastq > count/B16210_Rm0.txt
agrep -0 -c 'CGGGTCATCGTGTTATA' *.fastq > count/B16211_Rm0.txt
agrep -0 -c 'CTACCATCGGAACCGAG' *.fastq > count/B16212_Rm0.txt
agrep -0 -c 'ATTCGCATCGAATTGGC' *.fastq > count/B16215_Rm0.txt
agrep -0 -c 'TCTTTAAGCAGAGACAC' *.fastq > count/B16216_Rm0.txt
agrep -0 -c 'TTAACGTCGCTGGCTCG' *.fastq > count/B16217_Rm0.txt
agrep -0 -c 'GCGAAGTGCGGACTTAG' *.fastq > count/B16219_Rm0.txt
agrep -0 -c 'TTATCTCGCGTGTGTGG' *.fastq > count/B16220_Rm0.txt
agrep -0 -c 'AAGTGTAGCGGTCTCGA' *.fastq > count/B16221_Rm0.txt
agrep -0 -c 'GACCGTTATTTTTGCGA' *.fastq > count/B16222_Rm0.txt
agrep -0 -c 'CGATGAGGGACGAGATC' *.fastq > count/B16223_Rm0.txt
agrep -0 -c 'CCGGTAACTCAATTGCG' *.fastq > count/B16224_Rm0.txt
agrep -0 -c 'TCAGAACCCTACACTAG' *.fastq > count/B16225_Rm0.txt
agrep -0 -c 'AGGCTCGGAGTCAAGAT' *.fastq > count/B16226_Rm0.txt
agrep -0 -c 'TATACCAGGCAGCACTT' *.fastq > count/B16227_Rm0.txt
agrep -0 -c 'GTTTCCTGGATACATCC' *.fastq > count/B16228_Rm0.txt
agrep -0 -c 'AATGCAGCGGTTGGGTT' *.fastq > count/B16229_Rm0.txt
agrep -0 -c 'TATCCAGTGAACGAGAG' *.fastq > count/B16230_Rm0.txt
agrep -0 -c 'AGGACTTCGGGTCACAT' *.fastq > count/B16231_Rm0.txt
agrep -0 -c 'AGGTTACGTGCCCGTGT' *.fastq > count/B16232_Rm0.txt
agrep -0 -c 'CACCTTGCTCGAAACAC' *.fastq > count/B16234_Rm0.txt
agrep -0 -c 'ATTAACGCCTCCCGGTG' *.fastq > count/B16235_Rm0.txt
agrep -0 -c 'TGCATGCTCAAGCTTAC' *.fastq > count/B16236_Rm0.txt
agrep -0 -c 'CCCGAAGCATTAGTACC' *.fastq > count/B16239_Rm0.txt
agrep -0 -c 'AAACCAGTGAAGGCGCT' *.fastq > count/B16240_Rm0.txt
agrep -0 -c 'TGAGAGGTTTAAGACCT' *.fastq > count/B16241_Rm0.txt
agrep -0 -c 'TCCAGCGAGGAAGCACT' *.fastq > count/B16242_Rm0.txt
agrep -0 -c 'CAGACAGTTGGTCAAGA' *.fastq > count/B16243_Rm0.txt
agrep -0 -c 'GACCATGAACTACCTCC' *.fastq > count/B16244_Rm0.txt
agrep -0 -c 'GCCGATCAGTATGTGTT' *.fastq > count/B16245_Rm0.txt
agrep -0 -c 'AAAGCCAGGAGAATGTA' *.fastq > count/B16247_Rm0.txt
agrep -0 -c 'CCGGAGGTGCTATAATA' *.fastq > count/B16249_Rm0.txt
agrep -0 -c 'GCAAAGCTAGAGTTCGT' *.fastq > count/B16250_Rm0.txt
agrep -0 -c 'TCGAGGTTATTCGGTGC' *.fastq > count/B16251_Rm0.txt
agrep -0 -c 'GCTCTATATCTCGTTAC' *.fastq > count/B16252_Rm0.txt
agrep -0 -c 'TCACGGGGGGAACCATA' *.fastq > count/B16253_Rm0.txt
agrep -0 -c 'CCTGTTAAACTGCTCGT' *.fastq > count/B16254_Rm0.txt
agrep -0 -c 'GAAAAGGTGTCGTATAC' *.fastq > count/B16256_Rm0.txt
agrep -0 -c 'AACGCATTGCGCTATGG' *.fastq > count/B16257_Rm0.txt
agrep -0 -c 'AGAGCGAACAGCATTCC' *.fastq > count/B16258_Rm0.txt
agrep -0 -c 'ACGTAGCCGTGATCCAG' *.fastq > count/B16259_Rm0.txt
agrep -0 -c 'TGCATAACTCCGACCGA' *.fastq > count/B16263_Rm0.txt
agrep -0 -c 'TGTGTACACGATTCACT' *.fastq > count/B16264_Rm0.txt
agrep -0 -c 'TGGGCGAGCCTTTTCAT' *.fastq > count/B16265_Rm0.txt
agrep -0 -c 'TCGACCACCACATAGAC' *.fastq > count/B16266_Rm0.txt
agrep -0 -c 'GCGAAGAATCACGGCGT' *.fastq > count/B16267_Rm0.txt
agrep -0 -c 'TTCGTGTGTGTTATGGC' *.fastq > count/B16268_Rm0.txt
agrep -0 -c 'AGGCCATAACGGATGTT' *.fastq > count/B16269_Rm0.txt
agrep -0 -c 'TCCTGATCAGAGGTCGA' *.fastq > count/B16271_Rm0.txt
agrep -0 -c 'ATTGCGCGACTCCTCAA' *.fastq > count/B16272_Rm0.txt
agrep -0 -c 'ACGCTTCCGCACTAATG' *.fastq > count/B16273_Rm0.txt
agrep -0 -c 'TGGGCAGTGTGGATCAA' *.fastq > count/B16274_Rm0.txt
agrep -0 -c 'GCGTTAGTCTCAGGCTA' *.fastq > count/B16275_Rm0.txt
agrep -0 -c 'CGACTCCAATAATTCAG' *.fastq > count/B16277_Rm0.txt
agrep -0 -c 'ACTTGACTCGATCTCTA' *.fastq > count/B16278_Rm0.txt
agrep -0 -c 'AAAGTCCGTTCCGTTTG' *.fastq > count/B16279_Rm0.txt
agrep -0 -c 'TAACGGAAACCATGGAC' *.fastq > count/B16280_Rm0.txt
agrep -0 -c 'ACCGCATGTCAAGTGGT' *.fastq > count/B16281_Rm0.txt
agrep -0 -c 'CGTATCGTGCAAGCGAG' *.fastq > count/B16282_Rm0.txt
agrep -0 -c 'AATATAGGCGGGCTCTG' *.fastq > count/B16283_Rm0.txt
agrep -0 -c 'GGATTGACGCGGAGTAC' *.fastq > count/B16284_Rm0.txt
agrep -0 -c 'AGGTACTGCCTCAGTGG' *.fastq > count/B16285_Rm0.txt
agrep -0 -c 'CACTGCTGTTTGGCGAA' *.fastq > count/B16286_Rm0.txt
agrep -0 -c 'GCACTTAGGTTGTGTAC' *.fastq > count/B16287_Rm0.txt
agrep -0 -c 'GGTAGACTGCGGCTGAA' *.fastq > count/B16288_Rm0.txt
agrep -0 -c 'ATGGCGATAAACCACCC' *.fastq > count/B16289_Rm0.txt
agrep -0 -c 'CGAGTCGCGACATTCCT' *.fastq > count/B16292_Rm0.txt
agrep -0 -c 'CCTATGTCTGGTCGGGT' *.fastq > count/B16293_Rm0.txt
agrep -0 -c 'ACTATACTTTTACCCCC' *.fastq > count/B16294_Rm0.txt
agrep -0 -c 'AAGAAGTGCGGACAGCT' *.fastq > count/B16295_Rm0.txt
agrep -0 -c 'CAATGAGACCAATGCCA' *.fastq > count/B16297_Rm0.txt
agrep -0 -c 'ACCTATAGGGTTCAATG' *.fastq > count/B16298_Rm0.txt
agrep -0 -c 'TTACAGGTTCCAGCCGT' *.fastq > count/B16299_Rm0.txt
agrep -0 -c 'CGTACAGGAGTCATATG' *.fastq > count/B16300_Rm0.txt
agrep -0 -c 'GGGTCTTACGGTATTTA' *.fastq > count/B16301_Rm0.txt
agrep -0 -c 'TTTGTAGCATCTCCGTT' *.fastq > count/B16303_Rm0.txt
agrep -0 -c 'CGTTAAGGGCAATTGGC' *.fastq > count/B16304_Rm0.txt
agrep -0 -c 'CCGGCGGACACTCAAAT' *.fastq > count/B16305_Rm0.txt
agrep -0 -c 'GATGAAAGTTAGCAGAC' *.fastq > count/B16306_Rm0.txt
agrep -0 -c 'TCGAAAGAGCAAGCCGA' *.fastq > count/B16307_Rm0.txt
agrep -0 -c 'AATGGTTGGGCAGAGGT' *.fastq > count/B16308_Rm0.txt
agrep -0 -c 'TTTTCGATCAGAGATGG' *.fastq > count/B16309_Rm0.txt
agrep -0 -c 'TTAACGCATGAAGCGGC' *.fastq > count/B16310_Rm0.txt
agrep -0 -c 'TTGAACCCACTGCATCC' *.fastq > count/B16311_Rm0.txt
agrep -0 -c 'CCACAGCGCAGATCTAA' *.fastq > count/B16312_Rm0.txt
agrep -0 -c 'CCGTCTTTGGGAGTATA' *.fastq > count/B16313_Rm0.txt
agrep -0 -c 'TATAAAGTGGTGGACGA' *.fastq > count/B16314_Rm0.txt
agrep -0 -c 'TCATCGACTGACCTATA' *.fastq > count/B16316_Rm0.txt
agrep -0 -c 'AGGATTGACTAGTTGCC' *.fastq > count/B16317_Rm0.txt
agrep -0 -c 'AAGGGCTTGGGGCACAA' *.fastq > count/B16318_Rm0.txt
agrep -0 -c 'CAGGATCGCACTGAATG' *.fastq > count/B16319_Rm0.txt
agrep -0 -c 'GCACCACACTAAATCCC' *.fastq > count/B16320_Rm0.txt
agrep -0 -c 'TCAGTTGCCTGTCAGCG' *.fastq > count/B16322_Rm0.txt
agrep -0 -c 'CAGTTCGAAACGGAATT' *.fastq > count/B16323_Rm0.txt
agrep -0 -c 'TGGCTCGGTAAACTCGT' *.fastq > count/B16324_Rm0.txt
agrep -0 -c 'TCCTTTGGCTACATTAG' *.fastq > count/B16326_Rm0.txt
agrep -0 -c 'AGACCATCACGAGCGAG' *.fastq > count/B16328_Rm0.txt
agrep -0 -c 'CGGACTACTTGTACAGG' *.fastq > count/B16329_Rm0.txt
agrep -0 -c 'CTACGAACTCTGCGATA' *.fastq > count/B16330_Rm0.txt
agrep -0 -c 'CGGATTTCCGCGTTTAT' *.fastq > count/B16331_Rm0.txt
agrep -0 -c 'AGCATCATAGATCGCAG' *.fastq > count/B16333_Rm0.txt
agrep -0 -c 'TATGGGGGGGATTTGCT' *.fastq > count/B16335_Rm0.txt
agrep -0 -c 'AAGTACACTATGAGTCC' *.fastq > count/B16336_Rm0.txt
agrep -0 -c 'TAGTTATCGCAAGCCCC' *.fastq > count/B16337_Rm0.txt
agrep -0 -c 'TTACCTGGATAAACGAC' *.fastq > count/B16338_Rm0.txt
agrep -0 -c 'TTCCATCGCTCCAATTA' *.fastq > count/B16339_Rm0.txt
agrep -0 -c 'CCGCATACGGTTGAACT' *.fastq > count/B16341_Rm0.txt
agrep -0 -c 'TTAGTCATGCGTTGTAG' *.fastq > count/B16342_Rm0.txt
agrep -0 -c 'GGGAGCTCGTAAGATAA' *.fastq > count/B16343_Rm0.txt
agrep -0 -c 'GCGGTCTCTACCATTAC' *.fastq > count/B16344_Rm0.txt
agrep -0 -c 'ACCATTGCCGCTTCCAT' *.fastq > count/B16345_Rm0.txt
agrep -0 -c 'CTATGTTGGAACCGTCG' *.fastq > count/B16346_Rm0.txt
agrep -0 -c 'ACAAGGTCGCCCTGACA' *.fastq > count/B16347_Rm0.txt
agrep -0 -c 'CGTTATCCTCGCGCGAT' *.fastq > count/B16348_Rm0.txt
agrep -0 -c 'TTGATAATGACCGATCG' *.fastq > count/B16349_Rm0.txt
agrep -0 -c 'TTCCAGGGAACTATTCC' *.fastq > count/B16350_Rm0.txt
agrep -0 -c 'TTCCCGTAGGTGCCTTA' *.fastq > count/B16352_Rm0.txt
agrep -0 -c 'TGCCTCACACACATGCG' *.fastq > count/B16353_Rm0.txt
agrep -0 -c 'TGATTTACCGTGGACTA' *.fastq > count/B16354_Rm0.txt
agrep -0 -c 'ACTGAGAACGTTTCGCT' *.fastq > count/B16355_Rm0.txt
agrep -0 -c 'AGGCGAGCTAGATGAGG' *.fastq > count/B16357_Rm0.txt
agrep -0 -c 'GATATGGAAGCCGAACT' *.fastq > count/B16360_Rm0.txt
agrep -0 -c 'ATTTTCATTGAGACGCC' *.fastq > count/B16361_Rm0.txt
agrep -0 -c 'GAGCGAGACTGAGGATT' *.fastq > count/B16362_Rm0.txt
agrep -0 -c 'GAGTCCTAAAAAGACGC' *.fastq > count/B16366_Rm0.txt
agrep -0 -c 'CCTCGGCGTCTGTTATC' *.fastq > count/B16367_Rm0.txt
agrep -0 -c 'CTCTAGTTAAACCTCAG' *.fastq > count/B16369_Rm0.txt
agrep -0 -c 'CTACATATGCTACCTGG' *.fastq > count/B16370_Rm0.txt
agrep -0 -c 'CTGGGCAGTGACTGATC' *.fastq > count/B16371_Rm0.txt
agrep -0 -c 'GGACGGAATTGTCCCAT' *.fastq > count/B16372_Rm0.txt
agrep -0 -c 'CCCTCAGATCGACGAAC' *.fastq > count/B16373_Rm0.txt
agrep -0 -c 'GCTCCTCCTGTCGGATA' *.fastq > count/B16374_Rm0.txt
agrep -0 -c 'GCCTTTCAGATCGCGCA' *.fastq > count/B16375_Rm0.txt
agrep -0 -c 'ATGCCCCTTATTGCGAC' *.fastq > count/B16376_Rm0.txt
agrep -0 -c 'ACGGATCTTACGTCCCC' *.fastq > count/B16377_Rm0.txt
agrep -0 -c 'TAGTCTCTAGGACTCAG' *.fastq > count/B16378_Rm0.txt
agrep -0 -c 'TATCAAAGCGGGGACTG' *.fastq > count/B16379_Rm0.txt
agrep -0 -c 'CTAATTCGCAAATGGGC' *.fastq > count/B16380_Rm0.txt
agrep -0 -c 'GTAGTTTTTCCGCCACC' *.fastq > count/B16381_Rm0.txt
agrep -0 -c 'CGTGGGTGATTGTTACA' *.fastq > count/B16384_Rm0.txt
agrep -0 -c 'ACTCTCCCAGATATGTG' *.fastq > count/B16385_Rm0.txt
agrep -0 -c 'TCCGCATTGGTAACGAG' *.fastq > count/B16387_Rm0.txt
agrep -0 -c 'TATGTGGCGGGTGTACC' *.fastq > count/B16388_Rm0.txt
agrep -0 -c 'TGTTAGGGGCTCAGCCA' *.fastq > count/B16389_Rm0.txt
agrep -0 -c 'TTACCAAGGAGCGCCCT' *.fastq > count/B16390_Rm0.txt
agrep -0 -c 'ACATGTAGAGATACGTG' *.fastq > count/B16391_Rm0.txt
agrep -0 -c 'CTTCTTCTAGACCTTAC' *.fastq > count/B16392_Rm0.txt
agrep -0 -c 'CACCAGGACGCATCCAT' *.fastq > count/B16395_Rm0.txt
agrep -0 -c 'CTCACCGCAGTAATATA' *.fastq > count/B16396_Rm0.txt
agrep -0 -c 'TGAAGACACGAGACCGA' *.fastq > count/B16397_Rm0.txt
agrep -0 -c 'CGAACTGGTATGACAAC' *.fastq > count/B16398_Rm0.txt
agrep -0 -c 'TCTACGTCAAGCACTGT' *.fastq > count/B16400_Rm0.txt
agrep -0 -c 'GGAAAGCATCCTACCTA' *.fastq > count/B16401_Rm0.txt
agrep -0 -c 'CCAGCGTTCATCACCTG' *.fastq > count/B16402_Rm0.txt
agrep -0 -c 'TCACGAGTCACCTTCCA' *.fastq > count/B16403_Rm0.txt
agrep -0 -c 'ACGAATAGGCAACGGAC' *.fastq > count/B16404_Rm0.txt
agrep -0 -c 'AGGTGCACCTTACATCC' *.fastq > count/B16405_Rm0.txt
agrep -0 -c 'CCCCTGTCGCACGTAAT' *.fastq > count/B16406_Rm0.txt
agrep -0 -c 'TACGGTGCGTGGGATCA' *.fastq > count/B16408_Rm0.txt
agrep -0 -c 'CGACCTTATGCTAATCC' *.fastq > count/B16410_Rm0.txt
agrep -0 -c 'CAGCGAAAAGCCTACTT' *.fastq > count/B16413_Rm0.txt
agrep -0 -c 'GTGGGACGTCGAGAAAC' *.fastq > count/B16414_Rm0.txt
agrep -0 -c 'GGGCACGTAATAAGATA' *.fastq > count/B16415_Rm0.txt
agrep -0 -c 'AAAATATAGGCGGGGGT' *.fastq > count/B16416_Rm0.txt
agrep -0 -c 'ACCGGTACCAGCCTAGT' *.fastq > count/B16417_Rm0.txt
agrep -0 -c 'TCATCACCACTCGCAAT' *.fastq > count/B16418_Rm0.txt
agrep -0 -c 'TCTAGACGACATACTCC' *.fastq > count/B16419_Rm0.txt
agrep -0 -c 'TCTTCACGCTGCTTAAC' *.fastq > count/B16420_Rm0.txt
agrep -0 -c 'TATTCACTCTCGAGCAC' *.fastq > count/B16421_Rm0.txt
agrep -0 -c 'CGGAACTACTGGCTAAC' *.fastq > count/B16422_Rm0.txt
agrep -0 -c 'CAGCCGAACTGCTTTTA' *.fastq > count/B16423_Rm0.txt
agrep -0 -c 'AGTTCTCGTGACTAACC' *.fastq > count/B16424_Rm0.txt
agrep -0 -c 'GTCGCGGTGAAATAAAC' *.fastq > count/B16425_Rm0.txt
agrep -0 -c 'GTTTGTTGTTCGACCGT' *.fastq > count/B16426_Rm0.txt
agrep -0 -c 'CTATCGGACCCTTTGTG' *.fastq > count/B16427_Rm0.txt
agrep -0 -c 'CGAGCATCCTAGAAACC' *.fastq > count/B16428_Rm0.txt
agrep -0 -c 'ATGGGTGTACAATGGGT' *.fastq > count/B16429_Rm0.txt
agrep -0 -c 'ATCACCATTAGAGGGCT' *.fastq > count/B16430_Rm0.txt
agrep -0 -c 'TGATACTCCACAAACTC' *.fastq > count/B16431_Rm0.txt
agrep -0 -c 'GTACGCTGGCAATCAAC' *.fastq > count/B16433_Rm0.txt
agrep -0 -c 'AAATCCGGCGACCATAA' *.fastq > count/B16434_Rm0.txt
agrep -0 -c 'CGCTATAAACTGGCTGA' *.fastq > count/B16435_Rm0.txt
agrep -0 -c 'TCGGGTGTCGTGATCAT' *.fastq > count/B16438_Rm0.txt
agrep -0 -c 'GTAGTCAAAGTAAGGAC' *.fastq > count/B16439_Rm0.txt
agrep -0 -c 'CTTGATCACACTCTTAG' *.fastq > count/B16440_Rm0.txt
agrep -0 -c 'AATAACGCGTAACAGCG' *.fastq > count/B16441_Rm0.txt
agrep -0 -c 'GTCCAAAAGGGATTGCT' *.fastq > count/B16442_Rm0.txt
agrep -0 -c 'GCATGGTCTTCGGGATT' *.fastq > count/B16443_Rm0.txt
agrep -0 -c 'ACAGCTCCGGCACCAAT' *.fastq > count/B16444_Rm0.txt
agrep -0 -c 'TTCCTTTAACGCGAGTA' *.fastq > count/B16446_Rm0.txt
agrep -0 -c 'CTGAATGCGCGGCTATC' *.fastq > count/B16447_Rm0.txt
agrep -0 -c 'AACCCGGAATTCATCAA' *.fastq > count/B16448_Rm0.txt
agrep -0 -c 'TACTAGCGCATGTGTCC' *.fastq > count/B16449_Rm0.txt
agrep -0 -c 'GGAAAGCTGCCACTTGG' *.fastq > count/B16450_Rm0.txt
agrep -0 -c 'CGCCCCATAGGTGTAAC' *.fastq > count/B16451_Rm0.txt
agrep -0 -c 'GCTGAGCCAAGGTTACT' *.fastq > count/B16452_Rm0.txt
agrep -0 -c 'GCATGTAGGAGTCCCAG' *.fastq > count/B16454_Rm0.txt
agrep -0 -c 'TAGGCGGCTACTCAGGT' *.fastq > count/B16455_Rm0.txt
agrep -0 -c 'GCCCATTGCTGAACAAC' *.fastq > count/B16456_Rm0.txt
agrep -0 -c 'CGCAAATGATCGCACCT' *.fastq > count/B16457_Rm0.txt
agrep -0 -c 'TTGCCACTTAACCCAGT' *.fastq > count/B16459_Rm0.txt
agrep -0 -c 'GACGATGCATGGACAAC' *.fastq > count/B16460_Rm0.txt
agrep -0 -c 'GGCCCAGCAGCAATTCA' *.fastq > count/B16461_Rm0.txt
agrep -0 -c 'TGGTATATGGGATCGCC' *.fastq > count/B16462_Rm0.txt
agrep -0 -c 'CAACATGATGGATACCC' *.fastq > count/B16463_Rm0.txt
agrep -0 -c 'GTACAACCTAAGCCCCC' *.fastq > count/B16465_Rm0.txt
agrep -0 -c 'GTGATGTGAACTCATCG' *.fastq > count/B16466_Rm0.txt
agrep -0 -c 'GTGTAAGCCCCTATAGC' *.fastq > count/B16467_Rm0.txt
agrep -0 -c 'TAGTAAGGCAGATCAGG' *.fastq > count/B16468_Rm0.txt
agrep -0 -c 'CAGATACGCATATGTCA' *.fastq > count/B16470_Rm0.txt
agrep -0 -c 'TCCGACATTCTTATCCC' *.fastq > count/B16471_Rm0.txt
agrep -0 -c 'CCCAGCGGATATAGACA' *.fastq > count/B16473_Rm0.txt
agrep -0 -c 'TTCGGACCCTTGTTCCA' *.fastq > count/B16474_Rm0.txt
agrep -0 -c 'ACTGAAGCGGTGACTAG' *.fastq > count/B16475_Rm0.txt
agrep -0 -c 'TTAGGCTCCGTGAGATT' *.fastq > count/B16476_Rm0.txt
agrep -0 -c 'GCTATATTCGACGGTAT' *.fastq > count/B16477_Rm0.txt
agrep -0 -c 'CTAGCTGCATAACACGC' *.fastq > count/B16478_Rm0.txt
agrep -0 -c 'TAAGGAACGTTTTCCTG' *.fastq > count/B16479_Rm0.txt
agrep -0 -c 'GGACTGCATCTGACTAG' *.fastq > count/B16481_Rm0.txt
agrep -0 -c 'AGCTCAGAGTCGCATAT' *.fastq > count/B16482_Rm0.txt
agrep -0 -c 'CCCGGATGCCTACAACT' *.fastq > count/B16483_Rm0.txt
agrep -0 -c 'TTCAATTTGGGACCACT' *.fastq > count/B16484_Rm0.txt
agrep -0 -c 'TCCGGACGCTTGTGACA' *.fastq > count/B16485_Rm0.txt
agrep -0 -c 'CCACTGAGAAGCGTTGC' *.fastq > count/B16486_Rm0.txt
agrep -0 -c 'CCTGCTGTCAACAAGAA' *.fastq > count/B16487_Rm0.txt
agrep -0 -c 'ATTACCTATCTGTGCGG' *.fastq > count/B16488_Rm0.txt
agrep -0 -c 'TTCCTCGACTCATGTAG' *.fastq > count/B16489_Rm0.txt
agrep -0 -c 'TCAATGACTCGTGTGCT' *.fastq > count/B16490_Rm0.txt
agrep -0 -c 'ACTTGGTAGCAGCAGAC' *.fastq > count/B16491_Rm0.txt
agrep -0 -c 'CCATGATGAATCGCACT' *.fastq > count/B16492_Rm0.txt
agrep -0 -c 'GACTTGTTGGTAGTCGG' *.fastq > count/B16493_Rm0.txt
agrep -0 -c 'AGCTTTATGACGAGGTT' *.fastq > count/B16494_Rm0.txt
agrep -0 -c 'TACAATGAGTCACGCAC' *.fastq > count/B16495_Rm0.txt
agrep -0 -c 'GTCCATTGCTGAGCACA' *.fastq > count/B16497_Rm0.txt
agrep -0 -c 'CTGTCGATTAAAGTGGC' *.fastq > count/B16499_Rm0.txt
agrep -0 -c 'GTGGGATTCGACGATCT' *.fastq > count/B16500_Rm0.txt
agrep -0 -c 'TTACGCGGAACCAACAA' *.fastq > count/B16501_Rm0.txt
agrep -0 -c 'GCTCCGTGGACCATAAC' *.fastq > count/B16502_Rm0.txt
agrep -0 -c 'ATTCGCCACAGTGCGGT' *.fastq > count/B16503_Rm0.txt
agrep -0 -c 'TTATCGCTATCAGCCGG' *.fastq > count/B16504_Rm0.txt
agrep -0 -c 'GCGCTGTGTGTCAAGTT' *.fastq > count/B16505_Rm0.txt
agrep -0 -c 'TTCATCGATTCGCAGAA' *.fastq > count/B16506_Rm0.txt
agrep -0 -c 'CCGATCGAAGAGAGTCG' *.fastq > count/B16507_Rm0.txt
agrep -0 -c 'CGAATGCATGTAGCACG' *.fastq > count/B16508_Rm0.txt
agrep -0 -c 'AGTCACCATATATGTGG' *.fastq > count/B16509_Rm0.txt
agrep -0 -c 'GGAGAAATTGTAGCGTG' *.fastq > count/B16510_Rm0.txt
agrep -0 -c 'GCAGGACCTATGATCTT' *.fastq > count/B16511_Rm0.txt
agrep -0 -c 'GGTCCAACAACCTGTCA' *.fastq > count/B16512_Rm0.txt
agrep -0 -c 'AGTTTGGGGCAGAACTG' *.fastq > count/B16513_Rm0.txt
agrep -0 -c 'CATGCTGTGACGCATTA' *.fastq > count/B16514_Rm0.txt
agrep -0 -c 'CGGGTACCGTACATATC' *.fastq > count/B16515_Rm0.txt
agrep -0 -c 'TATTGCTTGACTTGGCG' *.fastq > count/B16516_Rm0.txt
agrep -0 -c 'CGCATAAAAGGGGCGAT' *.fastq > count/B16517_Rm0.txt
agrep -0 -c 'CGGTGCCTATGGTAACT' *.fastq > count/B16518_Rm0.txt
agrep -0 -c 'GGGTGTCCATCGAAAAC' *.fastq > count/B16519_Rm0.txt
agrep -0 -c 'GAGTGTCGCACCATTCG' *.fastq > count/B16520_Rm0.txt
agrep -0 -c 'TGTAGAGACACCTCCAC' *.fastq > count/B16521_Rm0.txt
agrep -0 -c 'AAACTGGGCTGCTCGAG' *.fastq > count/B16522_Rm0.txt
agrep -0 -c 'TCGAGAACCCTTGCCTA' *.fastq > count/B16523_Rm0.txt
agrep -0 -c 'ACTCAGCTGAGCGTTCG' *.fastq > count/B16524_Rm0.txt
agrep -0 -c 'GGTAGCGCTAAAGGCTG' *.fastq > count/B16525_Rm0.txt
agrep -0 -c 'ATGACACGTCTTAAGAC' *.fastq > count/B16526_Rm0.txt
agrep -0 -c 'GGAAATGAGATGCCCCG' *.fastq > count/B16527_Rm0.txt
agrep -0 -c 'CGGCTTCAAAACTCACG' *.fastq > count/B16528_Rm0.txt
agrep -0 -c 'GGCTTCTCACTCCTTGC' *.fastq > count/B16529_Rm0.txt
agrep -0 -c 'GCTTATGGGGGCCATGA' *.fastq > count/B16531_Rm0.txt
agrep -0 -c 'CGTGTAATTAACGACTG' *.fastq > count/B16532_Rm0.txt
agrep -0 -c 'TTCGATTACGCCATATG' *.fastq > count/B16534_Rm0.txt
agrep -0 -c 'TGTCATCATAACCAGGC' *.fastq > count/B16535_Rm0.txt
agrep -0 -c 'CCTGGTTATCTCCTTTA' *.fastq > count/B16536_Rm0.txt
agrep -0 -c 'AGCTGACTAGGAGGTCA' *.fastq > count/B16537_Rm0.txt
agrep -0 -c 'GAGAGCGACATACAGGT' *.fastq > count/B16538_Rm0.txt
agrep -0 -c 'AGACATACCCAAGCCGC' *.fastq > count/B16539_Rm0.txt
agrep -0 -c 'CTAACTAGAATGGGACG' *.fastq > count/B16540_Rm0.txt
agrep -0 -c 'GGACCGCGGTTTAATGA' *.fastq > count/B16541_Rm0.txt
agrep -0 -c 'CGCTTCCTTTACACTAG' *.fastq > count/B16542_Rm0.txt
agrep -0 -c 'ATGGGTGCATACCGCAT' *.fastq > count/B16543_Rm0.txt
agrep -0 -c 'AATGGCCAATTACCGGC' *.fastq > count/B16544_Rm0.txt
agrep -0 -c 'AGCCGACACGTAAACTC' *.fastq > count/B16545_Rm0.txt
agrep -0 -c 'TGAGTAGCTAGCAAACA' *.fastq > count/B16546_Rm0.txt
agrep -0 -c 'GACCTAAGCAAAAATGC' *.fastq > count/B16547_Rm0.txt
agrep -0 -c 'CCAGTATGCCCGACGTA' *.fastq > count/B16548_Rm0.txt
agrep -0 -c 'CTTATACTCGACCATAG' *.fastq > count/B16549_Rm0.txt
agrep -0 -c 'CGCCAACATCAAGCTCT' *.fastq > count/B16550_Rm0.txt
agrep -0 -c 'GTCAGCTCGGATTAAAC' *.fastq > count/B16551_Rm0.txt
agrep -0 -c 'GACTCGTTTCTCTGAAG' *.fastq > count/B16552_Rm0.txt
agrep -0 -c 'TACTCGCCAAAAGCGTA' *.fastq > count/B16553_Rm0.txt
agrep -0 -c 'TAGCTAAAAGCGGACTG' *.fastq > count/B16554_Rm0.txt
agrep -0 -c 'TAACTAAATTCTGGGCG' *.fastq > count/B16555_Rm0.txt
agrep -0 -c 'TTGATTACGCGAGATCC' *.fastq > count/B16556_Rm0.txt
agrep -0 -c 'CGCAATTCGGGTGTGAG' *.fastq > count/B16558_Rm0.txt
agrep -0 -c 'AGTCCAGTATTCGGTGA' *.fastq > count/B16560_Rm0.txt
agrep -0 -c 'CCCTCGAATGCGAAACA' *.fastq > count/B16561_Rm0.txt
agrep -0 -c 'GTACAAGCCGGTATAGA' *.fastq > count/B16562_Rm0.txt
agrep -0 -c 'AGATATATGCATCGACG' *.fastq > count/B16563_Rm0.txt
agrep -0 -c 'TCAATGCGGAAAACAAC' *.fastq > count/B16565_Rm0.txt
agrep -0 -c 'CGTCTATTTGGCGCGTG' *.fastq > count/B16567_Rm0.txt
agrep -0 -c 'AGCTTACCTCGTGCAGC' *.fastq > count/B16568_Rm0.txt
agrep -0 -c 'TAATGGATTCGCCTCCT' *.fastq > count/B16569_Rm0.txt
agrep -0 -c 'TTATCTTTTGCGAACGC' *.fastq > count/B16570_Rm0.txt
agrep -0 -c 'CTTCATGCTTGCGCGAC' *.fastq > count/B16573_Rm0.txt
agrep -0 -c 'CTAAGCGACCCAGCACA' *.fastq > count/B16574_Rm0.txt
agrep -0 -c 'TTAGAAAAGCGTCCGTC' *.fastq > count/B16576_Rm0.txt
agrep -0 -c 'ATATACCTCCAACAGCT' *.fastq > count/B16577_Rm0.txt
agrep -0 -c 'GGTGTAGTGAATCGTCT' *.fastq > count/B16578_Rm0.txt
agrep -0 -c 'AAATAGGTCTTCGGGTC' *.fastq > count/B16579_Rm0.txt
agrep -0 -c 'TTCACTTGGCCCATTCG' *.fastq > count/B16580_Rm0.txt
agrep -0 -c 'AATGGACAGATGGCGTA' *.fastq > count/B16581_Rm0.txt
agrep -0 -c 'GATATAGCTCACCACCG' *.fastq > count/B16582_Rm0.txt
agrep -0 -c 'CGAGAGTTAGCCAGCAT' *.fastq > count/B16583_Rm0.txt
agrep -0 -c 'GTTCCGTAAGGATATCG' *.fastq > count/B16584_Rm0.txt
agrep -0 -c 'TGCCCACCATTGATGCG' *.fastq > count/B16585_Rm0.txt
agrep -0 -c 'CGTGTCTGCCGATATAA' *.fastq > count/B16586_Rm0.txt
agrep -0 -c 'TCAGTTGGCCGCATAGA' *.fastq > count/B16587_Rm0.txt
agrep -0 -c 'TTTTTAGTCCCGTGCGT' *.fastq > count/B16589_Rm0.txt
agrep -0 -c 'TCTCCGATACGTATTAC' *.fastq > count/B16590_Rm0.txt
agrep -0 -c 'AAGTGGTATCGAGTAGA' *.fastq > count/B16591_Rm0.txt
agrep -0 -c 'TCCGCTATGGGGTATGA' *.fastq > count/B16593_Rm0.txt
agrep -0 -c 'ACCGCAGTTAAGGTCCC' *.fastq > count/B16594_Rm0.txt
agrep -0 -c 'GTGTTGATTGGACTGGT' *.fastq > count/B16595_Rm0.txt
agrep -0 -c 'TCCTAAAGCAGGTCTCA' *.fastq > count/B16596_Rm0.txt
agrep -0 -c 'TAACTTTTCCGGGTAGC' *.fastq > count/B16597_Rm0.txt
agrep -0 -c 'CGTATTCTACCAGCTTG' *.fastq > count/B16598_Rm0.txt
agrep -0 -c 'ACTTTGCACTCGACGCT' *.fastq > count/B16599_Rm0.txt
agrep -0 -c 'ACGAAACCATATCTGCG' *.fastq > count/B16600_Rm0.txt
agrep -0 -c 'TACCACCGCCCCTAAAT' *.fastq > count/B16602_Rm0.txt
agrep -0 -c 'CTTTTGCCTTAGGGGGC' *.fastq > count/B16603_Rm0.txt
agrep -0 -c 'GTCATAGAGTATACGAG' *.fastq > count/B16604_Rm0.txt
agrep -0 -c 'TGTGCCCATTCAGGACC' *.fastq > count/B16605_Rm0.txt
agrep -0 -c 'AAGTCACCTCTCAACTA' *.fastq > count/B16606_Rm0.txt
agrep -0 -c 'GCGGAGGTTCCTTTCAC' *.fastq > count/B16607_Rm0.txt
agrep -0 -c 'GAGGTTACGCACTCCAA' *.fastq > count/B16608_Rm0.txt
agrep -0 -c 'CATGCTCCAATCGGTAG' *.fastq > count/B16612_Rm0.txt
agrep -0 -c 'CGACAGTACTTGGCGAG' *.fastq > count/B16613_Rm0.txt
agrep -0 -c 'ATTGGACACGTCTCCGG' *.fastq > count/B16614_Rm0.txt
agrep -0 -c 'CACACGACGCATACGTT' *.fastq > count/B16615_Rm0.txt
agrep -0 -c 'ACAGTTCGCGAGCAGAT' *.fastq > count/B16616_Rm0.txt
agrep -0 -c 'AACCGACGTTTAGCCAA' *.fastq > count/B16617_Rm0.txt
agrep -0 -c 'TGCGAAATTTAGAGACC' *.fastq > count/B16618_Rm0.txt
agrep -0 -c 'ACATGTCAGACGAATAG' *.fastq > count/B16619_Rm0.txt
agrep -0 -c 'CCACGGCATCAATCGAT' *.fastq > count/B16622_Rm0.txt
agrep -0 -c 'GAAGTCTCGATTTGCTG' *.fastq > count/B16623_Rm0.txt
agrep -0 -c 'CCAATCTCGCTAAGTCA' *.fastq > count/B16624_Rm0.txt
agrep -0 -c 'GTTGGGCCTCATTGTGT' *.fastq > count/B16625_Rm0.txt
agrep -0 -c 'GGCCGAGAATGACTATT' *.fastq > count/B16626_Rm0.txt
agrep -0 -c 'GGACTGAGTCATTTTGA' *.fastq > count/B16627_Rm0.txt
agrep -0 -c 'GACTGCGAACTAACGTC' *.fastq > count/B16628_Rm0.txt
agrep -0 -c 'TGTTGAATAGCCGCTAT' *.fastq > count/B16629_Rm0.txt
agrep -0 -c 'CTACACGCAATCTTGCT' *.fastq > count/B16630_Rm0.txt
agrep -0 -c 'TCGTTAACCTGAACTGC' *.fastq > count/B16632_Rm0.txt
agrep -0 -c 'TTTAGCTTGTAGGGGCA' *.fastq > count/B16634_Rm0.txt
agrep -0 -c 'AATACTAACCGCTCGTC' *.fastq > count/B16635_Rm0.txt
agrep -0 -c 'GCCTCCACCATACGGAA' *.fastq > count/B16636_Rm0.txt
agrep -0 -c 'ATTATGGATCCTCTCCT' *.fastq > count/B16637_Rm0.txt
agrep -0 -c 'TGCTTTATCCCTAAGCA' *.fastq > count/B16639_Rm0.txt
agrep -0 -c 'CCCGATCAAAATAGTCA' *.fastq > count/B16640_Rm0.txt
agrep -0 -c 'AGGGAGCTGAAGAAGAC' *.fastq > count/B16641_Rm0.txt
agrep -0 -c 'CATTTCGGGCATACGCT' *.fastq > count/B16642_Rm0.txt
agrep -0 -c 'TCATCAGGCATTCGAAC' *.fastq > count/B16644_Rm0.txt
agrep -0 -c 'GATTATTGACCCAGGAT' *.fastq > count/B16646_Rm0.txt
agrep -0 -c 'TGTGCGGACTTAGAGTG' *.fastq > count/B16648_Rm0.txt
agrep -0 -c 'AATTGATAGAGGCGCTA' *.fastq > count/B16649_Rm0.txt
agrep -0 -c 'TATTCGCGACTCCCGAC' *.fastq > count/B16650_Rm0.txt
agrep -0 -c 'CTCTGGAAAAACTCAAC' *.fastq > count/B16651_Rm0.txt
agrep -0 -c 'CGGTAGAACTTGTTCTA' *.fastq > count/B16652_Rm0.txt
agrep -0 -c 'AGCCGTAATCGCGTTGC' *.fastq > count/B16653_Rm0.txt
agrep -0 -c 'ATTGGGCCTTCCGAGAC' *.fastq > count/B16654_Rm0.txt
agrep -0 -c 'CAAACGTGGTTCGCAAT' *.fastq > count/B16655_Rm0.txt
agrep -0 -c 'CGACAGGTACACCTCAG' *.fastq > count/B16656_Rm0.txt
agrep -0 -c 'TAGGGGTGGTGACCCTA' *.fastq > count/B16658_Rm0.txt
agrep -0 -c 'GATGGCTGAGTTCTCTC' *.fastq > count/B16659_Rm0.txt
agrep -0 -c 'AAATCCGTCCGGGAATA' *.fastq > count/B16663_Rm0.txt
agrep -0 -c 'CATCCGATACTTCGGAT' *.fastq > count/B16664_Rm0.txt
agrep -0 -c 'ATAATGGGCCGGAATCA' *.fastq > count/B16666_Rm0.txt
agrep -0 -c 'AACGCGAAGTTGGTGTC' *.fastq > count/B16668_Rm0.txt
agrep -0 -c 'GTCACTCCTATTCACCT' *.fastq > count/B16669_Rm0.txt
agrep -0 -c 'ACTGTTGGCTTTCATAG' *.fastq > count/B16670_Rm0.txt
agrep -0 -c 'CCGGTATATGTAGAAGA' *.fastq > count/B16671_Rm0.txt
agrep -0 -c 'GATACAGTTACCCCTCA' *.fastq > count/B16672_Rm0.txt
agrep -0 -c 'AGAAGTAACTGCGCTGC' *.fastq > count/B16673_Rm0.txt
agrep -0 -c 'TCAAACGAACCCAGCAA' *.fastq > count/B16674_Rm0.txt
agrep -0 -c 'GTTGGCTCCAGGTTATT' *.fastq > count/B16675_Rm0.txt
agrep -0 -c 'CTCCACATGATTGCCGA' *.fastq > count/B16676_Rm0.txt
agrep -0 -c 'GGTGAACCTCAGGAGAC' *.fastq > count/B16677_Rm0.txt
agrep -0 -c 'AAACGCCAATAGAGGCT' *.fastq > count/B16678_Rm0.txt
agrep -0 -c 'GTTGATTTTGGCGAGAT' *.fastq > count/B16679_Rm0.txt
agrep -0 -c 'ACGCGTGTACGGAGTGA' *.fastq > count/B16680_Rm0.txt
agrep -0 -c 'AGTCGTCGAAACGGACG' *.fastq > count/B16681_Rm0.txt
agrep -0 -c 'GGTGAGTCTACCAGCCA' *.fastq > count/B16682_Rm0.txt
agrep -0 -c 'GGCTTTCTGTCTGTCGA' *.fastq > count/B16684_Rm0.txt
agrep -0 -c 'TGGTTAAACGACCGTAA' *.fastq > count/B16686_Rm0.txt
agrep -0 -c 'ATGCCGCCCTATGGCTT' *.fastq > count/B16687_Rm0.txt
agrep -0 -c 'GTCTTCGTAATTCCCCG' *.fastq > count/B16688_Rm0.txt
agrep -0 -c 'TCCCCCTCAGGTGACTT' *.fastq > count/B16689_Rm0.txt
agrep -0 -c 'CCTATGCTCCACATGTG' *.fastq > count/B16690_Rm0.txt
agrep -0 -c 'CGTGTTGGAAGCTGTAA' *.fastq > count/B16691_Rm0.txt
agrep -0 -c 'TTATGTGGGACAAAGCC' *.fastq > count/B16692_Rm0.txt
agrep -0 -c 'CCGATAATAACCTCCCC' *.fastq > count/B16694_Rm0.txt
agrep -0 -c 'GTTCACTATTATGGGTC' *.fastq > count/B16696_Rm0.txt
agrep -0 -c 'CATGTGCTTCGAAACGT' *.fastq > count/B16697_Rm0.txt
agrep -0 -c 'CAAAGAGCACCCCAGCT' *.fastq > count/B16698_Rm0.txt
agrep -0 -c 'ATAGCTCAGTCAGCTCC' *.fastq > count/B16699_Rm0.txt
agrep -0 -c 'TGTCCGAGTGTCGTCTT' *.fastq > count/B16701_Rm0.txt
agrep -0 -c 'AGATGTTGGAGTCAGTA' *.fastq > count/B16702_Rm0.txt
agrep -0 -c 'GTCGAACCTAGCTTCCA' *.fastq > count/B16703_Rm0.txt
agrep -0 -c 'CCTTCAGATGTCGGTAT' *.fastq > count/B16704_Rm0.txt
agrep -0 -c 'TCACTGTACCTTCGGTG' *.fastq > count/B16707_Rm0.txt
agrep -0 -c 'CCGTCTGTAGTATGTTG' *.fastq > count/B16708_Rm0.txt
agrep -0 -c 'CCAACGAGTTGGTATCA' *.fastq > count/B16709_Rm0.txt
agrep -0 -c 'TTGTTCATCTCCCGGAG' *.fastq > count/B16711_Rm0.txt
agrep -0 -c 'GCCTTGTAAGTACCAGC' *.fastq > count/B16713_Rm0.txt
agrep -0 -c 'GTCTTTTACAGTGCATG' *.fastq > count/B16714_Rm0.txt
agrep -0 -c 'ATCCATTCTTCACACGT' *.fastq > count/B16715_Rm0.txt
agrep -0 -c 'TACCCTTCAGAGTGCGA' *.fastq > count/B16716_Rm0.txt
agrep -0 -c 'GTCTGATCAACTCTATC' *.fastq > count/B16717_Rm0.txt
agrep -0 -c 'ATACCTGCCGACATGAC' *.fastq > count/B16718_Rm0.txt
agrep -0 -c 'CTAGGGTGTACGTGTCA' *.fastq > count/B16719_Rm0.txt
agrep -0 -c 'GCCCCCATTAACTGCAG' *.fastq > count/B16720_Rm0.txt
agrep -0 -c 'CCTTTTTATAACCCCAC' *.fastq > count/B16721_Rm0.txt
agrep -0 -c 'GTGTATGGTCGTGTGCT' *.fastq > count/B16723_Rm0.txt
agrep -0 -c 'ATCTCACCCCGTATTCA' *.fastq > count/B16724_Rm0.txt
agrep -0 -c 'GCTCTCCGCCGTCTTTA' *.fastq > count/B16725_Rm0.txt
agrep -0 -c 'TCTCTGACAGAGCGTTG' *.fastq > count/B16726_Rm0.txt
agrep -0 -c 'GTGAATCGAAAGGTCTG' *.fastq > count/B16727_Rm0.txt
agrep -0 -c 'CTTTTACTGAGATGGGC' *.fastq > count/B16728_Rm0.txt
agrep -0 -c 'AGTGCAGCACCCTAAGC' *.fastq > count/B16729_Rm0.txt
agrep -0 -c 'ACCTTGCCGTAGAGGTA' *.fastq > count/B16730_Rm0.txt
agrep -0 -c 'CGCATATTGGTAACCTA' *.fastq > count/B16731_Rm0.txt
agrep -0 -c 'GTATAAGAACAGCTCCG' *.fastq > count/B16732_Rm0.txt
agrep -0 -c 'CAATTTCCGCTTGGCGT' *.fastq > count/B16733_Rm0.txt
agrep -0 -c 'TGTGTCGTGCACTAGTA' *.fastq > count/B16734_Rm0.txt
agrep -0 -c 'ACACTTAGGGACATCCG' *.fastq > count/B16735_Rm0.txt
agrep -0 -c 'GTCATTTGAGAGGTTCC' *.fastq > count/B16736_Rm0.txt
agrep -0 -c 'ATAGACGTACCATGCAG' *.fastq > count/B16737_Rm0.txt
agrep -0 -c 'ATCATACGAAGCGAGTA' *.fastq > count/B16738_Rm0.txt
agrep -0 -c 'TAAAGCGCCGGAAAGCC' *.fastq > count/B16739_Rm0.txt
agrep -0 -c 'CTCAGACCATACCACCT' *.fastq > count/B16742_Rm0.txt
agrep -0 -c 'CTTAATTCTGTTCTCGC' *.fastq > count/B16743_Rm0.txt
agrep -0 -c 'CAAATCACCGCCTGGAA' *.fastq > count/B16744_Rm0.txt
agrep -0 -c 'GGTCGAAGATGGACTGG' *.fastq > count/B16745_Rm0.txt
agrep -0 -c 'TGAATACTGGCGACTAC' *.fastq > count/B16747_Rm0.txt
agrep -0 -c 'TCGCATTGCTCTCGCGA' *.fastq > count/B16748_Rm0.txt
agrep -0 -c 'TGAAGATGAGTCACGGC' *.fastq > count/B16749_Rm0.txt
agrep -0 -c 'CTCCAATGGAACTGAGT' *.fastq > count/B16750_Rm0.txt
agrep -0 -c 'CGCTTGCAAAGAACCAT' *.fastq > count/B16752_Rm0.txt
agrep -0 -c 'TTCACATCTATCAGGCA' *.fastq > count/B16753_Rm0.txt
agrep -0 -c 'CCAGTAAACACCATTCG' *.fastq > count/B16754_Rm0.txt
agrep -0 -c 'CGAAGCTAATATCTCCT' *.fastq > count/B16755_Rm0.txt
agrep -0 -c 'CGAGTTACTGGGTAGTA' *.fastq > count/B16756_Rm0.txt
agrep -0 -c 'TTAGCCCCTGATCACTC' *.fastq > count/B16757_Rm0.txt
agrep -0 -c 'TGCTTAAGTAGGCTTTG' *.fastq > count/B16758_Rm0.txt
agrep -0 -c 'GCAGAGTCTATCCAAAC' *.fastq > count/B16759_Rm0.txt
agrep -0 -c 'CCTAAAACAGCCAACGA' *.fastq > count/B16760_Rm0.txt
agrep -0 -c 'GCAGTAAAGATCAACGG' *.fastq > count/B16761_Rm0.txt
agrep -0 -c 'ATTCGAGGGCGCTTGTT' *.fastq > count/B16762_Rm0.txt
agrep -0 -c 'ATGCTTAGCGCCTCGTC' *.fastq > count/B16763_Rm0.txt
agrep -0 -c 'AGGTTTCATATCTAGCG' *.fastq > count/B16764_Rm0.txt
agrep -0 -c 'TCGGGGTTTGTACACTA' *.fastq > count/B16765_Rm0.txt
agrep -0 -c 'TGAATATACGTGAGCGA' *.fastq > count/B16766_Rm0.txt
agrep -0 -c 'TATTGTCCATATTGGCC' *.fastq > count/B16767_Rm0.txt
agrep -0 -c 'GCCTTTTGAGAATGAGG' *.fastq > count/B16768_Rm0.txt
agrep -0 -c 'ACCGCAAATTCGGTGCC' *.fastq > count/B16769_Rm0.txt
agrep -0 -c 'CGACGCTTTGCTCTGCA' *.fastq > count/B16770_Rm0.txt
agrep -0 -c 'CCGAGACTCACGTGATG' *.fastq > count/B16771_Rm0.txt
agrep -0 -c 'CGTAGTTGTACGGTTAC' *.fastq > count/B16772_Rm0.txt
agrep -0 -c 'CGATATAAAAACCGCGT' *.fastq > count/B16774_Rm0.txt
agrep -0 -c 'ATTAGACCGTTTTTGCC' *.fastq > count/B16775_Rm0.txt
agrep -0 -c 'GGTTCCAAAAGGTCATT' *.fastq > count/B16777_Rm0.txt
agrep -0 -c 'TGGCCACCCCTAGGTAT' *.fastq > count/B16778_Rm0.txt
agrep -0 -c 'ATGACCACGGAACCCTG' *.fastq > count/B16780_Rm0.txt
agrep -0 -c 'ACCACTCCTCAAGCCTT' *.fastq > count/B16781_Rm0.txt
agrep -0 -c 'CCTAAACTCCCGGTGAC' *.fastq > count/B16782_Rm0.txt
agrep -0 -c 'AGCGGTTTACTGAAGGC' *.fastq > count/B16783_Rm0.txt
agrep -0 -c 'TAACTGCTCGTTGCACG' *.fastq > count/B16784_Rm0.txt
agrep -0 -c 'GCCTTTACCTCTGGCAG' *.fastq > count/B16785_Rm0.txt
agrep -0 -c 'GTTCTTAGAGGCTGTCA' *.fastq > count/B16787_Rm0.txt
agrep -0 -c 'CAAGCCTACACAAGGCG' *.fastq > count/B16788_Rm0.txt
agrep -0 -c 'AGTTGAGCCAGTCGATG' *.fastq > count/B16789_Rm0.txt
agrep -0 -c 'GTCACTCGAGTCTATGA' *.fastq > count/B16790_Rm0.txt
agrep -0 -c 'ATTAACCATGCGACGAT' *.fastq > count/B16791_Rm0.txt
agrep -0 -c 'TATGTTGTCGGTAGGTA' *.fastq > count/B16792_Rm0.txt
agrep -0 -c 'TTAGCTCTGGACATATC' *.fastq > count/B16793_Rm0.txt
agrep -0 -c 'GCTGACTGCAAAGCGAA' *.fastq > count/B16795_Rm0.txt
agrep -0 -c 'CTTCGCCGGTTTATTCG' *.fastq > count/B16797_Rm0.txt
agrep -0 -c 'CTCCAGGAAGGGCCTTA' *.fastq > count/B16798_Rm0.txt
agrep -0 -c 'TAGTCTAAGCCGTTATC' *.fastq > count/B16799_Rm0.txt
agrep -0 -c 'TCTAGCAAGGGTCGAAT' *.fastq > count/B16800_Rm0.txt
agrep -0 -c 'CTGCAGAACGCATGAAC' *.fastq > count/B16801_Rm0.txt
agrep -0 -c 'CCGGGAATCTCTCAAGA' *.fastq > count/B16802_Rm0.txt
agrep -0 -c 'GGGTTCCTTATTGGCTC' *.fastq > count/B16803_Rm0.txt
agrep -0 -c 'CGGAAACTGACGTACGG' *.fastq > count/B16804_Rm0.txt
agrep -0 -c 'CGTAATACTGTGTATCG' *.fastq > count/B16805_Rm0.txt
agrep -0 -c 'GGAGTAAGAAGTGCCAC' *.fastq > count/B16807_Rm0.txt
agrep -0 -c 'TACGAGTAGCAAACTGC' *.fastq > count/B16809_Rm0.txt
agrep -0 -c 'TAGAATGGAGCCGTATT' *.fastq > count/B16810_Rm0.txt
agrep -0 -c 'GAGGAGCGGAAAGATCT' *.fastq > count/B16813_Rm0.txt
agrep -0 -c 'CGCTAGTCTTACCTTCG' *.fastq > count/B16814_Rm0.txt
agrep -0 -c 'ACCCGATTACTACGGTA' *.fastq > count/B16815_Rm0.txt
agrep -0 -c 'ACTAACAAACACTGACC' *.fastq > count/B16816_Rm0.txt
agrep -0 -c 'GTGACCTGAAGGGTAAC' *.fastq > count/B16817_Rm0.txt
agrep -0 -c 'CGCTAACTTCCCATCTG' *.fastq > count/B16818_Rm0.txt
agrep -0 -c 'CAAGCAACAGAACGCTC' *.fastq > count/B16819_Rm0.txt
agrep -0 -c 'CATATACACATTCCCGG' *.fastq > count/B16820_Rm0.txt
agrep -0 -c 'GGTACTGATCGCTAAAT' *.fastq > count/B16821_Rm0.txt
agrep -0 -c 'TTTCCTCGTAATCCTAC' *.fastq > count/B16822_Rm0.txt
agrep -0 -c 'GCAGCATTTGCGGCTAA' *.fastq > count/B16823_Rm0.txt
agrep -0 -c 'GGTTCGCAACTGAGTAC' *.fastq > count/B16825_Rm0.txt
agrep -0 -c 'AGTAAAGCAGGAGTACC' *.fastq > count/B16826_Rm0.txt
agrep -0 -c 'AAGGTTGCGTAAAGCTA' *.fastq > count/B16827_Rm0.txt
agrep -0 -c 'ATGATTCCATGCTATGC' *.fastq > count/B16828_Rm0.txt
agrep -0 -c 'GATCGACTTCTTTTCCG' *.fastq > count/B16829_Rm0.txt
agrep -0 -c 'CGAATGGCTTCTCATAG' *.fastq > count/B16832_Rm0.txt
agrep -0 -c 'ATATCCCGATCAGCACC' *.fastq > count/B16833_Rm0.txt
agrep -0 -c 'TTGCCAATAAGGCCGGC' *.fastq > count/B16834_Rm0.txt
agrep -0 -c 'TACGACGTTGTGAATGT' *.fastq > count/B16835_Rm0.txt
agrep -0 -c 'GCGAGGTACCTGAGATT' *.fastq > count/B16836_Rm0.txt
agrep -0 -c 'GACACGACTTCATGGCG' *.fastq > count/B16837_Rm0.txt
agrep -0 -c 'ATCATTAGTCACGCAAG' *.fastq > count/B16838_Rm0.txt
agrep -0 -c 'ATCCTAATATTGTCCGC' *.fastq > count/B16840_Rm0.txt
agrep -0 -c 'CGCCTTAAGGGGAGCTT' *.fastq > count/B16842_Rm0.txt
agrep -0 -c 'GTCGTCAATGTTAAGTG' *.fastq > count/B16843_Rm0.txt
agrep -0 -c 'TCCTCACCCTAAATTCC' *.fastq > count/B16844_Rm0.txt
agrep -0 -c 'CAGGCATTATGAGAATG' *.fastq > count/B16845_Rm0.txt
agrep -0 -c 'GCCTAGGTGTTGATCGC' *.fastq > count/B16846_Rm0.txt
agrep -0 -c 'CATCAGACCAACATACG' *.fastq > count/B16847_Rm0.txt
agrep -0 -c 'CAGGCATCGGATATGGT' *.fastq > count/B16848_Rm0.txt
agrep -0 -c 'TCCAGAACCCTTTTACG' *.fastq > count/B16849_Rm0.txt
agrep -0 -c 'AGCCCGATAACAGCGGT' *.fastq > count/B16850_Rm0.txt
agrep -0 -c 'CCTTTAACTTCGGCAGG' *.fastq > count/B16851_Rm0.txt
agrep -0 -c 'CCCACAACGAAAATCTT' *.fastq > count/B16853_Rm0.txt
agrep -0 -c 'CAACGGCAGCTTAACTA' *.fastq > count/B16854_Rm0.txt
agrep -0 -c 'CCTTGTGGTACATCCCT' *.fastq > count/B16855_Rm0.txt
agrep -0 -c 'TCCCCCCCTGATCTTCA' *.fastq > count/B16856_Rm0.txt
agrep -0 -c 'CTTAATCCCGTTGGTTA' *.fastq > count/B16857_Rm0.txt
agrep -0 -c 'TGCGGTCCTAAAGGCCT' *.fastq > count/B16858_Rm0.txt
agrep -0 -c 'CATATATCAGGCGGATT' *.fastq > count/B16859_Rm0.txt
agrep -0 -c 'ACTCCCTATCTCGTTTA' *.fastq > count/B16862_Rm0.txt
agrep -0 -c 'TCGCAAAAGCGGGAATG' *.fastq > count/B16863_Rm0.txt
agrep -0 -c 'ACGTGGGGAGAACTTGC' *.fastq > count/B16864_Rm0.txt
agrep -0 -c 'GTCCCCATTGAACAGAT' *.fastq > count/B16865_Rm0.txt
agrep -0 -c 'AATCCACGATCCCGCGT' *.fastq > count/B16867_Rm0.txt
agrep -0 -c 'GATACACGAAAGCGGCA' *.fastq > count/B16869_Rm0.txt
agrep -0 -c 'AGTCGACTATCACTCTC' *.fastq > count/B16870_Rm0.txt
agrep -0 -c 'GCCGCTCACGTATCTAA' *.fastq > count/B16871_Rm0.txt
agrep -0 -c 'ATACTACCACGCATTAG' *.fastq > count/B16872_Rm0.txt
agrep -0 -c 'AGTATCCGTTTATCCTC' *.fastq > count/B16874_Rm0.txt
agrep -0 -c 'CCACCGGAGTCTAGGAA' *.fastq > count/B16875_Rm0.txt
agrep -0 -c 'GTAGCCCAACAATACGC' *.fastq > count/B16876_Rm0.txt
agrep -0 -c 'CTCCCGGAATTCACTAG' *.fastq > count/B16877_Rm0.txt
agrep -0 -c 'ATTGCCTTAGTGGAGGC' *.fastq > count/B16878_Rm0.txt
agrep -0 -c 'TACCCTAAACCCATCTC' *.fastq > count/B16879_Rm0.txt
agrep -0 -c 'TTGAGCGCACAAGCTTA' *.fastq > count/B16880_Rm0.txt
agrep -0 -c 'GTTTGTAGAGTAGTCGA' *.fastq > count/B16881_Rm0.txt
agrep -0 -c 'CTGAGTAGAGCCTTTAC' *.fastq > count/B16882_Rm0.txt
agrep -0 -c 'CCCACTCTTGGCTCCAA' *.fastq > count/B16883_Rm0.txt
agrep -0 -c 'TTTTTTGTGGTCCGATC' *.fastq > count/B16884_Rm0.txt
agrep -0 -c 'AATGCTAACAGACGAGT' *.fastq > count/B16885_Rm0.txt
agrep -0 -c 'CGTGTCTTGGCAGTTAA' *.fastq > count/B16886_Rm0.txt
agrep -0 -c 'AGACGTGAACCCTGTAC' *.fastq > count/B16888_Rm0.txt
agrep -0 -c 'ACGTGTTCAAGGTCCGC' *.fastq > count/B16889_Rm0.txt
agrep -0 -c 'CAATTACGGTACTTTGC' *.fastq > count/B16891_Rm0.txt
agrep -0 -c 'ATCTGCCGTTGCACGAA' *.fastq > count/B16894_Rm0.txt
agrep -0 -c 'CGGATTGCAACCGATGA' *.fastq > count/B16895_Rm0.txt
agrep -0 -c 'TGGTGACCCGTCATGCA' *.fastq > count/B16896_Rm0.txt
agrep -0 -c 'AATCGAAGGGGGATTCC' *.fastq > count/B16897_Rm0.txt
agrep -0 -c 'AACGACGGTGAGATTCA' *.fastq > count/B16898_Rm0.txt
agrep -0 -c 'TCCGTTCGTGGTTGACA' *.fastq > count/B16899_Rm0.txt
agrep -0 -c 'ACACGTAAGGAAAGGTT' *.fastq > count/B16900_Rm0.txt
agrep -0 -c 'AGCTCCTGTCCTTAGCA' *.fastq > count/B16902_Rm0.txt
agrep -0 -c 'TATTAGGCAGCACAGAA' *.fastq > count/B16905_Rm0.txt
agrep -0 -c 'AGCGGATCTTCCGTGTT' *.fastq > count/B16906_Rm0.txt
agrep -0 -c 'GCCGTCTAGATTGTAAT' *.fastq > count/B16907_Rm0.txt
agrep -0 -c 'ATATGCCACAATGGCTT' *.fastq > count/B16908_Rm0.txt
agrep -0 -c 'ACTTTCGGCGCTAATCC' *.fastq > count/B16909_Rm0.txt
agrep -0 -c 'GCGGAACATATATCTCA' *.fastq > count/B16912_Rm0.txt
agrep -0 -c 'ACGTTTTATTGTCGTGG' *.fastq > count/B16913_Rm0.txt
agrep -0 -c 'ATAATTGGGCCAGTTAG' *.fastq > count/B16914_Rm0.txt
agrep -0 -c 'AGCTGTATCTTCTCGAT' *.fastq > count/B16915_Rm0.txt
agrep -0 -c 'TCGGTAGTCTTCGCTCA' *.fastq > count/B16916_Rm0.txt
agrep -0 -c 'CGGATGGCTTCCTGCTA' *.fastq > count/B16917_Rm0.txt
agrep -0 -c 'CGAGGGCGTTATACTTA' *.fastq > count/B16919_Rm0.txt
agrep -0 -c 'ACAATCGCATGAACTAG' *.fastq > count/B16920_Rm0.txt
agrep -0 -c 'ACGCCTCGCCTAATTAG' *.fastq > count/B16921_Rm0.txt
agrep -0 -c 'GTAGGTAGAGGTAGCTT' *.fastq > count/B16923_Rm0.txt
agrep -0 -c 'GCGAGGGCAACTACATG' *.fastq > count/B16924_Rm0.txt
agrep -0 -c 'TTGCCTTCGGTTACTCG' *.fastq > count/B16925_Rm0.txt
agrep -0 -c 'AAACAAGTGGGCTAACA' *.fastq > count/B16926_Rm0.txt
agrep -0 -c 'CAGTCCGTTAAACGTAA' *.fastq > count/B16928_Rm0.txt
agrep -0 -c 'CTAGAATCTGGACGGTC' *.fastq > count/B16929_Rm0.txt
agrep -0 -c 'ACCTGCTTCCACCTATT' *.fastq > count/B16930_Rm0.txt
agrep -0 -c 'CAAAGCGTTGTTCGCGA' *.fastq > count/B16931_Rm0.txt
agrep -0 -c 'GCGCGAACTATGCAACT' *.fastq > count/B16932_Rm0.txt
agrep -0 -c 'TCGCTCGACACGTCTCT' *.fastq > count/B16933_Rm0.txt
agrep -0 -c 'TATTTAGGCGATTCCGG' *.fastq > count/B16934_Rm0.txt
agrep -0 -c 'GATCCCGAAACTTCCGT' *.fastq > count/B16936_Rm0.txt
agrep -0 -c 'ATTGTCACTCAGTGGTG' *.fastq > count/B16937_Rm0.txt
agrep -0 -c 'AAATCGCTATAGCAGGC' *.fastq > count/B16938_Rm0.txt
agrep -0 -c 'GACCAAGAGAACACGAC' *.fastq > count/B16939_Rm0.txt
agrep -0 -c 'GTTGAGAGACTTTCCGA' *.fastq > count/B16940_Rm0.txt
agrep -0 -c 'GGAAGTAGTACCCTACT' *.fastq > count/B16941_Rm0.txt
agrep -0 -c 'CTGTCGCGTCATTTACG' *.fastq > count/B16942_Rm0.txt
agrep -0 -c 'ATCTATCTGGCGCTCCA' *.fastq > count/B16944_Rm0.txt
agrep -0 -c 'GCTAGTTATTTCGTGCG' *.fastq > count/B16945_Rm0.txt
agrep -0 -c 'GTCTAGCAACACATAAG' *.fastq > count/B16946_Rm0.txt
agrep -0 -c 'ATGGACAATCACGCTAA' *.fastq > count/B16947_Rm0.txt
agrep -0 -c 'AGTGCCTTCCTTGGCGT' *.fastq > count/B16949_Rm0.txt
agrep -0 -c 'AAACAAAGGCTGAGTCC' *.fastq > count/B16950_Rm0.txt
agrep -0 -c 'AGTGGGAGGTTACACGG' *.fastq > count/B16951_Rm0.txt
agrep -0 -c 'ATCATGGGGGTAGGAAC' *.fastq > count/B16952_Rm0.txt
agrep -0 -c 'AACGCTAGGGCCTTCAA' *.fastq > count/B16953_Rm0.txt
agrep -0 -c 'ATGAATAAGAGGGGGTG' *.fastq > count/B16955_Rm0.txt
agrep -0 -c 'TTTGCTCTGAGTGCCGA' *.fastq > count/B16956_Rm0.txt
agrep -0 -c 'AGAAGTAACCGCGAGAA' *.fastq > count/B16958_Rm0.txt
agrep -0 -c 'ATGGCCGAGGGTGAATT' *.fastq > count/B16959_Rm0.txt
agrep -0 -c 'AATCGATCGAGTTCCGA' *.fastq > count/B16960_Rm0.txt
agrep -0 -c 'TGAAGGCGGTATCCTGA' *.fastq > count/B16961_Rm0.txt
agrep -0 -c 'GAAGAAGTACGCTGCGT' *.fastq > count/B16962_Rm0.txt
agrep -0 -c 'AGAAGAGCCCGCTTTGA' *.fastq > count/B16963_Rm0.txt
agrep -0 -c 'AAACACGCTGTGACTGA' *.fastq > count/B16964_Rm0.txt
agrep -0 -c 'TTGAAATCGGCAGTGCA' *.fastq > count/B16965_Rm0.txt
agrep -0 -c 'CGGGATTAGCCCTACAT' *.fastq > count/B16966_Rm0.txt
agrep -0 -c 'AAATTGAATGCACCGAG' *.fastq > count/B16967_Rm0.txt
agrep -0 -c 'AAACTCTTGTACGCGTG' *.fastq > count/B16968_Rm0.txt
agrep -0 -c 'GACCAGGGATCAATCAA' *.fastq > count/B16971_Rm0.txt
agrep -0 -c 'ATTGCGGGAGGTGGGAT' *.fastq > count/B16972_Rm0.txt
agrep -0 -c 'GGACAGTCTATGTCGGC' *.fastq > count/B16973_Rm0.txt
agrep -0 -c 'CATCTACCGTTGTAATC' *.fastq > count/B16974_Rm0.txt
agrep -0 -c 'GACAACGTAACCGCTCC' *.fastq > count/B16975_Rm0.txt
agrep -0 -c 'CATAAAACGCTCTCCGG' *.fastq > count/B16976_Rm0.txt
agrep -0 -c 'GCTATACCGTACAGCCC' *.fastq > count/B16978_Rm0.txt
agrep -0 -c 'GACTAAATGGTATAGGC' *.fastq > count/B16979_Rm0.txt
agrep -0 -c 'TGGAAGGCGAGGTTTAT' *.fastq > count/B16980_Rm0.txt
agrep -0 -c 'TTACGCGTGAGAGACTA' *.fastq > count/B16982_Rm0.txt
agrep -0 -c 'ACCACATGCGTGTCGAA' *.fastq > count/B16983_Rm0.txt
agrep -0 -c 'TCACAAACGGCGTGCAG' *.fastq > count/B16985_Rm0.txt
agrep -0 -c 'GGACGTTTTGCAAAGGC' *.fastq > count/B16986_Rm0.txt
agrep -0 -c 'GAGTACGAAGTGCGAGC' *.fastq > count/B16987_Rm0.txt
agrep -0 -c 'GAGATACCCAAACTCCA' *.fastq > count/B16988_Rm0.txt
agrep -0 -c 'ATCCACTAGTCGCCCTT' *.fastq > count/B16989_Rm0.txt
agrep -0 -c 'AGTGTTGCCGTGGATCA' *.fastq > count/B16990_Rm0.txt
agrep -0 -c 'GGTGAACACGGCTTTTA' *.fastq > count/B16991_Rm0.txt
agrep -0 -c 'CGTCATCAGGTAACCGG' *.fastq > count/B16993_Rm0.txt
agrep -0 -c 'ACTCACAGAATGTGACG' *.fastq > count/B16994_Rm0.txt
agrep -0 -c 'CGTATGCCGCTAGTAGA' *.fastq > count/B16995_Rm0.txt
agrep -0 -c 'ATTGATCCTAACCTGTC' *.fastq > count/B16996_Rm0.txt
agrep -0 -c 'GGAAACACTGCGAAGCA' *.fastq > count/B16998_Rm0.txt
agrep -0 -c 'TCCTTAATGTTCCCCGA' *.fastq > count/B16999_Rm0.txt
agrep -0 -c 'CTATCTGCCAGTAAAGT' *.fastq > count/B17000_Rm0.txt
agrep -0 -c 'CAAATTAGCAGCTCTGC' *.fastq > count/B17001_Rm0.txt
agrep -0 -c 'TTACAACCCGAGTCGTT' *.fastq > count/B17002_Rm0.txt
agrep -0 -c 'AGTGCCGTGTACAGAGG' *.fastq > count/B17003_Rm0.txt
agrep -0 -c 'CTAGCTGCTGCGATATG' *.fastq > count/B17005_Rm0.txt
agrep -0 -c 'CAAGAACCCTTAGTTAG' *.fastq > count/B17006_Rm0.txt
agrep -0 -c 'CGGACACGGTAATCGAC' *.fastq > count/B17007_Rm0.txt
agrep -0 -c 'TCTAGCAACCAGATCGG' *.fastq > count/B17008_Rm0.txt
agrep -0 -c 'GGCACCGTGAATAGTCT' *.fastq > count/B17009_Rm0.txt
agrep -0 -c 'CGCATATTATGTCGCCC' *.fastq > count/B17010_Rm0.txt
agrep -0 -c 'GCGTTGGTAGCTTCGAT' *.fastq > count/B17011_Rm0.txt
agrep -0 -c 'TCCATAGACACTAATGC' *.fastq > count/B17013_Rm0.txt
agrep -0 -c 'CTTGGTGTGTCTCCTAA' *.fastq > count/B17014_Rm0.txt
agrep -0 -c 'ACCTTATTTTCGGCCTT' *.fastq > count/B17016_Rm0.txt
agrep -0 -c 'TTGCTTTCCCTAGCGGC' *.fastq > count/B17017_Rm0.txt
agrep -0 -c 'AGGTTAGCAAGACCGTT' *.fastq > count/B17019_Rm0.txt
agrep -0 -c 'TACAACGGTACCTAGAA' *.fastq > count/B17020_Rm0.txt
agrep -0 -c 'ACTGTGTGCGGGTAACT' *.fastq > count/B17021_Rm0.txt
agrep -0 -c 'ACGTGGACCAAATAGCT' *.fastq > count/B17022_Rm0.txt
agrep -0 -c 'ATCTAGACATCCCGCGA' *.fastq > count/B17024_Rm0.txt
agrep -0 -c 'CGCCCAAGTAATGTTAC' *.fastq > count/B17025_Rm0.txt
agrep -0 -c 'AGCCACTTGGACCTAGA' *.fastq > count/B17027_Rm0.txt
agrep -0 -c 'CAGGAAAAACTTTCGCC' *.fastq > count/B17028_Rm0.txt
agrep -0 -c 'GAAACGGTACTCCTCCA' *.fastq > count/B17029_Rm0.txt
agrep -0 -c 'TAGGTACCTTGGTATAG' *.fastq > count/B17030_Rm0.txt
agrep -0 -c 'ATGATCAGGTCCATACC' *.fastq > count/B17031_Rm0.txt
agrep -0 -c 'CGATCAGATGCGCTCCA' *.fastq > count/B17032_Rm0.txt
agrep -0 -c 'CCGAGTAGACCATACAA' *.fastq > count/B17033_Rm0.txt
agrep -0 -c 'CTTAGAGTGACGACCGC' *.fastq > count/B17034_Rm0.txt
agrep -0 -c 'TCTAATGTGCAGCGAAC' *.fastq > count/B17035_Rm0.txt
agrep -0 -c 'GAGACGGGTTTCATAGG' *.fastq > count/B17036_Rm0.txt
agrep -0 -c 'CTACTCAACATCGTGAG' *.fastq > count/B17037_Rm0.txt
agrep -0 -c 'GTCCTGATTAAGTGTGC' *.fastq > count/B17038_Rm0.txt
agrep -0 -c 'CAGCACACGGAAACGAC' *.fastq > count/B17039_Rm0.txt
agrep -0 -c 'CCGTATTACCTCGACTT' *.fastq > count/B17040_Rm0.txt
agrep -0 -c 'CAGTCTTGCGGCTCAAC' *.fastq > count/B17041_Rm0.txt
agrep -0 -c 'TGCTCCGCGATCAAATT' *.fastq > count/B17042_Rm0.txt
agrep -0 -c 'ACAGTGCAGTCAGCTGA' *.fastq > count/B17044_Rm0.txt
agrep -0 -c 'TGGATTAAAGGGCCTAC' *.fastq > count/B17047_Rm0.txt
agrep -0 -c 'GACTATAGACTCGGCCA' *.fastq > count/B17048_Rm0.txt
agrep -0 -c 'ATCGATATCACACGTCC' *.fastq > count/B17049_Rm0.txt
agrep -0 -c 'GCACAACATTCCTCTCC' *.fastq > count/B17050_Rm0.txt
agrep -0 -c 'CTAAAGGCTCGAATCTG' *.fastq > count/B17052_Rm0.txt
agrep -0 -c 'TATCGCGCTTAACTTCT' *.fastq > count/B17053_Rm0.txt
agrep -0 -c 'CGAGAGCGTTCAACGCA' *.fastq > count/B17054_Rm0.txt
agrep -0 -c 'CCCCGTAAATTAGTGAT' *.fastq > count/B17055_Rm0.txt
agrep -0 -c 'TGTCCGATGCTCAGGGT' *.fastq > count/B17056_Rm0.txt
agrep -0 -c 'CCAGTATCCCACGATGA' *.fastq > count/B17057_Rm0.txt
agrep -0 -c 'TTCGCGTACACAGGTAG' *.fastq > count/B17058_Rm0.txt
agrep -0 -c 'TCCAGAGGACTTCCGAG' *.fastq > count/B17060_Rm0.txt
agrep -0 -c 'AGCGAAGAAGAATCTAG' *.fastq > count/B17061_Rm0.txt
agrep -0 -c 'AAGTGTCCCCTGCTCGA' *.fastq > count/B17063_Rm0.txt
agrep -0 -c 'CGCAACGTCGTATGAGA' *.fastq > count/B17065_Rm0.txt
agrep -0 -c 'TTCCTCGTAGCCTACAT' *.fastq > count/B17067_Rm0.txt
agrep -0 -c 'CCCCATGCATCGTAAGT' *.fastq > count/B17068_Rm0.txt
agrep -0 -c 'GGCCTCTCGTTTCTCAT' *.fastq > count/B17069_Rm0.txt
agrep -0 -c 'AATACATTTATCCGCGC' *.fastq > count/B17070_Rm0.txt
agrep -0 -c 'AGGCCTAATCTATCCAA' *.fastq > count/B17071_Rm0.txt
agrep -0 -c 'GAAATAGCCACCCTAAG' *.fastq > count/B17073_Rm0.txt
agrep -0 -c 'TCTTAAACTGCGCGTGT' *.fastq > count/B17074_Rm0.txt
agrep -0 -c 'CCTAAAGGAATCTGTTG' *.fastq > count/B17075_Rm0.txt
agrep -0 -c 'GACTTCGATGTCCCTCC' *.fastq > count/B17076_Rm0.txt
agrep -0 -c 'ACCAGTGGCTCTTGTGA' *.fastq > count/B17077_Rm0.txt
agrep -0 -c 'ACGGATGGGATCACAGA' *.fastq > count/B17079_Rm0.txt
agrep -0 -c 'GTGCGAAGTAGGAGATG' *.fastq > count/B17080_Rm0.txt
agrep -0 -c 'ACAGACCTATTTGAACG' *.fastq > count/B17081_Rm0.txt
agrep -0 -c 'CACGACCTCTCGTTTGA' *.fastq > count/B17084_Rm0.txt
agrep -0 -c 'ACGTTGCCTTGTTTCCG' *.fastq > count/B17085_Rm0.txt
agrep -0 -c 'CTCTCAGACTGAAACGC' *.fastq > count/B17086_Rm0.txt
agrep -0 -c 'CCAGCTGATTTTTCCAC' *.fastq > count/B17087_Rm0.txt
agrep -0 -c 'CGCGCCACTTGATCATA' *.fastq > count/B17088_Rm0.txt
agrep -0 -c 'GTCGTGTTAGCGACGAA' *.fastq > count/B17089_Rm0.txt
agrep -0 -c 'ACAAATCAGGGCGCGAG' *.fastq > count/B17090_Rm0.txt
agrep -0 -c 'ATCGTAATCTGCGCCGA' *.fastq > count/B17091_Rm0.txt
agrep -0 -c 'ACATCTGGCACAAACGG' *.fastq > count/B17092_Rm0.txt
agrep -0 -c 'TTTACCAAGGCCTAAGT' *.fastq > count/B17093_Rm0.txt
agrep -0 -c 'CAGAACGTTAGATCCTG' *.fastq > count/B17094_Rm0.txt
agrep -0 -c 'TGCATTCCGTCTGTGGT' *.fastq > count/B17096_Rm0.txt
agrep -0 -c 'CGGATACAGTCCATCTA' *.fastq > count/B17097_Rm0.txt
agrep -0 -c 'ACGTACAGAGATGAAAC' *.fastq > count/B17098_Rm0.txt
agrep -0 -c 'TTGCCAAGGGCACGTTA' *.fastq > count/B17099_Rm0.txt
agrep -0 -c 'CAGCGTTGGGTGCTACA' *.fastq > count/B17101_Rm0.txt
agrep -0 -c 'CGAATAGGAAGCCGTGC' *.fastq > count/B17102_Rm0.txt
agrep -0 -c 'TTCGTGGGTTAGCATGT' *.fastq > count/B17103_Rm0.txt
agrep -0 -c 'TTAAGCATTCTACGGAC' *.fastq > count/B17104_Rm0.txt
agrep -0 -c 'CGGTACTTGGTGTATGC' *.fastq > count/B17105_Rm0.txt
agrep -0 -c 'TTATAGCAGGATGTCCA' *.fastq > count/B17106_Rm0.txt
agrep -0 -c 'AGCACCATGTTAGTAAC' *.fastq > count/B17108_Rm0.txt
agrep -0 -c 'GTGGTCATAACGAGGTA' *.fastq > count/B17109_Rm0.txt
agrep -0 -c 'GTCTCCGAATTATCTCA' *.fastq > count/B17110_Rm0.txt
agrep -0 -c 'ACGAGAAACTTAACTGG' *.fastq > count/B17111_Rm0.txt
agrep -0 -c 'TGGTCCCGTATTGGCAC' *.fastq > count/B17112_Rm0.txt
agrep -0 -c 'CGTCGCGGAAACTCTCA' *.fastq > count/B17113_Rm0.txt
agrep -0 -c 'CGGGTGTGAGTCCAGTA' *.fastq > count/B17114_Rm0.txt
agrep -0 -c 'CTGTCGTAAGCCGGTGT' *.fastq > count/B17115_Rm0.txt
agrep -0 -c 'ACACTGCGTACCATCCT' *.fastq > count/B17116_Rm0.txt
agrep -0 -c 'TCTCGGGTCTTTACTCT' *.fastq > count/B17117_Rm0.txt
agrep -0 -c 'CGCAACTTCGAGGTCTT' *.fastq > count/B17121_Rm0.txt
agrep -0 -c 'GGCGGGGAGAAATCAAG' *.fastq > count/B17122_Rm0.txt
agrep -0 -c 'ATACCAGCTAGCAGCGA' *.fastq > count/B17123_Rm0.txt
agrep -0 -c 'GAAAAGCAACTACGCAA' *.fastq > count/B17125_Rm0.txt
agrep -0 -c 'ACCCGTAAACATGTCCG' *.fastq > count/B17127_Rm0.txt
agrep -0 -c 'TGTTTCTTCGCGTCGTC' *.fastq > count/B17129_Rm0.txt
agrep -0 -c 'CCCAGCGGACAGTATCA' *.fastq > count/B17130_Rm0.txt
agrep -0 -c 'TAAGCGCCGGACAGCTT' *.fastq > count/B17131_Rm0.txt
agrep -0 -c 'TCCGACATGAAGGTTAT' *.fastq > count/B17132_Rm0.txt
agrep -0 -c 'CACGCGTGAGATTAGGT' *.fastq > count/B17133_Rm0.txt
agrep -0 -c 'ATTCCCCCGCGATCGAT' *.fastq > count/B17134_Rm0.txt
agrep -0 -c 'CTTGCACGTATATTGCC' *.fastq > count/B17135_Rm0.txt
agrep -0 -c 'TACACCCGTACTTCCGG' *.fastq > count/B17136_Rm0.txt
agrep -0 -c 'TAAACTCGACGAGCTCC' *.fastq > count/B17137_Rm0.txt
agrep -0 -c 'CCAGCAATAGGAATTGG' *.fastq > count/B17139_Rm0.txt
agrep -0 -c 'GTAGCTCGTGACATACG' *.fastq > count/B17140_Rm0.txt
agrep -0 -c 'AGACCTTCCAGTTAAAC' *.fastq > count/B17141_Rm0.txt
agrep -0 -c 'AGGAAGTACCATCCAGC' *.fastq > count/B17142_Rm0.txt
agrep -0 -c 'TAAGTATGGGGGGTTGC' *.fastq > count/B17143_Rm0.txt
agrep -0 -c 'ACGTTTGACCTCCCCTC' *.fastq > count/B17146_Rm0.txt
agrep -0 -c 'GAGTCGATCCCTTATAA' *.fastq > count/B17147_Rm0.txt
agrep -0 -c 'GGCAATATCTCGACCGA' *.fastq > count/B17148_Rm0.txt
agrep -0 -c 'ATCAGTAGCGTAGTGTA' *.fastq > count/B17150_Rm0.txt
agrep -0 -c 'GTAATGGCAATTGCCTG' *.fastq > count/B17151_Rm0.txt
agrep -0 -c 'TCCATTAAGCCTCCACT' *.fastq > count/B17152_Rm0.txt
agrep -0 -c 'ATCGCTGCCCACGAACT' *.fastq > count/B17153_Rm0.txt
agrep -0 -c 'GGCACAATGTTATCTGT' *.fastq > count/B17156_Rm0.txt
agrep -0 -c 'CTTACCTGGGGGATGCA' *.fastq > count/B17157_Rm0.txt
agrep -0 -c 'CAATTCCGGCATTAAGC' *.fastq > count/B17158_Rm0.txt
agrep -0 -c 'AGTCTGCACCAACAAGC' *.fastq > count/B17159_Rm0.txt
agrep -0 -c 'GTTAACGGCTTCCCATT' *.fastq > count/B17160_Rm0.txt
agrep -0 -c 'TACATGTATGTCTCTCG' *.fastq > count/B17161_Rm0.txt
agrep -0 -c 'CCTAAGCGATCCCGAGT' *.fastq > count/B17162_Rm0.txt
agrep -0 -c 'CACGGGGGTGATCGATT' *.fastq > count/B17163_Rm0.txt
agrep -0 -c 'GCGAGTGTATGTGGTCT' *.fastq > count/B17164_Rm0.txt
agrep -0 -c 'GTTCAGTCAGTGTTTAG' *.fastq > count/B17166_Rm0.txt
agrep -0 -c 'CTCAGAATGGTAAGGCC' *.fastq > count/B17168_Rm0.txt
agrep -0 -c 'TGCGTCTTATCCTTTGG' *.fastq > count/B17170_Rm0.txt
agrep -0 -c 'TACAAGGAGCGACACTC' *.fastq > count/B17171_Rm0.txt
agrep -0 -c 'ACTCGCTTCAGCCTATA' *.fastq > count/B17172_Rm0.txt
agrep -0 -c 'ACGTCAAGGTCGTTCTA' *.fastq > count/B17173_Rm0.txt
agrep -0 -c 'CGTTAGCGAGTTTTCCT' *.fastq > count/B17174_Rm0.txt
agrep -0 -c 'CGGGGTATCGATTAACT' *.fastq > count/B17175_Rm0.txt
agrep -0 -c 'ATTGTTACAGCTCCGCT' *.fastq > count/B17177_Rm0.txt
agrep -0 -c 'CGGTTAGCCGCTTGACA' *.fastq > count/B17178_Rm0.txt
agrep -0 -c 'CGGTCTCGAATCCGCTT' *.fastq > count/B17179_Rm0.txt
agrep -0 -c 'GTTAGGGCGTGTTAACC' *.fastq > count/B17180_Rm0.txt
agrep -0 -c 'AGCGGTTCTACACTATG' *.fastq > count/B17181_Rm0.txt
agrep -0 -c 'CGAAACTTTGAGTAGAC' *.fastq > count/B17182_Rm0.txt
agrep -0 -c 'ACGGATACGTCGAAATC' *.fastq > count/B17183_Rm0.txt
agrep -0 -c 'GCCCATTTACCATTGCC' *.fastq > count/B17184_Rm0.txt
agrep -0 -c 'TAGCCTCAGGATGACCG' *.fastq > count/B17185_Rm0.txt
agrep -0 -c 'AGGGCATTGCGGATAGG' *.fastq > count/B17186_Rm0.txt
agrep -0 -c 'GACGTAGGTAGGGTAGG' *.fastq > count/B17187_Rm0.txt
agrep -0 -c 'ATGGGACGGTCCAGCTA' *.fastq > count/B17188_Rm0.txt
agrep -0 -c 'TAACCTGTTCTGCTTCC' *.fastq > count/B17189_Rm0.txt
agrep -0 -c 'ATTTGTCGAACTGGCCT' *.fastq > count/B17192_Rm0.txt
agrep -0 -c 'GTCGAAGGGATATAACG' *.fastq > count/B17193_Rm0.txt
agrep -0 -c 'CCCTCCCGAACTAAGCT' *.fastq > count/B17194_Rm0.txt
agrep -0 -c 'TAATAGGCCTAGCTCGC' *.fastq > count/B17195_Rm0.txt
agrep -0 -c 'GGAGAACTTCCACTGGT' *.fastq > count/B17196_Rm0.txt
agrep -0 -c 'ATATAGGGGTTGCTGTT' *.fastq > count/B17197_Rm0.txt
agrep -0 -c 'GTAAGGCGGAAAGCGAG' *.fastq > count/B17199_Rm0.txt
agrep -0 -c 'ACGGAACATTTCCCCGT' *.fastq > count/B17200_Rm0.txt
agrep -0 -c 'TCATGTACTGTTCCTAG' *.fastq > count/B17201_Rm0.txt
agrep -0 -c 'GGGACTATGTGACACCC' *.fastq > count/B17202_Rm0.txt
agrep -0 -c 'ATTGGCCCCATCTGTAA' *.fastq > count/B17203_Rm0.txt
agrep -0 -c 'ATTCGGCCAGTTTGGGT' *.fastq > count/B17205_Rm0.txt
agrep -0 -c 'TGCTCCCCTACAGCATT' *.fastq > count/B17206_Rm0.txt
agrep -0 -c 'TATTTCCATCGCTGGGC' *.fastq > count/B17207_Rm0.txt
agrep -0 -c 'GAGGGCCAATGTATCTA' *.fastq > count/B17208_Rm0.txt
agrep -0 -c 'GCCGTTATATCCTATAC' *.fastq > count/B17209_Rm0.txt
agrep -0 -c 'TGAAGATCGTACGAGGC' *.fastq > count/B17211_Rm0.txt
agrep -0 -c 'CAAGCCTGTGAACGTCA' *.fastq > count/B17212_Rm0.txt
agrep -0 -c 'TCGCTGTCACGACATAA' *.fastq > count/B17213_Rm0.txt
agrep -0 -c 'CAGACGCTATGTTTCTC' *.fastq > count/B17214_Rm0.txt
agrep -0 -c 'GAGTAGTGATGAAGACC' *.fastq > count/B17215_Rm0.txt
agrep -0 -c 'AGAACTCGCAGCCTTGG' *.fastq > count/B17216_Rm0.txt
agrep -0 -c 'ACACATGGCTAAGTTCG' *.fastq > count/B17217_Rm0.txt
agrep -0 -c 'TTGTAGAGCTATTGCGC' *.fastq > count/B17218_Rm0.txt
agrep -0 -c 'TGGAAGAACCAATTCCG' *.fastq > count/B17220_Rm0.txt
agrep -0 -c 'GCTTTTTCGACCCGCTC' *.fastq > count/B17221_Rm0.txt
agrep -0 -c 'ATACGAAGCTGATGCAC' *.fastq > count/B17222_Rm0.txt
agrep -0 -c 'TAGCTTCTTCACCGAGA' *.fastq > count/B17223_Rm0.txt
agrep -0 -c 'CGCCCGAACCAATTGAG' *.fastq > count/B17224_Rm0.txt
agrep -0 -c 'GATCTTATGGCTCAGAA' *.fastq > count/B17226_Rm0.txt
agrep -0 -c 'AGACTGACTTACGAGTG' *.fastq > count/B17227_Rm0.txt
agrep -0 -c 'GCCATTAACCGAGTATC' *.fastq > count/B17228_Rm0.txt
agrep -0 -c 'AGAAGGCCTCTACTTCA' *.fastq > count/B17229_Rm0.txt
agrep -0 -c 'ACCGGTATTGTTCAGAA' *.fastq > count/B17230_Rm0.txt
agrep -0 -c 'TTCAGGACCTTGCCTGA' *.fastq > count/B17231_Rm0.txt
agrep -0 -c 'AGGGTGTCTCACGTCGT' *.fastq > count/B17232_Rm0.txt
agrep -0 -c 'GGTACTGTGATCGTACG' *.fastq > count/B17235_Rm0.txt
agrep -0 -c 'TCCTAGAGGTGTGCCGA' *.fastq > count/B17236_Rm0.txt
agrep -0 -c 'TAGCCTTTAGTGGAGAG' *.fastq > count/B17237_Rm0.txt
agrep -0 -c 'CTCCATACTAATAGACG' *.fastq > count/B17238_Rm0.txt
agrep -0 -c 'GCTGAAAACGTGAATCC' *.fastq > count/B17239_Rm0.txt
agrep -0 -c 'AGCTAGGAATACGACAG' *.fastq > count/B17240_Rm0.txt
agrep -0 -c 'CAAGGTGAAACGGCAAT' *.fastq > count/B17241_Rm0.txt
agrep -0 -c 'GCTCTGTTTATGGGGAC' *.fastq > count/B17242_Rm0.txt
agrep -0 -c 'CAGATGCTATATCGACT' *.fastq > count/B17245_Rm0.txt
agrep -0 -c 'TAGCCCGTCAATCATCT' *.fastq > count/B17246_Rm0.txt
agrep -0 -c 'AAGCAAGGCTGTAGCGA' *.fastq > count/B17247_Rm0.txt
agrep -0 -c 'TGGTTGACTATCCATCG' *.fastq > count/B17248_Rm0.txt
agrep -0 -c 'CAGAACAACCGTACCAC' *.fastq > count/B17250_Rm0.txt
agrep -0 -c 'AGCAGAAACGTCAAGTC' *.fastq > count/B17251_Rm0.txt
agrep -0 -c 'CCGCTCGGACTTAGACT' *.fastq > count/B17252_Rm0.txt
agrep -0 -c 'CACCGTTATAAGGGAGG' *.fastq > count/B17253_Rm0.txt
agrep -0 -c 'GTTTGACAGGTTCGAAT' *.fastq > count/B17254_Rm0.txt
agrep -0 -c 'ACGTTGCCATCACAATA' *.fastq > count/B17255_Rm0.txt
agrep -0 -c 'GACTGATCTATGAGCGT' *.fastq > count/B17256_Rm0.txt
agrep -0 -c 'CAAAAGAGTTGAAGCCC' *.fastq > count/B17257_Rm0.txt
agrep -0 -c 'GCCTTTCTAGGCCTAGC' *.fastq > count/B17258_Rm0.txt
agrep -0 -c 'TGTGGTCACGCTCCGAA' *.fastq > count/B17259_Rm0.txt
agrep -0 -c 'CGCTATAGGGGGACATA' *.fastq > count/B17260_Rm0.txt
agrep -0 -c 'GGAGTATTCCTCAAGCT' *.fastq > count/B17261_Rm0.txt
agrep -0 -c 'TCTACGGCTGAGTGTCA' *.fastq > count/B17262_Rm0.txt
agrep -0 -c 'GAGCTTCGTGGACTCTA' *.fastq > count/B17263_Rm0.txt
agrep -0 -c 'ATCTCGGCCCCGTTAAG' *.fastq > count/B17264_Rm0.txt
agrep -0 -c 'CCTACCGCATCATCGCT' *.fastq > count/B17265_Rm0.txt
agrep -0 -c 'AATAAAGGATGGGCGCC' *.fastq > count/B17266_Rm0.txt
agrep -0 -c 'TGGCGAGTACTGTCCAC' *.fastq > count/B17267_Rm0.txt
agrep -0 -c 'ACTTGGAGACCGGTCAT' *.fastq > count/B17268_Rm0.txt
agrep -0 -c 'GAATTAGTTGGCCCAGC' *.fastq > count/B17270_Rm0.txt
agrep -0 -c 'AAGCAGTTCGGTCTGTG' *.fastq > count/B17274_Rm0.txt
agrep -0 -c 'GTTCGACCTCTTGAAGT' *.fastq > count/B17275_Rm0.txt
agrep -0 -c 'CAAAGGCTATGACACGT' *.fastq > count/B17276_Rm0.txt
agrep -0 -c 'CATCACAGTCCGTAGTA' *.fastq > count/B17277_Rm0.txt
agrep -0 -c 'CCCATGGTTAGCATCCG' *.fastq > count/B17278_Rm0.txt
agrep -0 -c 'CTTTACCGAGAGCTTAG' *.fastq > count/B17279_Rm0.txt
agrep -0 -c 'CTGGAACGGATTAGCGT' *.fastq > count/B17280_Rm0.txt
agrep -0 -c 'GGCAATCACGAGTCAGG' *.fastq > count/B17281_Rm0.txt
agrep -0 -c 'GACCACGCATTGTCAGG' *.fastq > count/B17282_Rm0.txt
agrep -0 -c 'CATTTTGAAGTTGAGGC' *.fastq > count/B17283_Rm0.txt
agrep -0 -c 'TGTGTGCCCGGATGATC' *.fastq > count/B17284_Rm0.txt
agrep -0 -c 'GGGATGACATGGAAGAT' *.fastq > count/B17285_Rm0.txt
agrep -0 -c 'GGGGTGCAACATATTAG' *.fastq > count/B17286_Rm0.txt
agrep -0 -c 'GGCTAGTAATCAACGAG' *.fastq > count/B17287_Rm0.txt
agrep -0 -c 'TAATACGGTAGTGCACA' *.fastq > count/B17288_Rm0.txt
agrep -0 -c 'CAAGTTCTCGCAACTCG' *.fastq > count/B17289_Rm0.txt
agrep -0 -c 'AGGAATAGCACCCGCAC' *.fastq > count/B17290_Rm0.txt
agrep -0 -c 'TTCCGATCACTGGTTTA' *.fastq > count/B17291_Rm0.txt
agrep -0 -c 'TAGAGTGGATGTGTTGT' *.fastq > count/B17293_Rm0.txt
agrep -0 -c 'ACACCAGACGTTGAAGC' *.fastq > count/B17294_Rm0.txt
agrep -0 -c 'ACAGCGAATTCAGTCTC' *.fastq > count/B17295_Rm0.txt
agrep -0 -c 'CTGGAAAATCTGACATC' *.fastq > count/B17296_Rm0.txt
agrep -0 -c 'ATACGCGCAATCCACCG' *.fastq > count/B17298_Rm0.txt
agrep -0 -c 'TGTCAGATCAGATGGCC' *.fastq > count/B17299_Rm0.txt
agrep -0 -c 'TTGGGGTATTGGTCGAT' *.fastq > count/B17300_Rm0.txt
agrep -0 -c 'GAGATGCCGCATTAACG' *.fastq > count/B17301_Rm0.txt
agrep -0 -c 'GGCAAACCTCGGATTCA' *.fastq > count/B17302_Rm0.txt
agrep -0 -c 'TAAAAGGACTAGTCAGG' *.fastq > count/B17303_Rm0.txt
agrep -0 -c 'AAGCGGTGTATGTGGCC' *.fastq > count/B17304_Rm0.txt
agrep -0 -c 'GAATGATCAGCTCTTAC' *.fastq > count/B17305_Rm0.txt
agrep -0 -c 'GGCTGCGTTGTTTCTCC' *.fastq > count/B17306_Rm0.txt
agrep -0 -c 'CCGTGATTATAGGTACT' *.fastq > count/B17307_Rm0.txt
agrep -0 -c 'TGAGCGTCCGAATATGA' *.fastq > count/B17308_Rm0.txt
agrep -0 -c 'GTCATGGGACACCAGTA' *.fastq > count/B17309_Rm0.txt
agrep -0 -c 'CCTTCACCAATAGCCCT' *.fastq > count/B17310_Rm0.txt
agrep -0 -c 'CAAAGGACAGTGGATGG' *.fastq > count/B17311_Rm0.txt
agrep -0 -c 'CCGGCATTGGTAATGCG' *.fastq > count/B17312_Rm0.txt
agrep -0 -c 'TAAACAGCCGTCACACA' *.fastq > count/B17313_Rm0.txt
agrep -0 -c 'GTCCTTAAGGACACCTA' *.fastq > count/B17315_Rm0.txt
agrep -0 -c 'AATCCCGCTTCAGCTTG' *.fastq > count/B17318_Rm0.txt
agrep -0 -c 'GGTTTGCGGATGTAGAT' *.fastq > count/B17320_Rm0.txt
agrep -0 -c 'ATCTGAACCTGGTTCAC' *.fastq > count/B17321_Rm0.txt
agrep -0 -c 'TAACGCACGTGTACATT' *.fastq > count/B17322_Rm0.txt
agrep -0 -c 'GCAGTACTCACGCTCGT' *.fastq > count/B17323_Rm0.txt
agrep -0 -c 'ATGGCAACCACCCGCTA' *.fastq > count/B17324_Rm0.txt
agrep -0 -c 'CTTCTAGTCCTCTCGCT' *.fastq > count/B17326_Rm0.txt
agrep -0 -c 'TGCGAGAAACCTTTCAT' *.fastq > count/B17327_Rm0.txt
agrep -0 -c 'GCCACAGTGCGTTGGAA' *.fastq > count/B17328_Rm0.txt
agrep -0 -c 'CACGTCACCCGTAATCG' *.fastq > count/B17331_Rm0.txt
agrep -0 -c 'ATCACAACGCACACCTC' *.fastq > count/B17332_Rm0.txt
agrep -0 -c 'AAGCGACGTGAACTCGA' *.fastq > count/B17333_Rm0.txt
agrep -0 -c 'CTAGAATGATGGTAGGC' *.fastq > count/B17335_Rm0.txt
agrep -0 -c 'GGTATGATCAGCTCGGC' *.fastq > count/B17338_Rm0.txt
agrep -0 -c 'ATCAAATGGTGCCATCT' *.fastq > count/B17339_Rm0.txt
agrep -0 -c 'CATCCCTGAGCTTATTA' *.fastq > count/B17340_Rm0.txt
agrep -0 -c 'GGCTTATTACGTGCCGA' *.fastq > count/B17341_Rm0.txt
agrep -0 -c 'TTGCCCGTACTTAGCTG' *.fastq > count/B17343_Rm0.txt
agrep -0 -c 'TTAGCGATCACACAGCG' *.fastq > count/B17344_Rm0.txt
agrep -0 -c 'TTACTGCCGATTCCACC' *.fastq > count/B17345_Rm0.txt
agrep -0 -c 'GACACCGAAGGTCTCAC' *.fastq > count/B17348_Rm0.txt
agrep -0 -c 'GCAGTGGTACAAGCTCC' *.fastq > count/B17349_Rm0.txt
agrep -0 -c 'CGCGTCTAACATAAGCG' *.fastq > count/B17350_Rm0.txt
agrep -0 -c 'ACGTAACTCGAGGTCCC' *.fastq > count/B17351_Rm0.txt
agrep -0 -c 'CGACTCCTATTTACGAC' *.fastq > count/B17353_Rm0.txt
agrep -0 -c 'ACGTGATGTTCACGCAC' *.fastq > count/B17354_Rm0.txt
agrep -0 -c 'AAGCCATGGTCCTGCCT' *.fastq > count/B17355_Rm0.txt
agrep -0 -c 'GTTTCCGTCTCAAATGT' *.fastq > count/B17356_Rm0.txt
agrep -0 -c 'CGCTAATGAAAGCCCTT' *.fastq > count/B17357_Rm0.txt
agrep -0 -c 'CGAATCATAGAGGGACG' *.fastq > count/B17358_Rm0.txt
agrep -0 -c 'ATTTCAGCATTCCGATG' *.fastq > count/B17359_Rm0.txt
agrep -0 -c 'GTGTTGCGAGATATACG' *.fastq > count/B17361_Rm0.txt
agrep -0 -c 'ACACAAGGTAGCTCCAT' *.fastq > count/B17362_Rm0.txt
agrep -0 -c 'GAAGGGATTCCCTTGCC' *.fastq > count/B17363_Rm0.txt
agrep -0 -c 'CTCGCTGCGATCTGATT' *.fastq > count/B17364_Rm0.txt
agrep -0 -c 'AGCTGGACAGATCACCC' *.fastq > count/B17365_Rm0.txt
agrep -0 -c 'ATCAACTCGGGCGAACA' *.fastq > count/B17366_Rm0.txt
agrep -0 -c 'TCGAATCAGCCCGATCG' *.fastq > count/B17367_Rm0.txt
agrep -0 -c 'GTTTGCAGACTAGCCCT' *.fastq > count/B17368_Rm0.txt
agrep -0 -c 'TTAAGTCCCGACTTCCC' *.fastq > count/B17370_Rm0.txt
agrep -0 -c 'GGGACGATCACGCTAAT' *.fastq > count/B17371_Rm0.txt
agrep -0 -c 'CCATTCATTGATGCCGA' *.fastq > count/B17372_Rm0.txt
agrep -0 -c 'CAGCTCCACCAAAGAGG' *.fastq > count/B17373_Rm0.txt
agrep -0 -c 'ACAAGATGTCGCGTTGT' *.fastq > count/B17374_Rm0.txt
agrep -0 -c 'TGTTTCCGATGCACACG' *.fastq > count/B17375_Rm0.txt
agrep -0 -c 'GCGCATAGAACATCTAA' *.fastq > count/B17376_Rm0.txt
agrep -0 -c 'TTATAACGCACACAGGT' *.fastq > count/B17377_Rm0.txt
agrep -0 -c 'GAACTATCCCCCTGCTG' *.fastq > count/B17379_Rm0.txt
agrep -0 -c 'TGGCGGAAGAGATAGAC' *.fastq > count/B17380_Rm0.txt
agrep -0 -c 'AGCGACCATGCTGTACA' *.fastq > count/B17381_Rm0.txt
agrep -0 -c 'CATGCCTGGTCAAACAT' *.fastq > count/B17382_Rm0.txt
agrep -0 -c 'TTATCCGCTTACCCTTG' *.fastq > count/B17383_Rm0.txt
agrep -0 -c 'GTGAAGTTGTTCTACGC' *.fastq > count/B17384_Rm0.txt
agrep -0 -c 'GAGACGCCTTGAGAGTT' *.fastq > count/B17386_Rm0.txt
agrep -0 -c 'CTCCACTCTACAGCGTC' *.fastq > count/B17387_Rm0.txt
agrep -0 -c 'GAACCGTGTGTCGACTC' *.fastq > count/B17388_Rm0.txt
agrep -0 -c 'ACGGGATGAACCTGTGC' *.fastq > count/B17389_Rm0.txt
agrep -0 -c 'TAATACGAGAGTCAGCC' *.fastq > count/B17390_Rm0.txt
agrep -0 -c 'TGGCCACGTCAAGGAGT' *.fastq > count/B17392_Rm0.txt
agrep -0 -c 'GGCACGGACACTTTAAC' *.fastq > count/B17393_Rm0.txt
agrep -0 -c 'CTACCCTGTCTGTCCAA' *.fastq > count/B17394_Rm0.txt
agrep -0 -c 'GTACGTAGACGTGGGTG' *.fastq > count/B17395_Rm0.txt
agrep -0 -c 'CATTTTCGGCATAAGCT' *.fastq > count/B17396_Rm0.txt
agrep -0 -c 'ATACTGTACAGTTCACC' *.fastq > count/B17398_Rm0.txt
agrep -0 -c 'TCGCTTACCGATACCAC' *.fastq > count/B17399_Rm0.txt
agrep -0 -c 'CTCGCCGTTAGATTAGT' *.fastq > count/B17400_Rm0.txt
agrep -0 -c 'TGGCTGTAGAGGCAACG' *.fastq > count/B17401_Rm0.txt
agrep -0 -c 'CCGATGTATGTGAGGCA' *.fastq > count/B17402_Rm0.txt
agrep -0 -c 'GGGTAGTAGTATGCCGT' *.fastq > count/B17404_Rm0.txt
agrep -0 -c 'CGGGTGTCCAACAACTT' *.fastq > count/B17405_Rm0.txt
agrep -0 -c 'ATACGACACGTGTGACC' *.fastq > count/B17406_Rm0.txt
agrep -0 -c 'TCGCAACTCAGGAAACA' *.fastq > count/B17407_Rm0.txt
agrep -0 -c 'GCGATTCTACAAAGGGC' *.fastq > count/B17408_Rm0.txt
agrep -0 -c 'TCCGGCTTACTATGAGA' *.fastq > count/B17409_Rm0.txt
agrep -0 -c 'ATTCCAGTAGCGGAATA' *.fastq > count/B17410_Rm0.txt
agrep -0 -c 'GAGTAAAGTCCTAGGGT' *.fastq > count/B17411_Rm0.txt
agrep -0 -c 'GCTCTTGAGCGAACCAT' *.fastq > count/B17412_Rm0.txt
agrep -0 -c 'AGCTCGGCTATTTACCC' *.fastq > count/B17413_Rm0.txt
agrep -0 -c 'TGTGGCGTTCAGCTAGG' *.fastq > count/B17414_Rm0.txt
agrep -0 -c 'GGGCACACTGTCAATAT' *.fastq > count/B17415_Rm0.txt
agrep -0 -c 'GACCAGGTATTGACTCG' *.fastq > count/B17416_Rm0.txt
agrep -0 -c 'GTAGTGAGTAGCTCCAG' *.fastq > count/B17417_Rm0.txt
agrep -0 -c 'AACTATCATAAGCCCCT' *.fastq > count/B17418_Rm0.txt
agrep -0 -c 'TCTACTAGGCTGCACAG' *.fastq > count/B17419_Rm0.txt
agrep -0 -c 'ATGGGCTGTAGTCGAGT' *.fastq > count/B17421_Rm0.txt
agrep -0 -c 'CTCATGTGAAGTATGTC' *.fastq > count/B17423_Rm0.txt
agrep -0 -c 'TGTCAGGCGTCATGAGA' *.fastq > count/B17424_Rm0.txt
agrep -0 -c 'CGGGTTCTGTTACTACT' *.fastq > count/B17425_Rm0.txt
agrep -0 -c 'CCTGTTTAATACGGTCC' *.fastq > count/B17426_Rm0.txt
agrep -0 -c 'AACTAGTAGTCCAGTAC' *.fastq > count/B17427_Rm0.txt
agrep -0 -c 'CCTAATGGTAGGACGTG' *.fastq > count/B17428_Rm0.txt
agrep -0 -c 'ATAAAATTGGTGGGTCG' *.fastq > count/B17430_Rm0.txt
agrep -0 -c 'GCCGAATCCGAGAGCTA' *.fastq > count/B17431_Rm0.txt
agrep -0 -c 'CGGGGCCTAGGGTATTA' *.fastq > count/B17433_Rm0.txt
agrep -0 -c 'CCGGGAGTACAATATAA' *.fastq > count/B17434_Rm0.txt
agrep -0 -c 'CAAACCCTAGTCCACTA' *.fastq > count/B17437_Rm0.txt
agrep -0 -c 'GAGAAACTAAGCATGAC' *.fastq > count/B17438_Rm0.txt
agrep -0 -c 'TGTAGACGCCCAGTTCG' *.fastq > count/B17439_Rm0.txt
agrep -0 -c 'GGCCCGCTATGTTCGAT' *.fastq > count/B17441_Rm0.txt
agrep -0 -c 'TAAGCTAAACCGTAAGC' *.fastq > count/B17442_Rm0.txt
agrep -0 -c 'TTTATCCGTATCGATCG' *.fastq > count/B17443_Rm0.txt
agrep -0 -c 'CAACAGGACCGGTACAA' *.fastq > count/B17444_Rm0.txt
agrep -0 -c 'ATAGAGATGCGAGTGTA' *.fastq > count/B17445_Rm0.txt
agrep -0 -c 'TTGTGGTATCTCGCCCT' *.fastq > count/B17446_Rm0.txt
agrep -0 -c 'TGCATCAACTATCGGAG' *.fastq > count/B17447_Rm0.txt
agrep -0 -c 'AATGGCACTAGCAGAAT' *.fastq > count/B17448_Rm0.txt
agrep -0 -c 'GCCCAATCACGTGGTAG' *.fastq > count/B17450_Rm0.txt
agrep -0 -c 'ATCGTAGCTTATACAGG' *.fastq > count/B17451_Rm0.txt
agrep -0 -c 'GTCTATAAAACTCCCGA' *.fastq > count/B17452_Rm0.txt
agrep -0 -c 'ACTGCTGGGCAACAGAC' *.fastq > count/B17453_Rm0.txt
agrep -0 -c 'CTCTGATCTAGTCTCGT' *.fastq > count/B17454_Rm0.txt
agrep -0 -c 'GAGGGTTATCAGTTTGA' *.fastq > count/B17455_Rm0.txt
agrep -0 -c 'GACATGCGCGTTCTGTA' *.fastq > count/B17456_Rm0.txt
agrep -0 -c 'GTTTATAGGGGTTAGGT' *.fastq > count/B17458_Rm0.txt
agrep -0 -c 'CCAACCCTATATGCTCA' *.fastq > count/B17459_Rm0.txt
agrep -0 -c 'GTGAAGTTTCTATTGCC' *.fastq > count/B17460_Rm0.txt
agrep -0 -c 'AGATACATGTGCGATGT' *.fastq > count/B17462_Rm0.txt
agrep -0 -c 'AAGTTGGTTACCCTGTT' *.fastq > count/B17465_Rm0.txt
agrep -0 -c 'AAGCGAGGGTGTTACGA' *.fastq > count/B17466_Rm0.txt
agrep -0 -c 'ACATCCGACTATATGCA' *.fastq > count/B17467_Rm0.txt
agrep -0 -c 'GGCTGCGTTGATTATTA' *.fastq > count/B17469_Rm0.txt
agrep -0 -c 'CGATGTGATAGATCCTG' *.fastq > count/B17470_Rm0.txt
agrep -0 -c 'GGAAGCATTAGTCAATG' *.fastq > count/B17473_Rm0.txt
agrep -0 -c 'CCCAAAACTCTGCCGAC' *.fastq > count/B17474_Rm0.txt
agrep -0 -c 'CAACTCGGCCTGTTATC' *.fastq > count/B17475_Rm0.txt
agrep -0 -c 'GAATCATACGCGTATCA' *.fastq > count/B17476_Rm0.txt
agrep -0 -c 'CGTCGCAATTGGCAAAC' *.fastq > count/B17477_Rm0.txt
agrep -0 -c 'GAATCCATACGAAGCGT' *.fastq > count/B17478_Rm0.txt
agrep -0 -c 'TTAGCCATGACCATTAG' *.fastq > count/B17479_Rm0.txt
agrep -0 -c 'TACCGATGGGACCGAAT' *.fastq > count/B17480_Rm0.txt
agrep -0 -c 'GAAGAGTTTTGAGAGCA' *.fastq > count/B17481_Rm0.txt
agrep -0 -c 'CCGTATAGTGGACCCAG' *.fastq > count/B17482_Rm0.txt
agrep -0 -c 'CTTACCGTCGGTATGGC' *.fastq > count/B17483_Rm0.txt
agrep -0 -c 'CCAAACCGATACCTACA' *.fastq > count/B17486_Rm0.txt
agrep -0 -c 'ATGTCTACGGACGGCTG' *.fastq > count/B17487_Rm0.txt
agrep -0 -c 'TGCGCTTGCTTGTCGCA' *.fastq > count/B17488_Rm0.txt
agrep -0 -c 'CCCGCACAATCGTGTCA' *.fastq > count/B17489_Rm0.txt
agrep -0 -c 'GTAGACGGTTGCGTGAC' *.fastq > count/B17490_Rm0.txt
agrep -0 -c 'GTCACAAAACGCGTATC' *.fastq > count/B17491_Rm0.txt
agrep -0 -c 'GTCCAACGGCCTAGATA' *.fastq > count/B17492_Rm0.txt
agrep -0 -c 'CATTCGTCTCCAGGCTA' *.fastq > count/B17494_Rm0.txt
agrep -0 -c 'GTAGTCAGGATACGTCT' *.fastq > count/B17495_Rm0.txt
agrep -0 -c 'ACTACGATCTGCCTACA' *.fastq > count/B17496_Rm0.txt
agrep -0 -c 'GGGATGCGAATCTTGGC' *.fastq > count/B17497_Rm0.txt
agrep -0 -c 'CTCTTATGCTGGTGCAA' *.fastq > count/B17498_Rm0.txt
agrep -0 -c 'TGCTCTCCGTAGCCATA' *.fastq > count/B17499_Rm0.txt
agrep -0 -c 'AATAAGATCACTTCGGC' *.fastq > count/B17500_Rm0.txt
agrep -0 -c 'TACACAGACGAATAGCG' *.fastq > count/B17501_Rm0.txt
agrep -0 -c 'TTGTACCGACCCATCGG' *.fastq > count/B17502_Rm0.txt
agrep -0 -c 'TCCCGTGCGTGAACGAT' *.fastq > count/B17503_Rm0.txt
agrep -0 -c 'TGCGACAAGAGACAAGG' *.fastq > count/B17505_Rm0.txt
agrep -0 -c 'CGTGTAGTAACCCACTC' *.fastq > count/B17506_Rm0.txt
agrep -0 -c 'GGACTAGCTCGCCTCTA' *.fastq > count/B17507_Rm0.txt
agrep -0 -c 'AGCGATTCTGTTGAACA' *.fastq > count/B17508_Rm0.txt
agrep -0 -c 'CCAGATCAATTCCATAC' *.fastq > count/B17510_Rm0.txt
agrep -0 -c 'CCTCTTTAAACGCCGCG' *.fastq > count/B17512_Rm0.txt
agrep -0 -c 'TCTGCCAACACTAGACC' *.fastq > count/B17513_Rm0.txt
agrep -0 -c 'CCCCAATCGATTAATCC' *.fastq > count/B17514_Rm0.txt
agrep -0 -c 'TCGGATTAGGAGCTGCG' *.fastq > count/B17515_Rm0.txt
agrep -0 -c 'GCAACATGCGTTGCAAC' *.fastq > count/B17516_Rm0.txt
agrep -0 -c 'CGTGTTCAGGACTAATC' *.fastq > count/B17517_Rm0.txt
agrep -0 -c 'TTGTCTTAGACGCAGAT' *.fastq > count/B17519_Rm0.txt
agrep -0 -c 'CCGGTTCCCGAAGACAT' *.fastq > count/B17520_Rm0.txt
agrep -0 -c 'GCGCGTTTGAAGAATCT' *.fastq > count/B17523_Rm0.txt
agrep -0 -c 'CCCAGTATTGGTTTAGA' *.fastq > count/B17524_Rm0.txt
agrep -0 -c 'GTACTGTGTTATCGGTT' *.fastq > count/B17525_Rm0.txt
agrep -0 -c 'ACGGTGGCACAAAGGAG' *.fastq > count/B17526_Rm0.txt
agrep -0 -c 'CTTCCAGATCACATGCG' *.fastq > count/B17527_Rm0.txt
agrep -0 -c 'TCGCCATGAGTTACTCG' *.fastq > count/B17529_Rm0.txt
agrep -0 -c 'TACTGCGGTTTAATCGG' *.fastq > count/B17530_Rm0.txt
agrep -0 -c 'AGTCGAAGTGACCTGTT' *.fastq > count/B17531_Rm0.txt
agrep -0 -c 'AGCACCTAATCGTATGG' *.fastq > count/B17532_Rm0.txt
agrep -0 -c 'TAAGGCAACGGAAACTA' *.fastq > count/B17533_Rm0.txt
agrep -0 -c 'GATAACATCGTAACGCT' *.fastq > count/B17534_Rm0.txt
agrep -0 -c 'GTCGAGGATTCCCGACA' *.fastq > count/B17536_Rm0.txt
agrep -0 -c 'GGCAATAGGAACGTACT' *.fastq > count/B17537_Rm0.txt
agrep -0 -c 'GGAGATTTGATCGGCTT' *.fastq > count/B17539_Rm0.txt
agrep -0 -c 'TAGAGTTGGCTAGGGTA' *.fastq > count/B17540_Rm0.txt
agrep -0 -c 'TGTCCGAGGATTTATGG' *.fastq > count/B17541_Rm0.txt
agrep -0 -c 'CAGGTAGCAGCTTGAAT' *.fastq > count/B17542_Rm0.txt
agrep -0 -c 'GTGTCTATCGGATAAGT' *.fastq > count/B17543_Rm0.txt
agrep -0 -c 'CCGTGGTCCACAACTTG' *.fastq > count/B17544_Rm0.txt
agrep -0 -c 'GTTCGTCAATCAAACGA' *.fastq > count/B17545_Rm0.txt
agrep -0 -c 'TGCGAGGAAGCGTTTCA' *.fastq > count/B17546_Rm0.txt
agrep -0 -c 'ATCTTGGAACGCACAAC' *.fastq > count/B17547_Rm0.txt
agrep -0 -c 'TGAGTGGACATTACCCT' *.fastq > count/B17548_Rm0.txt
agrep -0 -c 'TAATCACAATTTCGGCG' *.fastq > count/B17549_Rm0.txt
agrep -0 -c 'CCACCCTATAACATTCC' *.fastq > count/B17550_Rm0.txt
agrep -0 -c 'AGCGACATACAAATCAG' *.fastq > count/B17552_Rm0.txt
agrep -0 -c 'TACTAAGACAGCGATGC' *.fastq > count/B17553_Rm0.txt
agrep -0 -c 'GGAGATCGTCTTTTGCC' *.fastq > count/B17554_Rm0.txt
agrep -0 -c 'ATTACGACGCCATTAGA' *.fastq > count/B17555_Rm0.txt
agrep -0 -c 'TGATGACTTCAGTCGAA' *.fastq > count/B17556_Rm0.txt
agrep -0 -c 'GTGACCTCAATACTGCT' *.fastq > count/B17557_Rm0.txt
agrep -0 -c 'GCGGTCTTAGTTTAGCA' *.fastq > count/B17558_Rm0.txt
agrep -0 -c 'TCACTATGTCCTAGTTG' *.fastq > count/B17559_Rm0.txt
agrep -0 -c 'GACCACTTGCCTACAGG' *.fastq > count/B17560_Rm0.txt
agrep -0 -c 'AGTGCCTTGGTTGACGC' *.fastq > count/B17561_Rm0.txt
agrep -0 -c 'TTGTATCACAGGGCCGC' *.fastq > count/B17562_Rm0.txt
agrep -0 -c 'TTGAGTTTCGCAGGGCC' *.fastq > count/B17563_Rm0.txt
agrep -0 -c 'ATCTCAGTGTCTACGTG' *.fastq > count/B17564_Rm0.txt
agrep -0 -c 'GTCGCCCTGCCCATTTA' *.fastq > count/B17567_Rm0.txt
agrep -0 -c 'TCAGCACGTAAAGCATA' *.fastq > count/B17568_Rm0.txt
agrep -0 -c 'GAGACGTCTAAGGAAGA' *.fastq > count/B17569_Rm0.txt
agrep -0 -c 'GCTGTCGGTACTAGGTC' *.fastq > count/B17570_Rm0.txt
agrep -0 -c 'AATGCGGGCCAGAATAG' *.fastq > count/B17574_Rm0.txt
agrep -0 -c 'GTCTTACAAACTCAACG' *.fastq > count/B17575_Rm0.txt
agrep -0 -c 'AACCGTGTGTCGTAGGT' *.fastq > count/B17577_Rm0.txt
agrep -0 -c 'GCCCACCGTCATGACTT' *.fastq > count/B17578_Rm0.txt
agrep -0 -c 'CACCTAAACTAGTAGCT' *.fastq > count/B17579_Rm0.txt
agrep -0 -c 'TCGATACTTTAAGGCAG' *.fastq > count/B17580_Rm0.txt
agrep -0 -c 'TCTGAGAACGGAGTTGC' *.fastq > count/B17582_Rm0.txt
agrep -0 -c 'GAAGTGCGTTAAATCAG' *.fastq > count/B17584_Rm0.txt
agrep -0 -c 'TTGGTGCACTCGCGCAA' *.fastq > count/B17585_Rm0.txt
agrep -0 -c 'TTATTTGGACTCCGCGT' *.fastq > count/B17586_Rm0.txt
agrep -0 -c 'GCAAGGCGTTTTCTTGC' *.fastq > count/B17588_Rm0.txt
agrep -0 -c 'GTGCCGCTCGTATTTCA' *.fastq > count/B17589_Rm0.txt
agrep -0 -c 'TCGTGTCAACGCCGAAG' *.fastq > count/B17590_Rm0.txt
agrep -0 -c 'GTATAGTGTCAGGAAGC' *.fastq > count/B17591_Rm0.txt
agrep -0 -c 'GGGTATTCGGTTATGCC' *.fastq > count/B17592_Rm0.txt
agrep -0 -c 'GCCGAATTCGAACGCTA' *.fastq > count/B17594_Rm0.txt
agrep -0 -c 'AAATCATGTAGCCGCCG' *.fastq > count/B17595_Rm0.txt
agrep -0 -c 'TAGCTTTACGCGGGATA' *.fastq > count/B17596_Rm0.txt
agrep -0 -c 'CTTCGAGCCAGGAACAA' *.fastq > count/B17597_Rm0.txt
agrep -0 -c 'GGGCGTTCAACCTAATT' *.fastq > count/B17598_Rm0.txt
agrep -0 -c 'CTCTCCTAGTACCCTGC' *.fastq > count/B17600_Rm0.txt
agrep -0 -c 'AGTCCGCTTAATAGGTC' *.fastq > count/B17601_Rm0.txt
agrep -0 -c 'TGTTCCGCTTCAACCTT' *.fastq > count/B17602_Rm0.txt
agrep -0 -c 'GCGCACATTTCAGTTGG' *.fastq > count/B17603_Rm0.txt
agrep -0 -c 'TGGTATTGGTACGCGCA' *.fastq > count/B17604_Rm0.txt
agrep -0 -c 'GCTCATACTCTCATGCG' *.fastq > count/B17606_Rm0.txt
agrep -0 -c 'CTGGTAGACATCTAGTC' *.fastq > count/B17607_Rm0.txt
agrep -0 -c 'TTCTCGCTGCTTCGCCT' *.fastq > count/B17608_Rm0.txt
agrep -0 -c 'CCCTCAGTATCCCAATT' *.fastq > count/B17609_Rm0.txt
agrep -0 -c 'TATCACGCCGACAGTCG' *.fastq > count/B17611_Rm0.txt
agrep -0 -c 'ATCGTCGTGGAGTATGG' *.fastq > count/B17612_Rm0.txt
agrep -0 -c 'CTTTGTTCGACGGGGAC' *.fastq > count/B17613_Rm0.txt
agrep -0 -c 'AAAGCCACATTACCAAG' *.fastq > count/B17614_Rm0.txt
agrep -0 -c 'ATCTATCGAGTCGCCTG' *.fastq > count/B17615_Rm0.txt
agrep -0 -c 'AGTGGGAATGTTCGCTC' *.fastq > count/B17616_Rm0.txt
agrep -0 -c 'AGTAGGGGGAGTAGCGT' *.fastq > count/B17617_Rm0.txt
agrep -0 -c 'GGTGCCACTCATTCGAA' *.fastq > count/B17618_Rm0.txt
agrep -0 -c 'CAACCTAATGTGGCGAC' *.fastq > count/B17619_Rm0.txt
agrep -0 -c 'GCGTAGCGGCAATTCAC' *.fastq > count/B17620_Rm0.txt
agrep -0 -c 'TAAAGCCGAGGGATCCT' *.fastq > count/B17621_Rm0.txt
agrep -0 -c 'AAGCCTTATGGTTTCCT' *.fastq > count/B17622_Rm0.txt
agrep -0 -c 'TGTTTGCCGCACATCAA' *.fastq > count/B17623_Rm0.txt
agrep -0 -c 'CCAAATCGTGGGATCAA' *.fastq > count/B17625_Rm0.txt
agrep -0 -c 'GTCGCCTACAGAAGTCT' *.fastq > count/B17626_Rm0.txt
agrep -0 -c 'GCTAATCAAGATCGTCC' *.fastq > count/B17628_Rm0.txt
agrep -0 -c 'GAGTCATATCAGATAGG' *.fastq > count/B17629_Rm0.txt
agrep -0 -c 'CGGGATGGTGGCTTATC' *.fastq > count/B17630_Rm0.txt
agrep -0 -c 'GGACTCGACCATATGGT' *.fastq > count/B17631_Rm0.txt
agrep -0 -c 'GCTCCACTCGCTTGGAT' *.fastq > count/B17632_Rm0.txt
agrep -0 -c 'TTCGGAGAGCCTGTCTC' *.fastq > count/B17633_Rm0.txt
agrep -0 -c 'AATTACGCTAGACGTAC' *.fastq > count/B17634_Rm0.txt
agrep -0 -c 'TTCATCCGGAATATCCG' *.fastq > count/B17635_Rm0.txt
agrep -0 -c 'CAAACTCCAGCGGTGCA' *.fastq > count/B17636_Rm0.txt
agrep -0 -c 'CTACCGACATCACGAAG' *.fastq > count/B17637_Rm0.txt
agrep -0 -c 'CACGAGACCATTGCTTG' *.fastq > count/B17640_Rm0.txt
agrep -0 -c 'TAGCCCCTGAAGCTATT' *.fastq > count/B17641_Rm0.txt
agrep -0 -c 'TAGACCTTCATTGGTGA' *.fastq > count/B17642_Rm0.txt
agrep -0 -c 'TGCAGCCTAATTAAGAG' *.fastq > count/B17643_Rm0.txt
agrep -0 -c 'AAGGGTTGCATTACTCT' *.fastq > count/B17644_Rm0.txt
agrep -0 -c 'CCGCCTATACTGATCTC' *.fastq > count/B17645_Rm0.txt
agrep -0 -c 'TTAACGAGTGGATCCAA' *.fastq > count/B17646_Rm0.txt
agrep -0 -c 'CCTAGCCTTATGCGACA' *.fastq > count/B17647_Rm0.txt
agrep -0 -c 'AGGGGTGCTGGCAACAT' *.fastq > count/B17648_Rm0.txt
agrep -0 -c 'ACAGATGACAGGTCGTC' *.fastq > count/B17649_Rm0.txt
agrep -0 -c 'ATACCCTCCGGATATGC' *.fastq > count/B17650_Rm0.txt
agrep -0 -c 'GTTTAGAGAGGAGTCGG' *.fastq > count/B17651_Rm0.txt
agrep -0 -c 'CGTACCAGATACTCGTC' *.fastq > count/B17652_Rm0.txt
agrep -0 -c 'TAATGGTCGAATATCCG' *.fastq > count/B17653_Rm0.txt
agrep -0 -c 'TTCGATTCCTTTCTGAC' *.fastq > count/B17654_Rm0.txt
agrep -0 -c 'GCACCATGTAGATTGAC' *.fastq > count/B17655_Rm0.txt
agrep -0 -c 'TTAGCAACAAGAGTCGC' *.fastq > count/B17656_Rm0.txt
agrep -0 -c 'TACCGACCACAAACCGA' *.fastq > count/B17657_Rm0.txt
agrep -0 -c 'AGCTAGTTGCACGCATG' *.fastq > count/B17658_Rm0.txt
agrep -0 -c 'CTTAGTAGCCTCTGACA' *.fastq > count/B17659_Rm0.txt
agrep -0 -c 'CCCACTTGCTATGTCGC' *.fastq > count/B17660_Rm0.txt
agrep -0 -c 'TGTACCCGAAGCGCATC' *.fastq > count/B17661_Rm0.txt
agrep -0 -c 'AATGCGAGCTGTACGTG' *.fastq > count/B17662_Rm0.txt
agrep -0 -c 'TCACACGCTTACGGGAC' *.fastq > count/B17663_Rm0.txt
agrep -0 -c 'TGTAGCGGGACACGTGT' *.fastq > count/B17664_Rm0.txt
agrep -0 -c 'GTACTAAACGCCATTTG' *.fastq > count/B17667_Rm0.txt
agrep -0 -c 'GGAGGTAAAAGTGCCTT' *.fastq > count/B17668_Rm0.txt
agrep -0 -c 'TCTGATAGTAGACAGAG' *.fastq > count/B17669_Rm0.txt
agrep -0 -c 'GAGTATCTCGGTAACGA' *.fastq > count/B17670_Rm0.txt
agrep -0 -c 'GTAGGAACCGTGTAGTA' *.fastq > count/B17671_Rm0.txt
agrep -0 -c 'GTCTATGGGATCGACGC' *.fastq > count/B17672_Rm0.txt
agrep -0 -c 'CCGATAGGTCAATCACT' *.fastq > count/B17673_Rm0.txt
agrep -0 -c 'ATACGGAGAAAGACGAG' *.fastq > count/B17674_Rm0.txt
agrep -0 -c 'GGTCCTAACCATCATAT' *.fastq > count/B17675_Rm0.txt
agrep -0 -c 'TAAGCACAGCGGAATTA' *.fastq > count/B17676_Rm0.txt
agrep -0 -c 'TTGTATCGAGCTGCGCC' *.fastq > count/B17677_Rm0.txt
agrep -0 -c 'TTAGTACGCCAGTGAGC' *.fastq > count/B17678_Rm0.txt
agrep -0 -c 'ATCGCCCAAGGACGCAA' *.fastq > count/B17679_Rm0.txt
agrep -0 -c 'GCTAGGCCTTTTATACG' *.fastq > count/B17680_Rm0.txt
agrep -0 -c 'CAGGGGTATTTGTACGT' *.fastq > count/B17682_Rm0.txt
agrep -0 -c 'GACGAGCGCGAATCGAT' *.fastq > count/B17683_Rm0.txt
agrep -0 -c 'TACCGGAAAAGGGACAC' *.fastq > count/B17684_Rm0.txt
agrep -0 -c 'CCCTTAAATGAGGTCAG' *.fastq > count/B17686_Rm0.txt
agrep -0 -c 'TTAGTGACGCACTTAGA' *.fastq > count/B17689_Rm0.txt
agrep -0 -c 'GCATGCGCCACTTCAGA' *.fastq > count/B17690_Rm0.txt
agrep -0 -c 'GTTCTTTATCTGAAGCC' *.fastq > count/B17691_Rm0.txt
agrep -0 -c 'TAGACGCAGCACATCGC' *.fastq > count/B17692_Rm0.txt
agrep -0 -c 'GCATGATTCTTTACGTG' *.fastq > count/B17693_Rm0.txt
agrep -0 -c 'CCACATCAACCTGGATC' *.fastq > count/B17695_Rm0.txt
agrep -0 -c 'AAGTCGAATTCGAGCGC' *.fastq > count/B17697_Rm0.txt
agrep -0 -c 'CTGTATCAGTGGTCGCT' *.fastq > count/B17698_Rm0.txt
agrep -0 -c 'TTTACGAATCTCGGCCA' *.fastq > count/B17699_Rm0.txt
agrep -0 -c 'CTTGTCAAAGTAGGGGC' *.fastq > count/B17700_Rm0.txt
agrep -0 -c 'AGGGCACCTTTGTTGAG' *.fastq > count/B17702_Rm0.txt
agrep -0 -c 'GACCATACAGATAACGT' *.fastq > count/B17705_Rm0.txt
agrep -0 -c 'ACGACTTCGTTTTGTGG' *.fastq > count/B17706_Rm0.txt
agrep -0 -c 'TTGGGATGACTAGCTGT' *.fastq > count/B17707_Rm0.txt
agrep -0 -c 'AAGCTACTCAGTCCCCC' *.fastq > count/B17708_Rm0.txt
agrep -0 -c 'CGAGAATCAACACCCGA' *.fastq > count/B17709_Rm0.txt
agrep -0 -c 'AGGTAGTTGACTGAAGG' *.fastq > count/B17710_Rm0.txt
agrep -0 -c 'GAATTCATGTAAGCACC' *.fastq > count/B17711_Rm0.txt
agrep -0 -c 'CCATTGTATCCTCTACT' *.fastq > count/B17712_Rm0.txt
agrep -0 -c 'CACGGCACTTAAGAGAG' *.fastq > count/B17713_Rm0.txt
agrep -0 -c 'GTGGACTACATAGAAGA' *.fastq > count/B17714_Rm0.txt
agrep -0 -c 'AGACGGAGCATCTGGAA' *.fastq > count/B17715_Rm0.txt
agrep -0 -c 'CTCCGAATGTCATCTCC' *.fastq > count/B17716_Rm0.txt
agrep -0 -c 'AGGAGGTACAATTCTGC' *.fastq > count/B17718_Rm0.txt
agrep -0 -c 'AACATTTCACGACATGG' *.fastq > count/B17720_Rm0.txt
agrep -0 -c 'GCATTGAAGAGTAAGCA' *.fastq > count/B17722_Rm0.txt
agrep -0 -c 'GGTCTTAGTTTGCCGTT' *.fastq > count/B17723_Rm0.txt
agrep -0 -c 'ATGCTGGCTAGGCATGA' *.fastq > count/B17725_Rm0.txt
agrep -0 -c 'GTGTGTACGCGAAATGT' *.fastq > count/B17726_Rm0.txt
agrep -0 -c 'GGTCATCGTAAGCGTGG' *.fastq > count/B17728_Rm0.txt
agrep -0 -c 'TCTCCTCGAAAGAAGAA' *.fastq > count/B17729_Rm0.txt
agrep -0 -c 'TCTTTAGCCATAGTCCC' *.fastq > count/B17730_Rm0.txt
agrep -0 -c 'GGATTCAGGTCAGATCG' *.fastq > count/B17731_Rm0.txt
agrep -0 -c 'ATTGCAACGCAGGTCGT' *.fastq > count/B17732_Rm0.txt
agrep -0 -c 'CGAACATTCTCGCATAT' *.fastq > count/B17737_Rm0.txt
agrep -0 -c 'TGGAGGACGATCAGGAA' *.fastq > count/B17738_Rm0.txt
agrep -0 -c 'TATCGCACTTCGGATCT' *.fastq > count/B17739_Rm0.txt
agrep -0 -c 'ATGCTGAACGCGAAATT' *.fastq > count/B17740_Rm0.txt
agrep -0 -c 'TGTGGGCGTCATAGGTA' *.fastq > count/B17742_Rm0.txt
agrep -0 -c 'CGATAAGGTAAGGAAGC' *.fastq > count/B17743_Rm0.txt
agrep -0 -c 'CTACACGCTCCAGGATT' *.fastq > count/B17744_Rm0.txt
agrep -0 -c 'GTTTTGGGGGAGTTTCG' *.fastq > count/B17745_Rm0.txt
agrep -0 -c 'CACGCGCAGGATCAGTT' *.fastq > count/B17746_Rm0.txt
agrep -0 -c 'GGACGCTTCGTTGGACT' *.fastq > count/B17747_Rm0.txt
agrep -0 -c 'TCGCGGTATTAAGAGCT' *.fastq > count/B17749_Rm0.txt
agrep -0 -c 'GCTAGCCTATCGTCACC' *.fastq > count/B17750_Rm0.txt
agrep -0 -c 'AATAGAACGAGACACGT' *.fastq > count/B17752_Rm0.txt
agrep -0 -c 'GTGACGCTTTTACGCAA' *.fastq > count/B17753_Rm0.txt
agrep -0 -c 'GAAAATCTACGCTTGCT' *.fastq > count/B17754_Rm0.txt
agrep -0 -c 'TCTGATCACGACCGACC' *.fastq > count/B17755_Rm0.txt
agrep -0 -c 'AACACTGTGCGCTAGTG' *.fastq > count/B17756_Rm0.txt
agrep -0 -c 'TCCACTGTAGTTATGCC' *.fastq > count/B17757_Rm0.txt
agrep -0 -c 'CTATGCTAAGCAAGGCG' *.fastq > count/B17758_Rm0.txt
agrep -0 -c 'ACGTCTACCAAGAAGGT' *.fastq > count/B17760_Rm0.txt
agrep -0 -c 'ACTGCACTTTCGATTGC' *.fastq > count/B17761_Rm0.txt
agrep -0 -c 'TGCACTGAACACGTCTG' *.fastq > count/B17762_Rm0.txt
agrep -0 -c 'TATGTCAACCCCGGTAT' *.fastq > count/B17763_Rm0.txt
agrep -0 -c 'AAGGTATCCAAGGTTGA' *.fastq > count/B17764_Rm0.txt
agrep -0 -c 'AGAGATTATGGTAGTCG' *.fastq > count/B17765_Rm0.txt
agrep -0 -c 'GGGTAGACTTCCAGGTA' *.fastq > count/B17766_Rm0.txt
agrep -0 -c 'ACTATTGGTGCATCGGT' *.fastq > count/B17767_Rm0.txt
agrep -0 -c 'AGCTTGTAGAAAAGCAG' *.fastq > count/B17768_Rm0.txt
agrep -0 -c 'GGTTCGAAGGTGACAAC' *.fastq > count/B17769_Rm0.txt
agrep -0 -c 'ATTAGGGTAATCGCGCT' *.fastq > count/B17770_Rm0.txt
agrep -0 -c 'GAATAGCTGTATTCGGT' *.fastq > count/B17771_Rm0.txt
agrep -0 -c 'ATTTCCCGTTCGCCATT' *.fastq > count/B17772_Rm0.txt
agrep -0 -c 'GCGTGTGTATTCCAGTG' *.fastq > count/B17773_Rm0.txt
agrep -0 -c 'CCAGAGGTATTTTACGG' *.fastq > count/B17774_Rm0.txt
agrep -0 -c 'GATGTGCGAAGTTTAGC' *.fastq > count/B17775_Rm0.txt
agrep -0 -c 'TCATTCCGCCCAAACAT' *.fastq > count/B17776_Rm0.txt
agrep -0 -c 'GGTCTATTGCCATTACT' *.fastq > count/B17777_Rm0.txt
agrep -0 -c 'TCTGAGATGATTTACGC' *.fastq > count/B17779_Rm0.txt
agrep -0 -c 'GTTGCATCACAAGCAGA' *.fastq > count/B17781_Rm0.txt
agrep -0 -c 'CAGTATCACGCCCGACA' *.fastq > count/B17783_Rm0.txt
agrep -0 -c 'CTTCCTCTGCGGATATC' *.fastq > count/B17784_Rm0.txt
agrep -0 -c 'GTAGGGATAAGATTCGA' *.fastq > count/B17786_Rm0.txt
agrep -0 -c 'CAGCGGTGGACATGTCA' *.fastq > count/B17789_Rm0.txt
agrep -0 -c 'GGATTCTATATCGTCGA' *.fastq > count/B17790_Rm0.txt
agrep -0 -c 'TTCGACTCTCCAGCACC' *.fastq > count/B17792_Rm0.txt
agrep -0 -c 'GCTCTATTCCCGTGGTC' *.fastq > count/B17793_Rm0.txt
agrep -0 -c 'TTCCAACCGTTATGTGG' *.fastq > count/B17794_Rm0.txt
agrep -0 -c 'TCCATCTCTTGGAACCG' *.fastq > count/B17795_Rm0.txt
agrep -0 -c 'GACCCTATAACCCCAGA' *.fastq > count/B17796_Rm0.txt
agrep -0 -c 'CTGGTAGATACGCGCTG' *.fastq > count/B17797_Rm0.txt
agrep -0 -c 'CGATTCGGAATCGCCAA' *.fastq > count/B17798_Rm0.txt
agrep -0 -c 'CGCTGATGACACACGTT' *.fastq > count/B17799_Rm0.txt
agrep -0 -c 'GAGCATAGTAGGGGGTG' *.fastq > count/B17800_Rm0.txt
agrep -0 -c 'GCAGATACACCTCCGTA' *.fastq > count/B17803_Rm0.txt
agrep -0 -c 'CCATCATGGGGTGTACT' *.fastq > count/B17804_Rm0.txt
agrep -0 -c 'CTGGCTTCATTTCGTAT' *.fastq > count/B17805_Rm0.txt
agrep -0 -c 'CTATCGATTCTAGGCAG' *.fastq > count/B17807_Rm0.txt
agrep -0 -c 'TGGCTTCACAGGATGTC' *.fastq > count/B17808_Rm0.txt
agrep -0 -c 'GGCTTATGGGAAGTGCG' *.fastq > count/B17810_Rm0.txt
agrep -0 -c 'TGGTGTGTCCAATTCCC' *.fastq > count/B17811_Rm0.txt
agrep -0 -c 'TGGCCGTTTTGTCTCCC' *.fastq > count/B17812_Rm0.txt
agrep -0 -c 'CTCCGACCGGCGTTTAA' *.fastq > count/B17813_Rm0.txt
agrep -0 -c 'AAGGGGCGGCAGGTATT' *.fastq > count/B17814_Rm0.txt
agrep -0 -c 'TCTGGCCTATAGTTCGG' *.fastq > count/B17815_Rm0.txt
agrep -0 -c 'TCTAGATTACGTGACAG' *.fastq > count/B17816_Rm0.txt
agrep -0 -c 'AGGCCCATATCCGATCA' *.fastq > count/B17817_Rm0.txt
agrep -0 -c 'GAGATCGATTGTGCTAG' *.fastq > count/B17818_Rm0.txt
agrep -0 -c 'CATGGCAGTGTCTGGTT' *.fastq > count/B17819_Rm0.txt
agrep -0 -c 'GCTGGACTTAAGGTAGA' *.fastq > count/B17820_Rm0.txt
agrep -0 -c 'ACATGTGCCGACTATTG' *.fastq > count/B17821_Rm0.txt
agrep -0 -c 'AACACAGTGAGGGGTCG' *.fastq > count/B17822_Rm0.txt
agrep -0 -c 'AGGTTGGGATATTGAGC' *.fastq > count/B17823_Rm0.txt
agrep -0 -c 'TTATGCACGCCAGGTCC' *.fastq > count/B17824_Rm0.txt
agrep -0 -c 'AGGGCGAAGGAACTAAG' *.fastq > count/B17826_Rm0.txt
agrep -0 -c 'TTTGCTTCGGAACACTT' *.fastq > count/B17829_Rm0.txt
agrep -0 -c 'CTTAGGTCTAGCGAAGG' *.fastq > count/B17830_Rm0.txt
agrep -0 -c 'GTGGGTCTTTTGCGACG' *.fastq > count/B17831_Rm0.txt
agrep -0 -c 'TCCATTCGGAGTAATTG' *.fastq > count/B17832_Rm0.txt
agrep -0 -c 'ACGTAACCGGGAGACAT' *.fastq > count/B17833_Rm0.txt
agrep -0 -c 'ATGTAGAGTCGACACAA' *.fastq > count/B17834_Rm0.txt
agrep -0 -c 'GTTAAGAGCGGGCCATT' *.fastq > count/B17835_Rm0.txt
agrep -0 -c 'TGCCTACTATCCGCTGT' *.fastq > count/B17837_Rm0.txt
agrep -0 -c 'CTCCGTGCTAGATACGA' *.fastq > count/B17838_Rm0.txt
agrep -0 -c 'GTCCATCAACCGGTAAT' *.fastq > count/B17841_Rm0.txt
agrep -0 -c 'ACACTACGAGAATCTCC' *.fastq > count/B17842_Rm0.txt
agrep -0 -c 'GCAGTACGCTCAGTTAG' *.fastq > count/B17843_Rm0.txt
agrep -0 -c 'ACGATAACGTCCACACG' *.fastq > count/B17844_Rm0.txt
agrep -0 -c 'AGTCACGGGTTCTTCTT' *.fastq > count/B17846_Rm0.txt
agrep -0 -c 'TGAGTCGTTGAGGACAT' *.fastq > count/B17847_Rm0.txt
agrep -0 -c 'TATGTAGATGGTCCTTG' *.fastq > count/B17848_Rm0.txt
agrep -0 -c 'GGTCCGCTATTCTCTGT' *.fastq > count/B17851_Rm0.txt
agrep -0 -c 'GATGTACACATGCATCC' *.fastq > count/B17852_Rm0.txt
agrep -0 -c 'TACACACAGCAATGCGC' *.fastq > count/B17854_Rm0.txt
agrep -0 -c 'ATACAATTGCGCAACGG' *.fastq > count/B17855_Rm0.txt
agrep -0 -c 'CGAATGTTGCACCGACA' *.fastq > count/B17856_Rm0.txt
agrep -0 -c 'ACTGGTACGAGTACCTA' *.fastq > count/B17857_Rm0.txt
agrep -0 -c 'GCGAGCGCTGAAAATAA' *.fastq > count/B17858_Rm0.txt
agrep -0 -c 'GGTAATGCGAGGTCGAT' *.fastq > count/B17859_Rm0.txt
agrep -0 -c 'CCACATGGTATAACATG' *.fastq > count/B17860_Rm0.txt
agrep -0 -c 'GGACCCAAGGTTTTAAG' *.fastq > count/B17861_Rm0.txt
agrep -0 -c 'AAGCCGCTTTCGTCTGT' *.fastq > count/B17862_Rm0.txt
agrep -0 -c 'TCGTGCAGCTCCGGAAT' *.fastq > count/B17864_Rm0.txt
agrep -0 -c 'TTATCGATAAGCTCCGA' *.fastq > count/B17865_Rm0.txt
agrep -0 -c 'GTAGATTTACAGACGCC' *.fastq > count/B17866_Rm0.txt
agrep -0 -c 'TGCTCGGTTTTGTTAAC' *.fastq > count/B17867_Rm0.txt
agrep -0 -c 'GAGGTTCGAAAGGAACG' *.fastq > count/B17869_Rm0.txt
agrep -0 -c 'TACTGAGCTTAGTATGC' *.fastq > count/B17870_Rm0.txt
agrep -0 -c 'CAGGGCTCGTTAGTGAT' *.fastq > count/B17871_Rm0.txt
agrep -0 -c 'CGCTGTCCTATTGAGAG' *.fastq > count/B17872_Rm0.txt
agrep -0 -c 'GAATTTCAGGTCACAAG' *.fastq > count/B17873_Rm0.txt
agrep -0 -c 'GACAAACCGGTCAGAGG' *.fastq > count/B17874_Rm0.txt
agrep -0 -c 'TGCCCTCGCTTAATGGC' *.fastq > count/B17876_Rm0.txt
agrep -0 -c 'CAGGTCGTACGGTCTCA' *.fastq > count/B17877_Rm0.txt
agrep -0 -c 'CGCGTTTGTGGTTAAGT' *.fastq > count/B17879_Rm0.txt
agrep -0 -c 'CTGGCTCTCTGTAACGA' *.fastq > count/B17881_Rm0.txt
agrep -0 -c 'GCCCATTTATAGTAGGC' *.fastq > count/B17882_Rm0.txt
agrep -0 -c 'TCTCTCTAGCGTGTAGC' *.fastq > count/B17883_Rm0.txt
agrep -0 -c 'ATTATAACTTTCGGCCC' *.fastq > count/B17884_Rm0.txt
agrep -0 -c 'TTCACTATGCCAGATTG' *.fastq > count/B17886_Rm0.txt
agrep -0 -c 'CGCTCATGCATCTGTTA' *.fastq > count/B17887_Rm0.txt
agrep -0 -c 'TTGAAGGTGTCCTAAGG' *.fastq > count/B17889_Rm0.txt
agrep -0 -c 'TTCAGCAAGTGAAAAGG' *.fastq > count/B17890_Rm0.txt
agrep -0 -c 'ACGCAGTAAGATCAGTG' *.fastq > count/B17891_Rm0.txt
agrep -0 -c 'CTAACCAGTAAGCAACC' *.fastq > count/B17892_Rm0.txt
agrep -0 -c 'ACTCCACCACCCAATGC' *.fastq > count/B17893_Rm0.txt
agrep -0 -c 'GTTATTCCGTAGCTCAG' *.fastq > count/B17894_Rm0.txt
agrep -0 -c 'AATCCAAACCCGATGTG' *.fastq > count/B17895_Rm0.txt
agrep -0 -c 'GGTTCCGAATCAAGTTG' *.fastq > count/B17896_Rm0.txt
agrep -0 -c 'GATTACCGTCCTCTAAC' *.fastq > count/B17897_Rm0.txt
agrep -0 -c 'CGATAGGTCCTACAGGC' *.fastq > count/B17898_Rm0.txt
agrep -0 -c 'ATAGTAACATCCGCGCG' *.fastq > count/B17899_Rm0.txt
agrep -0 -c 'ACCTAAACGCCTCGTCA' *.fastq > count/B17900_Rm0.txt
agrep -0 -c 'TTGAAAACCCCAATCGC' *.fastq > count/B17901_Rm0.txt
agrep -0 -c 'TTGGTAGAGTTGCGATG' *.fastq > count/B17902_Rm0.txt
agrep -0 -c 'CCCACATATTTGTCCTC' *.fastq > count/B17904_Rm0.txt
agrep -0 -c 'GTAACGACTGGAACGTC' *.fastq > count/B17905_Rm0.txt
agrep -0 -c 'TTCAGGCCAAAGGCCGA' *.fastq > count/B17906_Rm0.txt
agrep -0 -c 'GCCCAGTAAGTTGCAGT' *.fastq > count/B17907_Rm0.txt
agrep -0 -c 'GCGGTCATCTAGTAAGG' *.fastq > count/B17908_Rm0.txt
agrep -0 -c 'ATAGTACATGCGACGTG' *.fastq > count/B17909_Rm0.txt
agrep -0 -c 'CTGATGCTCCTTAGATC' *.fastq > count/B17910_Rm0.txt
agrep -0 -c 'GGCGGGGAAAAGTTGTG' *.fastq > count/B17911_Rm0.txt
agrep -0 -c 'GCTAGTGCAAGGGCAAT' *.fastq > count/B17912_Rm0.txt
agrep -0 -c 'CGACGTCATTTCTCAGC' *.fastq > count/B17913_Rm0.txt
agrep -0 -c 'TTCAAGACGAAGTGCAG' *.fastq > count/B17914_Rm0.txt
agrep -0 -c 'CCCACCTGTACGCATCT' *.fastq > count/B17915_Rm0.txt
agrep -0 -c 'ATGTGCCCCCCAAAGTA' *.fastq > count/B17916_Rm0.txt
agrep -0 -c 'CACATAGGCAGTCTGTT' *.fastq > count/B17919_Rm0.txt
agrep -0 -c 'TTAGTTTTCACACTCCC' *.fastq > count/B17920_Rm0.txt
agrep -0 -c 'TAGGCTGGCTCGCGATA' *.fastq > count/B17921_Rm0.txt
agrep -0 -c 'TCGTCTATTGTTTGAGG' *.fastq > count/B17923_Rm0.txt
agrep -0 -c 'GTTCACTCAATTGCGTC' *.fastq > count/B17925_Rm0.txt
agrep -0 -c 'TTGAACCGTAATCGTCT' *.fastq > count/B17926_Rm0.txt
agrep -0 -c 'CTAAACTCACGTTTGCG' *.fastq > count/B17928_Rm0.txt
agrep -0 -c 'TCGCCCAGCAGCGAATT' *.fastq > count/B17929_Rm0.txt
agrep -0 -c 'CCGGCTGATAGTTACAT' *.fastq > count/B17930_Rm0.txt
agrep -0 -c 'GAAACTAGGCACGAAGC' *.fastq > count/B17931_Rm0.txt
agrep -0 -c 'AGTATGATGTCAGTCGC' *.fastq > count/B17932_Rm0.txt
agrep -0 -c 'TCGAGAAGTGATACTGA' *.fastq > count/B17933_Rm0.txt
agrep -0 -c 'AGTTCCCTAGCTGGTGG' *.fastq > count/B17934_Rm0.txt
agrep -0 -c 'GGCATCGAGTTACGTTG' *.fastq > count/B17935_Rm0.txt
agrep -0 -c 'GTATAGCGGCGGGATAC' *.fastq > count/B17937_Rm0.txt
agrep -0 -c 'ATTAAGGAGCAAGCTGT' *.fastq > count/B17938_Rm0.txt
agrep -0 -c 'TCGAAGCCTTTTCCTCT' *.fastq > count/B17939_Rm0.txt
agrep -0 -c 'CATATTCTGGCGCCTAG' *.fastq > count/B17940_Rm0.txt
agrep -0 -c 'ACCGCTCTCGCTTTTAT' *.fastq > count/B17941_Rm0.txt
agrep -0 -c 'TTCGCTGAAGACCCACC' *.fastq > count/B17944_Rm0.txt
agrep -0 -c 'TAACGCGGGGTTCATGA' *.fastq > count/B17945_Rm0.txt
agrep -0 -c 'GATTGGCGACTTCATGT' *.fastq > count/B17946_Rm0.txt
agrep -0 -c 'TCTTTCTGGTCGCGTGC' *.fastq > count/B17949_Rm0.txt
agrep -0 -c 'ACAACGCTCCATTCAAC' *.fastq > count/B17950_Rm0.txt
agrep -0 -c 'CTCTATCTGAGTACCAT' *.fastq > count/B17951_Rm0.txt
agrep -0 -c 'CAACTCGAGCCGTTACC' *.fastq > count/B17952_Rm0.txt
agrep -0 -c 'TCTAGCGTGCAAGCGTG' *.fastq > count/B17953_Rm0.txt
agrep -0 -c 'GCGCATATGTGGTTCTG' *.fastq > count/B17954_Rm0.txt
agrep -0 -c 'CTGCAGTCGCATTATCA' *.fastq > count/B17955_Rm0.txt
agrep -0 -c 'TTTTGGAATTGCAGCCT' *.fastq > count/B17957_Rm0.txt
agrep -0 -c 'CGAAATCAGGTGTAACT' *.fastq > count/B17960_Rm0.txt
agrep -0 -c 'GTCAACCGAACACTCCC' *.fastq > count/B17961_Rm0.txt
agrep -0 -c 'GGCCATCTCGTGGTACT' *.fastq > count/B17962_Rm0.txt
agrep -0 -c 'ACGTCGAAACGGCTATT' *.fastq > count/B17964_Rm0.txt
agrep -0 -c 'TGTGATTAGAGTGATGC' *.fastq > count/B17965_Rm0.txt
agrep -0 -c 'ACGGAGCATGCCTTTTG' *.fastq > count/B17967_Rm0.txt
agrep -0 -c 'CGTATTCTGCTTCCAGC' *.fastq > count/B17968_Rm0.txt
agrep -0 -c 'CATCCTTGAACGTCCGA' *.fastq > count/B17970_Rm0.txt
agrep -0 -c 'TATATAGTGCTAGGACG' *.fastq > count/B17971_Rm0.txt
agrep -0 -c 'AGTCAAAGAGAGCGCTC' *.fastq > count/B17972_Rm0.txt
agrep -0 -c 'TAGGGCGGTATGGTAGA' *.fastq > count/B17974_Rm0.txt
agrep -0 -c 'AGGACTCACTCCGCATT' *.fastq > count/B17975_Rm0.txt
agrep -0 -c 'GACGGGTTCATGGAACA' *.fastq > count/B17978_Rm0.txt
agrep -0 -c 'AGAACCAATATTCGCTG' *.fastq > count/B17979_Rm0.txt
agrep -0 -c 'CGGTAATCGCCAGGTAT' *.fastq > count/B17980_Rm0.txt
agrep -0 -c 'AGTTAACGGCAGGATAG' *.fastq > count/B17981_Rm0.txt
agrep -0 -c 'TACAAGGAGGCCACATC' *.fastq > count/B17983_Rm0.txt
agrep -0 -c 'TACCAAGCTAGCGACTG' *.fastq > count/B17984_Rm0.txt
agrep -0 -c 'GCCTAAACCGCATACAC' *.fastq > count/B17986_Rm0.txt
agrep -0 -c 'CCGGATGATGTCACTGA' *.fastq > count/B17987_Rm0.txt
agrep -0 -c 'TAAGCTGGGTGTAGGCC' *.fastq > count/B17988_Rm0.txt
agrep -0 -c 'TCTCGAATCAATACGGC' *.fastq > count/B17989_Rm0.txt
agrep -0 -c 'GTTTCTGCTCAGCTCGC' *.fastq > count/B17990_Rm0.txt
agrep -0 -c 'TACATACCCACAGCGAA' *.fastq > count/B17991_Rm0.txt
agrep -0 -c 'CGACTAAGATTCAGGCG' *.fastq > count/B17992_Rm0.txt
agrep -0 -c 'GCTCTGATTTAGTAAGC' *.fastq > count/B17994_Rm0.txt
agrep -0 -c 'GGCGTGTAGGCTATTAC' *.fastq > count/B17995_Rm0.txt
agrep -0 -c 'CTCTGCGTATATACGCA' *.fastq > count/B17997_Rm0.txt
agrep -0 -c 'GGGTACGTGTATCGACT' *.fastq > count/B17998_Rm0.txt
agrep -0 -c 'CTGTTCCCTGTTCTAGC' *.fastq > count/B17999_Rm0.txt
agrep -0 -c 'CGCATAATCAACCACCG' *.fastq > count/B18001_Rm0.txt
agrep -0 -c 'ACGGATCCACGAATAAT' *.fastq > count/B18003_Rm0.txt
agrep -0 -c 'GGTTTCCGGTATCGGCT' *.fastq > count/B18004_Rm0.txt
agrep -0 -c 'CCTGATGCTTAACTGAC' *.fastq > count/B18005_Rm0.txt
agrep -0 -c 'CCCAAGGAGGTCTAAGT' *.fastq > count/B18007_Rm0.txt
agrep -0 -c 'CTACCTACGGCGTTTTA' *.fastq > count/B18008_Rm0.txt
agrep -0 -c 'TTACTGTGACCTGCAAT' *.fastq > count/B18009_Rm0.txt
agrep -0 -c 'GCGGTAGGACCGAAAGT' *.fastq > count/B18011_Rm0.txt
agrep -0 -c 'CGTGCATCGAGGCAACA' *.fastq > count/B18012_Rm0.txt
agrep -0 -c 'ACTGTTCACCTACAACG' *.fastq > count/B18013_Rm0.txt
agrep -0 -c 'TCGACCCGGAGTAATGG' *.fastq > count/B18014_Rm0.txt
agrep -0 -c 'ACGACATCGGTTGGTGG' *.fastq > count/B18015_Rm0.txt
agrep -0 -c 'GGTGCGGAACCTCAATT' *.fastq > count/B18016_Rm0.txt
agrep -0 -c 'GCGACTACCTAGTCCTA' *.fastq > count/B18017_Rm0.txt
agrep -0 -c 'CGCCATAAATTGCGTGT' *.fastq > count/B18018_Rm0.txt
agrep -0 -c 'GGACGAGCCTTAGAACG' *.fastq > count/B18019_Rm0.txt
agrep -0 -c 'AAATGCCCTACCCTACG' *.fastq > count/B18020_Rm0.txt
agrep -0 -c 'TGCTACTCCCAAGGTTG' *.fastq > count/B18021_Rm0.txt
agrep -0 -c 'CCGATTGAAGGCAGGGT' *.fastq > count/B18023_Rm0.txt
agrep -0 -c 'CCAGTGACACGATTAGT' *.fastq > count/B18024_Rm0.txt
agrep -0 -c 'GCTTATAACATGGGGCG' *.fastq > count/B18026_Rm0.txt
agrep -0 -c 'TACTGCGAATCGAGCAT' *.fastq > count/B18027_Rm0.txt
agrep -0 -c 'CAAAAAGCCTTCCTAGA' *.fastq > count/B18028_Rm0.txt
agrep -0 -c 'CGCTGCCTATCAGATCT' *.fastq > count/B18029_Rm0.txt
agrep -0 -c 'GGGAAAGGAAGCTCCAT' *.fastq > count/B18030_Rm0.txt
agrep -0 -c 'CGATCGTTTATCACCGA' *.fastq > count/B18031_Rm0.txt
agrep -0 -c 'GTCTAACTCTAGTGGGC' *.fastq > count/B18032_Rm0.txt
agrep -0 -c 'AGGCTTGCAGCCTGACA' *.fastq > count/B18033_Rm0.txt
agrep -0 -c 'TGGTAGCACGAGCCGTA' *.fastq > count/B18034_Rm0.txt
agrep -0 -c 'GCCATGTTCCACACACG' *.fastq > count/B18035_Rm0.txt
agrep -0 -c 'GATAGATCACTCTGTGG' *.fastq > count/B18036_Rm0.txt
agrep -0 -c 'GGGCTCTCTGATTGACC' *.fastq > count/B18037_Rm0.txt
agrep -0 -c 'ACTCATGAAGGTTGCTT' *.fastq > count/B18038_Rm0.txt
agrep -0 -c 'AACGAGGAAGCTACCTT' *.fastq > count/B18040_Rm0.txt
agrep -0 -c 'GGAGTTTCGCTCGGTAC' *.fastq > count/B18042_Rm0.txt
agrep -0 -c 'GCCGATGCTTACCGCTT' *.fastq > count/B18043_Rm0.txt
agrep -0 -c 'CGACGTTCGTTCTTTGC' *.fastq > count/B18044_Rm0.txt
agrep -0 -c 'AATGTACCACGGCTAGG' *.fastq > count/B18045_Rm0.txt
agrep -0 -c 'ATACGATCCGTTAGCAC' *.fastq > count/B18046_Rm0.txt
agrep -0 -c 'ATGTTTGCTCGGTGTAT' *.fastq > count/B18047_Rm0.txt
agrep -0 -c 'TCTGTTGCGGTGATAAG' *.fastq > count/B18048_Rm0.txt
agrep -0 -c 'ACATGGCATCTAAATCC' *.fastq > count/B18049_Rm0.txt
agrep -0 -c 'GAGCGAACCGTATCAAT' *.fastq > count/B18050_Rm0.txt
agrep -0 -c 'TATCGCATAGAGGCGTA' *.fastq > count/B18051_Rm0.txt
agrep -0 -c 'CTCCTGGCGATAAACCT' *.fastq > count/B18052_Rm0.txt
agrep -0 -c 'CGAAATTACGCAGCGGT' *.fastq > count/B18053_Rm0.txt
agrep -0 -c 'ATTTGTAAACAGCAGCG' *.fastq > count/B18054_Rm0.txt
agrep -0 -c 'GTGCCGTAAACGGAGTT' *.fastq > count/B18056_Rm0.txt
agrep -0 -c 'ACCGTAACTGTCGTAAC' *.fastq > count/B18059_Rm0.txt
agrep -0 -c 'CATATTCTGGAGGATCG' *.fastq > count/B18060_Rm0.txt
agrep -0 -c 'CAGAAGTGCCTTACTTA' *.fastq > count/B18061_Rm0.txt
agrep -0 -c 'TCACATCGAACTTGATC' *.fastq > count/B18062_Rm0.txt
agrep -0 -c 'AAATGCACTCGCGGCGT' *.fastq > count/B18063_Rm0.txt
agrep -0 -c 'CACATGTTACGAATCGT' *.fastq > count/B18064_Rm0.txt
agrep -0 -c 'ACTGAGGTCTAGTAAGG' *.fastq > count/B18065_Rm0.txt
agrep -0 -c 'CATTGTCCATCGACCGG' *.fastq > count/B18066_Rm0.txt
agrep -0 -c 'TGCTACGTCTGTACTGA' *.fastq > count/B18067_Rm0.txt
agrep -0 -c 'GACGCTCAACGATGTCA' *.fastq > count/B18068_Rm0.txt
agrep -0 -c 'CGGGATAGACTAGAAAT' *.fastq > count/B18069_Rm0.txt
agrep -0 -c 'GCAGCATTCAAAGGGCT' *.fastq > count/B18071_Rm0.txt
agrep -0 -c 'CTATGGCTATTGAGTAC' *.fastq > count/B18073_Rm0.txt
agrep -0 -c 'GTAGGTACACAGGAACA' *.fastq > count/B18074_Rm0.txt
agrep -0 -c 'GAATTAACGGAGTCGGT' *.fastq > count/B18075_Rm0.txt
agrep -0 -c 'TGCAATAGGAGCGAGCA' *.fastq > count/B18076_Rm0.txt
agrep -0 -c 'CTAGACCGATTTGGAAG' *.fastq > count/B18078_Rm0.txt
agrep -0 -c 'CTCAGAAGAAACAGGCC' *.fastq > count/B18079_Rm0.txt
agrep -0 -c 'CGTACGAATGTTGCAGG' *.fastq > count/B18080_Rm0.txt
agrep -0 -c 'TTCACGCAAAAACATGG' *.fastq > count/B18081_Rm0.txt
agrep -0 -c 'ATAATATCGCAGGTGAG' *.fastq > count/B18082_Rm0.txt
agrep -0 -c 'AGGTAAGGGTCCACCGA' *.fastq > count/B18083_Rm0.txt
agrep -0 -c 'TAAAGTTTTCACCCGAC' *.fastq > count/B18084_Rm0.txt
agrep -0 -c 'GGAGTAGAATCGTGACC' *.fastq > count/B18085_Rm0.txt
agrep -0 -c 'AGGATCCCTCATGCAGC' *.fastq > count/B18086_Rm0.txt
agrep -0 -c 'AAAGCTGATGCGCCGAT' *.fastq > count/B18087_Rm0.txt
agrep -0 -c 'CCCCAAAAATGGTCTCG' *.fastq > count/B18088_Rm0.txt
agrep -0 -c 'TCACCAACAAAGTGCCG' *.fastq > count/B18089_Rm0.txt
agrep -0 -c 'GGATACTTAAGGGCCAT' *.fastq > count/B18090_Rm0.txt
agrep -0 -c 'AGTGTGCTATTTGGGGC' *.fastq > count/B18091_Rm0.txt
agrep -0 -c 'AGGCTAATCAGAAGACG' *.fastq > count/B18092_Rm0.txt
agrep -0 -c 'GCATTTGTGTATCCTTG' *.fastq > count/B18093_Rm0.txt
agrep -0 -c 'TGCTGGTGTCTTATACA' *.fastq > count/B18094_Rm0.txt
agrep -0 -c 'GACCGTTGCCAACGGTA' *.fastq > count/B18095_Rm0.txt
agrep -0 -c 'CCGCCTTAAAACCTAAT' *.fastq > count/B18096_Rm0.txt
agrep -0 -c 'ACAAGCCGTGCCTTAGC' *.fastq > count/B18097_Rm0.txt
agrep -0 -c 'AACGCACGCCCCTTTAG' *.fastq > count/B18098_Rm0.txt
agrep -0 -c 'CTCTTGATGCCGGTAGT' *.fastq > count/B18099_Rm0.txt
agrep -0 -c 'TCTCAACAGCGTAACCT' *.fastq > count/B18101_Rm0.txt
agrep -0 -c 'CGATTACTGTACTTGAG' *.fastq > count/B18102_Rm0.txt
agrep -0 -c 'CCGGCAGTCTTAAAAAC' *.fastq > count/B18103_Rm0.txt
agrep -0 -c 'CCGCTCGTATACCCTGA' *.fastq > count/B18104_Rm0.txt
agrep -0 -c 'GCTACCGATTATTCCTT' *.fastq > count/B18106_Rm0.txt
agrep -0 -c 'TGGAGCCGTATCGTGAG' *.fastq > count/B18107_Rm0.txt
agrep -0 -c 'AGACGATCGCAATCTGG' *.fastq > count/B18108_Rm0.txt
agrep -0 -c 'AGCGCCTATGTGCGGTA' *.fastq > count/B18110_Rm0.txt
agrep -0 -c 'GCCATGATGAAGGCATG' *.fastq > count/B18111_Rm0.txt
agrep -0 -c 'ACGCTGGGGATTTAAAT' *.fastq > count/B18112_Rm0.txt
agrep -0 -c 'TATACGGCCGAAGACTG' *.fastq > count/B18113_Rm0.txt
agrep -0 -c 'TGAATTCGGAGTCGACC' *.fastq > count/B18114_Rm0.txt
agrep -0 -c 'AACCGTAGTCTCGACTA' *.fastq > count/B18115_Rm0.txt
agrep -0 -c 'TAGCCAGTTAGATGGGT' *.fastq > count/B18116_Rm0.txt
agrep -0 -c 'AGTGACACACTGGGGGT' *.fastq > count/B18117_Rm0.txt
agrep -0 -c 'GTATCGACTGGTCCACA' *.fastq > count/B18118_Rm0.txt
agrep -0 -c 'CCCTAACGTGGAAGCAC' *.fastq > count/B18119_Rm0.txt
agrep -0 -c 'AACTACTAGACGTCGAT' *.fastq > count/B18120_Rm0.txt
agrep -0 -c 'ATATGACCGCTCTCGCA' *.fastq > count/B18121_Rm0.txt
agrep -0 -c 'GGTGTTCAATACCCATC' *.fastq > count/B18123_Rm0.txt
agrep -0 -c 'CTGATTAGGCTCGGTTA' *.fastq > count/B18124_Rm0.txt
agrep -0 -c 'GGAGAACACGAATTTCG' *.fastq > count/B18125_Rm0.txt
agrep -0 -c 'TCATGAACTGCTGCTCC' *.fastq > count/B18126_Rm0.txt
agrep -0 -c 'GTCGACACATTTTGCCA' *.fastq > count/B18127_Rm0.txt
agrep -0 -c 'GCCGTTTTGTACGAAGA' *.fastq > count/B18128_Rm0.txt
agrep -0 -c 'AGGATTAGATCATCCGA' *.fastq > count/B18130_Rm0.txt
agrep -0 -c 'TCCTAGGAATGGACCGC' *.fastq > count/B18131_Rm0.txt
agrep -0 -c 'GGTTCGAGCCTTCACAC' *.fastq > count/B18132_Rm0.txt
agrep -0 -c 'ACCGGTTCTCACTCGCT' *.fastq > count/B18133_Rm0.txt
agrep -0 -c 'ATCCAAACAGGCACCAC' *.fastq > count/B18134_Rm0.txt
agrep -0 -c 'TTGCGTATTCATACCGG' *.fastq > count/B18135_Rm0.txt
agrep -0 -c 'ACACATCCCAACCGCTC' *.fastq > count/B18136_Rm0.txt
agrep -0 -c 'ACCATCTGCCTGATTGG' *.fastq > count/B18137_Rm0.txt
agrep -0 -c 'CAAGAGTGGACAGCCGA' *.fastq > count/B18138_Rm0.txt
agrep -0 -c 'CCCGGTACTTAAGACTA' *.fastq > count/B18140_Rm0.txt
agrep -0 -c 'GAAGTCCTAAAGCACTG' *.fastq > count/B18141_Rm0.txt
agrep -0 -c 'CTGATTTAGGCGAATCT' *.fastq > count/B18142_Rm0.txt
agrep -0 -c 'GTCCGCACCAAGCTATT' *.fastq > count/B18143_Rm0.txt
agrep -0 -c 'AACCTCCAGCCATTTAG' *.fastq > count/B18144_Rm0.txt
agrep -0 -c 'CCATCGAGCTACAGTTA' *.fastq > count/B18145_Rm0.txt
agrep -0 -c 'AGTCATAAGAGTGCCCT' *.fastq > count/B18146_Rm0.txt
agrep -0 -c 'AGAATCATCGCTCTTGT' *.fastq > count/B18148_Rm0.txt
agrep -0 -c 'TAATCAACCCGTAAGAC' *.fastq > count/B18149_Rm0.txt
agrep -0 -c 'ATCGCGTGTGAGGACTC' *.fastq > count/B18150_Rm0.txt
agrep -0 -c 'CGCCGTTATGGCTTAAC' *.fastq > count/B18151_Rm0.txt
agrep -0 -c 'TTGGGCCGTTACATTAT' *.fastq > count/B18152_Rm0.txt
agrep -0 -c 'CAACTCGGGTCGGTAAG' *.fastq > count/B18153_Rm0.txt
agrep -0 -c 'GTAGAATGAGTGCACAA' *.fastq > count/B18156_Rm0.txt
agrep -0 -c 'TTTTTACCCGGTTAGTC' *.fastq > count/B18157_Rm0.txt
agrep -0 -c 'AATGGTGGCGTTTTGAC' *.fastq > count/B18158_Rm0.txt
agrep -0 -c 'AGACGAGTAAACTACTC' *.fastq > count/B18159_Rm0.txt
agrep -0 -c 'TAGAGATACTACGGGCT' *.fastq > count/B18160_Rm0.txt
agrep -0 -c 'TTACGAGCCATCGCGTA' *.fastq > count/B18161_Rm0.txt
agrep -0 -c 'TCATAGTGCTGCCCCTA' *.fastq > count/B18163_Rm0.txt
agrep -0 -c 'TCCGGTATTATGTGACC' *.fastq > count/B18168_Rm0.txt
agrep -0 -c 'CCGTCTAGCCCAACTAG' *.fastq > count/B18171_Rm0.txt
agrep -0 -c 'CTGCAACTCGGGATATG' *.fastq > count/B18172_Rm0.txt
agrep -0 -c 'CTGCAATTGGTTTCAGT' *.fastq > count/B18173_Rm0.txt
agrep -0 -c 'GCCCCTACTCGGACTTA' *.fastq > count/B18174_Rm0.txt
agrep -0 -c 'CTTGACACTTTGATCAC' *.fastq > count/B18175_Rm0.txt
agrep -0 -c 'CAGCCACGCTTTAAAGG' *.fastq > count/B18176_Rm0.txt
agrep -0 -c 'TGCTCTCCAGCTGTTAT' *.fastq > count/B18178_Rm0.txt
agrep -0 -c 'TACGGTCGGTCGAAGCA' *.fastq > count/B18181_Rm0.txt
agrep -0 -c 'TTGGTGGATGGGGACCT' *.fastq > count/B18182_Rm0.txt
agrep -0 -c 'TTTAAAGCAACGATCGC' *.fastq > count/B18183_Rm0.txt
agrep -0 -c 'GTCTTTATCCTAGCAAC' *.fastq > count/B18184_Rm0.txt
agrep -0 -c 'GATGCATGGTCGTTCTC' *.fastq > count/B18185_Rm0.txt
agrep -0 -c 'CTGCTGTACCTATAGCA' *.fastq > count/B18186_Rm0.txt
agrep -0 -c 'AAGATTCGCGGGAGTCA' *.fastq > count/B18188_Rm0.txt
agrep -0 -c 'TACGCCCGTTAACTCTT' *.fastq > count/B18189_Rm0.txt
agrep -0 -c 'TTGATTCACCTCTAGCA' *.fastq > count/B18190_Rm0.txt
agrep -0 -c 'CCCCTAAAACCGGTTTA' *.fastq > count/B18191_Rm0.txt
agrep -0 -c 'ACGTCTGAGTAACTTGG' *.fastq > count/B18192_Rm0.txt
agrep -0 -c 'CTGCCCTCTATCTGTGC' *.fastq > count/B18193_Rm0.txt
agrep -0 -c 'ACACCCTACCTAATCGA' *.fastq > count/B18194_Rm0.txt
agrep -0 -c 'GAGAAGTGGTCGTCCTC' *.fastq > count/B18195_Rm0.txt
agrep -0 -c 'GCGAATAACGATTGTGG' *.fastq > count/B18196_Rm0.txt
agrep -0 -c 'CTTGATCGGTCTCATTG' *.fastq > count/B18197_Rm0.txt
agrep -0 -c 'CCCAATCTAAACAGACC' *.fastq > count/B18198_Rm0.txt
agrep -0 -c 'GCGTACTATATTACCAG' *.fastq > count/B18199_Rm0.txt
agrep -0 -c 'GCTACAACCTCGTAGTT' *.fastq > count/B18200_Rm0.txt
agrep -0 -c 'CCCTACTCAGCAGTACC' *.fastq > count/B18201_Rm0.txt
agrep -0 -c 'CGGATGGTTGCTTATCG' *.fastq > count/B18202_Rm0.txt
agrep -0 -c 'TCGTATGGTCACTAACT' *.fastq > count/B18205_Rm0.txt
agrep -0 -c 'GATCTGCCGCGCATTAC' *.fastq > count/B18206_Rm0.txt
agrep -0 -c 'TGGTCTGCATGCTCGTC' *.fastq > count/B18207_Rm0.txt
agrep -0 -c 'CCATTCGAGACTTAGAA' *.fastq > count/B18208_Rm0.txt
agrep -0 -c 'TTACCGCAGTCCGGCAA' *.fastq > count/B18209_Rm0.txt
agrep -0 -c 'TGCTTGGTGCTGACTTA' *.fastq > count/B18210_Rm0.txt
agrep -0 -c 'TGCGAGTCTGTGATACA' *.fastq > count/B18211_Rm0.txt
agrep -0 -c 'ACTGCACATAGGTCCGT' *.fastq > count/B18213_Rm0.txt
agrep -0 -c 'CTAGCGGAAGGCATCTA' *.fastq > count/B18217_Rm0.txt
agrep -0 -c 'CAGAGCAGATTCACTTA' *.fastq > count/B18218_Rm0.txt
agrep -0 -c 'ATCCGCTGCTTTTTTCA' *.fastq > count/B18219_Rm0.txt
agrep -0 -c 'TAACCCCTCGCATTCTA' *.fastq > count/B18220_Rm0.txt
agrep -0 -c 'GACGCTGACTGCAAATT' *.fastq > count/B18221_Rm0.txt
agrep -0 -c 'GTAACACCCATGCCCTC' *.fastq > count/B18222_Rm0.txt
agrep -0 -c 'ACGAACAGGATCCTTAA' *.fastq > count/B18224_Rm0.txt
agrep -0 -c 'GTTTCCAGATCGGTCAT' *.fastq > count/B18226_Rm0.txt
agrep -0 -c 'AAGTGGGGGATGCTTCC' *.fastq > count/B18227_Rm0.txt
agrep -0 -c 'GTCGTGATTGGGATTGT' *.fastq > count/B18228_Rm0.txt
agrep -0 -c 'GTTCTAAATGGTTCGTC' *.fastq > count/B18229_Rm0.txt
agrep -0 -c 'CTGCGTCATCAAAGCGT' *.fastq > count/B18230_Rm0.txt
agrep -0 -c 'TAGTCATAAACGTCGAC' *.fastq > count/B18231_Rm0.txt
agrep -0 -c 'TTTCGAACATCGAGTCT' *.fastq > count/B18232_Rm0.txt
agrep -0 -c 'AGCACACGCAAAGCAGT' *.fastq > count/B18234_Rm0.txt
agrep -0 -c 'GCATCAAGAATTCAGCG' *.fastq > count/B18235_Rm0.txt
agrep -0 -c 'ACTGCACACAATACGAT' *.fastq > count/B18236_Rm0.txt
agrep -0 -c 'AAAGCCTGGACGCAGTA' *.fastq > count/B18237_Rm0.txt
agrep -0 -c 'CCTTTAACTGTGCTACT' *.fastq > count/B18238_Rm0.txt
agrep -0 -c 'GAGGAACGGCGAATACC' *.fastq > count/B18239_Rm0.txt
agrep -0 -c 'AAACTACCGATGTAGCG' *.fastq > count/B18240_Rm0.txt
agrep -0 -c 'CGGCTGTAAGTAGGAAC' *.fastq > count/B18241_Rm0.txt
agrep -0 -c 'CCTCTAATCTGACCGTT' *.fastq > count/B18242_Rm0.txt



#combine all search files into one text file
echo "Combining all search files into a single txt file."
awk '{print $0,FILENAME}' count/*.txt > all_counts.txt

#transform txt into csv to prepare for pivot
echo "Transforming this txt file into csv file"
{
echo "File,Count,ID"
sed -e 's/[[:space:]]\{1,\}/,/g' all_counts.txt
} > all_counts.csv

echo "Preparing file for final output"

#pivot the table using python script
python pivot_table.py
